# API Reference <a name="API Reference" id="api-reference"></a>

## Constructs <a name="Constructs" id="Constructs"></a>

### ApiService <a name="ApiService" id="cdk8s-metaflow.k8s.ApiService"></a>

APIService represents a server for a particular GroupVersion.

Name must be "version.group".

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ApiService.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ApiService(scope: Construct, id: string, props?: ApiServiceProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ApiServiceProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ApiService.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ApiService.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ApiService.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ApiServiceProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ApiService.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ApiService.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ApiService.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ApiService.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ApiService.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ApiService.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.kube-aggregator.pkg.apis.apiregistration.v1.APIService". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ApiService.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ApiService.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ApiService.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ApiService.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ApiService.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ApiService.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ApiService.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ApiService.manifest(props?: ApiServiceProps)
```

Renders a Kubernetes manifest for "io.k8s.kube-aggregator.pkg.apis.apiregistration.v1.APIService".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ApiService.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ApiServiceProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ApiService.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ApiService.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ApiService.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ApiService.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ApiService.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ApiService.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ApiService.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ApiService.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.kube-aggregator.pkg.apis.apiregistration.v1.APIService". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ApiService.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.kube-aggregator.pkg.apis.apiregistration.v1.APIService".

---

### ApiServiceList <a name="ApiServiceList" id="cdk8s-metaflow.k8s.ApiServiceList"></a>

APIServiceList is a list of APIService objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ApiServiceList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ApiServiceList(scope: Construct, id: string, props: ApiServiceListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ApiServiceListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ApiServiceList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ApiServiceList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ApiServiceList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ApiServiceListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ApiServiceList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ApiServiceList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ApiServiceList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ApiServiceList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ApiServiceList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ApiServiceList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.kube-aggregator.pkg.apis.apiregistration.v1.APIServiceList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ApiServiceList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ApiServiceList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ApiServiceList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ApiServiceList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ApiServiceList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ApiServiceList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ApiServiceList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ApiServiceList.manifest(props: ApiServiceListProps)
```

Renders a Kubernetes manifest for "io.k8s.kube-aggregator.pkg.apis.apiregistration.v1.APIServiceList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ApiServiceList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ApiServiceListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ApiServiceList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ApiServiceList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ApiServiceList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ApiServiceList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ApiServiceList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ApiServiceList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ApiServiceList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.kube-aggregator.pkg.apis.apiregistration.v1.APIServiceList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ApiServiceList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.kube-aggregator.pkg.apis.apiregistration.v1.APIServiceList".

---

### Binding <a name="Binding" id="cdk8s-metaflow.k8s.Binding"></a>

Binding ties one object to another;

for example, a pod is bound to a node by a scheduler. Deprecated in 1.7, please use the bindings subresource of pods instead.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.Binding.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.Binding(scope: Construct, id: string, props: BindingProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Binding.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.Binding.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.Binding.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.BindingProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.Binding.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.Binding.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.Binding.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.BindingProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Binding.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.Binding.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.Binding.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Binding.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.Binding.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.Binding.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.Binding.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.Binding.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.Binding.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.Binding.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Binding.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.Binding.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.Binding.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.Binding". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.Binding.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Binding.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.Binding.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.Binding.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Binding.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.Binding.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.Binding.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Binding.manifest(props: BindingProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.Binding".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.Binding.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.BindingProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Binding.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.Binding.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.Binding.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.Binding.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.Binding.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.Binding.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Binding.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.Binding.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.Binding.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.Binding.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.Binding.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.Binding.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.Binding.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Binding.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Binding.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.Binding". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.Binding.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.Binding".

---

### CertificateSigningRequest <a name="CertificateSigningRequest" id="cdk8s-metaflow.k8s.CertificateSigningRequest"></a>

CertificateSigningRequest objects provide a mechanism to obtain x509 certificates by submitting a certificate signing request, and having it asynchronously approved and issued.

Kubelets use this API to obtain:
1. client certificates to authenticate to kube-apiserver (with the "kubernetes.io/kube-apiserver-client-kubelet" signerName).
2. serving certificates for TLS endpoints kube-apiserver can connect to securely (with the "kubernetes.io/kubelet-serving" signerName).

This API can be used to request client certificates to authenticate to kube-apiserver (with the "kubernetes.io/kube-apiserver-client" signerName), or to obtain certificates from custom non-Kubernetes signers.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.CertificateSigningRequest.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.CertificateSigningRequest(scope: Construct, id: string, props: CertificateSigningRequestProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.CertificateSigningRequestProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.CertificateSigningRequest.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.CertificateSigningRequest.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CertificateSigningRequest.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CertificateSigningRequestProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.CertificateSigningRequest.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.CertificateSigningRequest.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.CertificateSigningRequest.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.CertificateSigningRequest.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.CertificateSigningRequest.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.CertificateSigningRequest.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.certificates.v1.CertificateSigningRequest". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.CertificateSigningRequest.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CertificateSigningRequest.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.CertificateSigningRequest.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.CertificateSigningRequest.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CertificateSigningRequest.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.CertificateSigningRequest.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.CertificateSigningRequest.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CertificateSigningRequest.manifest(props: CertificateSigningRequestProps)
```

Renders a Kubernetes manifest for "io.k8s.api.certificates.v1.CertificateSigningRequest".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CertificateSigningRequest.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CertificateSigningRequestProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.CertificateSigningRequest.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.CertificateSigningRequest.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CertificateSigningRequest.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.CertificateSigningRequest.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CertificateSigningRequest.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CertificateSigningRequest.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CertificateSigningRequest.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequest.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.certificates.v1.CertificateSigningRequest". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.CertificateSigningRequest.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.certificates.v1.CertificateSigningRequest".

---

### CertificateSigningRequestList <a name="CertificateSigningRequestList" id="cdk8s-metaflow.k8s.CertificateSigningRequestList"></a>

CertificateSigningRequestList is a collection of CertificateSigningRequest objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.CertificateSigningRequestList(scope: Construct, id: string, props: CertificateSigningRequestListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.CertificateSigningRequestListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CertificateSigningRequestListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.certificates.v1.CertificateSigningRequestList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CertificateSigningRequestList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CertificateSigningRequestList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CertificateSigningRequestList.manifest(props: CertificateSigningRequestListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.certificates.v1.CertificateSigningRequestList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CertificateSigningRequestListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.certificates.v1.CertificateSigningRequestList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.CertificateSigningRequestList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.certificates.v1.CertificateSigningRequestList".

---

### ClusterRole <a name="ClusterRole" id="cdk8s-metaflow.k8s.ClusterRole"></a>

ClusterRole is a cluster level, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding or ClusterRoleBinding.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ClusterRole.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ClusterRole(scope: Construct, id: string, props?: ClusterRoleProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ClusterRoleProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ClusterRole.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ClusterRole.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ClusterRole.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ClusterRoleProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ClusterRole.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ClusterRole.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ClusterRole.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ClusterRole.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ClusterRole.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ClusterRole.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.rbac.v1.ClusterRole". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ClusterRole.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRole.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ClusterRole.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ClusterRole.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRole.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ClusterRole.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ClusterRole.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRole.manifest(props?: ClusterRoleProps)
```

Renders a Kubernetes manifest for "io.k8s.api.rbac.v1.ClusterRole".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ClusterRole.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ClusterRoleProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ClusterRole.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ClusterRole.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ClusterRole.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ClusterRole.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ClusterRole.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ClusterRole.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ClusterRole.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRole.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.rbac.v1.ClusterRole". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ClusterRole.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.rbac.v1.ClusterRole".

---

### ClusterRoleBinding <a name="ClusterRoleBinding" id="cdk8s-metaflow.k8s.ClusterRoleBinding"></a>

ClusterRoleBinding references a ClusterRole, but not contain it.

It can reference a ClusterRole in the global namespace, and adds who information via Subject.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ClusterRoleBinding.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ClusterRoleBinding(scope: Construct, id: string, props: ClusterRoleBindingProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ClusterRoleBindingProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ClusterRoleBinding.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ClusterRoleBinding.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ClusterRoleBinding.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ClusterRoleBindingProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ClusterRoleBinding.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ClusterRoleBinding.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ClusterRoleBinding.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ClusterRoleBinding.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ClusterRoleBinding.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ClusterRoleBinding.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.rbac.v1.ClusterRoleBinding". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ClusterRoleBinding.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleBinding.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ClusterRoleBinding.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ClusterRoleBinding.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleBinding.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ClusterRoleBinding.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ClusterRoleBinding.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleBinding.manifest(props: ClusterRoleBindingProps)
```

Renders a Kubernetes manifest for "io.k8s.api.rbac.v1.ClusterRoleBinding".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ClusterRoleBinding.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ClusterRoleBindingProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ClusterRoleBinding.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ClusterRoleBinding.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ClusterRoleBinding.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ClusterRoleBinding.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ClusterRoleBinding.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ClusterRoleBinding.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ClusterRoleBinding.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBinding.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.rbac.v1.ClusterRoleBinding". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ClusterRoleBinding.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.rbac.v1.ClusterRoleBinding".

---

### ClusterRoleBindingList <a name="ClusterRoleBindingList" id="cdk8s-metaflow.k8s.ClusterRoleBindingList"></a>

ClusterRoleBindingList is a collection of ClusterRoleBindings.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ClusterRoleBindingList(scope: Construct, id: string, props: ClusterRoleBindingListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ClusterRoleBindingListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ClusterRoleBindingListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.rbac.v1.ClusterRoleBindingList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleBindingList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleBindingList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleBindingList.manifest(props: ClusterRoleBindingListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.rbac.v1.ClusterRoleBindingList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ClusterRoleBindingListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.rbac.v1.ClusterRoleBindingList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ClusterRoleBindingList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.rbac.v1.ClusterRoleBindingList".

---

### ClusterRoleBindingListV1Alpha1 <a name="ClusterRoleBindingListV1Alpha1" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1"></a>

ClusterRoleBindingList is a collection of ClusterRoleBindings.

Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 ClusterRoleBindings, and will no longer be served in v1.22.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ClusterRoleBindingListV1Alpha1(scope: Construct, id: string, props: ClusterRoleBindingListV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.rbac.v1alpha1.ClusterRoleBindingList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleBindingListV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleBindingListV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleBindingListV1Alpha1.manifest(props: ClusterRoleBindingListV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.rbac.v1alpha1.ClusterRoleBindingList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.rbac.v1alpha1.ClusterRoleBindingList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.rbac.v1alpha1.ClusterRoleBindingList".

---

### ClusterRoleBindingV1Alpha1 <a name="ClusterRoleBindingV1Alpha1" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1"></a>

ClusterRoleBinding references a ClusterRole, but not contain it.

It can reference a ClusterRole in the global namespace, and adds who information via Subject. Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 ClusterRoleBinding, and will no longer be served in v1.22.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ClusterRoleBindingV1Alpha1(scope: Construct, id: string, props: ClusterRoleBindingV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.rbac.v1alpha1.ClusterRoleBinding". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleBindingV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleBindingV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleBindingV1Alpha1.manifest(props: ClusterRoleBindingV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.rbac.v1alpha1.ClusterRoleBinding".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.rbac.v1alpha1.ClusterRoleBinding". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.rbac.v1alpha1.ClusterRoleBinding".

---

### ClusterRoleList <a name="ClusterRoleList" id="cdk8s-metaflow.k8s.ClusterRoleList"></a>

ClusterRoleList is a collection of ClusterRoles.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ClusterRoleList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ClusterRoleList(scope: Construct, id: string, props: ClusterRoleListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ClusterRoleListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ClusterRoleList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ClusterRoleList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ClusterRoleList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ClusterRoleListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ClusterRoleList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ClusterRoleList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ClusterRoleList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ClusterRoleList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ClusterRoleList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ClusterRoleList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.rbac.v1.ClusterRoleList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ClusterRoleList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ClusterRoleList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ClusterRoleList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ClusterRoleList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ClusterRoleList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleList.manifest(props: ClusterRoleListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.rbac.v1.ClusterRoleList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ClusterRoleList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ClusterRoleListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ClusterRoleList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ClusterRoleList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ClusterRoleList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ClusterRoleList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ClusterRoleList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ClusterRoleList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ClusterRoleList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.rbac.v1.ClusterRoleList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ClusterRoleList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.rbac.v1.ClusterRoleList".

---

### ClusterRoleListV1Alpha1 <a name="ClusterRoleListV1Alpha1" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1"></a>

ClusterRoleList is a collection of ClusterRoles.

Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 ClusterRoles, and will no longer be served in v1.22.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ClusterRoleListV1Alpha1(scope: Construct, id: string, props: ClusterRoleListV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.rbac.v1alpha1.ClusterRoleList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleListV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleListV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleListV1Alpha1.manifest(props: ClusterRoleListV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.rbac.v1alpha1.ClusterRoleList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.rbac.v1alpha1.ClusterRoleList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.rbac.v1alpha1.ClusterRoleList".

---

### ClusterRoleV1Alpha1 <a name="ClusterRoleV1Alpha1" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1"></a>

ClusterRole is a cluster level, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding or ClusterRoleBinding.

Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 ClusterRole, and will no longer be served in v1.22.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ClusterRoleV1Alpha1(scope: Construct, id: string, props?: ClusterRoleV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ClusterRoleV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ClusterRoleV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.rbac.v1alpha1.ClusterRole". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ClusterRoleV1Alpha1.manifest(props?: ClusterRoleV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.rbac.v1alpha1.ClusterRole".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ClusterRoleV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.rbac.v1alpha1.ClusterRole". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.rbac.v1alpha1.ClusterRole".

---

### ComponentStatus <a name="ComponentStatus" id="cdk8s-metaflow.k8s.ComponentStatus"></a>

ComponentStatus (and ComponentStatusList) holds the cluster validation info.

Deprecated: This API is deprecated in v1.19+

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ComponentStatus.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ComponentStatus(scope: Construct, id: string, props?: ComponentStatusProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ComponentStatusProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ComponentStatus.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ComponentStatus.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ComponentStatus.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ComponentStatusProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ComponentStatus.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ComponentStatus.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ComponentStatus.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ComponentStatus.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ComponentStatus.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ComponentStatus.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.ComponentStatus". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ComponentStatus.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ComponentStatus.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ComponentStatus.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ComponentStatus.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ComponentStatus.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ComponentStatus.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ComponentStatus.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ComponentStatus.manifest(props?: ComponentStatusProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.ComponentStatus".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ComponentStatus.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ComponentStatusProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ComponentStatus.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ComponentStatus.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ComponentStatus.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ComponentStatus.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ComponentStatus.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ComponentStatus.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ComponentStatus.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatus.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.ComponentStatus". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ComponentStatus.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.ComponentStatus".

---

### ComponentStatusList <a name="ComponentStatusList" id="cdk8s-metaflow.k8s.ComponentStatusList"></a>

Status of all the conditions for the component as a list of ComponentStatus objects.

Deprecated: This API is deprecated in v1.19+

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ComponentStatusList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ComponentStatusList(scope: Construct, id: string, props: ComponentStatusListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ComponentStatusListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ComponentStatusList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ComponentStatusList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ComponentStatusList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ComponentStatusListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ComponentStatusList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ComponentStatusList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ComponentStatusList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ComponentStatusList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ComponentStatusList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ComponentStatusList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.ComponentStatusList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ComponentStatusList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ComponentStatusList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ComponentStatusList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ComponentStatusList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ComponentStatusList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ComponentStatusList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ComponentStatusList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ComponentStatusList.manifest(props: ComponentStatusListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.ComponentStatusList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ComponentStatusList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ComponentStatusListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ComponentStatusList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ComponentStatusList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ComponentStatusList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ComponentStatusList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ComponentStatusList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ComponentStatusList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ComponentStatusList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.ComponentStatusList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ComponentStatusList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.ComponentStatusList".

---

### ConfigMap <a name="ConfigMap" id="cdk8s-metaflow.k8s.ConfigMap"></a>

ConfigMap holds configuration data for pods to consume.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ConfigMap.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ConfigMap(scope: Construct, id: string, props?: ConfigMapProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ConfigMapProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ConfigMap.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ConfigMap.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ConfigMap.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ConfigMapProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ConfigMap.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ConfigMap.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ConfigMap.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ConfigMap.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ConfigMap.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ConfigMap.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.ConfigMap". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ConfigMap.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ConfigMap.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ConfigMap.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ConfigMap.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ConfigMap.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ConfigMap.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ConfigMap.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ConfigMap.manifest(props?: ConfigMapProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.ConfigMap".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ConfigMap.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ConfigMapProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ConfigMap.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ConfigMap.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ConfigMap.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ConfigMap.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ConfigMap.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ConfigMap.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ConfigMap.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMap.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.ConfigMap". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ConfigMap.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.ConfigMap".

---

### ConfigMapList <a name="ConfigMapList" id="cdk8s-metaflow.k8s.ConfigMapList"></a>

ConfigMapList is a resource containing a list of ConfigMap objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ConfigMapList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ConfigMapList(scope: Construct, id: string, props: ConfigMapListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ConfigMapListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ConfigMapList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ConfigMapList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ConfigMapList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ConfigMapListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ConfigMapList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ConfigMapList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ConfigMapList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ConfigMapList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ConfigMapList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ConfigMapList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.ConfigMapList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ConfigMapList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ConfigMapList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ConfigMapList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ConfigMapList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ConfigMapList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ConfigMapList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ConfigMapList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ConfigMapList.manifest(props: ConfigMapListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.ConfigMapList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ConfigMapList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ConfigMapListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ConfigMapList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ConfigMapList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ConfigMapList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ConfigMapList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ConfigMapList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ConfigMapList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ConfigMapList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.ConfigMapList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ConfigMapList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.ConfigMapList".

---

### ControllerRevision <a name="ControllerRevision" id="cdk8s-metaflow.k8s.ControllerRevision"></a>

ControllerRevision implements an immutable snapshot of state data.

Clients are responsible for serializing and deserializing the objects that contain their internal state. Once a ControllerRevision has been successfully created, it can not be updated. The API Server will fail validation of all requests that attempt to mutate the Data field. ControllerRevisions may, however, be deleted. Note that, due to its use by both the DaemonSet and StatefulSet controllers for update and rollback, this object is beta. However, it may be subject to name and representation changes in future releases, and clients should not depend on its stability. It is primarily for internal use by controllers.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ControllerRevision.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ControllerRevision(scope: Construct, id: string, props: ControllerRevisionProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ControllerRevisionProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ControllerRevision.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ControllerRevision.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ControllerRevision.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ControllerRevisionProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ControllerRevision.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ControllerRevision.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ControllerRevision.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ControllerRevision.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ControllerRevision.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ControllerRevision.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.apps.v1.ControllerRevision". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ControllerRevision.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ControllerRevision.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ControllerRevision.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ControllerRevision.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ControllerRevision.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ControllerRevision.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ControllerRevision.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ControllerRevision.manifest(props: ControllerRevisionProps)
```

Renders a Kubernetes manifest for "io.k8s.api.apps.v1.ControllerRevision".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ControllerRevision.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ControllerRevisionProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ControllerRevision.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ControllerRevision.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ControllerRevision.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ControllerRevision.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ControllerRevision.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ControllerRevision.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ControllerRevision.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevision.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.apps.v1.ControllerRevision". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ControllerRevision.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.apps.v1.ControllerRevision".

---

### ControllerRevisionList <a name="ControllerRevisionList" id="cdk8s-metaflow.k8s.ControllerRevisionList"></a>

ControllerRevisionList is a resource containing a list of ControllerRevision objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ControllerRevisionList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ControllerRevisionList(scope: Construct, id: string, props: ControllerRevisionListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ControllerRevisionListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ControllerRevisionList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ControllerRevisionList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ControllerRevisionList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ControllerRevisionListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ControllerRevisionList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ControllerRevisionList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ControllerRevisionList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ControllerRevisionList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ControllerRevisionList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ControllerRevisionList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.apps.v1.ControllerRevisionList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ControllerRevisionList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ControllerRevisionList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ControllerRevisionList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ControllerRevisionList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ControllerRevisionList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ControllerRevisionList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ControllerRevisionList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ControllerRevisionList.manifest(props: ControllerRevisionListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.apps.v1.ControllerRevisionList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ControllerRevisionList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ControllerRevisionListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ControllerRevisionList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ControllerRevisionList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ControllerRevisionList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ControllerRevisionList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ControllerRevisionList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ControllerRevisionList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ControllerRevisionList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.apps.v1.ControllerRevisionList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ControllerRevisionList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.apps.v1.ControllerRevisionList".

---

### CronJob <a name="CronJob" id="cdk8s-metaflow.k8s.CronJob"></a>

CronJob represents the configuration of a single cron job.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.CronJob.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.CronJob(scope: Construct, id: string, props?: CronJobProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.CronJobProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.CronJob.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.CronJob.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.CronJob.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CronJobProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.CronJob.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.CronJob.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.CronJob.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.CronJob.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.CronJob.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.CronJob.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.batch.v1.CronJob". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.CronJob.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CronJob.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.CronJob.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.CronJob.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CronJob.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.CronJob.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.CronJob.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CronJob.manifest(props?: CronJobProps)
```

Renders a Kubernetes manifest for "io.k8s.api.batch.v1.CronJob".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.CronJob.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CronJobProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.CronJob.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.CronJob.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CronJob.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.CronJob.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CronJob.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CronJob.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CronJob.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJob.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.batch.v1.CronJob". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.CronJob.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.batch.v1.CronJob".

---

### CronJobList <a name="CronJobList" id="cdk8s-metaflow.k8s.CronJobList"></a>

CronJobList is a collection of cron jobs.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.CronJobList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.CronJobList(scope: Construct, id: string, props: CronJobListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.CronJobListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.CronJobList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.CronJobList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CronJobList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CronJobListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.CronJobList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.CronJobList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.CronJobList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.CronJobList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.CronJobList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.CronJobList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.batch.v1.CronJobList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.CronJobList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CronJobList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.CronJobList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.CronJobList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CronJobList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.CronJobList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.CronJobList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CronJobList.manifest(props: CronJobListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.batch.v1.CronJobList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CronJobList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CronJobListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.CronJobList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.CronJobList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CronJobList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.CronJobList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CronJobList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CronJobList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CronJobList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.batch.v1.CronJobList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.CronJobList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.batch.v1.CronJobList".

---

### CronJobListV1Beta1 <a name="CronJobListV1Beta1" id="cdk8s-metaflow.k8s.CronJobListV1Beta1"></a>

CronJobList is a collection of cron jobs.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.CronJobListV1Beta1(scope: Construct, id: string, props: CronJobListV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.CronJobListV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CronJobListV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.batch.v1beta1.CronJobList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CronJobListV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CronJobListV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CronJobListV1Beta1.manifest(props: CronJobListV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.batch.v1beta1.CronJobList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CronJobListV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.batch.v1beta1.CronJobList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.CronJobListV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.batch.v1beta1.CronJobList".

---

### CronJobV1Beta1 <a name="CronJobV1Beta1" id="cdk8s-metaflow.k8s.CronJobV1Beta1"></a>

CronJob represents the configuration of a single cron job.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.CronJobV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.CronJobV1Beta1(scope: Construct, id: string, props?: CronJobV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.CronJobV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.CronJobV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.CronJobV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.CronJobV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CronJobV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.CronJobV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.CronJobV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.CronJobV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.CronJobV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.CronJobV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.CronJobV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.batch.v1beta1.CronJob". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.CronJobV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CronJobV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.CronJobV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.CronJobV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CronJobV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.CronJobV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.CronJobV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CronJobV1Beta1.manifest(props?: CronJobV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.batch.v1beta1.CronJob".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.CronJobV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CronJobV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.CronJobV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.CronJobV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CronJobV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.CronJobV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CronJobV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CronJobV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CronJobV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.batch.v1beta1.CronJob". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.CronJobV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.batch.v1beta1.CronJob".

---

### CsiDriver <a name="CsiDriver" id="cdk8s-metaflow.k8s.CsiDriver"></a>

CSIDriver captures information about a Container Storage Interface (CSI) volume driver deployed on the cluster.

Kubernetes attach detach controller uses this object to determine whether attach is required. Kubelet uses this object to determine whether pod information needs to be passed on mount. CSIDriver objects are non-namespaced.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.CsiDriver.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.CsiDriver(scope: Construct, id: string, props: CsiDriverProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.CsiDriverProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.CsiDriver.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.CsiDriver.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CsiDriver.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CsiDriverProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.CsiDriver.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.CsiDriver.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.CsiDriver.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.CsiDriver.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.CsiDriver.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.CsiDriver.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.storage.v1.CSIDriver". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.CsiDriver.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiDriver.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.CsiDriver.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.CsiDriver.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiDriver.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.CsiDriver.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.CsiDriver.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiDriver.manifest(props: CsiDriverProps)
```

Renders a Kubernetes manifest for "io.k8s.api.storage.v1.CSIDriver".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CsiDriver.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CsiDriverProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.CsiDriver.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.CsiDriver.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CsiDriver.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.CsiDriver.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CsiDriver.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CsiDriver.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CsiDriver.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriver.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.storage.v1.CSIDriver". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.CsiDriver.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.storage.v1.CSIDriver".

---

### CsiDriverList <a name="CsiDriverList" id="cdk8s-metaflow.k8s.CsiDriverList"></a>

CSIDriverList is a collection of CSIDriver objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.CsiDriverList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.CsiDriverList(scope: Construct, id: string, props: CsiDriverListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.CsiDriverListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.CsiDriverList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.CsiDriverList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CsiDriverList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CsiDriverListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.CsiDriverList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.CsiDriverList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.CsiDriverList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.CsiDriverList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.CsiDriverList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.CsiDriverList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.storage.v1.CSIDriverList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.CsiDriverList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiDriverList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.CsiDriverList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.CsiDriverList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiDriverList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.CsiDriverList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.CsiDriverList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiDriverList.manifest(props: CsiDriverListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.storage.v1.CSIDriverList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CsiDriverList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CsiDriverListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.CsiDriverList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.CsiDriverList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CsiDriverList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.CsiDriverList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CsiDriverList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CsiDriverList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CsiDriverList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.storage.v1.CSIDriverList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.CsiDriverList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.storage.v1.CSIDriverList".

---

### CsiNode <a name="CsiNode" id="cdk8s-metaflow.k8s.CsiNode"></a>

CSINode holds information about all CSI drivers installed on a node.

CSI drivers do not need to create the CSINode object directly. As long as they use the node-driver-registrar sidecar container, the kubelet will automatically populate the CSINode object for the CSI driver as part of kubelet plugin registration. CSINode has the same name as a node. If the object is missing, it means either there are no CSI Drivers available on the node, or the Kubelet version is low enough that it doesn't create this object. CSINode has an OwnerReference that points to the corresponding node object.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.CsiNode.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.CsiNode(scope: Construct, id: string, props: CsiNodeProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.CsiNodeProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.CsiNode.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.CsiNode.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CsiNode.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CsiNodeProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.CsiNode.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.CsiNode.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.CsiNode.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.CsiNode.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.CsiNode.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.CsiNode.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.storage.v1.CSINode". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.CsiNode.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiNode.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.CsiNode.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.CsiNode.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiNode.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.CsiNode.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.CsiNode.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiNode.manifest(props: CsiNodeProps)
```

Renders a Kubernetes manifest for "io.k8s.api.storage.v1.CSINode".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CsiNode.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CsiNodeProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.CsiNode.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.CsiNode.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CsiNode.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.CsiNode.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CsiNode.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CsiNode.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CsiNode.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiNode.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.storage.v1.CSINode". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.CsiNode.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.storage.v1.CSINode".

---

### CsiNodeList <a name="CsiNodeList" id="cdk8s-metaflow.k8s.CsiNodeList"></a>

CSINodeList is a collection of CSINode objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.CsiNodeList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.CsiNodeList(scope: Construct, id: string, props: CsiNodeListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.CsiNodeListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.CsiNodeList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.CsiNodeList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CsiNodeList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CsiNodeListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.CsiNodeList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.CsiNodeList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.CsiNodeList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.CsiNodeList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.CsiNodeList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.CsiNodeList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.storage.v1.CSINodeList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.CsiNodeList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiNodeList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.CsiNodeList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.CsiNodeList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiNodeList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.CsiNodeList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.CsiNodeList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiNodeList.manifest(props: CsiNodeListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.storage.v1.CSINodeList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CsiNodeList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CsiNodeListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.CsiNodeList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.CsiNodeList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CsiNodeList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.CsiNodeList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CsiNodeList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CsiNodeList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CsiNodeList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.storage.v1.CSINodeList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.CsiNodeList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.storage.v1.CSINodeList".

---

### CsiStorageCapacityListV1Alpha1 <a name="CsiStorageCapacityListV1Alpha1" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1"></a>

CSIStorageCapacityList is a collection of CSIStorageCapacity objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.CsiStorageCapacityListV1Alpha1(scope: Construct, id: string, props: CsiStorageCapacityListV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.storage.v1alpha1.CSIStorageCapacityList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiStorageCapacityListV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiStorageCapacityListV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiStorageCapacityListV1Alpha1.manifest(props: CsiStorageCapacityListV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.storage.v1alpha1.CSIStorageCapacityList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.storage.v1alpha1.CSIStorageCapacityList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.storage.v1alpha1.CSIStorageCapacityList".

---

### CsiStorageCapacityListV1Beta1 <a name="CsiStorageCapacityListV1Beta1" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1"></a>

CSIStorageCapacityList is a collection of CSIStorageCapacity objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.CsiStorageCapacityListV1Beta1(scope: Construct, id: string, props: CsiStorageCapacityListV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.storage.v1beta1.CSIStorageCapacityList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiStorageCapacityListV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiStorageCapacityListV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiStorageCapacityListV1Beta1.manifest(props: CsiStorageCapacityListV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.storage.v1beta1.CSIStorageCapacityList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.storage.v1beta1.CSIStorageCapacityList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.storage.v1beta1.CSIStorageCapacityList".

---

### CsiStorageCapacityV1Alpha1 <a name="CsiStorageCapacityV1Alpha1" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1"></a>

CSIStorageCapacity stores the result of one CSI GetCapacity call.

For a given StorageClass, this describes the available capacity in a particular topology segment.  This can be used when considering where to instantiate new PersistentVolumes.

For example this can express things like: - StorageClass "standard" has "1234 GiB" available in "topology.kubernetes.io/zone=us-east1" - StorageClass "localssd" has "10 GiB" available in "kubernetes.io/hostname=knode-abc123"

The following three cases all imply that no capacity is available for a certain combination: - no object exists with suitable topology and storage class name - such an object exists, but the capacity is unset - such an object exists, but the capacity is zero

The producer of these objects can decide which approach is more suitable.

They are consumed by the kube-scheduler if the CSIStorageCapacity beta feature gate is enabled there and a CSI driver opts into capacity-aware scheduling with CSIDriver.StorageCapacity.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.CsiStorageCapacityV1Alpha1(scope: Construct, id: string, props: CsiStorageCapacityV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.storage.v1alpha1.CSIStorageCapacity". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiStorageCapacityV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiStorageCapacityV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiStorageCapacityV1Alpha1.manifest(props: CsiStorageCapacityV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.storage.v1alpha1.CSIStorageCapacity".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.storage.v1alpha1.CSIStorageCapacity". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.storage.v1alpha1.CSIStorageCapacity".

---

### CsiStorageCapacityV1Beta1 <a name="CsiStorageCapacityV1Beta1" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1"></a>

CSIStorageCapacity stores the result of one CSI GetCapacity call.

For a given StorageClass, this describes the available capacity in a particular topology segment.  This can be used when considering where to instantiate new PersistentVolumes.

For example this can express things like: - StorageClass "standard" has "1234 GiB" available in "topology.kubernetes.io/zone=us-east1" - StorageClass "localssd" has "10 GiB" available in "kubernetes.io/hostname=knode-abc123"

The following three cases all imply that no capacity is available for a certain combination: - no object exists with suitable topology and storage class name - such an object exists, but the capacity is unset - such an object exists, but the capacity is zero

The producer of these objects can decide which approach is more suitable.

They are consumed by the kube-scheduler if the CSIStorageCapacity beta feature gate is enabled there and a CSI driver opts into capacity-aware scheduling with CSIDriver.StorageCapacity.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.CsiStorageCapacityV1Beta1(scope: Construct, id: string, props: CsiStorageCapacityV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.storage.v1beta1.CSIStorageCapacity". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiStorageCapacityV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiStorageCapacityV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CsiStorageCapacityV1Beta1.manifest(props: CsiStorageCapacityV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.storage.v1beta1.CSIStorageCapacity".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.storage.v1beta1.CSIStorageCapacity". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.storage.v1beta1.CSIStorageCapacity".

---

### CustomResourceDefinition <a name="CustomResourceDefinition" id="cdk8s-metaflow.k8s.CustomResourceDefinition"></a>

CustomResourceDefinition represents a resource that should be exposed on the API server.

Its name MUST be in the format <.spec.name>.<.spec.group>.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.CustomResourceDefinition.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.CustomResourceDefinition(scope: Construct, id: string, props: CustomResourceDefinitionProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.CustomResourceDefinitionProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.CustomResourceDefinition.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.CustomResourceDefinition.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CustomResourceDefinition.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CustomResourceDefinitionProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.CustomResourceDefinition.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.CustomResourceDefinition.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.CustomResourceDefinition.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.CustomResourceDefinition.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.CustomResourceDefinition.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.CustomResourceDefinition.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.apiextensions-apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinition". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.CustomResourceDefinition.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CustomResourceDefinition.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.CustomResourceDefinition.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.CustomResourceDefinition.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CustomResourceDefinition.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.CustomResourceDefinition.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.CustomResourceDefinition.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CustomResourceDefinition.manifest(props: CustomResourceDefinitionProps)
```

Renders a Kubernetes manifest for "io.k8s.apiextensions-apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinition".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CustomResourceDefinition.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CustomResourceDefinitionProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.CustomResourceDefinition.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.CustomResourceDefinition.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CustomResourceDefinition.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.CustomResourceDefinition.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CustomResourceDefinition.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CustomResourceDefinition.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CustomResourceDefinition.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinition.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.apiextensions-apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinition". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.CustomResourceDefinition.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.apiextensions-apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinition".

---

### CustomResourceDefinitionList <a name="CustomResourceDefinitionList" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList"></a>

CustomResourceDefinitionList is a list of CustomResourceDefinition objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.CustomResourceDefinitionList(scope: Construct, id: string, props: CustomResourceDefinitionListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.CustomResourceDefinitionListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CustomResourceDefinitionListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.apiextensions-apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CustomResourceDefinitionList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CustomResourceDefinitionList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.CustomResourceDefinitionList.manifest(props: CustomResourceDefinitionListProps)
```

Renders a Kubernetes manifest for "io.k8s.apiextensions-apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.CustomResourceDefinitionListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.apiextensions-apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.CustomResourceDefinitionList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.apiextensions-apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionList".

---

### DaemonSet <a name="DaemonSet" id="cdk8s-metaflow.k8s.DaemonSet"></a>

DaemonSet represents the configuration of a daemon set.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.DaemonSet.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.DaemonSet(scope: Construct, id: string, props?: DaemonSetProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.DaemonSetProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.DaemonSet.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.DaemonSet.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.DaemonSet.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.DaemonSetProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.DaemonSet.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.DaemonSet.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.DaemonSet.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.DaemonSet.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.DaemonSet.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.DaemonSet.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.apps.v1.DaemonSet". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.DaemonSet.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.DaemonSet.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.DaemonSet.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.DaemonSet.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.DaemonSet.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.DaemonSet.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.DaemonSet.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.DaemonSet.manifest(props?: DaemonSetProps)
```

Renders a Kubernetes manifest for "io.k8s.api.apps.v1.DaemonSet".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.DaemonSet.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.DaemonSetProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.DaemonSet.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.DaemonSet.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.DaemonSet.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.DaemonSet.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.DaemonSet.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.DaemonSet.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.DaemonSet.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSet.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.apps.v1.DaemonSet". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.DaemonSet.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.apps.v1.DaemonSet".

---

### DaemonSetList <a name="DaemonSetList" id="cdk8s-metaflow.k8s.DaemonSetList"></a>

DaemonSetList is a collection of daemon sets.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.DaemonSetList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.DaemonSetList(scope: Construct, id: string, props: DaemonSetListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.DaemonSetListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.DaemonSetList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.DaemonSetList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.DaemonSetList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.DaemonSetListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.DaemonSetList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.DaemonSetList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.DaemonSetList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.DaemonSetList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.DaemonSetList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.DaemonSetList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.apps.v1.DaemonSetList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.DaemonSetList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.DaemonSetList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.DaemonSetList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.DaemonSetList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.DaemonSetList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.DaemonSetList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.DaemonSetList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.DaemonSetList.manifest(props: DaemonSetListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.apps.v1.DaemonSetList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.DaemonSetList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.DaemonSetListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.DaemonSetList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.DaemonSetList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.DaemonSetList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.DaemonSetList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.DaemonSetList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.DaemonSetList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.DaemonSetList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.apps.v1.DaemonSetList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.DaemonSetList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.apps.v1.DaemonSetList".

---

### Deployment <a name="Deployment" id="cdk8s-metaflow.k8s.Deployment"></a>

Deployment enables declarative updates for Pods and ReplicaSets.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.Deployment.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.Deployment(scope: Construct, id: string, props?: DeploymentProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.DeploymentProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.Deployment.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.Deployment.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Deployment.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.DeploymentProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.Deployment.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.Deployment.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.Deployment.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.Deployment.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.Deployment.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.Deployment.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.apps.v1.Deployment". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.Deployment.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Deployment.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.Deployment.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.Deployment.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Deployment.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.Deployment.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.Deployment.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Deployment.manifest(props?: DeploymentProps)
```

Renders a Kubernetes manifest for "io.k8s.api.apps.v1.Deployment".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Deployment.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.DeploymentProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.Deployment.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.Deployment.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.Deployment.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.Deployment.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.Deployment.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.Deployment.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Deployment.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Deployment.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.apps.v1.Deployment". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.Deployment.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.apps.v1.Deployment".

---

### DeploymentList <a name="DeploymentList" id="cdk8s-metaflow.k8s.DeploymentList"></a>

DeploymentList is a list of Deployments.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.DeploymentList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.DeploymentList(scope: Construct, id: string, props: DeploymentListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.DeploymentListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.DeploymentList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.DeploymentList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.DeploymentList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.DeploymentListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.DeploymentList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.DeploymentList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.DeploymentList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.DeploymentList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.DeploymentList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.DeploymentList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.apps.v1.DeploymentList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.DeploymentList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.DeploymentList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.DeploymentList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.DeploymentList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.DeploymentList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.DeploymentList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.DeploymentList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.DeploymentList.manifest(props: DeploymentListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.apps.v1.DeploymentList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.DeploymentList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.DeploymentListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.DeploymentList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.DeploymentList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.DeploymentList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.DeploymentList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.DeploymentList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.DeploymentList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.DeploymentList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.apps.v1.DeploymentList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.DeploymentList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.apps.v1.DeploymentList".

---

### Endpoints <a name="Endpoints" id="cdk8s-metaflow.k8s.Endpoints"></a>

Endpoints is a collection of endpoints that implement the actual service.

Example:
Name: "mysvc",
Subsets: [
  {
    Addresses: [{"ip": "10.10.1.1"}, {"ip": "10.10.2.2"}],
    Ports: [{"name": "a", "port": 8675}, {"name": "b", "port": 309}]
  },
  {
    Addresses: [{"ip": "10.10.3.3"}],
    Ports: [{"name": "a", "port": 93}, {"name": "b", "port": 76}]
  },
]

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.Endpoints.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.Endpoints(scope: Construct, id: string, props?: EndpointsProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.EndpointsProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.Endpoints.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.Endpoints.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Endpoints.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EndpointsProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.Endpoints.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.Endpoints.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.Endpoints.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.Endpoints.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.Endpoints.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.Endpoints.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.Endpoints". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.Endpoints.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Endpoints.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.Endpoints.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.Endpoints.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Endpoints.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.Endpoints.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.Endpoints.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Endpoints.manifest(props?: EndpointsProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.Endpoints".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Endpoints.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EndpointsProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.Endpoints.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.Endpoints.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.Endpoints.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.Endpoints.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.Endpoints.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.Endpoints.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Endpoints.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Endpoints.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.Endpoints". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.Endpoints.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.Endpoints".

---

### EndpointSlice <a name="EndpointSlice" id="cdk8s-metaflow.k8s.EndpointSlice"></a>

EndpointSlice represents a subset of the endpoints that implement a service.

For a given service there may be multiple EndpointSlice objects, selected by labels, which must be joined to produce the full set of endpoints.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.EndpointSlice.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.EndpointSlice(scope: Construct, id: string, props: EndpointSliceProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.EndpointSliceProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.EndpointSlice.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.EndpointSlice.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.EndpointSlice.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EndpointSliceProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.EndpointSlice.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.EndpointSlice.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.EndpointSlice.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.EndpointSlice.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.EndpointSlice.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.EndpointSlice.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.discovery.v1.EndpointSlice". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.EndpointSlice.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EndpointSlice.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.EndpointSlice.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.EndpointSlice.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EndpointSlice.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.EndpointSlice.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.EndpointSlice.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EndpointSlice.manifest(props: EndpointSliceProps)
```

Renders a Kubernetes manifest for "io.k8s.api.discovery.v1.EndpointSlice".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.EndpointSlice.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EndpointSliceProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.EndpointSlice.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.EndpointSlice.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.EndpointSlice.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.EndpointSlice.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.EndpointSlice.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EndpointSlice.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.EndpointSlice.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSlice.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.discovery.v1.EndpointSlice". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.EndpointSlice.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.discovery.v1.EndpointSlice".

---

### EndpointSliceList <a name="EndpointSliceList" id="cdk8s-metaflow.k8s.EndpointSliceList"></a>

EndpointSliceList represents a list of endpoint slices.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.EndpointSliceList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.EndpointSliceList(scope: Construct, id: string, props: EndpointSliceListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.EndpointSliceListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.EndpointSliceList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.EndpointSliceList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.EndpointSliceList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EndpointSliceListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.EndpointSliceList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.EndpointSliceList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.EndpointSliceList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.EndpointSliceList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.EndpointSliceList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.EndpointSliceList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.discovery.v1.EndpointSliceList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.EndpointSliceList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EndpointSliceList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.EndpointSliceList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.EndpointSliceList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EndpointSliceList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.EndpointSliceList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.EndpointSliceList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EndpointSliceList.manifest(props: EndpointSliceListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.discovery.v1.EndpointSliceList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.EndpointSliceList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EndpointSliceListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.EndpointSliceList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.EndpointSliceList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.EndpointSliceList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.EndpointSliceList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.EndpointSliceList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EndpointSliceList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.EndpointSliceList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.discovery.v1.EndpointSliceList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.EndpointSliceList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.discovery.v1.EndpointSliceList".

---

### EndpointSliceListV1Beta1 <a name="EndpointSliceListV1Beta1" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1"></a>

EndpointSliceList represents a list of endpoint slices.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.EndpointSliceListV1Beta1(scope: Construct, id: string, props: EndpointSliceListV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.EndpointSliceListV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EndpointSliceListV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.discovery.v1beta1.EndpointSliceList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EndpointSliceListV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EndpointSliceListV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EndpointSliceListV1Beta1.manifest(props: EndpointSliceListV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.discovery.v1beta1.EndpointSliceList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EndpointSliceListV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.discovery.v1beta1.EndpointSliceList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.discovery.v1beta1.EndpointSliceList".

---

### EndpointSliceV1Beta1 <a name="EndpointSliceV1Beta1" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1"></a>

EndpointSlice represents a subset of the endpoints that implement a service.

For a given service there may be multiple EndpointSlice objects, selected by labels, which must be joined to produce the full set of endpoints.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.EndpointSliceV1Beta1(scope: Construct, id: string, props: EndpointSliceV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.EndpointSliceV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EndpointSliceV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.discovery.v1beta1.EndpointSlice". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EndpointSliceV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EndpointSliceV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EndpointSliceV1Beta1.manifest(props: EndpointSliceV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.discovery.v1beta1.EndpointSlice".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EndpointSliceV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.discovery.v1beta1.EndpointSlice". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.discovery.v1beta1.EndpointSlice".

---

### EndpointsList <a name="EndpointsList" id="cdk8s-metaflow.k8s.EndpointsList"></a>

EndpointsList is a list of endpoints.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.EndpointsList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.EndpointsList(scope: Construct, id: string, props: EndpointsListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.EndpointsListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.EndpointsList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.EndpointsList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.EndpointsList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EndpointsListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.EndpointsList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.EndpointsList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.EndpointsList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.EndpointsList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.EndpointsList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.EndpointsList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.EndpointsList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.EndpointsList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EndpointsList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.EndpointsList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.EndpointsList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EndpointsList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.EndpointsList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.EndpointsList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EndpointsList.manifest(props: EndpointsListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.EndpointsList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.EndpointsList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EndpointsListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.EndpointsList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.EndpointsList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.EndpointsList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.EndpointsList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.EndpointsList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EndpointsList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.EndpointsList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.EndpointsList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.EndpointsList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.EndpointsList".

---

### Event <a name="Event" id="cdk8s-metaflow.k8s.Event"></a>

Event is a report of an event somewhere in the cluster.

It generally denotes some state change in the system. Events have a limited retention time and triggers and messages may evolve with time.  Event consumers should not rely on the timing of an event with a given Reason reflecting a consistent underlying trigger, or the continued existence of events with that Reason.  Events should be treated as informative, best-effort, supplemental data.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.Event.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.Event(scope: Construct, id: string, props: EventProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Event.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.Event.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.Event.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.EventProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.Event.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.Event.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.Event.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EventProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Event.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.Event.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.Event.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Event.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.Event.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.Event.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.Event.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.Event.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.Event.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.Event.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Event.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.Event.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.Event.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.events.v1.Event". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.Event.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Event.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.Event.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.Event.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Event.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.Event.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.Event.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Event.manifest(props: EventProps)
```

Renders a Kubernetes manifest for "io.k8s.api.events.v1.Event".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.Event.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EventProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Event.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.Event.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.Event.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.Event.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.Event.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.Event.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Event.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.Event.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.Event.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.Event.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.Event.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.Event.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.Event.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Event.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Event.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.events.v1.Event". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.Event.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.events.v1.Event".

---

### EventList <a name="EventList" id="cdk8s-metaflow.k8s.EventList"></a>

EventList is a list of Event objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.EventList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.EventList(scope: Construct, id: string, props: EventListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.EventList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.EventList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.EventListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.EventList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.EventList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.EventList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EventListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.EventList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.EventList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.EventList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.EventList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.EventList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.EventList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.EventList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.EventList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.EventList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.EventList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.EventList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.events.v1.EventList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.EventList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EventList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.EventList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.EventList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EventList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.EventList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.EventList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EventList.manifest(props: EventListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.events.v1.EventList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.EventList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EventListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.EventList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.EventList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.EventList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.EventList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.EventList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.EventList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.EventList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.EventList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.EventList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.EventList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.EventList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EventList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.EventList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.events.v1.EventList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.EventList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.events.v1.EventList".

---

### EventListV1Beta1 <a name="EventListV1Beta1" id="cdk8s-metaflow.k8s.EventListV1Beta1"></a>

EventList is a list of Event objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.EventListV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.EventListV1Beta1(scope: Construct, id: string, props: EventListV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.EventListV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.EventListV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.EventListV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.EventListV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EventListV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.EventListV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.EventListV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.EventListV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.EventListV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.EventListV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.EventListV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.events.v1beta1.EventList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.EventListV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EventListV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.EventListV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.EventListV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EventListV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.EventListV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.EventListV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EventListV1Beta1.manifest(props: EventListV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.events.v1beta1.EventList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.EventListV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EventListV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.EventListV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.EventListV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.EventListV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.EventListV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.EventListV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EventListV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.EventListV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.events.v1beta1.EventList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.EventListV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.events.v1beta1.EventList".

---

### EventV1Beta1 <a name="EventV1Beta1" id="cdk8s-metaflow.k8s.EventV1Beta1"></a>

Event is a report of an event somewhere in the cluster.

It generally denotes some state change in the system. Events have a limited retention time and triggers and messages may evolve with time.  Event consumers should not rely on the timing of an event with a given Reason reflecting a consistent underlying trigger, or the continued existence of events with that Reason.  Events should be treated as informative, best-effort, supplemental data.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.EventV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.EventV1Beta1(scope: Construct, id: string, props: EventV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.EventV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.EventV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.EventV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.EventV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EventV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.EventV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.EventV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.EventV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.EventV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.EventV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.EventV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.events.v1beta1.Event". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.EventV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EventV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.EventV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.EventV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EventV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.EventV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.EventV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.EventV1Beta1.manifest(props: EventV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.events.v1beta1.Event".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.EventV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EventV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.EventV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.EventV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.EventV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.EventV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.EventV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EventV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.EventV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.events.v1beta1.Event". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.EventV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.events.v1beta1.Event".

---

### Eviction <a name="Eviction" id="cdk8s-metaflow.k8s.Eviction"></a>

Eviction evicts a pod from its node subject to certain policies and safety constraints.

This is a subresource of Pod.  A request to cause such an eviction is created by POSTing to .../pods/<pod name>/evictions.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.Eviction.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.Eviction(scope: Construct, id: string, props?: EvictionProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.EvictionProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.Eviction.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.Eviction.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Eviction.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EvictionProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.Eviction.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.Eviction.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.Eviction.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.Eviction.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.Eviction.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.Eviction.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.policy.v1.Eviction". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.Eviction.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Eviction.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.Eviction.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.Eviction.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Eviction.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.Eviction.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.Eviction.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Eviction.manifest(props?: EvictionProps)
```

Renders a Kubernetes manifest for "io.k8s.api.policy.v1.Eviction".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Eviction.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.EvictionProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.Eviction.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.Eviction.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.Eviction.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.Eviction.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.Eviction.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.Eviction.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Eviction.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Eviction.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.policy.v1.Eviction". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.Eviction.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.policy.v1.Eviction".

---

### FlowSchemaListV1Beta1 <a name="FlowSchemaListV1Beta1" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1"></a>

FlowSchemaList is a list of FlowSchema objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.FlowSchemaListV1Beta1(scope: Construct, id: string, props: FlowSchemaListV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.FlowSchemaListV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.FlowSchemaListV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.flowcontrol.v1beta1.FlowSchemaList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.FlowSchemaListV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.FlowSchemaListV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.FlowSchemaListV1Beta1.manifest(props: FlowSchemaListV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.flowcontrol.v1beta1.FlowSchemaList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.FlowSchemaListV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.flowcontrol.v1beta1.FlowSchemaList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.flowcontrol.v1beta1.FlowSchemaList".

---

### FlowSchemaV1Beta1 <a name="FlowSchemaV1Beta1" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1"></a>

FlowSchema defines the schema of a group of flows.

Note that a flow is made up of a set of inbound API requests with similar attributes and is identified by a pair of strings: the name of the FlowSchema and a "flow distinguisher".

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.FlowSchemaV1Beta1(scope: Construct, id: string, props?: FlowSchemaV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.FlowSchemaV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.FlowSchemaV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.flowcontrol.v1beta1.FlowSchema". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.FlowSchemaV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.FlowSchemaV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.FlowSchemaV1Beta1.manifest(props?: FlowSchemaV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.flowcontrol.v1beta1.FlowSchema".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.FlowSchemaV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.flowcontrol.v1beta1.FlowSchema". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.flowcontrol.v1beta1.FlowSchema".

---

### HorizontalPodAutoscaler <a name="HorizontalPodAutoscaler" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler"></a>

configuration of a horizontal pod autoscaler.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.HorizontalPodAutoscaler(scope: Construct, id: string, props?: HorizontalPodAutoscalerProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.HorizontalPodAutoscalerProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.autoscaling.v1.HorizontalPodAutoscaler". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscaler.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscaler.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscaler.manifest(props?: HorizontalPodAutoscalerProps)
```

Renders a Kubernetes manifest for "io.k8s.api.autoscaling.v1.HorizontalPodAutoscaler".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscaler.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.autoscaling.v1.HorizontalPodAutoscaler". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.HorizontalPodAutoscaler.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.autoscaling.v1.HorizontalPodAutoscaler".

---

### HorizontalPodAutoscalerList <a name="HorizontalPodAutoscalerList" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList"></a>

list of horizontal pod autoscaler objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.HorizontalPodAutoscalerList(scope: Construct, id: string, props: HorizontalPodAutoscalerListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.HorizontalPodAutoscalerListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.autoscaling.v1.HorizontalPodAutoscalerList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscalerList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscalerList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscalerList.manifest(props: HorizontalPodAutoscalerListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.autoscaling.v1.HorizontalPodAutoscalerList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.autoscaling.v1.HorizontalPodAutoscalerList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.autoscaling.v1.HorizontalPodAutoscalerList".

---

### HorizontalPodAutoscalerListV2Beta1 <a name="HorizontalPodAutoscalerListV2Beta1" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1"></a>

HorizontalPodAutoscaler is a list of horizontal pod autoscaler objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.HorizontalPodAutoscalerListV2Beta1(scope: Construct, id: string, props: HorizontalPodAutoscalerListV2Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.autoscaling.v2beta1.HorizontalPodAutoscalerList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscalerListV2Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscalerListV2Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscalerListV2Beta1.manifest(props: HorizontalPodAutoscalerListV2Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.autoscaling.v2beta1.HorizontalPodAutoscalerList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.autoscaling.v2beta1.HorizontalPodAutoscalerList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.autoscaling.v2beta1.HorizontalPodAutoscalerList".

---

### HorizontalPodAutoscalerListV2Beta2 <a name="HorizontalPodAutoscalerListV2Beta2" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2"></a>

HorizontalPodAutoscalerList is a list of horizontal pod autoscaler objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.HorizontalPodAutoscalerListV2Beta2(scope: Construct, id: string, props: HorizontalPodAutoscalerListV2Beta2Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscalerList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscalerListV2Beta2.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscalerListV2Beta2.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscalerListV2Beta2.manifest(props: HorizontalPodAutoscalerListV2Beta2Props)
```

Renders a Kubernetes manifest for "io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscalerList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscalerList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscalerList".

---

### HorizontalPodAutoscalerV2Beta1 <a name="HorizontalPodAutoscalerV2Beta1" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1"></a>

HorizontalPodAutoscaler is the configuration for a horizontal pod autoscaler, which automatically manages the replica count of any resource implementing the scale subresource based on the metrics specified.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.HorizontalPodAutoscalerV2Beta1(scope: Construct, id: string, props?: HorizontalPodAutoscalerV2Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.autoscaling.v2beta1.HorizontalPodAutoscaler". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscalerV2Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscalerV2Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscalerV2Beta1.manifest(props?: HorizontalPodAutoscalerV2Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.autoscaling.v2beta1.HorizontalPodAutoscaler".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.autoscaling.v2beta1.HorizontalPodAutoscaler". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.autoscaling.v2beta1.HorizontalPodAutoscaler".

---

### HorizontalPodAutoscalerV2Beta2 <a name="HorizontalPodAutoscalerV2Beta2" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2"></a>

HorizontalPodAutoscaler is the configuration for a horizontal pod autoscaler, which automatically manages the replica count of any resource implementing the scale subresource based on the metrics specified.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.HorizontalPodAutoscalerV2Beta2(scope: Construct, id: string, props?: HorizontalPodAutoscalerV2Beta2Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscaler". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscalerV2Beta2.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscalerV2Beta2.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.HorizontalPodAutoscalerV2Beta2.manifest(props?: HorizontalPodAutoscalerV2Beta2Props)
```

Renders a Kubernetes manifest for "io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscaler".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscaler". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscaler".

---

### Ingress <a name="Ingress" id="cdk8s-metaflow.k8s.Ingress"></a>

Ingress is a collection of rules that allow inbound connections to reach the endpoints defined by a backend.

An Ingress can be configured to give services externally-reachable urls, load balance traffic, terminate SSL, offer name based virtual hosting etc.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.Ingress.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.Ingress(scope: Construct, id: string, props?: IngressProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.IngressProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.Ingress.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.Ingress.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Ingress.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.IngressProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.Ingress.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.Ingress.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.Ingress.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.Ingress.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.Ingress.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.Ingress.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.networking.v1.Ingress". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.Ingress.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Ingress.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.Ingress.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.Ingress.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Ingress.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.Ingress.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.Ingress.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Ingress.manifest(props?: IngressProps)
```

Renders a Kubernetes manifest for "io.k8s.api.networking.v1.Ingress".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Ingress.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.IngressProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.Ingress.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.Ingress.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.Ingress.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.Ingress.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.Ingress.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.Ingress.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Ingress.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Ingress.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.networking.v1.Ingress". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.Ingress.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.networking.v1.Ingress".

---

### IngressClass <a name="IngressClass" id="cdk8s-metaflow.k8s.IngressClass"></a>

IngressClass represents the class of the Ingress, referenced by the Ingress Spec.

The `ingressclass.kubernetes.io/is-default-class` annotation can be used to indicate that an IngressClass should be considered default. When a single IngressClass resource has this annotation set to true, new Ingress resources without a class specified will be assigned this default class.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.IngressClass.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.IngressClass(scope: Construct, id: string, props?: IngressClassProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.IngressClassProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.IngressClass.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.IngressClass.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.IngressClass.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.IngressClassProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.IngressClass.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.IngressClass.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.IngressClass.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.IngressClass.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.IngressClass.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.IngressClass.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.networking.v1.IngressClass". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.IngressClass.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.IngressClass.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.IngressClass.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.IngressClass.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.IngressClass.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.IngressClass.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.IngressClass.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.IngressClass.manifest(props?: IngressClassProps)
```

Renders a Kubernetes manifest for "io.k8s.api.networking.v1.IngressClass".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.IngressClass.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.IngressClassProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.IngressClass.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.IngressClass.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.IngressClass.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.IngressClass.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.IngressClass.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.IngressClass.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.IngressClass.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressClass.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.networking.v1.IngressClass". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.IngressClass.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.networking.v1.IngressClass".

---

### IngressClassList <a name="IngressClassList" id="cdk8s-metaflow.k8s.IngressClassList"></a>

IngressClassList is a collection of IngressClasses.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.IngressClassList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.IngressClassList(scope: Construct, id: string, props: IngressClassListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.IngressClassListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.IngressClassList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.IngressClassList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.IngressClassList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.IngressClassListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.IngressClassList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.IngressClassList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.IngressClassList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.IngressClassList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.IngressClassList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.IngressClassList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.networking.v1.IngressClassList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.IngressClassList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.IngressClassList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.IngressClassList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.IngressClassList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.IngressClassList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.IngressClassList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.IngressClassList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.IngressClassList.manifest(props: IngressClassListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.networking.v1.IngressClassList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.IngressClassList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.IngressClassListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.IngressClassList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.IngressClassList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.IngressClassList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.IngressClassList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.IngressClassList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.IngressClassList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.IngressClassList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.networking.v1.IngressClassList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.IngressClassList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.networking.v1.IngressClassList".

---

### IngressList <a name="IngressList" id="cdk8s-metaflow.k8s.IngressList"></a>

IngressList is a collection of Ingress.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.IngressList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.IngressList(scope: Construct, id: string, props: IngressListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.IngressListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.IngressList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.IngressList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.IngressList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.IngressListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.IngressList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.IngressList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.IngressList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.IngressList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.IngressList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.IngressList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.networking.v1.IngressList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.IngressList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.IngressList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.IngressList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.IngressList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.IngressList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.IngressList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.IngressList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.IngressList.manifest(props: IngressListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.networking.v1.IngressList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.IngressList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.IngressListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.IngressList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.IngressList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.IngressList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.IngressList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.IngressList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.IngressList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.IngressList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.networking.v1.IngressList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.IngressList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.networking.v1.IngressList".

---

### Job <a name="Job" id="cdk8s-metaflow.k8s.Job"></a>

Job represents the configuration of a single job.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.Job.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.Job(scope: Construct, id: string, props?: JobProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Job.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.Job.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.Job.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.JobProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.Job.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.Job.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Job.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.JobProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Job.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.Job.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.Job.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Job.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.Job.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.Job.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.Job.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.Job.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.Job.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.Job.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Job.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.Job.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.Job.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.batch.v1.Job". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.Job.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Job.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.Job.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.Job.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Job.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.Job.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.Job.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Job.manifest(props?: JobProps)
```

Renders a Kubernetes manifest for "io.k8s.api.batch.v1.Job".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Job.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.JobProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Job.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.Job.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.Job.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.Job.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.Job.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.Job.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Job.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.Job.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.Job.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.Job.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.Job.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.Job.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.Job.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Job.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Job.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.batch.v1.Job". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.Job.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.batch.v1.Job".

---

### JobList <a name="JobList" id="cdk8s-metaflow.k8s.JobList"></a>

JobList is a collection of jobs.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.JobList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.JobList(scope: Construct, id: string, props: JobListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.JobList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.JobList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.JobList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.JobListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.JobList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.JobList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.JobList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.JobListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.JobList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.JobList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.JobList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.JobList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.JobList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.JobList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.JobList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.JobList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.JobList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.JobList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.JobList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.JobList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.JobList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.batch.v1.JobList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.JobList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.JobList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.JobList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.JobList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.JobList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.JobList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.JobList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.JobList.manifest(props: JobListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.batch.v1.JobList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.JobList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.JobListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.JobList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.JobList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.JobList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.JobList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.JobList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.JobList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.JobList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.JobList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.JobList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.JobList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.JobList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.JobList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.JobList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.JobList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.JobList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.batch.v1.JobList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.JobList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.batch.v1.JobList".

---

### Lease <a name="Lease" id="cdk8s-metaflow.k8s.Lease"></a>

Lease defines a lease concept.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.Lease.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.Lease(scope: Construct, id: string, props?: LeaseProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Lease.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.Lease.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.Lease.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.LeaseProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.Lease.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.Lease.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Lease.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.LeaseProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Lease.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.Lease.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.Lease.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Lease.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.Lease.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.Lease.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.Lease.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.Lease.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.Lease.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.Lease.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Lease.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.Lease.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.Lease.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.coordination.v1.Lease". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.Lease.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Lease.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.Lease.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.Lease.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Lease.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.Lease.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.Lease.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Lease.manifest(props?: LeaseProps)
```

Renders a Kubernetes manifest for "io.k8s.api.coordination.v1.Lease".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Lease.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.LeaseProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Lease.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.Lease.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.Lease.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.Lease.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.Lease.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.Lease.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Lease.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.Lease.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.Lease.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.Lease.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.Lease.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.Lease.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.Lease.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Lease.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Lease.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.coordination.v1.Lease". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.Lease.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.coordination.v1.Lease".

---

### LeaseList <a name="LeaseList" id="cdk8s-metaflow.k8s.LeaseList"></a>

LeaseList is a list of Lease objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.LeaseList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.LeaseList(scope: Construct, id: string, props: LeaseListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.LeaseListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.LeaseList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.LeaseList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.LeaseList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.LeaseListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.LeaseList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.LeaseList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.LeaseList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.LeaseList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.LeaseList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.LeaseList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.coordination.v1.LeaseList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.LeaseList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.LeaseList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.LeaseList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.LeaseList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.LeaseList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.LeaseList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.LeaseList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.LeaseList.manifest(props: LeaseListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.coordination.v1.LeaseList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.LeaseList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.LeaseListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.LeaseList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.LeaseList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.LeaseList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.LeaseList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.LeaseList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.LeaseList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.LeaseList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LeaseList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.coordination.v1.LeaseList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.LeaseList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.coordination.v1.LeaseList".

---

### LimitRange <a name="LimitRange" id="cdk8s-metaflow.k8s.LimitRange"></a>

LimitRange sets resource usage limits for each kind of resource in a Namespace.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.LimitRange.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.LimitRange(scope: Construct, id: string, props?: LimitRangeProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.LimitRangeProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.LimitRange.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.LimitRange.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.LimitRange.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.LimitRangeProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.LimitRange.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.LimitRange.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.LimitRange.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.LimitRange.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.LimitRange.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.LimitRange.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.LimitRange". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.LimitRange.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.LimitRange.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.LimitRange.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.LimitRange.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.LimitRange.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.LimitRange.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.LimitRange.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.LimitRange.manifest(props?: LimitRangeProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.LimitRange".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.LimitRange.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.LimitRangeProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.LimitRange.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.LimitRange.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.LimitRange.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.LimitRange.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.LimitRange.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.LimitRange.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.LimitRange.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LimitRange.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.LimitRange". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.LimitRange.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.LimitRange".

---

### LimitRangeList <a name="LimitRangeList" id="cdk8s-metaflow.k8s.LimitRangeList"></a>

LimitRangeList is a list of LimitRange items.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.LimitRangeList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.LimitRangeList(scope: Construct, id: string, props: LimitRangeListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.LimitRangeListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.LimitRangeList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.LimitRangeList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.LimitRangeList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.LimitRangeListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.LimitRangeList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.LimitRangeList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.LimitRangeList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.LimitRangeList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.LimitRangeList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.LimitRangeList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.LimitRangeList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.LimitRangeList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.LimitRangeList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.LimitRangeList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.LimitRangeList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.LimitRangeList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.LimitRangeList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.LimitRangeList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.LimitRangeList.manifest(props: LimitRangeListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.LimitRangeList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.LimitRangeList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.LimitRangeListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.LimitRangeList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.LimitRangeList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.LimitRangeList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.LimitRangeList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.LimitRangeList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.LimitRangeList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.LimitRangeList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.LimitRangeList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.LimitRangeList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.LimitRangeList".

---

### LocalSubjectAccessReview <a name="LocalSubjectAccessReview" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview"></a>

LocalSubjectAccessReview checks whether or not a user or group can perform an action in a given namespace.

Having a namespace scoped resource makes it much easier to grant namespace scoped policy that includes permissions checking.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.LocalSubjectAccessReview(scope: Construct, id: string, props: LocalSubjectAccessReviewProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.LocalSubjectAccessReviewProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.LocalSubjectAccessReviewProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.authorization.v1.LocalSubjectAccessReview". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.LocalSubjectAccessReview.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.LocalSubjectAccessReview.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.LocalSubjectAccessReview.manifest(props: LocalSubjectAccessReviewProps)
```

Renders a Kubernetes manifest for "io.k8s.api.authorization.v1.LocalSubjectAccessReview".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.LocalSubjectAccessReviewProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReview.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.authorization.v1.LocalSubjectAccessReview". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.LocalSubjectAccessReview.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.authorization.v1.LocalSubjectAccessReview".

---

### MetadataDatabase <a name="MetadataDatabase" id="cdk8s-metaflow.MetadataDatabase"></a>

#### Initializers <a name="Initializers" id="cdk8s-metaflow.MetadataDatabase.Initializer"></a>

```typescript
import { MetadataDatabase } from 'cdk8s-metaflow'

new MetadataDatabase(scope: Construct, id: string, props: MetadataDatabaseProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.MetadataDatabase.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetadataDatabase.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetadataDatabase.Initializer.parameter.props">props</a></code> | <code><a href="#cdk8s-metaflow.MetadataDatabaseProps">MetadataDatabaseProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.MetadataDatabase.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.MetadataDatabase.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.MetadataDatabase.Initializer.parameter.props"></a>

- *Type:* <a href="#cdk8s-metaflow.MetadataDatabaseProps">MetadataDatabaseProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.MetadataDatabase.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.MetadataDatabase.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.MetadataDatabase.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.MetadataDatabase.isConstruct"></a>

```typescript
import { MetadataDatabase } from 'cdk8s-metaflow'

MetadataDatabase.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.MetadataDatabase.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.MetadataDatabase.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.MetadataDatabase.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---


### MetaflowService <a name="MetaflowService" id="cdk8s-metaflow.MetaflowService"></a>

#### Initializers <a name="Initializers" id="cdk8s-metaflow.MetaflowService.Initializer"></a>

```typescript
import { MetaflowService } from 'cdk8s-metaflow'

new MetaflowService(scope: Construct, id: string, props: MetaflowServiceProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.MetaflowService.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowService.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowService.Initializer.parameter.props">props</a></code> | <code><a href="#cdk8s-metaflow.MetaflowServiceProps">MetaflowServiceProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.MetaflowService.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.MetaflowService.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.MetaflowService.Initializer.parameter.props"></a>

- *Type:* <a href="#cdk8s-metaflow.MetaflowServiceProps">MetaflowServiceProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.MetaflowService.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.MetaflowService.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.MetaflowService.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.MetaflowService.isConstruct"></a>

```typescript
import { MetaflowService } from 'cdk8s-metaflow'

MetaflowService.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.MetaflowService.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.MetaflowService.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.MetaflowService.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---


### MetaflowUI <a name="MetaflowUI" id="cdk8s-metaflow.MetaflowUI"></a>

#### Initializers <a name="Initializers" id="cdk8s-metaflow.MetaflowUI.Initializer"></a>

```typescript
import { MetaflowUI } from 'cdk8s-metaflow'

new MetaflowUI(scope: Construct, id: string, props: MetaflowUIProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.MetaflowUI.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUI.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUI.Initializer.parameter.props">props</a></code> | <code><a href="#cdk8s-metaflow.MetaflowUIProps">MetaflowUIProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.MetaflowUI.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.MetaflowUI.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.MetaflowUI.Initializer.parameter.props"></a>

- *Type:* <a href="#cdk8s-metaflow.MetaflowUIProps">MetaflowUIProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.MetaflowUI.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.MetaflowUI.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.MetaflowUI.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.MetaflowUI.isConstruct"></a>

```typescript
import { MetaflowUI } from 'cdk8s-metaflow'

MetaflowUI.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.MetaflowUI.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.MetaflowUI.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.MetaflowUI.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---


### MutatingWebhookConfiguration <a name="MutatingWebhookConfiguration" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration"></a>

MutatingWebhookConfiguration describes the configuration of and admission webhook that accept or reject and may change the object.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.MutatingWebhookConfiguration(scope: Construct, id: string, props?: MutatingWebhookConfigurationProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.MutatingWebhookConfigurationProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.MutatingWebhookConfigurationProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.admissionregistration.v1.MutatingWebhookConfiguration". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.MutatingWebhookConfiguration.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.MutatingWebhookConfiguration.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.MutatingWebhookConfiguration.manifest(props?: MutatingWebhookConfigurationProps)
```

Renders a Kubernetes manifest for "io.k8s.api.admissionregistration.v1.MutatingWebhookConfiguration".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.MutatingWebhookConfigurationProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfiguration.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.admissionregistration.v1.MutatingWebhookConfiguration". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.MutatingWebhookConfiguration.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.admissionregistration.v1.MutatingWebhookConfiguration".

---

### MutatingWebhookConfigurationList <a name="MutatingWebhookConfigurationList" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList"></a>

MutatingWebhookConfigurationList is a list of MutatingWebhookConfiguration.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.MutatingWebhookConfigurationList(scope: Construct, id: string, props: MutatingWebhookConfigurationListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.MutatingWebhookConfigurationListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.MutatingWebhookConfigurationListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.admissionregistration.v1.MutatingWebhookConfigurationList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.MutatingWebhookConfigurationList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.MutatingWebhookConfigurationList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.MutatingWebhookConfigurationList.manifest(props: MutatingWebhookConfigurationListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.admissionregistration.v1.MutatingWebhookConfigurationList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.MutatingWebhookConfigurationListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.admissionregistration.v1.MutatingWebhookConfigurationList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.admissionregistration.v1.MutatingWebhookConfigurationList".

---

### Namespace <a name="Namespace" id="cdk8s-metaflow.k8s.Namespace"></a>

Namespace provides a scope for Names.

Use of multiple namespaces is optional.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.Namespace.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.Namespace(scope: Construct, id: string, props?: NamespaceProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.NamespaceProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.Namespace.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.Namespace.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Namespace.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.NamespaceProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.Namespace.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.Namespace.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.Namespace.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.Namespace.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.Namespace.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.Namespace.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.Namespace". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.Namespace.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Namespace.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.Namespace.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.Namespace.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Namespace.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.Namespace.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.Namespace.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Namespace.manifest(props?: NamespaceProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.Namespace".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Namespace.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.NamespaceProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.Namespace.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.Namespace.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.Namespace.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.Namespace.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.Namespace.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.Namespace.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Namespace.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Namespace.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.Namespace". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.Namespace.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.Namespace".

---

### NamespaceList <a name="NamespaceList" id="cdk8s-metaflow.k8s.NamespaceList"></a>

NamespaceList is a list of Namespaces.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.NamespaceList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.NamespaceList(scope: Construct, id: string, props: NamespaceListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.NamespaceListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.NamespaceList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.NamespaceList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.NamespaceList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.NamespaceListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.NamespaceList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.NamespaceList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.NamespaceList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.NamespaceList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.NamespaceList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.NamespaceList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.NamespaceList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.NamespaceList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.NamespaceList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.NamespaceList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.NamespaceList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.NamespaceList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.NamespaceList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.NamespaceList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.NamespaceList.manifest(props: NamespaceListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.NamespaceList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.NamespaceList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.NamespaceListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.NamespaceList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.NamespaceList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.NamespaceList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.NamespaceList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.NamespaceList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.NamespaceList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.NamespaceList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.NamespaceList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.NamespaceList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.NamespaceList".

---

### NetworkPolicy <a name="NetworkPolicy" id="cdk8s-metaflow.k8s.NetworkPolicy"></a>

NetworkPolicy describes what network traffic is allowed for a set of Pods.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.NetworkPolicy.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.NetworkPolicy(scope: Construct, id: string, props?: NetworkPolicyProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.NetworkPolicyProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.NetworkPolicy.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.NetworkPolicy.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.NetworkPolicy.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.NetworkPolicyProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.NetworkPolicy.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.NetworkPolicy.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.NetworkPolicy.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.NetworkPolicy.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.NetworkPolicy.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.NetworkPolicy.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.networking.v1.NetworkPolicy". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.NetworkPolicy.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.NetworkPolicy.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.NetworkPolicy.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.NetworkPolicy.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.NetworkPolicy.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.NetworkPolicy.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.NetworkPolicy.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.NetworkPolicy.manifest(props?: NetworkPolicyProps)
```

Renders a Kubernetes manifest for "io.k8s.api.networking.v1.NetworkPolicy".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.NetworkPolicy.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.NetworkPolicyProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.NetworkPolicy.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.NetworkPolicy.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.NetworkPolicy.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.NetworkPolicy.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.NetworkPolicy.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.NetworkPolicy.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.NetworkPolicy.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicy.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.networking.v1.NetworkPolicy". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.NetworkPolicy.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.networking.v1.NetworkPolicy".

---

### NetworkPolicyList <a name="NetworkPolicyList" id="cdk8s-metaflow.k8s.NetworkPolicyList"></a>

NetworkPolicyList is a list of NetworkPolicy objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.NetworkPolicyList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.NetworkPolicyList(scope: Construct, id: string, props: NetworkPolicyListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.NetworkPolicyListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.NetworkPolicyList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.NetworkPolicyList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.NetworkPolicyList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.NetworkPolicyListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.NetworkPolicyList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.NetworkPolicyList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.NetworkPolicyList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.NetworkPolicyList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.NetworkPolicyList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.NetworkPolicyList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.networking.v1.NetworkPolicyList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.NetworkPolicyList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.NetworkPolicyList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.NetworkPolicyList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.NetworkPolicyList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.NetworkPolicyList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.NetworkPolicyList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.NetworkPolicyList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.NetworkPolicyList.manifest(props: NetworkPolicyListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.networking.v1.NetworkPolicyList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.NetworkPolicyList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.NetworkPolicyListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.NetworkPolicyList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.NetworkPolicyList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.NetworkPolicyList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.NetworkPolicyList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.NetworkPolicyList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.NetworkPolicyList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.NetworkPolicyList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.networking.v1.NetworkPolicyList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.NetworkPolicyList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.networking.v1.NetworkPolicyList".

---

### Node <a name="Node" id="cdk8s-metaflow.k8s.Node"></a>

Node is a worker node in Kubernetes.

Each node will have a unique identifier in the cache (i.e. in etcd).

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.Node.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.Node(scope: Construct, id: string, props?: NodeProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Node.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.Node.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.Node.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.NodeProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.Node.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.Node.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Node.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.NodeProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Node.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.Node.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.Node.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Node.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.Node.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.Node.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.Node.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.Node.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.Node.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.Node.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Node.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.Node.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.Node.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.Node". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.Node.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Node.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.Node.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.Node.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Node.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.Node.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.Node.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Node.manifest(props?: NodeProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.Node".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Node.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.NodeProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Node.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.Node.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.Node.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.Node.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.Node.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.Node.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Node.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.Node.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.Node.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.Node.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.Node.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.Node.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.Node.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Node.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Node.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.Node". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.Node.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.Node".

---

### NodeList <a name="NodeList" id="cdk8s-metaflow.k8s.NodeList"></a>

NodeList is the whole list of all Nodes which have been registered with master.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.NodeList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.NodeList(scope: Construct, id: string, props: NodeListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.NodeListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.NodeList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.NodeList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.NodeList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.NodeListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.NodeList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.NodeList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.NodeList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.NodeList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.NodeList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.NodeList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.NodeList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.NodeList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.NodeList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.NodeList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.NodeList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.NodeList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.NodeList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.NodeList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.NodeList.manifest(props: NodeListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.NodeList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.NodeList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.NodeListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.NodeList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.NodeList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.NodeList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.NodeList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.NodeList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.NodeList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.NodeList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NodeList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.NodeList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.NodeList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.NodeList".

---

### PersistentVolume <a name="PersistentVolume" id="cdk8s-metaflow.k8s.PersistentVolume"></a>

PersistentVolume (PV) is a storage resource provisioned by an administrator.

It is analogous to a node. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PersistentVolume.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PersistentVolume(scope: Construct, id: string, props?: PersistentVolumeProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PersistentVolumeProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PersistentVolume.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PersistentVolume.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.PersistentVolume.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PersistentVolumeProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PersistentVolume.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PersistentVolume.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PersistentVolume.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PersistentVolume.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PersistentVolume.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PersistentVolume.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.PersistentVolume". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PersistentVolume.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PersistentVolume.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PersistentVolume.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PersistentVolume.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PersistentVolume.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PersistentVolume.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PersistentVolume.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PersistentVolume.manifest(props?: PersistentVolumeProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.PersistentVolume".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.PersistentVolume.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PersistentVolumeProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PersistentVolume.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PersistentVolume.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PersistentVolume.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PersistentVolume.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PersistentVolume.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PersistentVolume.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PersistentVolume.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolume.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.PersistentVolume". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PersistentVolume.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.PersistentVolume".

---

### PersistentVolumeClaim <a name="PersistentVolumeClaim" id="cdk8s-metaflow.k8s.PersistentVolumeClaim"></a>

PersistentVolumeClaim is a user's request for and claim to a persistent volume.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PersistentVolumeClaim(scope: Construct, id: string, props?: PersistentVolumeClaimProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PersistentVolumeClaimProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PersistentVolumeClaimProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.PersistentVolumeClaim". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PersistentVolumeClaim.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PersistentVolumeClaim.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PersistentVolumeClaim.manifest(props?: PersistentVolumeClaimProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.PersistentVolumeClaim".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PersistentVolumeClaimProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaim.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.PersistentVolumeClaim". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PersistentVolumeClaim.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.PersistentVolumeClaim".

---

### PersistentVolumeClaimList <a name="PersistentVolumeClaimList" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList"></a>

PersistentVolumeClaimList is a list of PersistentVolumeClaim items.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PersistentVolumeClaimList(scope: Construct, id: string, props: PersistentVolumeClaimListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PersistentVolumeClaimListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PersistentVolumeClaimListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.PersistentVolumeClaimList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PersistentVolumeClaimList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PersistentVolumeClaimList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PersistentVolumeClaimList.manifest(props: PersistentVolumeClaimListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.PersistentVolumeClaimList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PersistentVolumeClaimListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.PersistentVolumeClaimList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PersistentVolumeClaimList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.PersistentVolumeClaimList".

---

### PersistentVolumeList <a name="PersistentVolumeList" id="cdk8s-metaflow.k8s.PersistentVolumeList"></a>

PersistentVolumeList is a list of PersistentVolume items.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PersistentVolumeList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PersistentVolumeList(scope: Construct, id: string, props: PersistentVolumeListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PersistentVolumeListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PersistentVolumeList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PersistentVolumeList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PersistentVolumeList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PersistentVolumeListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PersistentVolumeList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PersistentVolumeList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PersistentVolumeList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PersistentVolumeList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PersistentVolumeList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PersistentVolumeList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.PersistentVolumeList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PersistentVolumeList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PersistentVolumeList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PersistentVolumeList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PersistentVolumeList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PersistentVolumeList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PersistentVolumeList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PersistentVolumeList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PersistentVolumeList.manifest(props: PersistentVolumeListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.PersistentVolumeList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PersistentVolumeList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PersistentVolumeListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PersistentVolumeList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PersistentVolumeList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PersistentVolumeList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PersistentVolumeList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PersistentVolumeList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PersistentVolumeList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PersistentVolumeList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.PersistentVolumeList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PersistentVolumeList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.PersistentVolumeList".

---

### Pod <a name="Pod" id="cdk8s-metaflow.k8s.Pod"></a>

Pod is a collection of containers that can run on a host.

This resource is created by clients and scheduled onto hosts.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.Pod.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.Pod(scope: Construct, id: string, props?: PodProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Pod.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.Pod.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.Pod.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PodProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.Pod.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.Pod.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Pod.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Pod.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.Pod.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.Pod.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Pod.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.Pod.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.Pod.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.Pod.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.Pod.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.Pod.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.Pod.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Pod.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.Pod.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.Pod.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.Pod". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.Pod.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Pod.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.Pod.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.Pod.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Pod.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.Pod.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.Pod.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Pod.manifest(props?: PodProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.Pod".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Pod.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Pod.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.Pod.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.Pod.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.Pod.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.Pod.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.Pod.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Pod.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.Pod.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.Pod.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.Pod.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.Pod.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.Pod.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.Pod.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Pod.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Pod.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.Pod". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.Pod.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.Pod".

---

### PodDisruptionBudget <a name="PodDisruptionBudget" id="cdk8s-metaflow.k8s.PodDisruptionBudget"></a>

PodDisruptionBudget is an object to define the max disruption that can be caused to a collection of pods.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PodDisruptionBudget.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PodDisruptionBudget(scope: Construct, id: string, props?: PodDisruptionBudgetProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PodDisruptionBudgetProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PodDisruptionBudget.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PodDisruptionBudget.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.PodDisruptionBudget.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodDisruptionBudgetProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PodDisruptionBudget.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PodDisruptionBudget.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PodDisruptionBudget.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PodDisruptionBudget.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PodDisruptionBudget.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PodDisruptionBudget.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.policy.v1.PodDisruptionBudget". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PodDisruptionBudget.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodDisruptionBudget.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PodDisruptionBudget.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PodDisruptionBudget.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodDisruptionBudget.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PodDisruptionBudget.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PodDisruptionBudget.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodDisruptionBudget.manifest(props?: PodDisruptionBudgetProps)
```

Renders a Kubernetes manifest for "io.k8s.api.policy.v1.PodDisruptionBudget".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.PodDisruptionBudget.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodDisruptionBudgetProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PodDisruptionBudget.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PodDisruptionBudget.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PodDisruptionBudget.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PodDisruptionBudget.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PodDisruptionBudget.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodDisruptionBudget.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PodDisruptionBudget.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudget.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.policy.v1.PodDisruptionBudget". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PodDisruptionBudget.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.policy.v1.PodDisruptionBudget".

---

### PodDisruptionBudgetList <a name="PodDisruptionBudgetList" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList"></a>

PodDisruptionBudgetList is a collection of PodDisruptionBudgets.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PodDisruptionBudgetList(scope: Construct, id: string, props: PodDisruptionBudgetListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PodDisruptionBudgetListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodDisruptionBudgetListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.policy.v1.PodDisruptionBudgetList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodDisruptionBudgetList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodDisruptionBudgetList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodDisruptionBudgetList.manifest(props: PodDisruptionBudgetListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.policy.v1.PodDisruptionBudgetList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodDisruptionBudgetListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.policy.v1.PodDisruptionBudgetList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PodDisruptionBudgetList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.policy.v1.PodDisruptionBudgetList".

---

### PodDisruptionBudgetListV1Beta1 <a name="PodDisruptionBudgetListV1Beta1" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1"></a>

PodDisruptionBudgetList is a collection of PodDisruptionBudgets.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PodDisruptionBudgetListV1Beta1(scope: Construct, id: string, props: PodDisruptionBudgetListV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.policy.v1beta1.PodDisruptionBudgetList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodDisruptionBudgetListV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodDisruptionBudgetListV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodDisruptionBudgetListV1Beta1.manifest(props: PodDisruptionBudgetListV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.policy.v1beta1.PodDisruptionBudgetList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.policy.v1beta1.PodDisruptionBudgetList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.policy.v1beta1.PodDisruptionBudgetList".

---

### PodDisruptionBudgetV1Beta1 <a name="PodDisruptionBudgetV1Beta1" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1"></a>

PodDisruptionBudget is an object to define the max disruption that can be caused to a collection of pods.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PodDisruptionBudgetV1Beta1(scope: Construct, id: string, props?: PodDisruptionBudgetV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.policy.v1beta1.PodDisruptionBudget". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodDisruptionBudgetV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodDisruptionBudgetV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodDisruptionBudgetV1Beta1.manifest(props?: PodDisruptionBudgetV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.policy.v1beta1.PodDisruptionBudget".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.policy.v1beta1.PodDisruptionBudget". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.policy.v1beta1.PodDisruptionBudget".

---

### PodList <a name="PodList" id="cdk8s-metaflow.k8s.PodList"></a>

PodList is a list of Pods.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PodList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PodList(scope: Construct, id: string, props: PodListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PodList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PodList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PodListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PodList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PodList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PodList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PodList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PodList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PodList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PodList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PodList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PodList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PodList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.PodList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PodList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PodList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PodList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PodList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PodList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodList.manifest(props: PodListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.PodList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PodList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PodList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PodList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PodList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PodList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PodList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PodList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PodList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PodList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PodList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PodList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PodList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.PodList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PodList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.PodList".

---

### PodSecurityPolicyListV1Beta1 <a name="PodSecurityPolicyListV1Beta1" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1"></a>

PodSecurityPolicyList is a list of PodSecurityPolicy objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PodSecurityPolicyListV1Beta1(scope: Construct, id: string, props: PodSecurityPolicyListV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.policy.v1beta1.PodSecurityPolicyList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodSecurityPolicyListV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodSecurityPolicyListV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodSecurityPolicyListV1Beta1.manifest(props: PodSecurityPolicyListV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.policy.v1beta1.PodSecurityPolicyList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.policy.v1beta1.PodSecurityPolicyList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.policy.v1beta1.PodSecurityPolicyList".

---

### PodSecurityPolicyV1Beta1 <a name="PodSecurityPolicyV1Beta1" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1"></a>

PodSecurityPolicy governs the ability to make requests that affect the Security Context that will be applied to a pod and container.

Deprecated in 1.21.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PodSecurityPolicyV1Beta1(scope: Construct, id: string, props?: PodSecurityPolicyV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.policy.v1beta1.PodSecurityPolicy". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodSecurityPolicyV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodSecurityPolicyV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodSecurityPolicyV1Beta1.manifest(props?: PodSecurityPolicyV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.policy.v1beta1.PodSecurityPolicy".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.policy.v1beta1.PodSecurityPolicy". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.policy.v1beta1.PodSecurityPolicy".

---

### PodTemplate <a name="PodTemplate" id="cdk8s-metaflow.k8s.PodTemplate"></a>

PodTemplate describes a template for creating copies of a predefined pod.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PodTemplate.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PodTemplate(scope: Construct, id: string, props?: PodTemplateProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PodTemplateProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PodTemplate.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PodTemplate.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.PodTemplate.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodTemplateProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PodTemplate.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PodTemplate.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PodTemplate.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PodTemplate.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PodTemplate.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PodTemplate.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.PodTemplate". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PodTemplate.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodTemplate.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PodTemplate.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PodTemplate.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodTemplate.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PodTemplate.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PodTemplate.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodTemplate.manifest(props?: PodTemplateProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.PodTemplate".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.PodTemplate.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodTemplateProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PodTemplate.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PodTemplate.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PodTemplate.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PodTemplate.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PodTemplate.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodTemplate.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PodTemplate.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplate.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.PodTemplate". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PodTemplate.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.PodTemplate".

---

### PodTemplateList <a name="PodTemplateList" id="cdk8s-metaflow.k8s.PodTemplateList"></a>

PodTemplateList is a list of PodTemplates.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PodTemplateList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PodTemplateList(scope: Construct, id: string, props: PodTemplateListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PodTemplateListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PodTemplateList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PodTemplateList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PodTemplateList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodTemplateListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PodTemplateList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PodTemplateList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PodTemplateList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PodTemplateList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PodTemplateList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PodTemplateList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.PodTemplateList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PodTemplateList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodTemplateList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PodTemplateList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PodTemplateList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodTemplateList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PodTemplateList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PodTemplateList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PodTemplateList.manifest(props: PodTemplateListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.PodTemplateList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PodTemplateList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PodTemplateListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PodTemplateList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PodTemplateList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PodTemplateList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PodTemplateList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PodTemplateList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodTemplateList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PodTemplateList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.PodTemplateList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PodTemplateList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.PodTemplateList".

---

### PriorityClass <a name="PriorityClass" id="cdk8s-metaflow.k8s.PriorityClass"></a>

PriorityClass defines mapping from a priority class name to the priority integer value.

The value can be any valid integer.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PriorityClass.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PriorityClass(scope: Construct, id: string, props: PriorityClassProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PriorityClassProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PriorityClass.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PriorityClass.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PriorityClass.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PriorityClassProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PriorityClass.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PriorityClass.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PriorityClass.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PriorityClass.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PriorityClass.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PriorityClass.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.scheduling.v1.PriorityClass". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PriorityClass.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityClass.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PriorityClass.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PriorityClass.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityClass.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PriorityClass.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PriorityClass.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityClass.manifest(props: PriorityClassProps)
```

Renders a Kubernetes manifest for "io.k8s.api.scheduling.v1.PriorityClass".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PriorityClass.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PriorityClassProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PriorityClass.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PriorityClass.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PriorityClass.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PriorityClass.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PriorityClass.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PriorityClass.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PriorityClass.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClass.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.scheduling.v1.PriorityClass". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PriorityClass.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.scheduling.v1.PriorityClass".

---

### PriorityClassList <a name="PriorityClassList" id="cdk8s-metaflow.k8s.PriorityClassList"></a>

PriorityClassList is a collection of priority classes.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PriorityClassList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PriorityClassList(scope: Construct, id: string, props: PriorityClassListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PriorityClassListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PriorityClassList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PriorityClassList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PriorityClassList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PriorityClassListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PriorityClassList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PriorityClassList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PriorityClassList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PriorityClassList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PriorityClassList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PriorityClassList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.scheduling.v1.PriorityClassList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PriorityClassList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityClassList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PriorityClassList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PriorityClassList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityClassList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PriorityClassList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PriorityClassList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityClassList.manifest(props: PriorityClassListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.scheduling.v1.PriorityClassList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PriorityClassList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PriorityClassListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PriorityClassList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PriorityClassList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PriorityClassList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PriorityClassList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PriorityClassList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PriorityClassList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PriorityClassList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.scheduling.v1.PriorityClassList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PriorityClassList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.scheduling.v1.PriorityClassList".

---

### PriorityClassListV1Alpha1 <a name="PriorityClassListV1Alpha1" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1"></a>

PriorityClassList is a collection of priority classes.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PriorityClassListV1Alpha1(scope: Construct, id: string, props: PriorityClassListV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PriorityClassListV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PriorityClassListV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.scheduling.v1alpha1.PriorityClassList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityClassListV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityClassListV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityClassListV1Alpha1.manifest(props: PriorityClassListV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.scheduling.v1alpha1.PriorityClassList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PriorityClassListV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.scheduling.v1alpha1.PriorityClassList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.scheduling.v1alpha1.PriorityClassList".

---

### PriorityClassV1Alpha1 <a name="PriorityClassV1Alpha1" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1"></a>

DEPRECATED - This group version of PriorityClass is deprecated by scheduling.k8s.io/v1/PriorityClass. PriorityClass defines mapping from a priority class name to the priority integer value. The value can be any valid integer.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PriorityClassV1Alpha1(scope: Construct, id: string, props: PriorityClassV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PriorityClassV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PriorityClassV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.scheduling.v1alpha1.PriorityClass". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityClassV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityClassV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityClassV1Alpha1.manifest(props: PriorityClassV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.scheduling.v1alpha1.PriorityClass".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PriorityClassV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.scheduling.v1alpha1.PriorityClass". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.scheduling.v1alpha1.PriorityClass".

---

### PriorityLevelConfigurationListV1Beta1 <a name="PriorityLevelConfigurationListV1Beta1" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1"></a>

PriorityLevelConfigurationList is a list of PriorityLevelConfiguration objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PriorityLevelConfigurationListV1Beta1(scope: Construct, id: string, props: PriorityLevelConfigurationListV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.flowcontrol.v1beta1.PriorityLevelConfigurationList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityLevelConfigurationListV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityLevelConfigurationListV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityLevelConfigurationListV1Beta1.manifest(props: PriorityLevelConfigurationListV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.flowcontrol.v1beta1.PriorityLevelConfigurationList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.flowcontrol.v1beta1.PriorityLevelConfigurationList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.flowcontrol.v1beta1.PriorityLevelConfigurationList".

---

### PriorityLevelConfigurationV1Beta1 <a name="PriorityLevelConfigurationV1Beta1" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1"></a>

PriorityLevelConfiguration represents the configuration of a priority level.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.PriorityLevelConfigurationV1Beta1(scope: Construct, id: string, props?: PriorityLevelConfigurationV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.flowcontrol.v1beta1.PriorityLevelConfiguration". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityLevelConfigurationV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityLevelConfigurationV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.PriorityLevelConfigurationV1Beta1.manifest(props?: PriorityLevelConfigurationV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.flowcontrol.v1beta1.PriorityLevelConfiguration".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.flowcontrol.v1beta1.PriorityLevelConfiguration". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.flowcontrol.v1beta1.PriorityLevelConfiguration".

---

### ReplicaSet <a name="ReplicaSet" id="cdk8s-metaflow.k8s.ReplicaSet"></a>

ReplicaSet ensures that a specified number of pod replicas are running at any given time.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ReplicaSet.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ReplicaSet(scope: Construct, id: string, props?: ReplicaSetProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ReplicaSetProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ReplicaSet.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ReplicaSet.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ReplicaSet.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ReplicaSetProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ReplicaSet.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ReplicaSet.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ReplicaSet.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ReplicaSet.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ReplicaSet.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ReplicaSet.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.apps.v1.ReplicaSet". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ReplicaSet.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ReplicaSet.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ReplicaSet.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ReplicaSet.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ReplicaSet.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ReplicaSet.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ReplicaSet.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ReplicaSet.manifest(props?: ReplicaSetProps)
```

Renders a Kubernetes manifest for "io.k8s.api.apps.v1.ReplicaSet".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ReplicaSet.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ReplicaSetProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ReplicaSet.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ReplicaSet.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ReplicaSet.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ReplicaSet.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ReplicaSet.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ReplicaSet.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ReplicaSet.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSet.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.apps.v1.ReplicaSet". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ReplicaSet.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.apps.v1.ReplicaSet".

---

### ReplicaSetList <a name="ReplicaSetList" id="cdk8s-metaflow.k8s.ReplicaSetList"></a>

ReplicaSetList is a collection of ReplicaSets.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ReplicaSetList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ReplicaSetList(scope: Construct, id: string, props: ReplicaSetListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ReplicaSetListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ReplicaSetList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ReplicaSetList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ReplicaSetList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ReplicaSetListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ReplicaSetList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ReplicaSetList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ReplicaSetList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ReplicaSetList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ReplicaSetList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ReplicaSetList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.apps.v1.ReplicaSetList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ReplicaSetList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ReplicaSetList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ReplicaSetList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ReplicaSetList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ReplicaSetList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ReplicaSetList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ReplicaSetList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ReplicaSetList.manifest(props: ReplicaSetListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.apps.v1.ReplicaSetList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ReplicaSetList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ReplicaSetListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ReplicaSetList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ReplicaSetList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ReplicaSetList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ReplicaSetList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ReplicaSetList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ReplicaSetList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ReplicaSetList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.apps.v1.ReplicaSetList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ReplicaSetList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.apps.v1.ReplicaSetList".

---

### ReplicationController <a name="ReplicationController" id="cdk8s-metaflow.k8s.ReplicationController"></a>

ReplicationController represents the configuration of a replication controller.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ReplicationController.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ReplicationController(scope: Construct, id: string, props?: ReplicationControllerProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ReplicationControllerProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ReplicationController.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ReplicationController.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ReplicationController.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ReplicationControllerProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ReplicationController.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ReplicationController.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ReplicationController.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ReplicationController.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ReplicationController.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ReplicationController.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.ReplicationController". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ReplicationController.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ReplicationController.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ReplicationController.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ReplicationController.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ReplicationController.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ReplicationController.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ReplicationController.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ReplicationController.manifest(props?: ReplicationControllerProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.ReplicationController".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ReplicationController.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ReplicationControllerProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ReplicationController.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ReplicationController.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ReplicationController.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ReplicationController.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ReplicationController.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ReplicationController.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ReplicationController.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationController.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.ReplicationController". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ReplicationController.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.ReplicationController".

---

### ReplicationControllerList <a name="ReplicationControllerList" id="cdk8s-metaflow.k8s.ReplicationControllerList"></a>

ReplicationControllerList is a collection of replication controllers.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ReplicationControllerList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ReplicationControllerList(scope: Construct, id: string, props: ReplicationControllerListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ReplicationControllerListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ReplicationControllerList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ReplicationControllerList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ReplicationControllerList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ReplicationControllerListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ReplicationControllerList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ReplicationControllerList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ReplicationControllerList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ReplicationControllerList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ReplicationControllerList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ReplicationControllerList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.ReplicationControllerList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ReplicationControllerList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ReplicationControllerList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ReplicationControllerList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ReplicationControllerList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ReplicationControllerList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ReplicationControllerList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ReplicationControllerList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ReplicationControllerList.manifest(props: ReplicationControllerListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.ReplicationControllerList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ReplicationControllerList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ReplicationControllerListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ReplicationControllerList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ReplicationControllerList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ReplicationControllerList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ReplicationControllerList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ReplicationControllerList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ReplicationControllerList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ReplicationControllerList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.ReplicationControllerList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ReplicationControllerList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.ReplicationControllerList".

---

### ResourceQuota <a name="ResourceQuota" id="cdk8s-metaflow.k8s.ResourceQuota"></a>

ResourceQuota sets aggregate quota restrictions enforced per namespace.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ResourceQuota.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ResourceQuota(scope: Construct, id: string, props?: ResourceQuotaProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ResourceQuotaProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ResourceQuota.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ResourceQuota.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ResourceQuota.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ResourceQuotaProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ResourceQuota.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ResourceQuota.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ResourceQuota.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ResourceQuota.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ResourceQuota.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ResourceQuota.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.ResourceQuota". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ResourceQuota.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ResourceQuota.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ResourceQuota.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ResourceQuota.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ResourceQuota.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ResourceQuota.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ResourceQuota.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ResourceQuota.manifest(props?: ResourceQuotaProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.ResourceQuota".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ResourceQuota.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ResourceQuotaProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ResourceQuota.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ResourceQuota.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ResourceQuota.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ResourceQuota.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ResourceQuota.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ResourceQuota.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ResourceQuota.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuota.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.ResourceQuota". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ResourceQuota.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.ResourceQuota".

---

### ResourceQuotaList <a name="ResourceQuotaList" id="cdk8s-metaflow.k8s.ResourceQuotaList"></a>

ResourceQuotaList is a list of ResourceQuota items.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ResourceQuotaList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ResourceQuotaList(scope: Construct, id: string, props: ResourceQuotaListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ResourceQuotaListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ResourceQuotaList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ResourceQuotaList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ResourceQuotaList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ResourceQuotaListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ResourceQuotaList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ResourceQuotaList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ResourceQuotaList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ResourceQuotaList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ResourceQuotaList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ResourceQuotaList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.ResourceQuotaList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ResourceQuotaList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ResourceQuotaList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ResourceQuotaList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ResourceQuotaList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ResourceQuotaList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ResourceQuotaList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ResourceQuotaList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ResourceQuotaList.manifest(props: ResourceQuotaListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.ResourceQuotaList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ResourceQuotaList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ResourceQuotaListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ResourceQuotaList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ResourceQuotaList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ResourceQuotaList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ResourceQuotaList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ResourceQuotaList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ResourceQuotaList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ResourceQuotaList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.ResourceQuotaList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ResourceQuotaList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.ResourceQuotaList".

---

### Role <a name="Role" id="cdk8s-metaflow.k8s.Role"></a>

Role is a namespaced, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.Role.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.Role(scope: Construct, id: string, props?: RoleProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Role.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.Role.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.Role.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.RoleProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.Role.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.Role.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Role.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RoleProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Role.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.Role.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.Role.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Role.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.Role.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.Role.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.Role.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.Role.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.Role.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.Role.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Role.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.Role.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.Role.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.rbac.v1.Role". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.Role.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Role.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.Role.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.Role.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Role.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.Role.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.Role.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Role.manifest(props?: RoleProps)
```

Renders a Kubernetes manifest for "io.k8s.api.rbac.v1.Role".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Role.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RoleProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Role.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.Role.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.Role.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.Role.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.Role.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.Role.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Role.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.Role.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.Role.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.Role.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.Role.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.Role.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.Role.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Role.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Role.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.rbac.v1.Role". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.Role.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.rbac.v1.Role".

---

### RoleBinding <a name="RoleBinding" id="cdk8s-metaflow.k8s.RoleBinding"></a>

RoleBinding references a role, but does not contain it.

It can reference a Role in the same namespace or a ClusterRole in the global namespace. It adds who information via Subjects and namespace information by which namespace it exists in.  RoleBindings in a given namespace only have effect in that namespace.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.RoleBinding.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.RoleBinding(scope: Construct, id: string, props: RoleBindingProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.RoleBindingProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.RoleBinding.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.RoleBinding.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RoleBinding.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RoleBindingProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.RoleBinding.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.RoleBinding.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.RoleBinding.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.RoleBinding.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.RoleBinding.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.RoleBinding.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.rbac.v1.RoleBinding". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.RoleBinding.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleBinding.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.RoleBinding.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.RoleBinding.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleBinding.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.RoleBinding.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.RoleBinding.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleBinding.manifest(props: RoleBindingProps)
```

Renders a Kubernetes manifest for "io.k8s.api.rbac.v1.RoleBinding".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RoleBinding.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RoleBindingProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.RoleBinding.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.RoleBinding.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.RoleBinding.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.RoleBinding.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.RoleBinding.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RoleBinding.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.RoleBinding.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBinding.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.rbac.v1.RoleBinding". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.RoleBinding.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.rbac.v1.RoleBinding".

---

### RoleBindingList <a name="RoleBindingList" id="cdk8s-metaflow.k8s.RoleBindingList"></a>

RoleBindingList is a collection of RoleBindings.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.RoleBindingList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.RoleBindingList(scope: Construct, id: string, props: RoleBindingListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.RoleBindingListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.RoleBindingList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.RoleBindingList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RoleBindingList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RoleBindingListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.RoleBindingList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.RoleBindingList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.RoleBindingList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.RoleBindingList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.RoleBindingList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.RoleBindingList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.rbac.v1.RoleBindingList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.RoleBindingList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleBindingList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.RoleBindingList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.RoleBindingList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleBindingList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.RoleBindingList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.RoleBindingList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleBindingList.manifest(props: RoleBindingListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.rbac.v1.RoleBindingList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RoleBindingList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RoleBindingListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.RoleBindingList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.RoleBindingList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.RoleBindingList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.RoleBindingList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.RoleBindingList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RoleBindingList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.RoleBindingList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.rbac.v1.RoleBindingList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.RoleBindingList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.rbac.v1.RoleBindingList".

---

### RoleBindingListV1Alpha1 <a name="RoleBindingListV1Alpha1" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1"></a>

RoleBindingList is a collection of RoleBindings Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 RoleBindingList, and will no longer be served in v1.22.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.RoleBindingListV1Alpha1(scope: Construct, id: string, props: RoleBindingListV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.RoleBindingListV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RoleBindingListV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.rbac.v1alpha1.RoleBindingList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleBindingListV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleBindingListV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleBindingListV1Alpha1.manifest(props: RoleBindingListV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.rbac.v1alpha1.RoleBindingList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RoleBindingListV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.rbac.v1alpha1.RoleBindingList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.rbac.v1alpha1.RoleBindingList".

---

### RoleBindingV1Alpha1 <a name="RoleBindingV1Alpha1" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1"></a>

RoleBinding references a role, but does not contain it.

It can reference a Role in the same namespace or a ClusterRole in the global namespace. It adds who information via Subjects and namespace information by which namespace it exists in.  RoleBindings in a given namespace only have effect in that namespace. Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 RoleBinding, and will no longer be served in v1.22.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.RoleBindingV1Alpha1(scope: Construct, id: string, props: RoleBindingV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.RoleBindingV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RoleBindingV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.rbac.v1alpha1.RoleBinding". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleBindingV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleBindingV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleBindingV1Alpha1.manifest(props: RoleBindingV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.rbac.v1alpha1.RoleBinding".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RoleBindingV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.rbac.v1alpha1.RoleBinding". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.rbac.v1alpha1.RoleBinding".

---

### RoleList <a name="RoleList" id="cdk8s-metaflow.k8s.RoleList"></a>

RoleList is a collection of Roles.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.RoleList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.RoleList(scope: Construct, id: string, props: RoleListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.RoleListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.RoleList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.RoleList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RoleList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RoleListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.RoleList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.RoleList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.RoleList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.RoleList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.RoleList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.RoleList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.rbac.v1.RoleList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.RoleList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.RoleList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.RoleList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.RoleList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.RoleList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleList.manifest(props: RoleListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.rbac.v1.RoleList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RoleList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RoleListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.RoleList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.RoleList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.RoleList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.RoleList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.RoleList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RoleList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.RoleList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.rbac.v1.RoleList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.RoleList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.rbac.v1.RoleList".

---

### RoleListV1Alpha1 <a name="RoleListV1Alpha1" id="cdk8s-metaflow.k8s.RoleListV1Alpha1"></a>

RoleList is a collection of Roles.

Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 RoleList, and will no longer be served in v1.22.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.RoleListV1Alpha1(scope: Construct, id: string, props: RoleListV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.RoleListV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RoleListV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.rbac.v1alpha1.RoleList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleListV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleListV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleListV1Alpha1.manifest(props: RoleListV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.rbac.v1alpha1.RoleList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RoleListV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.rbac.v1alpha1.RoleList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.RoleListV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.rbac.v1alpha1.RoleList".

---

### RoleV1Alpha1 <a name="RoleV1Alpha1" id="cdk8s-metaflow.k8s.RoleV1Alpha1"></a>

Role is a namespaced, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding.

Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 Role, and will no longer be served in v1.22.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.RoleV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.RoleV1Alpha1(scope: Construct, id: string, props?: RoleV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.RoleV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.RoleV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.RoleV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.RoleV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RoleV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.RoleV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.RoleV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.RoleV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.RoleV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.RoleV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.RoleV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.rbac.v1alpha1.Role". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.RoleV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.RoleV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.RoleV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.RoleV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.RoleV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RoleV1Alpha1.manifest(props?: RoleV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.rbac.v1alpha1.Role".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.RoleV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RoleV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.RoleV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.RoleV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.RoleV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.RoleV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.RoleV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RoleV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.RoleV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.rbac.v1alpha1.Role". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.RoleV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.rbac.v1alpha1.Role".

---

### RuntimeClass <a name="RuntimeClass" id="cdk8s-metaflow.k8s.RuntimeClass"></a>

RuntimeClass defines a class of container runtime supported in the cluster.

The RuntimeClass is used to determine which container runtime is used to run all containers in a pod. RuntimeClasses are manually defined by a user or cluster provisioner, and referenced in the PodSpec. The Kubelet is responsible for resolving the RuntimeClassName reference before running the pod.  For more details, see https://kubernetes.io/docs/concepts/containers/runtime-class/

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.RuntimeClass.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.RuntimeClass(scope: Construct, id: string, props: RuntimeClassProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.RuntimeClassProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.RuntimeClass.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.RuntimeClass.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RuntimeClass.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RuntimeClassProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.RuntimeClass.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.RuntimeClass.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.RuntimeClass.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.RuntimeClass.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.RuntimeClass.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.RuntimeClass.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.node.v1.RuntimeClass". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.RuntimeClass.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClass.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.RuntimeClass.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.RuntimeClass.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClass.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.RuntimeClass.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.RuntimeClass.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClass.manifest(props: RuntimeClassProps)
```

Renders a Kubernetes manifest for "io.k8s.api.node.v1.RuntimeClass".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RuntimeClass.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RuntimeClassProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.RuntimeClass.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.RuntimeClass.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.RuntimeClass.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.RuntimeClass.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.RuntimeClass.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RuntimeClass.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.RuntimeClass.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClass.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.node.v1.RuntimeClass". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.RuntimeClass.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.node.v1.RuntimeClass".

---

### RuntimeClassList <a name="RuntimeClassList" id="cdk8s-metaflow.k8s.RuntimeClassList"></a>

RuntimeClassList is a list of RuntimeClass objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.RuntimeClassList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.RuntimeClassList(scope: Construct, id: string, props: RuntimeClassListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.RuntimeClassListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.RuntimeClassList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.RuntimeClassList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RuntimeClassList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RuntimeClassListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.RuntimeClassList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.RuntimeClassList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.RuntimeClassList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.RuntimeClassList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.RuntimeClassList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.RuntimeClassList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.node.v1.RuntimeClassList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.RuntimeClassList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClassList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.RuntimeClassList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.RuntimeClassList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClassList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.RuntimeClassList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.RuntimeClassList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClassList.manifest(props: RuntimeClassListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.node.v1.RuntimeClassList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RuntimeClassList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RuntimeClassListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.RuntimeClassList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.RuntimeClassList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.RuntimeClassList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.RuntimeClassList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.RuntimeClassList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RuntimeClassList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.RuntimeClassList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.node.v1.RuntimeClassList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.RuntimeClassList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.node.v1.RuntimeClassList".

---

### RuntimeClassListV1Alpha1 <a name="RuntimeClassListV1Alpha1" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1"></a>

RuntimeClassList is a list of RuntimeClass objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.RuntimeClassListV1Alpha1(scope: Construct, id: string, props: RuntimeClassListV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.node.v1alpha1.RuntimeClassList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClassListV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClassListV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClassListV1Alpha1.manifest(props: RuntimeClassListV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.node.v1alpha1.RuntimeClassList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.node.v1alpha1.RuntimeClassList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.node.v1alpha1.RuntimeClassList".

---

### RuntimeClassListV1Beta1 <a name="RuntimeClassListV1Beta1" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1"></a>

RuntimeClassList is a list of RuntimeClass objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.RuntimeClassListV1Beta1(scope: Construct, id: string, props: RuntimeClassListV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.RuntimeClassListV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RuntimeClassListV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.node.v1beta1.RuntimeClassList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClassListV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClassListV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClassListV1Beta1.manifest(props: RuntimeClassListV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.node.v1beta1.RuntimeClassList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RuntimeClassListV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.node.v1beta1.RuntimeClassList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.node.v1beta1.RuntimeClassList".

---

### RuntimeClassV1Alpha1 <a name="RuntimeClassV1Alpha1" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1"></a>

RuntimeClass defines a class of container runtime supported in the cluster.

The RuntimeClass is used to determine which container runtime is used to run all containers in a pod. RuntimeClasses are (currently) manually defined by a user or cluster provisioner, and referenced in the PodSpec. The Kubelet is responsible for resolving the RuntimeClassName reference before running the pod.  For more details, see https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.RuntimeClassV1Alpha1(scope: Construct, id: string, props: RuntimeClassV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.RuntimeClassV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RuntimeClassV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.node.v1alpha1.RuntimeClass". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClassV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClassV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClassV1Alpha1.manifest(props: RuntimeClassV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.node.v1alpha1.RuntimeClass".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RuntimeClassV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.node.v1alpha1.RuntimeClass". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.node.v1alpha1.RuntimeClass".

---

### RuntimeClassV1Beta1 <a name="RuntimeClassV1Beta1" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1"></a>

RuntimeClass defines a class of container runtime supported in the cluster.

The RuntimeClass is used to determine which container runtime is used to run all containers in a pod. RuntimeClasses are (currently) manually defined by a user or cluster provisioner, and referenced in the PodSpec. The Kubelet is responsible for resolving the RuntimeClassName reference before running the pod.  For more details, see https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.RuntimeClassV1Beta1(scope: Construct, id: string, props: RuntimeClassV1Beta1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.RuntimeClassV1Beta1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RuntimeClassV1Beta1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.node.v1beta1.RuntimeClass". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClassV1Beta1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClassV1Beta1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.RuntimeClassV1Beta1.manifest(props: RuntimeClassV1Beta1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.node.v1beta1.RuntimeClass".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.RuntimeClassV1Beta1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.node.v1beta1.RuntimeClass". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.node.v1beta1.RuntimeClass".

---

### Scale <a name="Scale" id="cdk8s-metaflow.k8s.Scale"></a>

Scale represents a scaling request for a resource.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.Scale.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.Scale(scope: Construct, id: string, props?: ScaleProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Scale.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.Scale.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.Scale.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ScaleProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.Scale.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.Scale.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Scale.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ScaleProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Scale.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.Scale.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.Scale.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Scale.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.Scale.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.Scale.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.Scale.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.Scale.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.Scale.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.Scale.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Scale.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.Scale.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.Scale.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.autoscaling.v1.Scale". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.Scale.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Scale.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.Scale.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.Scale.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Scale.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.Scale.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.Scale.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Scale.manifest(props?: ScaleProps)
```

Renders a Kubernetes manifest for "io.k8s.api.autoscaling.v1.Scale".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Scale.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ScaleProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Scale.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.Scale.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.Scale.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.Scale.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.Scale.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.Scale.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Scale.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.Scale.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.Scale.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.Scale.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.Scale.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.Scale.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.Scale.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Scale.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Scale.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.autoscaling.v1.Scale". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.Scale.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.autoscaling.v1.Scale".

---

### Secret <a name="Secret" id="cdk8s-metaflow.k8s.Secret"></a>

Secret holds secret data of a certain type.

The total bytes of the values in the Data field must be less than MaxSecretSize bytes.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.Secret.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.Secret(scope: Construct, id: string, props?: SecretProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Secret.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.Secret.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.Secret.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.SecretProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.Secret.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.Secret.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Secret.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.SecretProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Secret.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.Secret.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.Secret.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Secret.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.Secret.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.Secret.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.Secret.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.Secret.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.Secret.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.Secret.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Secret.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.Secret.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.Secret.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.Secret". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.Secret.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Secret.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.Secret.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.Secret.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Secret.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.Secret.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.Secret.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Secret.manifest(props?: SecretProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.Secret".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Secret.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.SecretProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Secret.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.Secret.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.Secret.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.Secret.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.Secret.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.Secret.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Secret.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.Secret.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.Secret.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.Secret.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.Secret.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.Secret.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.Secret.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Secret.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Secret.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.Secret". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.Secret.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.Secret".

---

### SecretList <a name="SecretList" id="cdk8s-metaflow.k8s.SecretList"></a>

SecretList is a list of Secret.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.SecretList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.SecretList(scope: Construct, id: string, props: SecretListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.SecretListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.SecretList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.SecretList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.SecretList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.SecretListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.SecretList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.SecretList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.SecretList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.SecretList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.SecretList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.SecretList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.SecretList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.SecretList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.SecretList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.SecretList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.SecretList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.SecretList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.SecretList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.SecretList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.SecretList.manifest(props: SecretListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.SecretList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.SecretList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.SecretListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.SecretList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.SecretList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.SecretList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.SecretList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.SecretList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.SecretList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.SecretList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SecretList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.SecretList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.SecretList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.SecretList".

---

### SelfSubjectAccessReview <a name="SelfSubjectAccessReview" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview"></a>

SelfSubjectAccessReview checks whether or the current user can perform an action.

Not filling in a spec.namespace means "in all namespaces".  Self is a special case, because users should always be able to check whether they can perform an action

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.SelfSubjectAccessReview(scope: Construct, id: string, props: SelfSubjectAccessReviewProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.SelfSubjectAccessReviewProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.SelfSubjectAccessReviewProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.authorization.v1.SelfSubjectAccessReview". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.SelfSubjectAccessReview.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.SelfSubjectAccessReview.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.SelfSubjectAccessReview.manifest(props: SelfSubjectAccessReviewProps)
```

Renders a Kubernetes manifest for "io.k8s.api.authorization.v1.SelfSubjectAccessReview".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.SelfSubjectAccessReviewProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReview.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.authorization.v1.SelfSubjectAccessReview". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.SelfSubjectAccessReview.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.authorization.v1.SelfSubjectAccessReview".

---

### SelfSubjectRulesReview <a name="SelfSubjectRulesReview" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview"></a>

SelfSubjectRulesReview enumerates the set of actions the current user can perform within a namespace.

The returned list of actions may be incomplete depending on the server's authorization mode, and any errors experienced during the evaluation. SelfSubjectRulesReview should be used by UIs to show/hide actions, or to quickly let an end user reason about their permissions. It should NOT Be used by external systems to drive authorization decisions as this raises confused deputy, cache lifetime/revocation, and correctness concerns. SubjectAccessReview, and LocalAccessReview are the correct way to defer authorization decisions to the API server.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.SelfSubjectRulesReview(scope: Construct, id: string, props: SelfSubjectRulesReviewProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.SelfSubjectRulesReviewProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.SelfSubjectRulesReviewProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.authorization.v1.SelfSubjectRulesReview". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.SelfSubjectRulesReview.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.SelfSubjectRulesReview.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.SelfSubjectRulesReview.manifest(props: SelfSubjectRulesReviewProps)
```

Renders a Kubernetes manifest for "io.k8s.api.authorization.v1.SelfSubjectRulesReview".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.SelfSubjectRulesReviewProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReview.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.authorization.v1.SelfSubjectRulesReview". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.SelfSubjectRulesReview.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.authorization.v1.SelfSubjectRulesReview".

---

### Service <a name="Service" id="cdk8s-metaflow.k8s.Service"></a>

Service is a named abstraction of software service (for example, mysql) consisting of local port (for example 3306) that the proxy listens on, and the selector that determines which pods will answer requests sent through the proxy.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.Service.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.Service(scope: Construct, id: string, props?: ServiceProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Service.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.Service.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.Service.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ServiceProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.Service.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.Service.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Service.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ServiceProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Service.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.Service.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.Service.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Service.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.Service.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.Service.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.Service.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.Service.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.Service.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.Service.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Service.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.Service.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.Service.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.Service". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.Service.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Service.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.Service.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.Service.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Service.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.Service.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.Service.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Service.manifest(props?: ServiceProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.Service".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Service.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ServiceProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Service.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.Service.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.Service.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.Service.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.Service.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.Service.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Service.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.Service.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.Service.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.Service.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.Service.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.Service.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.Service.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Service.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Service.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.Service". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.Service.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.Service".

---

### ServiceAccount <a name="ServiceAccount" id="cdk8s-metaflow.k8s.ServiceAccount"></a>

ServiceAccount binds together: * a name, understood by users, and perhaps by peripheral systems, for an identity * a principal that can be authenticated and authorized * a set of secrets.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ServiceAccount.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ServiceAccount(scope: Construct, id: string, props?: ServiceAccountProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ServiceAccountProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ServiceAccount.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ServiceAccount.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ServiceAccount.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ServiceAccountProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ServiceAccount.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ServiceAccount.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ServiceAccount.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ServiceAccount.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ServiceAccount.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ServiceAccount.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.ServiceAccount". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ServiceAccount.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ServiceAccount.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ServiceAccount.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ServiceAccount.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ServiceAccount.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ServiceAccount.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ServiceAccount.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ServiceAccount.manifest(props?: ServiceAccountProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.ServiceAccount".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ServiceAccount.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ServiceAccountProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ServiceAccount.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ServiceAccount.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ServiceAccount.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ServiceAccount.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ServiceAccount.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ServiceAccount.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ServiceAccount.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccount.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.ServiceAccount". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ServiceAccount.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.ServiceAccount".

---

### ServiceAccountList <a name="ServiceAccountList" id="cdk8s-metaflow.k8s.ServiceAccountList"></a>

ServiceAccountList is a list of ServiceAccount objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ServiceAccountList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ServiceAccountList(scope: Construct, id: string, props: ServiceAccountListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ServiceAccountListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ServiceAccountList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ServiceAccountList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ServiceAccountList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ServiceAccountListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ServiceAccountList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ServiceAccountList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ServiceAccountList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ServiceAccountList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ServiceAccountList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ServiceAccountList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.ServiceAccountList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ServiceAccountList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ServiceAccountList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ServiceAccountList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ServiceAccountList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ServiceAccountList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ServiceAccountList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ServiceAccountList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ServiceAccountList.manifest(props: ServiceAccountListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.ServiceAccountList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ServiceAccountList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ServiceAccountListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ServiceAccountList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ServiceAccountList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ServiceAccountList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ServiceAccountList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ServiceAccountList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ServiceAccountList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ServiceAccountList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.ServiceAccountList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ServiceAccountList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.ServiceAccountList".

---

### ServiceList <a name="ServiceList" id="cdk8s-metaflow.k8s.ServiceList"></a>

ServiceList holds a list of services.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ServiceList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ServiceList(scope: Construct, id: string, props: ServiceListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ServiceListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ServiceList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ServiceList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ServiceList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ServiceListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ServiceList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ServiceList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ServiceList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ServiceList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ServiceList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ServiceList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.core.v1.ServiceList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ServiceList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ServiceList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ServiceList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ServiceList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ServiceList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ServiceList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ServiceList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ServiceList.manifest(props: ServiceListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.core.v1.ServiceList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ServiceList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ServiceListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ServiceList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ServiceList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ServiceList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ServiceList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ServiceList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ServiceList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ServiceList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.core.v1.ServiceList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ServiceList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.core.v1.ServiceList".

---

### StatefulSet <a name="StatefulSet" id="cdk8s-metaflow.k8s.StatefulSet"></a>

StatefulSet represents a set of pods with consistent identities.

Identities are defined as:
- Network: A single stable DNS and hostname.
- Storage: As many VolumeClaims as requested.
The StatefulSet guarantees that a given network identity will always map to the same storage identity.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.StatefulSet.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.StatefulSet(scope: Construct, id: string, props?: StatefulSetProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.StatefulSetProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.StatefulSet.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.StatefulSet.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.StatefulSet.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.StatefulSetProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.StatefulSet.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.StatefulSet.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.StatefulSet.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.StatefulSet.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.StatefulSet.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.StatefulSet.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.apps.v1.StatefulSet". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.StatefulSet.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StatefulSet.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.StatefulSet.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.StatefulSet.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StatefulSet.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.StatefulSet.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.StatefulSet.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StatefulSet.manifest(props?: StatefulSetProps)
```

Renders a Kubernetes manifest for "io.k8s.api.apps.v1.StatefulSet".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.StatefulSet.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.StatefulSetProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.StatefulSet.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.StatefulSet.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.StatefulSet.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.StatefulSet.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.StatefulSet.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.StatefulSet.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.StatefulSet.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSet.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.apps.v1.StatefulSet". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.StatefulSet.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.apps.v1.StatefulSet".

---

### StatefulSetList <a name="StatefulSetList" id="cdk8s-metaflow.k8s.StatefulSetList"></a>

StatefulSetList is a collection of StatefulSets.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.StatefulSetList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.StatefulSetList(scope: Construct, id: string, props: StatefulSetListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.StatefulSetListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.StatefulSetList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.StatefulSetList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.StatefulSetList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.StatefulSetListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.StatefulSetList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.StatefulSetList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.StatefulSetList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.StatefulSetList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.StatefulSetList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.StatefulSetList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.apps.v1.StatefulSetList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.StatefulSetList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StatefulSetList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.StatefulSetList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.StatefulSetList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StatefulSetList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.StatefulSetList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.StatefulSetList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StatefulSetList.manifest(props: StatefulSetListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.apps.v1.StatefulSetList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.StatefulSetList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.StatefulSetListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.StatefulSetList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.StatefulSetList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.StatefulSetList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.StatefulSetList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.StatefulSetList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.StatefulSetList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.StatefulSetList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.apps.v1.StatefulSetList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.StatefulSetList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.apps.v1.StatefulSetList".

---

### Status <a name="Status" id="cdk8s-metaflow.k8s.Status"></a>

Status is a return value for calls that don't return other objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.Status.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.Status(scope: Construct, id: string, props?: StatusProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Status.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.Status.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.Status.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.StatusProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.Status.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.Status.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Status.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.StatusProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Status.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.Status.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.Status.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Status.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.Status.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.Status.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.Status.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.Status.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.Status.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.Status.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Status.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.Status.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.Status.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.apimachinery.pkg.apis.meta.v1.Status". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.Status.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Status.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.Status.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.Status.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Status.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.Status.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.Status.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Status.manifest(props?: StatusProps)
```

Renders a Kubernetes manifest for "io.k8s.apimachinery.pkg.apis.meta.v1.Status".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.Status.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.StatusProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Status.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.Status.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.Status.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.Status.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.Status.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.Status.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.Status.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.Status.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.Status.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.Status.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.Status.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.Status.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.Status.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Status.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Status.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.apimachinery.pkg.apis.meta.v1.Status". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.Status.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.apimachinery.pkg.apis.meta.v1.Status".

---

### StorageClass <a name="StorageClass" id="cdk8s-metaflow.k8s.StorageClass"></a>

StorageClass describes the parameters for a class of storage for which PersistentVolumes can be dynamically provisioned.

StorageClasses are non-namespaced; the name of the storage class according to etcd is in ObjectMeta.Name.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.StorageClass.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.StorageClass(scope: Construct, id: string, props: StorageClassProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.StorageClassProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.StorageClass.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.StorageClass.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.StorageClass.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.StorageClassProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.StorageClass.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.StorageClass.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.StorageClass.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.StorageClass.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.StorageClass.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.StorageClass.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.storage.v1.StorageClass". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.StorageClass.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StorageClass.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.StorageClass.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.StorageClass.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StorageClass.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.StorageClass.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.StorageClass.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StorageClass.manifest(props: StorageClassProps)
```

Renders a Kubernetes manifest for "io.k8s.api.storage.v1.StorageClass".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.StorageClass.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.StorageClassProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.StorageClass.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.StorageClass.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.StorageClass.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.StorageClass.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.StorageClass.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.StorageClass.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.StorageClass.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageClass.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.storage.v1.StorageClass". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.StorageClass.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.storage.v1.StorageClass".

---

### StorageClassList <a name="StorageClassList" id="cdk8s-metaflow.k8s.StorageClassList"></a>

StorageClassList is a collection of storage classes.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.StorageClassList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.StorageClassList(scope: Construct, id: string, props: StorageClassListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.StorageClassListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.StorageClassList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.StorageClassList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.StorageClassList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.StorageClassListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.StorageClassList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.StorageClassList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.StorageClassList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.StorageClassList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.StorageClassList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.StorageClassList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.storage.v1.StorageClassList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.StorageClassList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StorageClassList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.StorageClassList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.StorageClassList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StorageClassList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.StorageClassList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.StorageClassList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StorageClassList.manifest(props: StorageClassListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.storage.v1.StorageClassList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.StorageClassList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.StorageClassListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.StorageClassList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.StorageClassList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.StorageClassList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.StorageClassList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.StorageClassList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.StorageClassList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.StorageClassList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.storage.v1.StorageClassList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.StorageClassList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.storage.v1.StorageClassList".

---

### StorageVersionListV1Alpha1 <a name="StorageVersionListV1Alpha1" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1"></a>

A list of StorageVersions.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.StorageVersionListV1Alpha1(scope: Construct, id: string, props: StorageVersionListV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.StorageVersionListV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.StorageVersionListV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.apiserverinternal.v1alpha1.StorageVersionList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StorageVersionListV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StorageVersionListV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StorageVersionListV1Alpha1.manifest(props: StorageVersionListV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.apiserverinternal.v1alpha1.StorageVersionList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.StorageVersionListV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.apiserverinternal.v1alpha1.StorageVersionList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.apiserverinternal.v1alpha1.StorageVersionList".

---

### StorageVersionV1Alpha1 <a name="StorageVersionV1Alpha1" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1"></a>

Storage version of a specific resource.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.StorageVersionV1Alpha1(scope: Construct, id: string, props: StorageVersionV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.StorageVersionV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.StorageVersionV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.apiserverinternal.v1alpha1.StorageVersion". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StorageVersionV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StorageVersionV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.StorageVersionV1Alpha1.manifest(props: StorageVersionV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.apiserverinternal.v1alpha1.StorageVersion".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.StorageVersionV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.apiserverinternal.v1alpha1.StorageVersion". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.apiserverinternal.v1alpha1.StorageVersion".

---

### SubjectAccessReview <a name="SubjectAccessReview" id="cdk8s-metaflow.k8s.SubjectAccessReview"></a>

SubjectAccessReview checks whether or not a user or group can perform an action.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.SubjectAccessReview.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.SubjectAccessReview(scope: Construct, id: string, props: SubjectAccessReviewProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.SubjectAccessReviewProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.SubjectAccessReview.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.SubjectAccessReview.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.SubjectAccessReview.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.SubjectAccessReviewProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.SubjectAccessReview.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.SubjectAccessReview.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.SubjectAccessReview.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.SubjectAccessReview.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.SubjectAccessReview.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.SubjectAccessReview.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.authorization.v1.SubjectAccessReview". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.SubjectAccessReview.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.SubjectAccessReview.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.SubjectAccessReview.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.SubjectAccessReview.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.SubjectAccessReview.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.SubjectAccessReview.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.SubjectAccessReview.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.SubjectAccessReview.manifest(props: SubjectAccessReviewProps)
```

Renders a Kubernetes manifest for "io.k8s.api.authorization.v1.SubjectAccessReview".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.SubjectAccessReview.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.SubjectAccessReviewProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.SubjectAccessReview.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.SubjectAccessReview.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.SubjectAccessReview.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.SubjectAccessReview.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.SubjectAccessReview.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.SubjectAccessReview.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.SubjectAccessReview.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReview.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.authorization.v1.SubjectAccessReview". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.SubjectAccessReview.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.authorization.v1.SubjectAccessReview".

---

### TokenRequest <a name="TokenRequest" id="cdk8s-metaflow.k8s.TokenRequest"></a>

TokenRequest requests a token for a given service account.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.TokenRequest.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.TokenRequest(scope: Construct, id: string, props: TokenRequestProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.TokenRequestProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.TokenRequest.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.TokenRequest.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.TokenRequest.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.TokenRequestProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.TokenRequest.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.TokenRequest.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.TokenRequest.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.TokenRequest.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.TokenRequest.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.TokenRequest.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.authentication.v1.TokenRequest". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.TokenRequest.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.TokenRequest.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.TokenRequest.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.TokenRequest.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.TokenRequest.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.TokenRequest.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.TokenRequest.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.TokenRequest.manifest(props: TokenRequestProps)
```

Renders a Kubernetes manifest for "io.k8s.api.authentication.v1.TokenRequest".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.TokenRequest.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.TokenRequestProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.TokenRequest.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.TokenRequest.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.TokenRequest.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.TokenRequest.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.TokenRequest.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.TokenRequest.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.TokenRequest.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequest.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.authentication.v1.TokenRequest". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.TokenRequest.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.authentication.v1.TokenRequest".

---

### TokenReview <a name="TokenReview" id="cdk8s-metaflow.k8s.TokenReview"></a>

TokenReview attempts to authenticate a token to a known user.

Note: TokenReview requests may be cached by the webhook token authenticator plugin in the kube-apiserver.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.TokenReview.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.TokenReview(scope: Construct, id: string, props: TokenReviewProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.TokenReviewProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.TokenReview.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.TokenReview.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.TokenReview.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.TokenReviewProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.TokenReview.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.TokenReview.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.TokenReview.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.TokenReview.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.TokenReview.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.TokenReview.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.authentication.v1.TokenReview". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.TokenReview.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.TokenReview.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.TokenReview.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.TokenReview.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.TokenReview.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.TokenReview.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.TokenReview.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.TokenReview.manifest(props: TokenReviewProps)
```

Renders a Kubernetes manifest for "io.k8s.api.authentication.v1.TokenReview".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.TokenReview.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.TokenReviewProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.TokenReview.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.TokenReview.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.TokenReview.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.TokenReview.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.TokenReview.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.TokenReview.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.TokenReview.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TokenReview.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.authentication.v1.TokenReview". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.TokenReview.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.authentication.v1.TokenReview".

---

### ValidatingWebhookConfiguration <a name="ValidatingWebhookConfiguration" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration"></a>

ValidatingWebhookConfiguration describes the configuration of and admission webhook that accept or reject and object without changing it.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ValidatingWebhookConfiguration(scope: Construct, id: string, props?: ValidatingWebhookConfigurationProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ValidatingWebhookConfigurationProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ValidatingWebhookConfigurationProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.admissionregistration.v1.ValidatingWebhookConfiguration". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ValidatingWebhookConfiguration.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ValidatingWebhookConfiguration.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ValidatingWebhookConfiguration.manifest(props?: ValidatingWebhookConfigurationProps)
```

Renders a Kubernetes manifest for "io.k8s.api.admissionregistration.v1.ValidatingWebhookConfiguration".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Optional</sup> <a name="props" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ValidatingWebhookConfigurationProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.admissionregistration.v1.ValidatingWebhookConfiguration". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ValidatingWebhookConfiguration.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.admissionregistration.v1.ValidatingWebhookConfiguration".

---

### ValidatingWebhookConfigurationList <a name="ValidatingWebhookConfigurationList" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList"></a>

ValidatingWebhookConfigurationList is a list of ValidatingWebhookConfiguration.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.ValidatingWebhookConfigurationList(scope: Construct, id: string, props: ValidatingWebhookConfigurationListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.ValidatingWebhookConfigurationListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ValidatingWebhookConfigurationListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.admissionregistration.v1.ValidatingWebhookConfigurationList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ValidatingWebhookConfigurationList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ValidatingWebhookConfigurationList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.ValidatingWebhookConfigurationList.manifest(props: ValidatingWebhookConfigurationListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.admissionregistration.v1.ValidatingWebhookConfigurationList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.ValidatingWebhookConfigurationListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.admissionregistration.v1.ValidatingWebhookConfigurationList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.admissionregistration.v1.ValidatingWebhookConfigurationList".

---

### VolumeAttachment <a name="VolumeAttachment" id="cdk8s-metaflow.k8s.VolumeAttachment"></a>

VolumeAttachment captures the intent to attach or detach the specified volume to/from the specified node.

VolumeAttachment objects are non-namespaced.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.VolumeAttachment.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.VolumeAttachment(scope: Construct, id: string, props: VolumeAttachmentProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.VolumeAttachmentProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.VolumeAttachment.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.VolumeAttachment.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.VolumeAttachment.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.VolumeAttachmentProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.VolumeAttachment.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.VolumeAttachment.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.VolumeAttachment.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.VolumeAttachment.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.VolumeAttachment.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.VolumeAttachment.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.storage.v1.VolumeAttachment". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.VolumeAttachment.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.VolumeAttachment.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.VolumeAttachment.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.VolumeAttachment.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.VolumeAttachment.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.VolumeAttachment.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.VolumeAttachment.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.VolumeAttachment.manifest(props: VolumeAttachmentProps)
```

Renders a Kubernetes manifest for "io.k8s.api.storage.v1.VolumeAttachment".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.VolumeAttachment.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.VolumeAttachmentProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.VolumeAttachment.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.VolumeAttachment.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.VolumeAttachment.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.VolumeAttachment.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.VolumeAttachment.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.VolumeAttachment.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.VolumeAttachment.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachment.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.storage.v1.VolumeAttachment". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.VolumeAttachment.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.storage.v1.VolumeAttachment".

---

### VolumeAttachmentList <a name="VolumeAttachmentList" id="cdk8s-metaflow.k8s.VolumeAttachmentList"></a>

VolumeAttachmentList is a collection of VolumeAttachment objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.VolumeAttachmentList.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.VolumeAttachmentList(scope: Construct, id: string, props: VolumeAttachmentListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.VolumeAttachmentListProps</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.VolumeAttachmentList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.VolumeAttachmentList.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.VolumeAttachmentList.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.VolumeAttachmentListProps

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.VolumeAttachmentList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.VolumeAttachmentList.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.VolumeAttachmentList.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.VolumeAttachmentList.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.VolumeAttachmentList.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.VolumeAttachmentList.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.storage.v1.VolumeAttachmentList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.VolumeAttachmentList.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.VolumeAttachmentList.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.VolumeAttachmentList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.VolumeAttachmentList.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.VolumeAttachmentList.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.VolumeAttachmentList.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.VolumeAttachmentList.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.VolumeAttachmentList.manifest(props: VolumeAttachmentListProps)
```

Renders a Kubernetes manifest for "io.k8s.api.storage.v1.VolumeAttachmentList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.VolumeAttachmentList.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.VolumeAttachmentListProps

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.VolumeAttachmentList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.VolumeAttachmentList.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.VolumeAttachmentList.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.VolumeAttachmentList.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.VolumeAttachmentList.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.VolumeAttachmentList.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.VolumeAttachmentList.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentList.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.storage.v1.VolumeAttachmentList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.VolumeAttachmentList.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.storage.v1.VolumeAttachmentList".

---

### VolumeAttachmentListV1Alpha1 <a name="VolumeAttachmentListV1Alpha1" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1"></a>

VolumeAttachmentList is a collection of VolumeAttachment objects.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.VolumeAttachmentListV1Alpha1(scope: Construct, id: string, props: VolumeAttachmentListV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.storage.v1alpha1.VolumeAttachmentList". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.VolumeAttachmentListV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.VolumeAttachmentListV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.VolumeAttachmentListV1Alpha1.manifest(props: VolumeAttachmentListV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.storage.v1alpha1.VolumeAttachmentList".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.storage.v1alpha1.VolumeAttachmentList". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.storage.v1alpha1.VolumeAttachmentList".

---

### VolumeAttachmentV1Alpha1 <a name="VolumeAttachmentV1Alpha1" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1"></a>

VolumeAttachment captures the intent to attach or detach the specified volume to/from the specified node.

VolumeAttachment objects are non-namespaced.

#### Initializers <a name="Initializers" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

new k8s.VolumeAttachmentV1Alpha1(scope: Construct, id: string, props: VolumeAttachmentV1Alpha1Props)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | the scope in which to define this object. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.Initializer.parameter.id">id</a></code> | <code>string</code> | a scope-local name for the object. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.Initializer.parameter.props">props</a></code> | <code>cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1Props</code> | initialization props. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

the scope in which to define this object.

---

##### `id`<sup>Required</sup> <a name="id" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.Initializer.parameter.id"></a>

- *Type:* string

a scope-local name for the object.

---

##### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.Initializer.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1Props

initialization props.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.addDependency">addDependency</a></code> | Create a dependency between this ApiObject and other constructs. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.addJsonPatch">addJsonPatch</a></code> | Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.toJson">toJson</a></code> | Renders the object to Kubernetes JSON. |

---

##### `toString` <a name="toString" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `addDependency` <a name="addDependency" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.addDependency"></a>

```typescript
public addDependency(dependencies: IConstruct): void
```

Create a dependency between this ApiObject and other constructs.

These can be other ApiObjects, Charts, or custom.

###### `dependencies`<sup>Required</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.addDependency.parameter.dependencies"></a>

- *Type:* constructs.IConstruct

the dependencies to add.

---

##### `addJsonPatch` <a name="addJsonPatch" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.addJsonPatch"></a>

```typescript
public addJsonPatch(ops: JsonPatch): void
```

Applies a set of RFC-6902 JSON-Patch operations to the manifest synthesized for this API object.

*Example*

```typescript
  kubePod.addJsonPatch(JsonPatch.replace('/spec/enableServiceLinks', true));
```


###### `ops`<sup>Required</sup> <a name="ops" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.addJsonPatch.parameter.ops"></a>

- *Type:* cdk8s.JsonPatch

The JSON-Patch operations to apply.

---

##### `toJson` <a name="toJson" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.toJson"></a>

```typescript
public toJson(): any
```

Renders the object to Kubernetes JSON.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.of">of</a></code> | Returns the `ApiObject` named `Resource` which is a child of the given construct. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.manifest">manifest</a></code> | Renders a Kubernetes manifest for "io.k8s.api.storage.v1alpha1.VolumeAttachment". |

---

##### `isConstruct` <a name="isConstruct" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.isConstruct"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.VolumeAttachmentV1Alpha1.isConstruct(x: any)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `of` <a name="of" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.of"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.VolumeAttachmentV1Alpha1.of(c: IConstruct)
```

Returns the `ApiObject` named `Resource` which is a child of the given construct.

If `c` is an `ApiObject`, it is returned directly. Throws an
exception if the construct does not have a child named `Default` _or_ if
this child is not an `ApiObject`.

###### `c`<sup>Required</sup> <a name="c" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.of.parameter.c"></a>

- *Type:* constructs.IConstruct

The higher-level construct.

---

##### `manifest` <a name="manifest" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.manifest"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.VolumeAttachmentV1Alpha1.manifest(props: VolumeAttachmentV1Alpha1Props)
```

Renders a Kubernetes manifest for "io.k8s.api.storage.v1alpha1.VolumeAttachment".

This can be used to inline resource manifests inside other objects (e.g. as templates).

###### `props`<sup>Required</sup> <a name="props" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.manifest.parameter.props"></a>

- *Type:* cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1Props

initialization props.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | The group portion of the API version (e.g. `authorization.k8s.io`). |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | The object's API version (e.g. `authorization.k8s.io/v1`). |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.property.chart">chart</a></code> | <code>cdk8s.Chart</code> | The chart in which this object is defined. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.property.kind">kind</a></code> | <code>string</code> | The object kind. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.property.metadata">metadata</a></code> | <code>cdk8s.ApiObjectMetadataDefinition</code> | Metadata associated with this API object. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.property.name">name</a></code> | <code>string</code> | The name of the API object. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

The group portion of the API version (e.g. `authorization.k8s.io`).

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

The object's API version (e.g. `authorization.k8s.io/v1`).

---

##### `chart`<sup>Required</sup> <a name="chart" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.property.chart"></a>

```typescript
public readonly chart: Chart;
```

- *Type:* cdk8s.Chart

The chart in which this object is defined.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The object kind.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.property.metadata"></a>

```typescript
public readonly metadata: ApiObjectMetadataDefinition;
```

- *Type:* cdk8s.ApiObjectMetadataDefinition

Metadata associated with this API object.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the API object.

If a name is specified in `metadata.name` this will be the name returned.
Otherwise, a name will be generated by calling
`Chart.of(this).generatedObjectName(this)`, which by default uses the
construct path to generate a DNS-compatible name for the resource.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.property.GVK">GVK</a></code> | <code>cdk8s.GroupVersionKind</code> | Returns the apiVersion and kind for "io.k8s.api.storage.v1alpha1.VolumeAttachment". |

---

##### `GVK`<sup>Required</sup> <a name="GVK" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1.property.GVK"></a>

```typescript
public readonly GVK: GroupVersionKind;
```

- *Type:* cdk8s.GroupVersionKind

Returns the apiVersion and kind for "io.k8s.api.storage.v1alpha1.VolumeAttachment".

---

## Structs <a name="Structs" id="Structs"></a>

### Affinity <a name="Affinity" id="cdk8s-metaflow.k8s.Affinity"></a>

Affinity is a group of affinity scheduling rules.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.Affinity.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const affinity: k8s.Affinity = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Affinity.property.nodeAffinity">nodeAffinity</a></code> | <code>cdk8s-metaflow.k8s.NodeAffinity</code> | Describes node affinity scheduling rules for the pod. |
| <code><a href="#cdk8s-metaflow.k8s.Affinity.property.podAffinity">podAffinity</a></code> | <code>cdk8s-metaflow.k8s.PodAffinity</code> | Describes pod affinity scheduling rules (e.g. co-locate this pod in the same node, zone, etc. as some other pod(s)). |
| <code><a href="#cdk8s-metaflow.k8s.Affinity.property.podAntiAffinity">podAntiAffinity</a></code> | <code>cdk8s-metaflow.k8s.PodAntiAffinity</code> | Describes pod anti-affinity scheduling rules (e.g. avoid putting this pod in the same node, zone, etc. as some other pod(s)). |

---

##### `nodeAffinity`<sup>Optional</sup> <a name="nodeAffinity" id="cdk8s-metaflow.k8s.Affinity.property.nodeAffinity"></a>

```typescript
public readonly nodeAffinity: NodeAffinity;
```

- *Type:* cdk8s-metaflow.k8s.NodeAffinity

Describes node affinity scheduling rules for the pod.

---

##### `podAffinity`<sup>Optional</sup> <a name="podAffinity" id="cdk8s-metaflow.k8s.Affinity.property.podAffinity"></a>

```typescript
public readonly podAffinity: PodAffinity;
```

- *Type:* cdk8s-metaflow.k8s.PodAffinity

Describes pod affinity scheduling rules (e.g. co-locate this pod in the same node, zone, etc. as some other pod(s)).

---

##### `podAntiAffinity`<sup>Optional</sup> <a name="podAntiAffinity" id="cdk8s-metaflow.k8s.Affinity.property.podAntiAffinity"></a>

```typescript
public readonly podAntiAffinity: PodAntiAffinity;
```

- *Type:* cdk8s-metaflow.k8s.PodAntiAffinity

Describes pod anti-affinity scheduling rules (e.g. avoid putting this pod in the same node, zone, etc. as some other pod(s)).

---

### AggregationRule <a name="AggregationRule" id="cdk8s-metaflow.k8s.AggregationRule"></a>

AggregationRule describes how to locate ClusterRoles to aggregate into the ClusterRole.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.AggregationRule.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const aggregationRule: k8s.AggregationRule = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.AggregationRule.property.clusterRoleSelectors">clusterRoleSelectors</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector[]</code> | ClusterRoleSelectors holds a list of selectors which will be used to find ClusterRoles and create the rules. |

---

##### `clusterRoleSelectors`<sup>Optional</sup> <a name="clusterRoleSelectors" id="cdk8s-metaflow.k8s.AggregationRule.property.clusterRoleSelectors"></a>

```typescript
public readonly clusterRoleSelectors: LabelSelector[];
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector[]

ClusterRoleSelectors holds a list of selectors which will be used to find ClusterRoles and create the rules.

If any of the selectors match, then the ClusterRole's permissions will be added

---

### AggregationRuleV1Alpha1 <a name="AggregationRuleV1Alpha1" id="cdk8s-metaflow.k8s.AggregationRuleV1Alpha1"></a>

AggregationRule describes how to locate ClusterRoles to aggregate into the ClusterRole.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.AggregationRuleV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const aggregationRuleV1Alpha1: k8s.AggregationRuleV1Alpha1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.AggregationRuleV1Alpha1.property.clusterRoleSelectors">clusterRoleSelectors</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector[]</code> | ClusterRoleSelectors holds a list of selectors which will be used to find ClusterRoles and create the rules. |

---

##### `clusterRoleSelectors`<sup>Optional</sup> <a name="clusterRoleSelectors" id="cdk8s-metaflow.k8s.AggregationRuleV1Alpha1.property.clusterRoleSelectors"></a>

```typescript
public readonly clusterRoleSelectors: LabelSelector[];
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector[]

ClusterRoleSelectors holds a list of selectors which will be used to find ClusterRoles and create the rules.

If any of the selectors match, then the ClusterRole's permissions will be added

---

### AllowedCsiDriverV1Beta1 <a name="AllowedCsiDriverV1Beta1" id="cdk8s-metaflow.k8s.AllowedCsiDriverV1Beta1"></a>

AllowedCSIDriver represents a single inline CSI Driver that is allowed to be used.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.AllowedCsiDriverV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const allowedCsiDriverV1Beta1: k8s.AllowedCsiDriverV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.AllowedCsiDriverV1Beta1.property.name">name</a></code> | <code>string</code> | Name is the registered name of the CSI driver. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.AllowedCsiDriverV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name is the registered name of the CSI driver.

---

### AllowedFlexVolumeV1Beta1 <a name="AllowedFlexVolumeV1Beta1" id="cdk8s-metaflow.k8s.AllowedFlexVolumeV1Beta1"></a>

AllowedFlexVolume represents a single Flexvolume that is allowed to be used.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.AllowedFlexVolumeV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const allowedFlexVolumeV1Beta1: k8s.AllowedFlexVolumeV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.AllowedFlexVolumeV1Beta1.property.driver">driver</a></code> | <code>string</code> | driver is the name of the Flexvolume driver. |

---

##### `driver`<sup>Required</sup> <a name="driver" id="cdk8s-metaflow.k8s.AllowedFlexVolumeV1Beta1.property.driver"></a>

```typescript
public readonly driver: string;
```

- *Type:* string

driver is the name of the Flexvolume driver.

---

### AllowedHostPathV1Beta1 <a name="AllowedHostPathV1Beta1" id="cdk8s-metaflow.k8s.AllowedHostPathV1Beta1"></a>

AllowedHostPath defines the host volume conditions that will be enabled by a policy for pods to use.

It requires the path prefix to be defined.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.AllowedHostPathV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const allowedHostPathV1Beta1: k8s.AllowedHostPathV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.AllowedHostPathV1Beta1.property.pathPrefix">pathPrefix</a></code> | <code>string</code> | pathPrefix is the path prefix that the host volume must match. |
| <code><a href="#cdk8s-metaflow.k8s.AllowedHostPathV1Beta1.property.readOnly">readOnly</a></code> | <code>boolean</code> | when set to true, will allow host volumes matching the pathPrefix only if all volume mounts are readOnly. |

---

##### `pathPrefix`<sup>Optional</sup> <a name="pathPrefix" id="cdk8s-metaflow.k8s.AllowedHostPathV1Beta1.property.pathPrefix"></a>

```typescript
public readonly pathPrefix: string;
```

- *Type:* string

pathPrefix is the path prefix that the host volume must match.

It does not support `*`. Trailing slashes are trimmed when validating the path prefix with a host path.

Examples: `/foo` would allow `/foo`, `/foo/` and `/foo/bar` `/foo` would not allow `/food` or `/etc/foo`

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.AllowedHostPathV1Beta1.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean

when set to true, will allow host volumes matching the pathPrefix only if all volume mounts are readOnly.

---

### ApiServiceListProps <a name="ApiServiceListProps" id="cdk8s-metaflow.k8s.ApiServiceListProps"></a>

APIServiceList is a list of APIService objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ApiServiceListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const apiServiceListProps: k8s.ApiServiceListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.ApiService[]</code> | Items is the list of APIService. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.ApiServiceListProps.property.items"></a>

```typescript
public readonly items: ApiService[];
```

- *Type:* cdk8s-metaflow.k8s.ApiService[]

Items is the list of APIService.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ApiServiceListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

### ApiServiceProps <a name="ApiServiceProps" id="cdk8s-metaflow.k8s.ApiServiceProps"></a>

APIService represents a server for a particular GroupVersion.

Name must be "version.group".

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ApiServiceProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const apiServiceProps: k8s.ApiServiceProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.ApiServiceSpec</code> | Spec contains information for locating and communicating with a server. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ApiServiceProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.ApiServiceProps.property.spec"></a>

```typescript
public readonly spec: ApiServiceSpec;
```

- *Type:* cdk8s-metaflow.k8s.ApiServiceSpec

Spec contains information for locating and communicating with a server.

---

### ApiServiceSpec <a name="ApiServiceSpec" id="cdk8s-metaflow.k8s.ApiServiceSpec"></a>

APIServiceSpec contains information for locating and communicating with a server.

Only https is supported, though you are able to disable certificate verification.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ApiServiceSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const apiServiceSpec: k8s.ApiServiceSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceSpec.property.groupPriorityMinimum">groupPriorityMinimum</a></code> | <code>number</code> | GroupPriorityMininum is the priority this group should have at least. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceSpec.property.versionPriority">versionPriority</a></code> | <code>number</code> | VersionPriority controls the ordering of this API version inside of its group. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceSpec.property.caBundle">caBundle</a></code> | <code>string</code> | CABundle is a PEM encoded CA bundle which will be used to validate an API server's serving certificate. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceSpec.property.group">group</a></code> | <code>string</code> | Group is the API group name this server hosts. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceSpec.property.insecureSkipTlsVerify">insecureSkipTlsVerify</a></code> | <code>boolean</code> | InsecureSkipTLSVerify disables TLS certificate verification when communicating with this server. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceSpec.property.service">service</a></code> | <code>cdk8s-metaflow.k8s.ServiceReference</code> | Service is a reference to the service for this API server. |
| <code><a href="#cdk8s-metaflow.k8s.ApiServiceSpec.property.version">version</a></code> | <code>string</code> | Version is the API version this server hosts. |

---

##### `groupPriorityMinimum`<sup>Required</sup> <a name="groupPriorityMinimum" id="cdk8s-metaflow.k8s.ApiServiceSpec.property.groupPriorityMinimum"></a>

```typescript
public readonly groupPriorityMinimum: number;
```

- *Type:* number

GroupPriorityMininum is the priority this group should have at least.

Higher priority means that the group is preferred by clients over lower priority ones. Note that other versions of this group might specify even higher GroupPriorityMininum values such that the whole group gets a higher priority. The primary sort is based on GroupPriorityMinimum, ordered highest number to lowest (20 before 10). The secondary sort is based on the alphabetical comparison of the name of the object.  (v1.bar before v1.foo) We'd recommend something like: *.k8s.io (except extensions) at 18000 and PaaSes (OpenShift, Deis) are recommended to be in the 2000s

---

##### `versionPriority`<sup>Required</sup> <a name="versionPriority" id="cdk8s-metaflow.k8s.ApiServiceSpec.property.versionPriority"></a>

```typescript
public readonly versionPriority: number;
```

- *Type:* number

VersionPriority controls the ordering of this API version inside of its group.

Must be greater than zero. The primary sort is based on VersionPriority, ordered highest to lowest (20 before 10). Since it's inside of a group, the number can be small, probably in the 10s. In case of equal version priorities, the version string will be used to compute the order inside a group. If the version string is "kube-like", it will sort above non "kube-like" version strings, which are ordered lexicographically. "Kube-like" versions start with a "v", then are followed by a number (the major version), then optionally the string "alpha" or "beta" and another number (the minor version). These are sorted first by GA > beta > alpha (where GA is a version with no suffix such as beta or alpha), and then by comparing major version, then minor version. An example sorted list of versions: v10, v2, v1, v11beta2, v10beta3, v3beta1, v12alpha1, v11alpha2, foo1, foo10.

---

##### `caBundle`<sup>Optional</sup> <a name="caBundle" id="cdk8s-metaflow.k8s.ApiServiceSpec.property.caBundle"></a>

```typescript
public readonly caBundle: string;
```

- *Type:* string

CABundle is a PEM encoded CA bundle which will be used to validate an API server's serving certificate.

If unspecified, system trust roots on the apiserver are used.

---

##### `group`<sup>Optional</sup> <a name="group" id="cdk8s-metaflow.k8s.ApiServiceSpec.property.group"></a>

```typescript
public readonly group: string;
```

- *Type:* string

Group is the API group name this server hosts.

---

##### `insecureSkipTlsVerify`<sup>Optional</sup> <a name="insecureSkipTlsVerify" id="cdk8s-metaflow.k8s.ApiServiceSpec.property.insecureSkipTlsVerify"></a>

```typescript
public readonly insecureSkipTlsVerify: boolean;
```

- *Type:* boolean

InsecureSkipTLSVerify disables TLS certificate verification when communicating with this server.

This is strongly discouraged.  You should use the CABundle instead.

---

##### `service`<sup>Optional</sup> <a name="service" id="cdk8s-metaflow.k8s.ApiServiceSpec.property.service"></a>

```typescript
public readonly service: ServiceReference;
```

- *Type:* cdk8s-metaflow.k8s.ServiceReference

Service is a reference to the service for this API server.

It must communicate on port 443. If the Service is nil, that means the handling for the API groupversion is handled locally on this server. The call will simply delegate to the normal handler chain to be fulfilled.

---

##### `version`<sup>Optional</sup> <a name="version" id="cdk8s-metaflow.k8s.ApiServiceSpec.property.version"></a>

```typescript
public readonly version: string;
```

- *Type:* string

Version is the API version this server hosts.

For example, "v1"

---

### AutoscalingOptions <a name="AutoscalingOptions" id="cdk8s-metaflow.AutoscalingOptions"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.AutoscalingOptions.Initializer"></a>

```typescript
import { AutoscalingOptions } from 'cdk8s-metaflow'

const autoscalingOptions: AutoscalingOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.AutoscalingOptions.property.enabled">enabled</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.AutoscalingOptions.property.maxReplicas">maxReplicas</a></code> | <code>number</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.AutoscalingOptions.property.minReplicas">minReplicas</a></code> | <code>number</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.AutoscalingOptions.property.targetCPUUtilizationPercentage">targetCPUUtilizationPercentage</a></code> | <code>number</code> | *No description.* |

---

##### `enabled`<sup>Optional</sup> <a name="enabled" id="cdk8s-metaflow.AutoscalingOptions.property.enabled"></a>

```typescript
public readonly enabled: boolean;
```

- *Type:* boolean

---

##### `maxReplicas`<sup>Optional</sup> <a name="maxReplicas" id="cdk8s-metaflow.AutoscalingOptions.property.maxReplicas"></a>

```typescript
public readonly maxReplicas: number;
```

- *Type:* number

---

##### `minReplicas`<sup>Optional</sup> <a name="minReplicas" id="cdk8s-metaflow.AutoscalingOptions.property.minReplicas"></a>

```typescript
public readonly minReplicas: number;
```

- *Type:* number

---

##### `targetCPUUtilizationPercentage`<sup>Optional</sup> <a name="targetCPUUtilizationPercentage" id="cdk8s-metaflow.AutoscalingOptions.property.targetCPUUtilizationPercentage"></a>

```typescript
public readonly targetCPUUtilizationPercentage: number;
```

- *Type:* number

---

### AwsElasticBlockStoreVolumeSource <a name="AwsElasticBlockStoreVolumeSource" id="cdk8s-metaflow.k8s.AwsElasticBlockStoreVolumeSource"></a>

Represents a Persistent Disk resource in AWS.

An AWS EBS disk must exist before mounting to a container. The disk must also be in the same AWS zone as the kubelet. An AWS EBS disk can only be mounted as read/write once. AWS EBS volumes support ownership management and SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.AwsElasticBlockStoreVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const awsElasticBlockStoreVolumeSource: k8s.AwsElasticBlockStoreVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.AwsElasticBlockStoreVolumeSource.property.volumeId">volumeId</a></code> | <code>string</code> | Unique ID of the persistent disk resource in AWS (Amazon EBS volume). |
| <code><a href="#cdk8s-metaflow.k8s.AwsElasticBlockStoreVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type of the volume that you want to mount. |
| <code><a href="#cdk8s-metaflow.k8s.AwsElasticBlockStoreVolumeSource.property.partition">partition</a></code> | <code>number</code> | The partition in the volume that you want to mount. |
| <code><a href="#cdk8s-metaflow.k8s.AwsElasticBlockStoreVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Specify "true" to force and set the ReadOnly property in VolumeMounts to "true". |

---

##### `volumeId`<sup>Required</sup> <a name="volumeId" id="cdk8s-metaflow.k8s.AwsElasticBlockStoreVolumeSource.property.volumeId"></a>

```typescript
public readonly volumeId: string;
```

- *Type:* string

Unique ID of the persistent disk resource in AWS (Amazon EBS volume).

More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.AwsElasticBlockStoreVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type of the volume that you want to mount.

Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore

---

##### `partition`<sup>Optional</sup> <a name="partition" id="cdk8s-metaflow.k8s.AwsElasticBlockStoreVolumeSource.property.partition"></a>

```typescript
public readonly partition: number;
```

- *Type:* number

The partition in the volume that you want to mount.

If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty).

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.AwsElasticBlockStoreVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean

Specify "true" to force and set the ReadOnly property in VolumeMounts to "true".

If omitted, the default is "false". More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore

---

### AzureDiskVolumeSource <a name="AzureDiskVolumeSource" id="cdk8s-metaflow.k8s.AzureDiskVolumeSource"></a>

AzureDisk represents an Azure Data Disk mount on the host and bind mount to the pod.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.AzureDiskVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const azureDiskVolumeSource: k8s.AzureDiskVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.AzureDiskVolumeSource.property.diskName">diskName</a></code> | <code>string</code> | The Name of the data disk in the blob storage. |
| <code><a href="#cdk8s-metaflow.k8s.AzureDiskVolumeSource.property.diskUri">diskUri</a></code> | <code>string</code> | The URI the data disk in the blob storage. |
| <code><a href="#cdk8s-metaflow.k8s.AzureDiskVolumeSource.property.cachingMode">cachingMode</a></code> | <code>string</code> | Host Caching mode: None, Read Only, Read Write. |
| <code><a href="#cdk8s-metaflow.k8s.AzureDiskVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type to mount. |
| <code><a href="#cdk8s-metaflow.k8s.AzureDiskVolumeSource.property.kind">kind</a></code> | <code>string</code> | Expected values Shared: multiple blob disks per storage account  Dedicated: single blob disk per storage account  Managed: azure managed data disk (only in managed availability set). |
| <code><a href="#cdk8s-metaflow.k8s.AzureDiskVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Defaults to false (read/write). |

---

##### `diskName`<sup>Required</sup> <a name="diskName" id="cdk8s-metaflow.k8s.AzureDiskVolumeSource.property.diskName"></a>

```typescript
public readonly diskName: string;
```

- *Type:* string

The Name of the data disk in the blob storage.

---

##### `diskUri`<sup>Required</sup> <a name="diskUri" id="cdk8s-metaflow.k8s.AzureDiskVolumeSource.property.diskUri"></a>

```typescript
public readonly diskUri: string;
```

- *Type:* string

The URI the data disk in the blob storage.

---

##### `cachingMode`<sup>Optional</sup> <a name="cachingMode" id="cdk8s-metaflow.k8s.AzureDiskVolumeSource.property.cachingMode"></a>

```typescript
public readonly cachingMode: string;
```

- *Type:* string

Host Caching mode: None, Read Only, Read Write.

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.AzureDiskVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type to mount.

Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.

---

##### `kind`<sup>Optional</sup> <a name="kind" id="cdk8s-metaflow.k8s.AzureDiskVolumeSource.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

Expected values Shared: multiple blob disks per storage account  Dedicated: single blob disk per storage account  Managed: azure managed data disk (only in managed availability set).

defaults to shared

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.AzureDiskVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.

Defaults to false (read/write).

ReadOnly here will force the ReadOnly setting in VolumeMounts.

---

### AzureFilePersistentVolumeSource <a name="AzureFilePersistentVolumeSource" id="cdk8s-metaflow.k8s.AzureFilePersistentVolumeSource"></a>

AzureFile represents an Azure File Service mount on the host and bind mount to the pod.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.AzureFilePersistentVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const azureFilePersistentVolumeSource: k8s.AzureFilePersistentVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.AzureFilePersistentVolumeSource.property.secretName">secretName</a></code> | <code>string</code> | the name of secret that contains Azure Storage Account Name and Key. |
| <code><a href="#cdk8s-metaflow.k8s.AzureFilePersistentVolumeSource.property.shareName">shareName</a></code> | <code>string</code> | Share Name. |
| <code><a href="#cdk8s-metaflow.k8s.AzureFilePersistentVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Defaults to false (read/write). |
| <code><a href="#cdk8s-metaflow.k8s.AzureFilePersistentVolumeSource.property.secretNamespace">secretNamespace</a></code> | <code>string</code> | the namespace of the secret that contains Azure Storage Account Name and Key default is the same as the Pod. |

---

##### `secretName`<sup>Required</sup> <a name="secretName" id="cdk8s-metaflow.k8s.AzureFilePersistentVolumeSource.property.secretName"></a>

```typescript
public readonly secretName: string;
```

- *Type:* string

the name of secret that contains Azure Storage Account Name and Key.

---

##### `shareName`<sup>Required</sup> <a name="shareName" id="cdk8s-metaflow.k8s.AzureFilePersistentVolumeSource.property.shareName"></a>

```typescript
public readonly shareName: string;
```

- *Type:* string

Share Name.

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.AzureFilePersistentVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.

Defaults to false (read/write).

ReadOnly here will force the ReadOnly setting in VolumeMounts.

---

##### `secretNamespace`<sup>Optional</sup> <a name="secretNamespace" id="cdk8s-metaflow.k8s.AzureFilePersistentVolumeSource.property.secretNamespace"></a>

```typescript
public readonly secretNamespace: string;
```

- *Type:* string

the namespace of the secret that contains Azure Storage Account Name and Key default is the same as the Pod.

---

### AzureFileVolumeSource <a name="AzureFileVolumeSource" id="cdk8s-metaflow.k8s.AzureFileVolumeSource"></a>

AzureFile represents an Azure File Service mount on the host and bind mount to the pod.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.AzureFileVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const azureFileVolumeSource: k8s.AzureFileVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.AzureFileVolumeSource.property.secretName">secretName</a></code> | <code>string</code> | the name of secret that contains Azure Storage Account Name and Key. |
| <code><a href="#cdk8s-metaflow.k8s.AzureFileVolumeSource.property.shareName">shareName</a></code> | <code>string</code> | Share Name. |
| <code><a href="#cdk8s-metaflow.k8s.AzureFileVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Defaults to false (read/write). |

---

##### `secretName`<sup>Required</sup> <a name="secretName" id="cdk8s-metaflow.k8s.AzureFileVolumeSource.property.secretName"></a>

```typescript
public readonly secretName: string;
```

- *Type:* string

the name of secret that contains Azure Storage Account Name and Key.

---

##### `shareName`<sup>Required</sup> <a name="shareName" id="cdk8s-metaflow.k8s.AzureFileVolumeSource.property.shareName"></a>

```typescript
public readonly shareName: string;
```

- *Type:* string

Share Name.

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.AzureFileVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.

Defaults to false (read/write).

ReadOnly here will force the ReadOnly setting in VolumeMounts.

---

### BindingProps <a name="BindingProps" id="cdk8s-metaflow.k8s.BindingProps"></a>

Binding ties one object to another;

for example, a pod is bound to a node by a scheduler. Deprecated in 1.7, please use the bindings subresource of pods instead.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.BindingProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const bindingProps: k8s.BindingProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.BindingProps.property.target">target</a></code> | <code>cdk8s-metaflow.k8s.ObjectReference</code> | The target object that you want to bind to the standard object. |
| <code><a href="#cdk8s-metaflow.k8s.BindingProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |

---

##### `target`<sup>Required</sup> <a name="target" id="cdk8s-metaflow.k8s.BindingProps.property.target"></a>

```typescript
public readonly target: ObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.ObjectReference

The target object that you want to bind to the standard object.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.BindingProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### BoundObjectReference <a name="BoundObjectReference" id="cdk8s-metaflow.k8s.BoundObjectReference"></a>

BoundObjectReference is a reference to an object that a token is bound to.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.BoundObjectReference.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const boundObjectReference: k8s.BoundObjectReference = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.BoundObjectReference.property.apiVersion">apiVersion</a></code> | <code>string</code> | API version of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.BoundObjectReference.property.kind">kind</a></code> | <code>string</code> | Kind of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.BoundObjectReference.property.name">name</a></code> | <code>string</code> | Name of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.BoundObjectReference.property.uid">uid</a></code> | <code>string</code> | UID of the referent. |

---

##### `apiVersion`<sup>Optional</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.BoundObjectReference.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

API version of the referent.

---

##### `kind`<sup>Optional</sup> <a name="kind" id="cdk8s-metaflow.k8s.BoundObjectReference.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

Kind of the referent.

Valid kinds are 'Pod' and 'Secret'.

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.BoundObjectReference.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the referent.

---

##### `uid`<sup>Optional</sup> <a name="uid" id="cdk8s-metaflow.k8s.BoundObjectReference.property.uid"></a>

```typescript
public readonly uid: string;
```

- *Type:* string

UID of the referent.

---

### Capabilities <a name="Capabilities" id="cdk8s-metaflow.k8s.Capabilities"></a>

Adds and removes POSIX capabilities from running containers.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.Capabilities.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const capabilities: k8s.Capabilities = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Capabilities.property.add">add</a></code> | <code>string[]</code> | Added capabilities. |
| <code><a href="#cdk8s-metaflow.k8s.Capabilities.property.drop">drop</a></code> | <code>string[]</code> | Removed capabilities. |

---

##### `add`<sup>Optional</sup> <a name="add" id="cdk8s-metaflow.k8s.Capabilities.property.add"></a>

```typescript
public readonly add: string[];
```

- *Type:* string[]

Added capabilities.

---

##### `drop`<sup>Optional</sup> <a name="drop" id="cdk8s-metaflow.k8s.Capabilities.property.drop"></a>

```typescript
public readonly drop: string[];
```

- *Type:* string[]

Removed capabilities.

---

### CephFsPersistentVolumeSource <a name="CephFsPersistentVolumeSource" id="cdk8s-metaflow.k8s.CephFsPersistentVolumeSource"></a>

Represents a Ceph Filesystem mount that lasts the lifetime of a pod Cephfs volumes do not support ownership management or SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CephFsPersistentVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const cephFsPersistentVolumeSource: k8s.CephFsPersistentVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CephFsPersistentVolumeSource.property.monitors">monitors</a></code> | <code>string[]</code> | Required: Monitors is a collection of Ceph monitors More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it. |
| <code><a href="#cdk8s-metaflow.k8s.CephFsPersistentVolumeSource.property.path">path</a></code> | <code>string</code> | Optional: Used as the mounted root, rather than the full Ceph tree, default is /. |
| <code><a href="#cdk8s-metaflow.k8s.CephFsPersistentVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Optional: Defaults to false (read/write). |
| <code><a href="#cdk8s-metaflow.k8s.CephFsPersistentVolumeSource.property.secretFile">secretFile</a></code> | <code>string</code> | Optional: SecretFile is the path to key ring for User, default is /etc/ceph/user.secret More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it. |
| <code><a href="#cdk8s-metaflow.k8s.CephFsPersistentVolumeSource.property.secretRef">secretRef</a></code> | <code>cdk8s-metaflow.k8s.SecretReference</code> | Optional: SecretRef is reference to the authentication secret for User, default is empty. |
| <code><a href="#cdk8s-metaflow.k8s.CephFsPersistentVolumeSource.property.user">user</a></code> | <code>string</code> | Optional: User is the rados user name, default is admin More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it. |

---

##### `monitors`<sup>Required</sup> <a name="monitors" id="cdk8s-metaflow.k8s.CephFsPersistentVolumeSource.property.monitors"></a>

```typescript
public readonly monitors: string[];
```

- *Type:* string[]

Required: Monitors is a collection of Ceph monitors More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it.

---

##### `path`<sup>Optional</sup> <a name="path" id="cdk8s-metaflow.k8s.CephFsPersistentVolumeSource.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* string

Optional: Used as the mounted root, rather than the full Ceph tree, default is /.

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.CephFsPersistentVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it

Optional: Defaults to false (read/write).

ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it

---

##### `secretFile`<sup>Optional</sup> <a name="secretFile" id="cdk8s-metaflow.k8s.CephFsPersistentVolumeSource.property.secretFile"></a>

```typescript
public readonly secretFile: string;
```

- *Type:* string

Optional: SecretFile is the path to key ring for User, default is /etc/ceph/user.secret More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it.

---

##### `secretRef`<sup>Optional</sup> <a name="secretRef" id="cdk8s-metaflow.k8s.CephFsPersistentVolumeSource.property.secretRef"></a>

```typescript
public readonly secretRef: SecretReference;
```

- *Type:* cdk8s-metaflow.k8s.SecretReference

Optional: SecretRef is reference to the authentication secret for User, default is empty.

More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it

---

##### `user`<sup>Optional</sup> <a name="user" id="cdk8s-metaflow.k8s.CephFsPersistentVolumeSource.property.user"></a>

```typescript
public readonly user: string;
```

- *Type:* string

Optional: User is the rados user name, default is admin More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it.

---

### CephFsVolumeSource <a name="CephFsVolumeSource" id="cdk8s-metaflow.k8s.CephFsVolumeSource"></a>

Represents a Ceph Filesystem mount that lasts the lifetime of a pod Cephfs volumes do not support ownership management or SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CephFsVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const cephFsVolumeSource: k8s.CephFsVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CephFsVolumeSource.property.monitors">monitors</a></code> | <code>string[]</code> | Required: Monitors is a collection of Ceph monitors More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it. |
| <code><a href="#cdk8s-metaflow.k8s.CephFsVolumeSource.property.path">path</a></code> | <code>string</code> | Optional: Used as the mounted root, rather than the full Ceph tree, default is /. |
| <code><a href="#cdk8s-metaflow.k8s.CephFsVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Optional: Defaults to false (read/write). |
| <code><a href="#cdk8s-metaflow.k8s.CephFsVolumeSource.property.secretFile">secretFile</a></code> | <code>string</code> | Optional: SecretFile is the path to key ring for User, default is /etc/ceph/user.secret More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it. |
| <code><a href="#cdk8s-metaflow.k8s.CephFsVolumeSource.property.secretRef">secretRef</a></code> | <code>cdk8s-metaflow.k8s.LocalObjectReference</code> | Optional: SecretRef is reference to the authentication secret for User, default is empty. |
| <code><a href="#cdk8s-metaflow.k8s.CephFsVolumeSource.property.user">user</a></code> | <code>string</code> | Optional: User is the rados user name, default is admin More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it. |

---

##### `monitors`<sup>Required</sup> <a name="monitors" id="cdk8s-metaflow.k8s.CephFsVolumeSource.property.monitors"></a>

```typescript
public readonly monitors: string[];
```

- *Type:* string[]

Required: Monitors is a collection of Ceph monitors More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it.

---

##### `path`<sup>Optional</sup> <a name="path" id="cdk8s-metaflow.k8s.CephFsVolumeSource.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* string

Optional: Used as the mounted root, rather than the full Ceph tree, default is /.

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.CephFsVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it

Optional: Defaults to false (read/write).

ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it

---

##### `secretFile`<sup>Optional</sup> <a name="secretFile" id="cdk8s-metaflow.k8s.CephFsVolumeSource.property.secretFile"></a>

```typescript
public readonly secretFile: string;
```

- *Type:* string

Optional: SecretFile is the path to key ring for User, default is /etc/ceph/user.secret More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it.

---

##### `secretRef`<sup>Optional</sup> <a name="secretRef" id="cdk8s-metaflow.k8s.CephFsVolumeSource.property.secretRef"></a>

```typescript
public readonly secretRef: LocalObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.LocalObjectReference

Optional: SecretRef is reference to the authentication secret for User, default is empty.

More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it

---

##### `user`<sup>Optional</sup> <a name="user" id="cdk8s-metaflow.k8s.CephFsVolumeSource.property.user"></a>

```typescript
public readonly user: string;
```

- *Type:* string

Optional: User is the rados user name, default is admin More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it.

---

### CertificateSigningRequestListProps <a name="CertificateSigningRequestListProps" id="cdk8s-metaflow.k8s.CertificateSigningRequestListProps"></a>

CertificateSigningRequestList is a collection of CertificateSigningRequest objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CertificateSigningRequestListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const certificateSigningRequestListProps: k8s.CertificateSigningRequestListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.CertificateSigningRequest[]</code> | items is a collection of CertificateSigningRequest objects. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | *No description.* |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.CertificateSigningRequestListProps.property.items"></a>

```typescript
public readonly items: CertificateSigningRequest[];
```

- *Type:* cdk8s-metaflow.k8s.CertificateSigningRequest[]

items is a collection of CertificateSigningRequest objects.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CertificateSigningRequestListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

---

### CertificateSigningRequestProps <a name="CertificateSigningRequestProps" id="cdk8s-metaflow.k8s.CertificateSigningRequestProps"></a>

CertificateSigningRequest objects provide a mechanism to obtain x509 certificates by submitting a certificate signing request, and having it asynchronously approved and issued.

Kubelets use this API to obtain:
1. client certificates to authenticate to kube-apiserver (with the "kubernetes.io/kube-apiserver-client-kubelet" signerName).
2. serving certificates for TLS endpoints kube-apiserver can connect to securely (with the "kubernetes.io/kubelet-serving" signerName).

This API can be used to request client certificates to authenticate to kube-apiserver (with the "kubernetes.io/kube-apiserver-client" signerName), or to obtain certificates from custom non-Kubernetes signers.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CertificateSigningRequestProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const certificateSigningRequestProps: k8s.CertificateSigningRequestProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.CertificateSigningRequestSpec</code> | spec contains the certificate request, and is immutable after creation. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | *No description.* |

---

##### `spec`<sup>Required</sup> <a name="spec" id="cdk8s-metaflow.k8s.CertificateSigningRequestProps.property.spec"></a>

```typescript
public readonly spec: CertificateSigningRequestSpec;
```

- *Type:* cdk8s-metaflow.k8s.CertificateSigningRequestSpec

spec contains the certificate request, and is immutable after creation.

Only the request, signerName, expirationSeconds, and usages fields can be set on creation. Other fields are derived by Kubernetes and cannot be modified by users.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CertificateSigningRequestProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

---

### CertificateSigningRequestSpec <a name="CertificateSigningRequestSpec" id="cdk8s-metaflow.k8s.CertificateSigningRequestSpec"></a>

CertificateSigningRequestSpec contains the certificate request.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CertificateSigningRequestSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const certificateSigningRequestSpec: k8s.CertificateSigningRequestSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestSpec.property.request">request</a></code> | <code>string</code> | request contains an x509 certificate signing request encoded in a "CERTIFICATE REQUEST" PEM block. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestSpec.property.signerName">signerName</a></code> | <code>string</code> | signerName indicates the requested signer, and is a qualified name. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestSpec.property.expirationSeconds">expirationSeconds</a></code> | <code>number</code> | expirationSeconds is the requested duration of validity of the issued certificate. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestSpec.property.extra">extra</a></code> | <code>{[ key: string ]: string[]}</code> | extra contains extra attributes of the user that created the CertificateSigningRequest. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestSpec.property.groups">groups</a></code> | <code>string[]</code> | groups contains group membership of the user that created the CertificateSigningRequest. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestSpec.property.uid">uid</a></code> | <code>string</code> | uid contains the uid of the user that created the CertificateSigningRequest. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestSpec.property.usages">usages</a></code> | <code>string[]</code> | usages specifies a set of key usages requested in the issued certificate. |
| <code><a href="#cdk8s-metaflow.k8s.CertificateSigningRequestSpec.property.username">username</a></code> | <code>string</code> | username contains the name of the user that created the CertificateSigningRequest. |

---

##### `request`<sup>Required</sup> <a name="request" id="cdk8s-metaflow.k8s.CertificateSigningRequestSpec.property.request"></a>

```typescript
public readonly request: string;
```

- *Type:* string

request contains an x509 certificate signing request encoded in a "CERTIFICATE REQUEST" PEM block.

When serialized as JSON or YAML, the data is additionally base64-encoded.

---

##### `signerName`<sup>Required</sup> <a name="signerName" id="cdk8s-metaflow.k8s.CertificateSigningRequestSpec.property.signerName"></a>

```typescript
public readonly signerName: string;
```

- *Type:* string

signerName indicates the requested signer, and is a qualified name.

List/watch requests for CertificateSigningRequests can filter on this field using a "spec.signerName=NAME" fieldSelector.

Well-known Kubernetes signers are:
1. "kubernetes.io/kube-apiserver-client": issues client certificates that can be used to authenticate to kube-apiserver.
Requests for this signer are never auto-approved by kube-controller-manager, can be issued by the "csrsigning" controller in kube-controller-manager.
2. "kubernetes.io/kube-apiserver-client-kubelet": issues client certificates that kubelets use to authenticate to kube-apiserver.
Requests for this signer can be auto-approved by the "csrapproving" controller in kube-controller-manager, and can be issued by the "csrsigning" controller in kube-controller-manager.
3. "kubernetes.io/kubelet-serving" issues serving certificates that kubelets use to serve TLS endpoints, which kube-apiserver can connect to securely.
Requests for this signer are never auto-approved by kube-controller-manager, and can be issued by the "csrsigning" controller in kube-controller-manager.

More details are available at https://k8s.io/docs/reference/access-authn-authz/certificate-signing-requests/#kubernetes-signers

Custom signerNames can also be specified. The signer defines:
1. Trust distribution: how trust (CA bundles) are distributed.
2. Permitted subjects: and behavior when a disallowed subject is requested.
3. Required, permitted, or forbidden x509 extensions in the request (including whether subjectAltNames are allowed, which types, restrictions on allowed values) and behavior when a disallowed extension is requested.
4. Required, permitted, or forbidden key usages / extended key usages.
5. Expiration/certificate lifetime: whether it is fixed by the signer, configurable by the admin.
6. Whether or not requests for CA certificates are allowed.

---

##### `expirationSeconds`<sup>Optional</sup> <a name="expirationSeconds" id="cdk8s-metaflow.k8s.CertificateSigningRequestSpec.property.expirationSeconds"></a>

```typescript
public readonly expirationSeconds: number;
```

- *Type:* number

expirationSeconds is the requested duration of validity of the issued certificate.

The certificate signer may issue a certificate with a different validity duration so a client must check the delta between the notBefore and and notAfter fields in the issued certificate to determine the actual duration.

The v1.22+ in-tree implementations of the well-known Kubernetes signers will honor this field as long as the requested duration is not greater than the maximum duration they will honor per the --cluster-signing-duration CLI flag to the Kubernetes controller manager.

Certificate signers may not honor this field for various reasons:

1. Old signer that is unaware of the field (such as the in-tree
implementations prior to v1.22)
2. Signer whose configured maximum is shorter than the requested duration
3. Signer whose configured minimum is longer than the requested duration

The minimum valid value for expirationSeconds is 600, i.e. 10 minutes.

As of v1.22, this field is beta and is controlled via the CSRDuration feature gate.

---

##### `extra`<sup>Optional</sup> <a name="extra" id="cdk8s-metaflow.k8s.CertificateSigningRequestSpec.property.extra"></a>

```typescript
public readonly extra: {[ key: string ]: string[]};
```

- *Type:* {[ key: string ]: string[]}

extra contains extra attributes of the user that created the CertificateSigningRequest.

Populated by the API server on creation and immutable.

---

##### `groups`<sup>Optional</sup> <a name="groups" id="cdk8s-metaflow.k8s.CertificateSigningRequestSpec.property.groups"></a>

```typescript
public readonly groups: string[];
```

- *Type:* string[]

groups contains group membership of the user that created the CertificateSigningRequest.

Populated by the API server on creation and immutable.

---

##### `uid`<sup>Optional</sup> <a name="uid" id="cdk8s-metaflow.k8s.CertificateSigningRequestSpec.property.uid"></a>

```typescript
public readonly uid: string;
```

- *Type:* string

uid contains the uid of the user that created the CertificateSigningRequest.

Populated by the API server on creation and immutable.

---

##### `usages`<sup>Optional</sup> <a name="usages" id="cdk8s-metaflow.k8s.CertificateSigningRequestSpec.property.usages"></a>

```typescript
public readonly usages: string[];
```

- *Type:* string[]

usages specifies a set of key usages requested in the issued certificate.

Requests for TLS client certificates typically request: "digital signature", "key encipherment", "client auth".

Requests for TLS serving certificates typically request: "key encipherment", "digital signature", "server auth".

Valid values are:
"signing", "digital signature", "content commitment",
"key encipherment", "key agreement", "data encipherment",
"cert sign", "crl sign", "encipher only", "decipher only", "any",
"server auth", "client auth",
"code signing", "email protection", "s/mime",
"ipsec end system", "ipsec tunnel", "ipsec user",
"timestamping", "ocsp signing", "microsoft sgc", "netscape sgc"

---

##### `username`<sup>Optional</sup> <a name="username" id="cdk8s-metaflow.k8s.CertificateSigningRequestSpec.property.username"></a>

```typescript
public readonly username: string;
```

- *Type:* string

username contains the name of the user that created the CertificateSigningRequest.

Populated by the API server on creation and immutable.

---

### CinderPersistentVolumeSource <a name="CinderPersistentVolumeSource" id="cdk8s-metaflow.k8s.CinderPersistentVolumeSource"></a>

Represents a cinder volume resource in Openstack.

A Cinder volume must exist before mounting to a container. The volume must also be in the same region as the kubelet. Cinder volumes support ownership management and SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CinderPersistentVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const cinderPersistentVolumeSource: k8s.CinderPersistentVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CinderPersistentVolumeSource.property.volumeId">volumeId</a></code> | <code>string</code> | volume id used to identify the volume in cinder. |
| <code><a href="#cdk8s-metaflow.k8s.CinderPersistentVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type to mount. |
| <code><a href="#cdk8s-metaflow.k8s.CinderPersistentVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Optional: Defaults to false (read/write). |
| <code><a href="#cdk8s-metaflow.k8s.CinderPersistentVolumeSource.property.secretRef">secretRef</a></code> | <code>cdk8s-metaflow.k8s.SecretReference</code> | Optional: points to a secret object containing parameters used to connect to OpenStack. |

---

##### `volumeId`<sup>Required</sup> <a name="volumeId" id="cdk8s-metaflow.k8s.CinderPersistentVolumeSource.property.volumeId"></a>

```typescript
public readonly volumeId: string;
```

- *Type:* string

volume id used to identify the volume in cinder.

More info: https://examples.k8s.io/mysql-cinder-pd/README.md

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.CinderPersistentVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type to mount.

Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://examples.k8s.io/mysql-cinder-pd/README.md

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.CinderPersistentVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/mysql-cinder-pd/README.md

Optional: Defaults to false (read/write).

ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/mysql-cinder-pd/README.md

---

##### `secretRef`<sup>Optional</sup> <a name="secretRef" id="cdk8s-metaflow.k8s.CinderPersistentVolumeSource.property.secretRef"></a>

```typescript
public readonly secretRef: SecretReference;
```

- *Type:* cdk8s-metaflow.k8s.SecretReference

Optional: points to a secret object containing parameters used to connect to OpenStack.

---

### CinderVolumeSource <a name="CinderVolumeSource" id="cdk8s-metaflow.k8s.CinderVolumeSource"></a>

Represents a cinder volume resource in Openstack.

A Cinder volume must exist before mounting to a container. The volume must also be in the same region as the kubelet. Cinder volumes support ownership management and SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CinderVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const cinderVolumeSource: k8s.CinderVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CinderVolumeSource.property.volumeId">volumeId</a></code> | <code>string</code> | volume id used to identify the volume in cinder. |
| <code><a href="#cdk8s-metaflow.k8s.CinderVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type to mount. |
| <code><a href="#cdk8s-metaflow.k8s.CinderVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Optional: Defaults to false (read/write). |
| <code><a href="#cdk8s-metaflow.k8s.CinderVolumeSource.property.secretRef">secretRef</a></code> | <code>cdk8s-metaflow.k8s.LocalObjectReference</code> | Optional: points to a secret object containing parameters used to connect to OpenStack. |

---

##### `volumeId`<sup>Required</sup> <a name="volumeId" id="cdk8s-metaflow.k8s.CinderVolumeSource.property.volumeId"></a>

```typescript
public readonly volumeId: string;
```

- *Type:* string

volume id used to identify the volume in cinder.

More info: https://examples.k8s.io/mysql-cinder-pd/README.md

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.CinderVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type to mount.

Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://examples.k8s.io/mysql-cinder-pd/README.md

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.CinderVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/mysql-cinder-pd/README.md

Optional: Defaults to false (read/write).

ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/mysql-cinder-pd/README.md

---

##### `secretRef`<sup>Optional</sup> <a name="secretRef" id="cdk8s-metaflow.k8s.CinderVolumeSource.property.secretRef"></a>

```typescript
public readonly secretRef: LocalObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.LocalObjectReference

Optional: points to a secret object containing parameters used to connect to OpenStack.

---

### ClientIpConfig <a name="ClientIpConfig" id="cdk8s-metaflow.k8s.ClientIpConfig"></a>

ClientIPConfig represents the configurations of Client IP based session affinity.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ClientIpConfig.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const clientIpConfig: k8s.ClientIpConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClientIpConfig.property.timeoutSeconds">timeoutSeconds</a></code> | <code>number</code> | timeoutSeconds specifies the seconds of ClientIP type session sticky time. |

---

##### `timeoutSeconds`<sup>Optional</sup> <a name="timeoutSeconds" id="cdk8s-metaflow.k8s.ClientIpConfig.property.timeoutSeconds"></a>

```typescript
public readonly timeoutSeconds: number;
```

- *Type:* number

timeoutSeconds specifies the seconds of ClientIP type session sticky time.

The value must be >0 && <=86400(for 1 day) if ServiceAffinity == "ClientIP". Default value is 10800(for 3 hours).

---

### ClusterRoleBindingListProps <a name="ClusterRoleBindingListProps" id="cdk8s-metaflow.k8s.ClusterRoleBindingListProps"></a>

ClusterRoleBindingList is a collection of ClusterRoleBindings.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ClusterRoleBindingListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const clusterRoleBindingListProps: k8s.ClusterRoleBindingListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.ClusterRoleBinding[]</code> | Items is a list of ClusterRoleBindings. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard object's metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.ClusterRoleBindingListProps.property.items"></a>

```typescript
public readonly items: ClusterRoleBinding[];
```

- *Type:* cdk8s-metaflow.k8s.ClusterRoleBinding[]

Items is a list of ClusterRoleBindings.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ClusterRoleBindingListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard object's metadata.

---

### ClusterRoleBindingListV1Alpha1Props <a name="ClusterRoleBindingListV1Alpha1Props" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1Props"></a>

ClusterRoleBindingList is a collection of ClusterRoleBindings.

Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 ClusterRoleBindings, and will no longer be served in v1.22.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const clusterRoleBindingListV1Alpha1Props: k8s.ClusterRoleBindingListV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1[]</code> | Items is a list of ClusterRoleBindings. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard object's metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1Props.property.items"></a>

```typescript
public readonly items: ClusterRoleBindingV1Alpha1[];
```

- *Type:* cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1[]

Items is a list of ClusterRoleBindings.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ClusterRoleBindingListV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard object's metadata.

---

### ClusterRoleBindingProps <a name="ClusterRoleBindingProps" id="cdk8s-metaflow.k8s.ClusterRoleBindingProps"></a>

ClusterRoleBinding references a ClusterRole, but not contain it.

It can reference a ClusterRole in the global namespace, and adds who information via Subject.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ClusterRoleBindingProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const clusterRoleBindingProps: k8s.ClusterRoleBindingProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingProps.property.roleRef">roleRef</a></code> | <code>cdk8s-metaflow.k8s.RoleRef</code> | RoleRef can only reference a ClusterRole in the global namespace. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingProps.property.subjects">subjects</a></code> | <code>cdk8s-metaflow.k8s.Subject[]</code> | Subjects holds references to the objects the role applies to. |

---

##### `roleRef`<sup>Required</sup> <a name="roleRef" id="cdk8s-metaflow.k8s.ClusterRoleBindingProps.property.roleRef"></a>

```typescript
public readonly roleRef: RoleRef;
```

- *Type:* cdk8s-metaflow.k8s.RoleRef

RoleRef can only reference a ClusterRole in the global namespace.

If the RoleRef cannot be resolved, the Authorizer must return an error.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ClusterRoleBindingProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

---

##### `subjects`<sup>Optional</sup> <a name="subjects" id="cdk8s-metaflow.k8s.ClusterRoleBindingProps.property.subjects"></a>

```typescript
public readonly subjects: Subject[];
```

- *Type:* cdk8s-metaflow.k8s.Subject[]

Subjects holds references to the objects the role applies to.

---

### ClusterRoleBindingV1Alpha1Props <a name="ClusterRoleBindingV1Alpha1Props" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1Props"></a>

ClusterRoleBinding references a ClusterRole, but not contain it.

It can reference a ClusterRole in the global namespace, and adds who information via Subject. Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 ClusterRoleBinding, and will no longer be served in v1.22.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const clusterRoleBindingV1Alpha1Props: k8s.ClusterRoleBindingV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1Props.property.roleRef">roleRef</a></code> | <code>cdk8s-metaflow.k8s.RoleRefV1Alpha1</code> | RoleRef can only reference a ClusterRole in the global namespace. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1Props.property.subjects">subjects</a></code> | <code>cdk8s-metaflow.k8s.SubjectV1Alpha1[]</code> | Subjects holds references to the objects the role applies to. |

---

##### `roleRef`<sup>Required</sup> <a name="roleRef" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1Props.property.roleRef"></a>

```typescript
public readonly roleRef: RoleRefV1Alpha1;
```

- *Type:* cdk8s-metaflow.k8s.RoleRefV1Alpha1

RoleRef can only reference a ClusterRole in the global namespace.

If the RoleRef cannot be resolved, the Authorizer must return an error.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

---

##### `subjects`<sup>Optional</sup> <a name="subjects" id="cdk8s-metaflow.k8s.ClusterRoleBindingV1Alpha1Props.property.subjects"></a>

```typescript
public readonly subjects: SubjectV1Alpha1[];
```

- *Type:* cdk8s-metaflow.k8s.SubjectV1Alpha1[]

Subjects holds references to the objects the role applies to.

---

### ClusterRoleListProps <a name="ClusterRoleListProps" id="cdk8s-metaflow.k8s.ClusterRoleListProps"></a>

ClusterRoleList is a collection of ClusterRoles.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ClusterRoleListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const clusterRoleListProps: k8s.ClusterRoleListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.ClusterRole[]</code> | Items is a list of ClusterRoles. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard object's metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.ClusterRoleListProps.property.items"></a>

```typescript
public readonly items: ClusterRole[];
```

- *Type:* cdk8s-metaflow.k8s.ClusterRole[]

Items is a list of ClusterRoles.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ClusterRoleListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard object's metadata.

---

### ClusterRoleListV1Alpha1Props <a name="ClusterRoleListV1Alpha1Props" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1Props"></a>

ClusterRoleList is a collection of ClusterRoles.

Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 ClusterRoles, and will no longer be served in v1.22.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const clusterRoleListV1Alpha1Props: k8s.ClusterRoleListV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.ClusterRoleV1Alpha1[]</code> | Items is a list of ClusterRoles. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard object's metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1Props.property.items"></a>

```typescript
public readonly items: ClusterRoleV1Alpha1[];
```

- *Type:* cdk8s-metaflow.k8s.ClusterRoleV1Alpha1[]

Items is a list of ClusterRoles.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ClusterRoleListV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard object's metadata.

---

### ClusterRoleProps <a name="ClusterRoleProps" id="cdk8s-metaflow.k8s.ClusterRoleProps"></a>

ClusterRole is a cluster level, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding or ClusterRoleBinding.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ClusterRoleProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const clusterRoleProps: k8s.ClusterRoleProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleProps.property.aggregationRule">aggregationRule</a></code> | <code>cdk8s-metaflow.k8s.AggregationRule</code> | AggregationRule is an optional field that describes how to build the Rules for this ClusterRole. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleProps.property.rules">rules</a></code> | <code>cdk8s-metaflow.k8s.PolicyRule[]</code> | Rules holds all the PolicyRules for this ClusterRole. |

---

##### `aggregationRule`<sup>Optional</sup> <a name="aggregationRule" id="cdk8s-metaflow.k8s.ClusterRoleProps.property.aggregationRule"></a>

```typescript
public readonly aggregationRule: AggregationRule;
```

- *Type:* cdk8s-metaflow.k8s.AggregationRule

AggregationRule is an optional field that describes how to build the Rules for this ClusterRole.

If AggregationRule is set, then the Rules are controller managed and direct changes to Rules will be stomped by the controller.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ClusterRoleProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

---

##### `rules`<sup>Optional</sup> <a name="rules" id="cdk8s-metaflow.k8s.ClusterRoleProps.property.rules"></a>

```typescript
public readonly rules: PolicyRule[];
```

- *Type:* cdk8s-metaflow.k8s.PolicyRule[]

Rules holds all the PolicyRules for this ClusterRole.

---

### ClusterRoleV1Alpha1Props <a name="ClusterRoleV1Alpha1Props" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1Props"></a>

ClusterRole is a cluster level, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding or ClusterRoleBinding.

Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 ClusterRole, and will no longer be served in v1.22.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const clusterRoleV1Alpha1Props: k8s.ClusterRoleV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1Props.property.aggregationRule">aggregationRule</a></code> | <code>cdk8s-metaflow.k8s.AggregationRuleV1Alpha1</code> | AggregationRule is an optional field that describes how to build the Rules for this ClusterRole. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.ClusterRoleV1Alpha1Props.property.rules">rules</a></code> | <code>cdk8s-metaflow.k8s.PolicyRuleV1Alpha1[]</code> | Rules holds all the PolicyRules for this ClusterRole. |

---

##### `aggregationRule`<sup>Optional</sup> <a name="aggregationRule" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1Props.property.aggregationRule"></a>

```typescript
public readonly aggregationRule: AggregationRuleV1Alpha1;
```

- *Type:* cdk8s-metaflow.k8s.AggregationRuleV1Alpha1

AggregationRule is an optional field that describes how to build the Rules for this ClusterRole.

If AggregationRule is set, then the Rules are controller managed and direct changes to Rules will be stomped by the controller.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

---

##### `rules`<sup>Optional</sup> <a name="rules" id="cdk8s-metaflow.k8s.ClusterRoleV1Alpha1Props.property.rules"></a>

```typescript
public readonly rules: PolicyRuleV1Alpha1[];
```

- *Type:* cdk8s-metaflow.k8s.PolicyRuleV1Alpha1[]

Rules holds all the PolicyRules for this ClusterRole.

---

### ComponentCondition <a name="ComponentCondition" id="cdk8s-metaflow.k8s.ComponentCondition"></a>

Information about the condition of a component.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ComponentCondition.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const componentCondition: k8s.ComponentCondition = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ComponentCondition.property.status">status</a></code> | <code>string</code> | Status of the condition for a component. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentCondition.property.type">type</a></code> | <code>string</code> | Type of condition for a component. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentCondition.property.error">error</a></code> | <code>string</code> | Condition error code for a component. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentCondition.property.message">message</a></code> | <code>string</code> | Message about the condition for a component. |

---

##### `status`<sup>Required</sup> <a name="status" id="cdk8s-metaflow.k8s.ComponentCondition.property.status"></a>

```typescript
public readonly status: string;
```

- *Type:* string

Status of the condition for a component.

Valid values for "Healthy": "True", "False", or "Unknown".

---

##### `type`<sup>Required</sup> <a name="type" id="cdk8s-metaflow.k8s.ComponentCondition.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

Type of condition for a component.

Valid value: "Healthy"

---

##### `error`<sup>Optional</sup> <a name="error" id="cdk8s-metaflow.k8s.ComponentCondition.property.error"></a>

```typescript
public readonly error: string;
```

- *Type:* string

Condition error code for a component.

For example, a health check error code.

---

##### `message`<sup>Optional</sup> <a name="message" id="cdk8s-metaflow.k8s.ComponentCondition.property.message"></a>

```typescript
public readonly message: string;
```

- *Type:* string

Message about the condition for a component.

For example, information about a health check.

---

### ComponentStatusListProps <a name="ComponentStatusListProps" id="cdk8s-metaflow.k8s.ComponentStatusListProps"></a>

Status of all the conditions for the component as a list of ComponentStatus objects.

Deprecated: This API is deprecated in v1.19+

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ComponentStatusListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const componentStatusListProps: k8s.ComponentStatusListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.ComponentStatus[]</code> | List of ComponentStatus objects. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.ComponentStatusListProps.property.items"></a>

```typescript
public readonly items: ComponentStatus[];
```

- *Type:* cdk8s-metaflow.k8s.ComponentStatus[]

List of ComponentStatus objects.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ComponentStatusListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

### ComponentStatusProps <a name="ComponentStatusProps" id="cdk8s-metaflow.k8s.ComponentStatusProps"></a>

ComponentStatus (and ComponentStatusList) holds the cluster validation info.

Deprecated: This API is deprecated in v1.19+

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ComponentStatusProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const componentStatusProps: k8s.ComponentStatusProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusProps.property.conditions">conditions</a></code> | <code>cdk8s-metaflow.k8s.ComponentCondition[]</code> | List of component conditions observed. |
| <code><a href="#cdk8s-metaflow.k8s.ComponentStatusProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |

---

##### `conditions`<sup>Optional</sup> <a name="conditions" id="cdk8s-metaflow.k8s.ComponentStatusProps.property.conditions"></a>

```typescript
public readonly conditions: ComponentCondition[];
```

- *Type:* cdk8s-metaflow.k8s.ComponentCondition[]

List of component conditions observed.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ComponentStatusProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### ConfigMapEnvSource <a name="ConfigMapEnvSource" id="cdk8s-metaflow.k8s.ConfigMapEnvSource"></a>

ConfigMapEnvSource selects a ConfigMap to populate the environment variables with.

The contents of the target ConfigMap's Data field will represent the key-value pairs as environment variables.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ConfigMapEnvSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const configMapEnvSource: k8s.ConfigMapEnvSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapEnvSource.property.name">name</a></code> | <code>string</code> | Name of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapEnvSource.property.optional">optional</a></code> | <code>boolean</code> | Specify whether the ConfigMap must be defined. |

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.ConfigMapEnvSource.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the referent.

More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names

---

##### `optional`<sup>Optional</sup> <a name="optional" id="cdk8s-metaflow.k8s.ConfigMapEnvSource.property.optional"></a>

```typescript
public readonly optional: boolean;
```

- *Type:* boolean

Specify whether the ConfigMap must be defined.

---

### ConfigMapKeySelector <a name="ConfigMapKeySelector" id="cdk8s-metaflow.k8s.ConfigMapKeySelector"></a>

Selects a key from a ConfigMap.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ConfigMapKeySelector.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const configMapKeySelector: k8s.ConfigMapKeySelector = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapKeySelector.property.key">key</a></code> | <code>string</code> | The key to select. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapKeySelector.property.name">name</a></code> | <code>string</code> | Name of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapKeySelector.property.optional">optional</a></code> | <code>boolean</code> | Specify whether the ConfigMap or its key must be defined. |

---

##### `key`<sup>Required</sup> <a name="key" id="cdk8s-metaflow.k8s.ConfigMapKeySelector.property.key"></a>

```typescript
public readonly key: string;
```

- *Type:* string

The key to select.

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.ConfigMapKeySelector.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the referent.

More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names

---

##### `optional`<sup>Optional</sup> <a name="optional" id="cdk8s-metaflow.k8s.ConfigMapKeySelector.property.optional"></a>

```typescript
public readonly optional: boolean;
```

- *Type:* boolean

Specify whether the ConfigMap or its key must be defined.

---

### ConfigMapListProps <a name="ConfigMapListProps" id="cdk8s-metaflow.k8s.ConfigMapListProps"></a>

ConfigMapList is a resource containing a list of ConfigMap objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ConfigMapListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const configMapListProps: k8s.ConfigMapListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.ConfigMap[]</code> | Items is the list of ConfigMaps. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.ConfigMapListProps.property.items"></a>

```typescript
public readonly items: ConfigMap[];
```

- *Type:* cdk8s-metaflow.k8s.ConfigMap[]

Items is the list of ConfigMaps.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ConfigMapListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

### ConfigMapNodeConfigSource <a name="ConfigMapNodeConfigSource" id="cdk8s-metaflow.k8s.ConfigMapNodeConfigSource"></a>

ConfigMapNodeConfigSource contains the information to reference a ConfigMap as a config source for the Node.

This API is deprecated since 1.22: https://git.k8s.io/enhancements/keps/sig-node/281-dynamic-kubelet-configuration

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ConfigMapNodeConfigSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const configMapNodeConfigSource: k8s.ConfigMapNodeConfigSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapNodeConfigSource.property.kubeletConfigKey">kubeletConfigKey</a></code> | <code>string</code> | KubeletConfigKey declares which key of the referenced ConfigMap corresponds to the KubeletConfiguration structure This field is required in all cases. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapNodeConfigSource.property.name">name</a></code> | <code>string</code> | Name is the metadata.name of the referenced ConfigMap. This field is required in all cases. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapNodeConfigSource.property.namespace">namespace</a></code> | <code>string</code> | Namespace is the metadata.namespace of the referenced ConfigMap. This field is required in all cases. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapNodeConfigSource.property.resourceVersion">resourceVersion</a></code> | <code>string</code> | ResourceVersion is the metadata.ResourceVersion of the referenced ConfigMap. This field is forbidden in Node.Spec, and required in Node.Status. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapNodeConfigSource.property.uid">uid</a></code> | <code>string</code> | UID is the metadata.UID of the referenced ConfigMap. This field is forbidden in Node.Spec, and required in Node.Status. |

---

##### `kubeletConfigKey`<sup>Required</sup> <a name="kubeletConfigKey" id="cdk8s-metaflow.k8s.ConfigMapNodeConfigSource.property.kubeletConfigKey"></a>

```typescript
public readonly kubeletConfigKey: string;
```

- *Type:* string

KubeletConfigKey declares which key of the referenced ConfigMap corresponds to the KubeletConfiguration structure This field is required in all cases.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ConfigMapNodeConfigSource.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name is the metadata.name of the referenced ConfigMap. This field is required in all cases.

---

##### `namespace`<sup>Required</sup> <a name="namespace" id="cdk8s-metaflow.k8s.ConfigMapNodeConfigSource.property.namespace"></a>

```typescript
public readonly namespace: string;
```

- *Type:* string

Namespace is the metadata.namespace of the referenced ConfigMap. This field is required in all cases.

---

##### `resourceVersion`<sup>Optional</sup> <a name="resourceVersion" id="cdk8s-metaflow.k8s.ConfigMapNodeConfigSource.property.resourceVersion"></a>

```typescript
public readonly resourceVersion: string;
```

- *Type:* string

ResourceVersion is the metadata.ResourceVersion of the referenced ConfigMap. This field is forbidden in Node.Spec, and required in Node.Status.

---

##### `uid`<sup>Optional</sup> <a name="uid" id="cdk8s-metaflow.k8s.ConfigMapNodeConfigSource.property.uid"></a>

```typescript
public readonly uid: string;
```

- *Type:* string

UID is the metadata.UID of the referenced ConfigMap. This field is forbidden in Node.Spec, and required in Node.Status.

---

### ConfigMapProjection <a name="ConfigMapProjection" id="cdk8s-metaflow.k8s.ConfigMapProjection"></a>

Adapts a ConfigMap into a projected volume.

The contents of the target ConfigMap's Data field will be presented in a projected volume as files using the keys in the Data field as the file names, unless the items element is populated with specific mappings of keys to paths. Note that this is identical to a configmap volume source without the default mode.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ConfigMapProjection.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const configMapProjection: k8s.ConfigMapProjection = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapProjection.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.KeyToPath[]</code> | If unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapProjection.property.name">name</a></code> | <code>string</code> | Name of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapProjection.property.optional">optional</a></code> | <code>boolean</code> | Specify whether the ConfigMap or its keys must be defined. |

---

##### `items`<sup>Optional</sup> <a name="items" id="cdk8s-metaflow.k8s.ConfigMapProjection.property.items"></a>

```typescript
public readonly items: KeyToPath[];
```

- *Type:* cdk8s-metaflow.k8s.KeyToPath[]

If unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value.

If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.ConfigMapProjection.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the referent.

More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names

---

##### `optional`<sup>Optional</sup> <a name="optional" id="cdk8s-metaflow.k8s.ConfigMapProjection.property.optional"></a>

```typescript
public readonly optional: boolean;
```

- *Type:* boolean

Specify whether the ConfigMap or its keys must be defined.

---

### ConfigMapProps <a name="ConfigMapProps" id="cdk8s-metaflow.k8s.ConfigMapProps"></a>

ConfigMap holds configuration data for pods to consume.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ConfigMapProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const configMapProps: k8s.ConfigMapProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapProps.property.binaryData">binaryData</a></code> | <code>{[ key: string ]: string}</code> | BinaryData contains the binary data. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapProps.property.data">data</a></code> | <code>{[ key: string ]: string}</code> | Data contains the configuration data. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapProps.property.immutable">immutable</a></code> | <code>boolean</code> | Immutable, if set to true, ensures that data stored in the ConfigMap cannot be updated (only object metadata can be modified). |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |

---

##### `binaryData`<sup>Optional</sup> <a name="binaryData" id="cdk8s-metaflow.k8s.ConfigMapProps.property.binaryData"></a>

```typescript
public readonly binaryData: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

BinaryData contains the binary data.

Each key must consist of alphanumeric characters, '-', '_' or '.'. BinaryData can contain byte sequences that are not in the UTF-8 range. The keys stored in BinaryData must not overlap with the ones in the Data field, this is enforced during validation process. Using this field will require 1.10+ apiserver and kubelet.

---

##### `data`<sup>Optional</sup> <a name="data" id="cdk8s-metaflow.k8s.ConfigMapProps.property.data"></a>

```typescript
public readonly data: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

Data contains the configuration data.

Each key must consist of alphanumeric characters, '-', '_' or '.'. Values with non-UTF-8 byte sequences must use the BinaryData field. The keys stored in Data must not overlap with the keys in the BinaryData field, this is enforced during validation process.

---

##### `immutable`<sup>Optional</sup> <a name="immutable" id="cdk8s-metaflow.k8s.ConfigMapProps.property.immutable"></a>

```typescript
public readonly immutable: boolean;
```

- *Type:* boolean

Immutable, if set to true, ensures that data stored in the ConfigMap cannot be updated (only object metadata can be modified).

If not set to true, the field can be modified at any time. Defaulted to nil.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ConfigMapProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### ConfigMapVolumeSource <a name="ConfigMapVolumeSource" id="cdk8s-metaflow.k8s.ConfigMapVolumeSource"></a>

Adapts a ConfigMap into a volume.

The contents of the target ConfigMap's Data field will be presented in a volume as files using the keys in the Data field as the file names, unless the items element is populated with specific mappings of keys to paths. ConfigMap volumes support ownership management and SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ConfigMapVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const configMapVolumeSource: k8s.ConfigMapVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapVolumeSource.property.defaultMode">defaultMode</a></code> | <code>number</code> | Optional: mode bits used to set permissions on created files by default. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapVolumeSource.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.KeyToPath[]</code> | If unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapVolumeSource.property.name">name</a></code> | <code>string</code> | Name of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.ConfigMapVolumeSource.property.optional">optional</a></code> | <code>boolean</code> | Specify whether the ConfigMap or its keys must be defined. |

---

##### `defaultMode`<sup>Optional</sup> <a name="defaultMode" id="cdk8s-metaflow.k8s.ConfigMapVolumeSource.property.defaultMode"></a>

```typescript
public readonly defaultMode: number;
```

- *Type:* number
- *Default:* 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.

Optional: mode bits used to set permissions on created files by default.

Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.

---

##### `items`<sup>Optional</sup> <a name="items" id="cdk8s-metaflow.k8s.ConfigMapVolumeSource.property.items"></a>

```typescript
public readonly items: KeyToPath[];
```

- *Type:* cdk8s-metaflow.k8s.KeyToPath[]

If unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value.

If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.ConfigMapVolumeSource.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the referent.

More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names

---

##### `optional`<sup>Optional</sup> <a name="optional" id="cdk8s-metaflow.k8s.ConfigMapVolumeSource.property.optional"></a>

```typescript
public readonly optional: boolean;
```

- *Type:* boolean

Specify whether the ConfigMap or its keys must be defined.

---

### Container <a name="Container" id="cdk8s-metaflow.k8s.Container"></a>

A single application container that you want to run within a pod.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.Container.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const container: k8s.Container = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.name">name</a></code> | <code>string</code> | Name of the container specified as a DNS_LABEL. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.args">args</a></code> | <code>string[]</code> | Arguments to the entrypoint. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.command">command</a></code> | <code>string[]</code> | Entrypoint array. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.env">env</a></code> | <code>cdk8s-metaflow.k8s.EnvVar[]</code> | List of environment variables to set in the container. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.envFrom">envFrom</a></code> | <code>cdk8s-metaflow.k8s.EnvFromSource[]</code> | List of sources to populate environment variables in the container. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.image">image</a></code> | <code>string</code> | Docker image name. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.imagePullPolicy">imagePullPolicy</a></code> | <code>string</code> | Image pull policy. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.lifecycle">lifecycle</a></code> | <code>cdk8s-metaflow.k8s.Lifecycle</code> | Actions that the management system should take in response to container lifecycle events. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.livenessProbe">livenessProbe</a></code> | <code>cdk8s-metaflow.k8s.Probe</code> | Periodic probe of container liveness. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.ports">ports</a></code> | <code>cdk8s-metaflow.k8s.ContainerPort[]</code> | List of ports to expose from the container. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.readinessProbe">readinessProbe</a></code> | <code>cdk8s-metaflow.k8s.Probe</code> | Periodic probe of container service readiness. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.resources">resources</a></code> | <code>cdk8s-metaflow.k8s.ResourceRequirements</code> | Compute Resources required by this container. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.securityContext">securityContext</a></code> | <code>cdk8s-metaflow.k8s.SecurityContext</code> | SecurityContext defines the security options the container should be run with. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.startupProbe">startupProbe</a></code> | <code>cdk8s-metaflow.k8s.Probe</code> | StartupProbe indicates that the Pod has successfully initialized. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.stdin">stdin</a></code> | <code>boolean</code> | Whether this container should allocate a buffer for stdin in the container runtime. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.stdinOnce">stdinOnce</a></code> | <code>boolean</code> | Whether the container runtime should close the stdin channel after it has been opened by a single attach. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.terminationMessagePath">terminationMessagePath</a></code> | <code>string</code> | Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.terminationMessagePolicy">terminationMessagePolicy</a></code> | <code>string</code> | Indicate how the termination message should be populated. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.tty">tty</a></code> | <code>boolean</code> | Whether this container should allocate a TTY for itself, also requires 'stdin' to be true. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.volumeDevices">volumeDevices</a></code> | <code>cdk8s-metaflow.k8s.VolumeDevice[]</code> | volumeDevices is the list of block devices to be used by the container. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.volumeMounts">volumeMounts</a></code> | <code>cdk8s-metaflow.k8s.VolumeMount[]</code> | Pod volumes to mount into the container's filesystem. |
| <code><a href="#cdk8s-metaflow.k8s.Container.property.workingDir">workingDir</a></code> | <code>string</code> | Container's working directory. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Container.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the container specified as a DNS_LABEL.

Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.

---

##### `args`<sup>Optional</sup> <a name="args" id="cdk8s-metaflow.k8s.Container.property.args"></a>

```typescript
public readonly args: string[];
```

- *Type:* string[]

Arguments to the entrypoint.

The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell

---

##### `command`<sup>Optional</sup> <a name="command" id="cdk8s-metaflow.k8s.Container.property.command"></a>

```typescript
public readonly command: string[];
```

- *Type:* string[]

Entrypoint array.

Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell

---

##### `env`<sup>Optional</sup> <a name="env" id="cdk8s-metaflow.k8s.Container.property.env"></a>

```typescript
public readonly env: EnvVar[];
```

- *Type:* cdk8s-metaflow.k8s.EnvVar[]

List of environment variables to set in the container.

Cannot be updated.

---

##### `envFrom`<sup>Optional</sup> <a name="envFrom" id="cdk8s-metaflow.k8s.Container.property.envFrom"></a>

```typescript
public readonly envFrom: EnvFromSource[];
```

- *Type:* cdk8s-metaflow.k8s.EnvFromSource[]

List of sources to populate environment variables in the container.

The keys defined within a source must be a C_IDENTIFIER. All invalid keys will be reported as an event when the container is starting. When a key exists in multiple sources, the value associated with the last source will take precedence. Values defined by an Env with a duplicate key will take precedence. Cannot be updated.

---

##### `image`<sup>Optional</sup> <a name="image" id="cdk8s-metaflow.k8s.Container.property.image"></a>

```typescript
public readonly image: string;
```

- *Type:* string

Docker image name.

More info: https://kubernetes.io/docs/concepts/containers/images This field is optional to allow higher level config management to default or override container images in workload controllers like Deployments and StatefulSets.

---

##### `imagePullPolicy`<sup>Optional</sup> <a name="imagePullPolicy" id="cdk8s-metaflow.k8s.Container.property.imagePullPolicy"></a>

```typescript
public readonly imagePullPolicy: string;
```

- *Type:* string
- *Default:* Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: https://kubernetes.io/docs/concepts/containers/images#updating-images

Image pull policy.

One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: https://kubernetes.io/docs/concepts/containers/images#updating-images

---

##### `lifecycle`<sup>Optional</sup> <a name="lifecycle" id="cdk8s-metaflow.k8s.Container.property.lifecycle"></a>

```typescript
public readonly lifecycle: Lifecycle;
```

- *Type:* cdk8s-metaflow.k8s.Lifecycle

Actions that the management system should take in response to container lifecycle events.

Cannot be updated.

---

##### `livenessProbe`<sup>Optional</sup> <a name="livenessProbe" id="cdk8s-metaflow.k8s.Container.property.livenessProbe"></a>

```typescript
public readonly livenessProbe: Probe;
```

- *Type:* cdk8s-metaflow.k8s.Probe

Periodic probe of container liveness.

Container will be restarted if the probe fails. Cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes

---

##### `ports`<sup>Optional</sup> <a name="ports" id="cdk8s-metaflow.k8s.Container.property.ports"></a>

```typescript
public readonly ports: ContainerPort[];
```

- *Type:* cdk8s-metaflow.k8s.ContainerPort[]

List of ports to expose from the container.

Exposing a port here gives the system additional information about the network connections a container uses, but is primarily informational. Not specifying a port here DOES NOT prevent that port from being exposed. Any port which is listening on the default "0.0.0.0" address inside a container will be accessible from the network. Cannot be updated.

---

##### `readinessProbe`<sup>Optional</sup> <a name="readinessProbe" id="cdk8s-metaflow.k8s.Container.property.readinessProbe"></a>

```typescript
public readonly readinessProbe: Probe;
```

- *Type:* cdk8s-metaflow.k8s.Probe

Periodic probe of container service readiness.

Container will be removed from service endpoints if the probe fails. Cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes

---

##### `resources`<sup>Optional</sup> <a name="resources" id="cdk8s-metaflow.k8s.Container.property.resources"></a>

```typescript
public readonly resources: ResourceRequirements;
```

- *Type:* cdk8s-metaflow.k8s.ResourceRequirements

Compute Resources required by this container.

Cannot be updated. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/

---

##### `securityContext`<sup>Optional</sup> <a name="securityContext" id="cdk8s-metaflow.k8s.Container.property.securityContext"></a>

```typescript
public readonly securityContext: SecurityContext;
```

- *Type:* cdk8s-metaflow.k8s.SecurityContext

SecurityContext defines the security options the container should be run with.

If set, the fields of SecurityContext override the equivalent fields of PodSecurityContext. More info: https://kubernetes.io/docs/tasks/configure-pod-container/security-context/

---

##### `startupProbe`<sup>Optional</sup> <a name="startupProbe" id="cdk8s-metaflow.k8s.Container.property.startupProbe"></a>

```typescript
public readonly startupProbe: Probe;
```

- *Type:* cdk8s-metaflow.k8s.Probe

StartupProbe indicates that the Pod has successfully initialized.

If specified, no other probes are executed until this completes successfully. If this probe fails, the Pod will be restarted, just as if the livenessProbe failed. This can be used to provide different probe parameters at the beginning of a Pod's lifecycle, when it might take a long time to load data or warm a cache, than during steady-state operation. This cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes

---

##### `stdin`<sup>Optional</sup> <a name="stdin" id="cdk8s-metaflow.k8s.Container.property.stdin"></a>

```typescript
public readonly stdin: boolean;
```

- *Type:* boolean
- *Default:* false.

Whether this container should allocate a buffer for stdin in the container runtime.

If this is not set, reads from stdin in the container will always result in EOF. Default is false.

---

##### `stdinOnce`<sup>Optional</sup> <a name="stdinOnce" id="cdk8s-metaflow.k8s.Container.property.stdinOnce"></a>

```typescript
public readonly stdinOnce: boolean;
```

- *Type:* boolean
- *Default:* false

Whether the container runtime should close the stdin channel after it has been opened by a single attach.

When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF. Default is false

---

##### `terminationMessagePath`<sup>Optional</sup> <a name="terminationMessagePath" id="cdk8s-metaflow.k8s.Container.property.terminationMessagePath"></a>

```typescript
public readonly terminationMessagePath: string;
```

- *Type:* string
- *Default:* dev/termination-log. Cannot be updated.

Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.

Message written is intended to be brief final status, such as an assertion failure message. Will be truncated by the node if greater than 4096 bytes. The total message length across all containers will be limited to 12kb. Defaults to /dev/termination-log. Cannot be updated.

---

##### `terminationMessagePolicy`<sup>Optional</sup> <a name="terminationMessagePolicy" id="cdk8s-metaflow.k8s.Container.property.terminationMessagePolicy"></a>

```typescript
public readonly terminationMessagePolicy: string;
```

- *Type:* string
- *Default:* File. Cannot be updated.

Indicate how the termination message should be populated.

File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.

---

##### `tty`<sup>Optional</sup> <a name="tty" id="cdk8s-metaflow.k8s.Container.property.tty"></a>

```typescript
public readonly tty: boolean;
```

- *Type:* boolean
- *Default:* false.

Whether this container should allocate a TTY for itself, also requires 'stdin' to be true.

Default is false.

---

##### `volumeDevices`<sup>Optional</sup> <a name="volumeDevices" id="cdk8s-metaflow.k8s.Container.property.volumeDevices"></a>

```typescript
public readonly volumeDevices: VolumeDevice[];
```

- *Type:* cdk8s-metaflow.k8s.VolumeDevice[]

volumeDevices is the list of block devices to be used by the container.

---

##### `volumeMounts`<sup>Optional</sup> <a name="volumeMounts" id="cdk8s-metaflow.k8s.Container.property.volumeMounts"></a>

```typescript
public readonly volumeMounts: VolumeMount[];
```

- *Type:* cdk8s-metaflow.k8s.VolumeMount[]

Pod volumes to mount into the container's filesystem.

Cannot be updated.

---

##### `workingDir`<sup>Optional</sup> <a name="workingDir" id="cdk8s-metaflow.k8s.Container.property.workingDir"></a>

```typescript
public readonly workingDir: string;
```

- *Type:* string

Container's working directory.

If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.

---

### ContainerPort <a name="ContainerPort" id="cdk8s-metaflow.k8s.ContainerPort"></a>

ContainerPort represents a network port in a single container.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ContainerPort.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const containerPort: k8s.ContainerPort = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ContainerPort.property.containerPort">containerPort</a></code> | <code>number</code> | Number of port to expose on the pod's IP address. |
| <code><a href="#cdk8s-metaflow.k8s.ContainerPort.property.hostIp">hostIp</a></code> | <code>string</code> | What host IP to bind the external port to. |
| <code><a href="#cdk8s-metaflow.k8s.ContainerPort.property.hostPort">hostPort</a></code> | <code>number</code> | Number of port to expose on the host. |
| <code><a href="#cdk8s-metaflow.k8s.ContainerPort.property.name">name</a></code> | <code>string</code> | If specified, this must be an IANA_SVC_NAME and unique within the pod. |
| <code><a href="#cdk8s-metaflow.k8s.ContainerPort.property.protocol">protocol</a></code> | <code>string</code> | Protocol for port. |

---

##### `containerPort`<sup>Required</sup> <a name="containerPort" id="cdk8s-metaflow.k8s.ContainerPort.property.containerPort"></a>

```typescript
public readonly containerPort: number;
```

- *Type:* number

Number of port to expose on the pod's IP address.

This must be a valid port number, 0 < x < 65536.

---

##### `hostIp`<sup>Optional</sup> <a name="hostIp" id="cdk8s-metaflow.k8s.ContainerPort.property.hostIp"></a>

```typescript
public readonly hostIp: string;
```

- *Type:* string

What host IP to bind the external port to.

---

##### `hostPort`<sup>Optional</sup> <a name="hostPort" id="cdk8s-metaflow.k8s.ContainerPort.property.hostPort"></a>

```typescript
public readonly hostPort: number;
```

- *Type:* number

Number of port to expose on the host.

If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.ContainerPort.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

If specified, this must be an IANA_SVC_NAME and unique within the pod.

Each named port in a pod must have a unique name. Name for the port that can be referred to by services.

---

##### `protocol`<sup>Optional</sup> <a name="protocol" id="cdk8s-metaflow.k8s.ContainerPort.property.protocol"></a>

```typescript
public readonly protocol: string;
```

- *Type:* string
- *Default:* TCP".

Protocol for port.

Must be UDP, TCP, or SCTP. Defaults to "TCP".

---

### ContainerResourceMetricSourceV2Beta1 <a name="ContainerResourceMetricSourceV2Beta1" id="cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta1"></a>

ContainerResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const containerResourceMetricSourceV2Beta1: k8s.ContainerResourceMetricSourceV2Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta1.property.container">container</a></code> | <code>string</code> | container is the name of the container in the pods of the scaling target. |
| <code><a href="#cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta1.property.name">name</a></code> | <code>string</code> | name is the name of the resource in question. |
| <code><a href="#cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta1.property.targetAverageUtilization">targetAverageUtilization</a></code> | <code>number</code> | targetAverageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods. |
| <code><a href="#cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta1.property.targetAverageValue">targetAverageValue</a></code> | <code>cdk8s-metaflow.k8s.Quantity</code> | targetAverageValue is the target value of the average of the resource metric across all relevant pods, as a raw value (instead of as a percentage of the request), similar to the "pods" metric source type. |

---

##### `container`<sup>Required</sup> <a name="container" id="cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta1.property.container"></a>

```typescript
public readonly container: string;
```

- *Type:* string

container is the name of the container in the pods of the scaling target.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

name is the name of the resource in question.

---

##### `targetAverageUtilization`<sup>Optional</sup> <a name="targetAverageUtilization" id="cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta1.property.targetAverageUtilization"></a>

```typescript
public readonly targetAverageUtilization: number;
```

- *Type:* number

targetAverageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.

---

##### `targetAverageValue`<sup>Optional</sup> <a name="targetAverageValue" id="cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta1.property.targetAverageValue"></a>

```typescript
public readonly targetAverageValue: Quantity;
```

- *Type:* cdk8s-metaflow.k8s.Quantity

targetAverageValue is the target value of the average of the resource metric across all relevant pods, as a raw value (instead of as a percentage of the request), similar to the "pods" metric source type.

---

### ContainerResourceMetricSourceV2Beta2 <a name="ContainerResourceMetricSourceV2Beta2" id="cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta2"></a>

ContainerResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta2.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const containerResourceMetricSourceV2Beta2: k8s.ContainerResourceMetricSourceV2Beta2 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta2.property.container">container</a></code> | <code>string</code> | container is the name of the container in the pods of the scaling target. |
| <code><a href="#cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta2.property.name">name</a></code> | <code>string</code> | name is the name of the resource in question. |
| <code><a href="#cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta2.property.target">target</a></code> | <code>cdk8s-metaflow.k8s.MetricTargetV2Beta2</code> | target specifies the target value for the given metric. |

---

##### `container`<sup>Required</sup> <a name="container" id="cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta2.property.container"></a>

```typescript
public readonly container: string;
```

- *Type:* string

container is the name of the container in the pods of the scaling target.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta2.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

name is the name of the resource in question.

---

##### `target`<sup>Required</sup> <a name="target" id="cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta2.property.target"></a>

```typescript
public readonly target: MetricTargetV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.MetricTargetV2Beta2

target specifies the target value for the given metric.

---

### ControllerRevisionListProps <a name="ControllerRevisionListProps" id="cdk8s-metaflow.k8s.ControllerRevisionListProps"></a>

ControllerRevisionList is a resource containing a list of ControllerRevision objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ControllerRevisionListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const controllerRevisionListProps: k8s.ControllerRevisionListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.ControllerRevision[]</code> | Items is the list of ControllerRevisions. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.ControllerRevisionListProps.property.items"></a>

```typescript
public readonly items: ControllerRevision[];
```

- *Type:* cdk8s-metaflow.k8s.ControllerRevision[]

Items is the list of ControllerRevisions.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ControllerRevisionListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

### ControllerRevisionProps <a name="ControllerRevisionProps" id="cdk8s-metaflow.k8s.ControllerRevisionProps"></a>

ControllerRevision implements an immutable snapshot of state data.

Clients are responsible for serializing and deserializing the objects that contain their internal state. Once a ControllerRevision has been successfully created, it can not be updated. The API Server will fail validation of all requests that attempt to mutate the Data field. ControllerRevisions may, however, be deleted. Note that, due to its use by both the DaemonSet and StatefulSet controllers for update and rollback, this object is beta. However, it may be subject to name and representation changes in future releases, and clients should not depend on its stability. It is primarily for internal use by controllers.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ControllerRevisionProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const controllerRevisionProps: k8s.ControllerRevisionProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionProps.property.revision">revision</a></code> | <code>number</code> | Revision indicates the revision of the state represented by Data. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionProps.property.data">data</a></code> | <code>any</code> | Data is the serialized representation of the state. |
| <code><a href="#cdk8s-metaflow.k8s.ControllerRevisionProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |

---

##### `revision`<sup>Required</sup> <a name="revision" id="cdk8s-metaflow.k8s.ControllerRevisionProps.property.revision"></a>

```typescript
public readonly revision: number;
```

- *Type:* number

Revision indicates the revision of the state represented by Data.

---

##### `data`<sup>Optional</sup> <a name="data" id="cdk8s-metaflow.k8s.ControllerRevisionProps.property.data"></a>

```typescript
public readonly data: any;
```

- *Type:* any

Data is the serialized representation of the state.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ControllerRevisionProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### CronJobListProps <a name="CronJobListProps" id="cdk8s-metaflow.k8s.CronJobListProps"></a>

CronJobList is a collection of cron jobs.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CronJobListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const cronJobListProps: k8s.CronJobListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.CronJob[]</code> | items is the list of CronJobs. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.CronJobListProps.property.items"></a>

```typescript
public readonly items: CronJob[];
```

- *Type:* cdk8s-metaflow.k8s.CronJob[]

items is the list of CronJobs.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CronJobListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### CronJobListV1Beta1Props <a name="CronJobListV1Beta1Props" id="cdk8s-metaflow.k8s.CronJobListV1Beta1Props"></a>

CronJobList is a collection of cron jobs.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CronJobListV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const cronJobListV1Beta1Props: k8s.CronJobListV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.CronJobV1Beta1[]</code> | items is the list of CronJobs. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobListV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.CronJobListV1Beta1Props.property.items"></a>

```typescript
public readonly items: CronJobV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.CronJobV1Beta1[]

items is the list of CronJobs.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CronJobListV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### CronJobProps <a name="CronJobProps" id="cdk8s-metaflow.k8s.CronJobProps"></a>

CronJob represents the configuration of a single cron job.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CronJobProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const cronJobProps: k8s.CronJobProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.CronJobSpec</code> | Specification of the desired behavior of a cron job, including the schedule. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CronJobProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.CronJobProps.property.spec"></a>

```typescript
public readonly spec: CronJobSpec;
```

- *Type:* cdk8s-metaflow.k8s.CronJobSpec

Specification of the desired behavior of a cron job, including the schedule.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### CronJobSpec <a name="CronJobSpec" id="cdk8s-metaflow.k8s.CronJobSpec"></a>

CronJobSpec describes how the job execution will look like and when it will actually run.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CronJobSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const cronJobSpec: k8s.CronJobSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobSpec.property.jobTemplate">jobTemplate</a></code> | <code>cdk8s-metaflow.k8s.JobTemplateSpec</code> | Specifies the job that will be created when executing a CronJob. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobSpec.property.schedule">schedule</a></code> | <code>string</code> | The schedule in Cron format, see https://en.wikipedia.org/wiki/Cron. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobSpec.property.concurrencyPolicy">concurrencyPolicy</a></code> | <code>string</code> | Specifies how to treat concurrent executions of a Job. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobSpec.property.failedJobsHistoryLimit">failedJobsHistoryLimit</a></code> | <code>number</code> | The number of failed finished jobs to retain. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobSpec.property.startingDeadlineSeconds">startingDeadlineSeconds</a></code> | <code>number</code> | Optional deadline in seconds for starting the job if it misses scheduled time for any reason. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobSpec.property.successfulJobsHistoryLimit">successfulJobsHistoryLimit</a></code> | <code>number</code> | The number of successful finished jobs to retain. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobSpec.property.suspend">suspend</a></code> | <code>boolean</code> | This flag tells the controller to suspend subsequent executions, it does not apply to already started executions. |

---

##### `jobTemplate`<sup>Required</sup> <a name="jobTemplate" id="cdk8s-metaflow.k8s.CronJobSpec.property.jobTemplate"></a>

```typescript
public readonly jobTemplate: JobTemplateSpec;
```

- *Type:* cdk8s-metaflow.k8s.JobTemplateSpec

Specifies the job that will be created when executing a CronJob.

---

##### `schedule`<sup>Required</sup> <a name="schedule" id="cdk8s-metaflow.k8s.CronJobSpec.property.schedule"></a>

```typescript
public readonly schedule: string;
```

- *Type:* string

The schedule in Cron format, see https://en.wikipedia.org/wiki/Cron.

---

##### `concurrencyPolicy`<sup>Optional</sup> <a name="concurrencyPolicy" id="cdk8s-metaflow.k8s.CronJobSpec.property.concurrencyPolicy"></a>

```typescript
public readonly concurrencyPolicy: string;
```

- *Type:* string

Specifies how to treat concurrent executions of a Job.

Valid values are: - "Allow" (default): allows CronJobs to run concurrently; - "Forbid": forbids concurrent runs, skipping next run if previous run hasn't finished yet; - "Replace": cancels currently running job and replaces it with a new one

---

##### `failedJobsHistoryLimit`<sup>Optional</sup> <a name="failedJobsHistoryLimit" id="cdk8s-metaflow.k8s.CronJobSpec.property.failedJobsHistoryLimit"></a>

```typescript
public readonly failedJobsHistoryLimit: number;
```

- *Type:* number
- *Default:* 1.

The number of failed finished jobs to retain.

Value must be non-negative integer. Defaults to 1.

---

##### `startingDeadlineSeconds`<sup>Optional</sup> <a name="startingDeadlineSeconds" id="cdk8s-metaflow.k8s.CronJobSpec.property.startingDeadlineSeconds"></a>

```typescript
public readonly startingDeadlineSeconds: number;
```

- *Type:* number

Optional deadline in seconds for starting the job if it misses scheduled time for any reason.

Missed jobs executions will be counted as failed ones.

---

##### `successfulJobsHistoryLimit`<sup>Optional</sup> <a name="successfulJobsHistoryLimit" id="cdk8s-metaflow.k8s.CronJobSpec.property.successfulJobsHistoryLimit"></a>

```typescript
public readonly successfulJobsHistoryLimit: number;
```

- *Type:* number
- *Default:* 3.

The number of successful finished jobs to retain.

Value must be non-negative integer. Defaults to 3.

---

##### `suspend`<sup>Optional</sup> <a name="suspend" id="cdk8s-metaflow.k8s.CronJobSpec.property.suspend"></a>

```typescript
public readonly suspend: boolean;
```

- *Type:* boolean
- *Default:* false.

This flag tells the controller to suspend subsequent executions, it does not apply to already started executions.

Defaults to false.

---

### CronJobSpecV1Beta1 <a name="CronJobSpecV1Beta1" id="cdk8s-metaflow.k8s.CronJobSpecV1Beta1"></a>

CronJobSpec describes how the job execution will look like and when it will actually run.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CronJobSpecV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const cronJobSpecV1Beta1: k8s.CronJobSpecV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobSpecV1Beta1.property.jobTemplate">jobTemplate</a></code> | <code>cdk8s-metaflow.k8s.JobTemplateSpecV1Beta1</code> | Specifies the job that will be created when executing a CronJob. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobSpecV1Beta1.property.schedule">schedule</a></code> | <code>string</code> | The schedule in Cron format, see https://en.wikipedia.org/wiki/Cron. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobSpecV1Beta1.property.concurrencyPolicy">concurrencyPolicy</a></code> | <code>string</code> | Specifies how to treat concurrent executions of a Job. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobSpecV1Beta1.property.failedJobsHistoryLimit">failedJobsHistoryLimit</a></code> | <code>number</code> | The number of failed finished jobs to retain. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobSpecV1Beta1.property.startingDeadlineSeconds">startingDeadlineSeconds</a></code> | <code>number</code> | Optional deadline in seconds for starting the job if it misses scheduled time for any reason. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobSpecV1Beta1.property.successfulJobsHistoryLimit">successfulJobsHistoryLimit</a></code> | <code>number</code> | The number of successful finished jobs to retain. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobSpecV1Beta1.property.suspend">suspend</a></code> | <code>boolean</code> | This flag tells the controller to suspend subsequent executions, it does not apply to already started executions. |

---

##### `jobTemplate`<sup>Required</sup> <a name="jobTemplate" id="cdk8s-metaflow.k8s.CronJobSpecV1Beta1.property.jobTemplate"></a>

```typescript
public readonly jobTemplate: JobTemplateSpecV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.JobTemplateSpecV1Beta1

Specifies the job that will be created when executing a CronJob.

---

##### `schedule`<sup>Required</sup> <a name="schedule" id="cdk8s-metaflow.k8s.CronJobSpecV1Beta1.property.schedule"></a>

```typescript
public readonly schedule: string;
```

- *Type:* string

The schedule in Cron format, see https://en.wikipedia.org/wiki/Cron.

---

##### `concurrencyPolicy`<sup>Optional</sup> <a name="concurrencyPolicy" id="cdk8s-metaflow.k8s.CronJobSpecV1Beta1.property.concurrencyPolicy"></a>

```typescript
public readonly concurrencyPolicy: string;
```

- *Type:* string

Specifies how to treat concurrent executions of a Job.

Valid values are: - "Allow" (default): allows CronJobs to run concurrently; - "Forbid": forbids concurrent runs, skipping next run if previous run hasn't finished yet; - "Replace": cancels currently running job and replaces it with a new one

---

##### `failedJobsHistoryLimit`<sup>Optional</sup> <a name="failedJobsHistoryLimit" id="cdk8s-metaflow.k8s.CronJobSpecV1Beta1.property.failedJobsHistoryLimit"></a>

```typescript
public readonly failedJobsHistoryLimit: number;
```

- *Type:* number
- *Default:* 1.

The number of failed finished jobs to retain.

This is a pointer to distinguish between explicit zero and not specified. Defaults to 1.

---

##### `startingDeadlineSeconds`<sup>Optional</sup> <a name="startingDeadlineSeconds" id="cdk8s-metaflow.k8s.CronJobSpecV1Beta1.property.startingDeadlineSeconds"></a>

```typescript
public readonly startingDeadlineSeconds: number;
```

- *Type:* number

Optional deadline in seconds for starting the job if it misses scheduled time for any reason.

Missed jobs executions will be counted as failed ones.

---

##### `successfulJobsHistoryLimit`<sup>Optional</sup> <a name="successfulJobsHistoryLimit" id="cdk8s-metaflow.k8s.CronJobSpecV1Beta1.property.successfulJobsHistoryLimit"></a>

```typescript
public readonly successfulJobsHistoryLimit: number;
```

- *Type:* number
- *Default:* 3.

The number of successful finished jobs to retain.

This is a pointer to distinguish between explicit zero and not specified. Defaults to 3.

---

##### `suspend`<sup>Optional</sup> <a name="suspend" id="cdk8s-metaflow.k8s.CronJobSpecV1Beta1.property.suspend"></a>

```typescript
public readonly suspend: boolean;
```

- *Type:* boolean
- *Default:* false.

This flag tells the controller to suspend subsequent executions, it does not apply to already started executions.

Defaults to false.

---

### CronJobV1Beta1Props <a name="CronJobV1Beta1Props" id="cdk8s-metaflow.k8s.CronJobV1Beta1Props"></a>

CronJob represents the configuration of a single cron job.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CronJobV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const cronJobV1Beta1Props: k8s.CronJobV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.CronJobV1Beta1Props.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.CronJobSpecV1Beta1</code> | Specification of the desired behavior of a cron job, including the schedule. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CronJobV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.CronJobV1Beta1Props.property.spec"></a>

```typescript
public readonly spec: CronJobSpecV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.CronJobSpecV1Beta1

Specification of the desired behavior of a cron job, including the schedule.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### CrossVersionObjectReference <a name="CrossVersionObjectReference" id="cdk8s-metaflow.k8s.CrossVersionObjectReference"></a>

CrossVersionObjectReference contains enough information to let you identify the referred resource.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CrossVersionObjectReference.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const crossVersionObjectReference: k8s.CrossVersionObjectReference = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CrossVersionObjectReference.property.kind">kind</a></code> | <code>string</code> | Kind of the referent; |
| <code><a href="#cdk8s-metaflow.k8s.CrossVersionObjectReference.property.name">name</a></code> | <code>string</code> | Name of the referent; |
| <code><a href="#cdk8s-metaflow.k8s.CrossVersionObjectReference.property.apiVersion">apiVersion</a></code> | <code>string</code> | API version of the referent. |

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CrossVersionObjectReference.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

Kind of the referent;

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds"

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CrossVersionObjectReference.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the referent;

More info: http://kubernetes.io/docs/user-guide/identifiers#names

---

##### `apiVersion`<sup>Optional</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CrossVersionObjectReference.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

API version of the referent.

---

### CrossVersionObjectReferenceV2Beta1 <a name="CrossVersionObjectReferenceV2Beta1" id="cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta1"></a>

CrossVersionObjectReference contains enough information to let you identify the referred resource.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const crossVersionObjectReferenceV2Beta1: k8s.CrossVersionObjectReferenceV2Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta1.property.kind">kind</a></code> | <code>string</code> | Kind of the referent; |
| <code><a href="#cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta1.property.name">name</a></code> | <code>string</code> | Name of the referent; |
| <code><a href="#cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta1.property.apiVersion">apiVersion</a></code> | <code>string</code> | API version of the referent. |

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

Kind of the referent;

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds"

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the referent;

More info: http://kubernetes.io/docs/user-guide/identifiers#names

---

##### `apiVersion`<sup>Optional</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

API version of the referent.

---

### CrossVersionObjectReferenceV2Beta2 <a name="CrossVersionObjectReferenceV2Beta2" id="cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta2"></a>

CrossVersionObjectReference contains enough information to let you identify the referred resource.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta2.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const crossVersionObjectReferenceV2Beta2: k8s.CrossVersionObjectReferenceV2Beta2 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta2.property.kind">kind</a></code> | <code>string</code> | Kind of the referent; |
| <code><a href="#cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta2.property.name">name</a></code> | <code>string</code> | Name of the referent; |
| <code><a href="#cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta2.property.apiVersion">apiVersion</a></code> | <code>string</code> | API version of the referent. |

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta2.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

Kind of the referent;

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds"

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta2.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the referent;

More info: http://kubernetes.io/docs/user-guide/identifiers#names

---

##### `apiVersion`<sup>Optional</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta2.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

API version of the referent.

---

### CsiDriverListProps <a name="CsiDriverListProps" id="cdk8s-metaflow.k8s.CsiDriverListProps"></a>

CSIDriverList is a collection of CSIDriver objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CsiDriverListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const csiDriverListProps: k8s.CsiDriverListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.CsiDriver[]</code> | items is the list of CSIDriver. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.CsiDriverListProps.property.items"></a>

```typescript
public readonly items: CsiDriver[];
```

- *Type:* cdk8s-metaflow.k8s.CsiDriver[]

items is the list of CSIDriver.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CsiDriverListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

### CsiDriverProps <a name="CsiDriverProps" id="cdk8s-metaflow.k8s.CsiDriverProps"></a>

CSIDriver captures information about a Container Storage Interface (CSI) volume driver deployed on the cluster.

Kubernetes attach detach controller uses this object to determine whether attach is required. Kubelet uses this object to determine whether pod information needs to be passed on mount. CSIDriver objects are non-namespaced.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CsiDriverProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const csiDriverProps: k8s.CsiDriverProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.CsiDriverSpec</code> | Specification of the CSI Driver. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object metadata. |

---

##### `spec`<sup>Required</sup> <a name="spec" id="cdk8s-metaflow.k8s.CsiDriverProps.property.spec"></a>

```typescript
public readonly spec: CsiDriverSpec;
```

- *Type:* cdk8s-metaflow.k8s.CsiDriverSpec

Specification of the CSI Driver.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CsiDriverProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object metadata.

metadata.Name indicates the name of the CSI driver that this object refers to; it MUST be the same name returned by the CSI GetPluginName() call for that driver. The driver name must be 63 characters or less, beginning and ending with an alphanumeric character ([a-z0-9A-Z]) with dashes (-), dots (.), and alphanumerics between. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### CsiDriverSpec <a name="CsiDriverSpec" id="cdk8s-metaflow.k8s.CsiDriverSpec"></a>

CSIDriverSpec is the specification of a CSIDriver.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CsiDriverSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const csiDriverSpec: k8s.CsiDriverSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverSpec.property.attachRequired">attachRequired</a></code> | <code>boolean</code> | attachRequired indicates this CSI volume driver requires an attach operation (because it implements the CSI ControllerPublishVolume() method), and that the Kubernetes attach detach controller should call the attach volume interface which checks the volumeattachment status and waits until the volume is attached before proceeding to mounting. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverSpec.property.fsGroupPolicy">fsGroupPolicy</a></code> | <code>string</code> | Defines if the underlying volume supports changing ownership and permission of the volume before being mounted. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverSpec.property.podInfoOnMount">podInfoOnMount</a></code> | <code>boolean</code> | If set to true, podInfoOnMount indicates this CSI volume driver requires additional pod information (like podName, podUID, etc.) during mount operations. If set to false, pod information will not be passed on mount. Default is false. The CSI driver specifies podInfoOnMount as part of driver deployment. If true, Kubelet will pass pod information as VolumeContext in the CSI NodePublishVolume() calls. The CSI driver is responsible for parsing and validating the information passed in as VolumeContext. The following VolumeConext will be passed if podInfoOnMount is set to true. This list might grow, but the prefix will be used. "csi.storage.k8s.io/pod.name": pod.Name "csi.storage.k8s.io/pod.namespace": pod.Namespace "csi.storage.k8s.io/pod.uid": string(pod.UID) "csi.storage.k8s.io/ephemeral": "true" if the volume is an ephemeral inline volume defined by a CSIVolumeSource, otherwise "false". |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverSpec.property.requiresRepublish">requiresRepublish</a></code> | <code>boolean</code> | RequiresRepublish indicates the CSI driver wants `NodePublishVolume` being periodically called to reflect any possible change in the mounted volume. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverSpec.property.storageCapacity">storageCapacity</a></code> | <code>boolean</code> | If set to true, storageCapacity indicates that the CSI volume driver wants pod scheduling to consider the storage capacity that the driver deployment will report by creating CSIStorageCapacity objects with capacity information. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverSpec.property.tokenRequests">tokenRequests</a></code> | <code>cdk8s-metaflow.k8s.TokenRequest[]</code> | TokenRequests indicates the CSI driver needs pods' service account tokens it is mounting volume for to do necessary authentication. |
| <code><a href="#cdk8s-metaflow.k8s.CsiDriverSpec.property.volumeLifecycleModes">volumeLifecycleModes</a></code> | <code>string[]</code> | volumeLifecycleModes defines what kind of volumes this CSI volume driver supports. |

---

##### `attachRequired`<sup>Optional</sup> <a name="attachRequired" id="cdk8s-metaflow.k8s.CsiDriverSpec.property.attachRequired"></a>

```typescript
public readonly attachRequired: boolean;
```

- *Type:* boolean

attachRequired indicates this CSI volume driver requires an attach operation (because it implements the CSI ControllerPublishVolume() method), and that the Kubernetes attach detach controller should call the attach volume interface which checks the volumeattachment status and waits until the volume is attached before proceeding to mounting.

The CSI external-attacher coordinates with CSI volume driver and updates the volumeattachment status when the attach operation is complete. If the CSIDriverRegistry feature gate is enabled and the value is specified to false, the attach operation will be skipped. Otherwise the attach operation will be called.

This field is immutable.

---

##### `fsGroupPolicy`<sup>Optional</sup> <a name="fsGroupPolicy" id="cdk8s-metaflow.k8s.CsiDriverSpec.property.fsGroupPolicy"></a>

```typescript
public readonly fsGroupPolicy: string;
```

- *Type:* string
- *Default:* ReadWriteOnceWithFSType, which will examine each volume to determine if Kubernetes should modify ownership and permissions of the volume. With the default policy the defined fsGroup will only be applied if a fstype is defined and the volume's access mode contains ReadWriteOnce.

Defines if the underlying volume supports changing ownership and permission of the volume before being mounted.

Refer to the specific FSGroupPolicy values for additional details. This field is beta, and is only honored by servers that enable the CSIVolumeFSGroupPolicy feature gate.

This field is immutable.

Defaults to ReadWriteOnceWithFSType, which will examine each volume to determine if Kubernetes should modify ownership and permissions of the volume. With the default policy the defined fsGroup will only be applied if a fstype is defined and the volume's access mode contains ReadWriteOnce.

---

##### `podInfoOnMount`<sup>Optional</sup> <a name="podInfoOnMount" id="cdk8s-metaflow.k8s.CsiDriverSpec.property.podInfoOnMount"></a>

```typescript
public readonly podInfoOnMount: boolean;
```

- *Type:* boolean
- *Default:* false. The CSI driver specifies podInfoOnMount as part of driver deployment. If true, Kubelet will pass pod information as VolumeContext in the CSI NodePublishVolume() calls. The CSI driver is responsible for parsing and validating the information passed in as VolumeContext. The following VolumeConext will be passed if podInfoOnMount is set to true. This list might grow, but the prefix will be used. "csi.storage.k8s.io/pod.name": pod.Name "csi.storage.k8s.io/pod.namespace": pod.Namespace "csi.storage.k8s.io/pod.uid": string(pod.UID) "csi.storage.k8s.io/ephemeral": "true" if the volume is an ephemeral inline volume

If set to true, podInfoOnMount indicates this CSI volume driver requires additional pod information (like podName, podUID, etc.) during mount operations. If set to false, pod information will not be passed on mount. Default is false. The CSI driver specifies podInfoOnMount as part of driver deployment. If true, Kubelet will pass pod information as VolumeContext in the CSI NodePublishVolume() calls. The CSI driver is responsible for parsing and validating the information passed in as VolumeContext. The following VolumeConext will be passed if podInfoOnMount is set to true. This list might grow, but the prefix will be used. "csi.storage.k8s.io/pod.name": pod.Name "csi.storage.k8s.io/pod.namespace": pod.Namespace "csi.storage.k8s.io/pod.uid": string(pod.UID) "csi.storage.k8s.io/ephemeral": "true" if the volume is an ephemeral inline volume defined by a CSIVolumeSource, otherwise "false".

"csi.storage.k8s.io/ephemeral" is a new feature in Kubernetes 1.16. It is only required for drivers which support both the "Persistent" and "Ephemeral" VolumeLifecycleMode. Other drivers can leave pod info disabled and/or ignore this field. As Kubernetes 1.15 doesn't support this field, drivers can only support one mode when deployed on such a cluster and the deployment determines which mode that is, for example via a command line parameter of the driver.

This field is immutable.

---

##### `requiresRepublish`<sup>Optional</sup> <a name="requiresRepublish" id="cdk8s-metaflow.k8s.CsiDriverSpec.property.requiresRepublish"></a>

```typescript
public readonly requiresRepublish: boolean;
```

- *Type:* boolean

RequiresRepublish indicates the CSI driver wants `NodePublishVolume` being periodically called to reflect any possible change in the mounted volume.

This field defaults to false.

Note: After a successful initial NodePublishVolume call, subsequent calls to NodePublishVolume should only update the contents of the volume. New mount points will not be seen by a running container.

---

##### `storageCapacity`<sup>Optional</sup> <a name="storageCapacity" id="cdk8s-metaflow.k8s.CsiDriverSpec.property.storageCapacity"></a>

```typescript
public readonly storageCapacity: boolean;
```

- *Type:* boolean

If set to true, storageCapacity indicates that the CSI volume driver wants pod scheduling to consider the storage capacity that the driver deployment will report by creating CSIStorageCapacity objects with capacity information.

The check can be enabled immediately when deploying a driver. In that case, provisioning new volumes with late binding will pause until the driver deployment has published some suitable CSIStorageCapacity object.

Alternatively, the driver can be deployed with the field unset or false and it can be flipped later when storage capacity information has been published.

This field is immutable.

This is a beta field and only available when the CSIStorageCapacity feature is enabled. The default is false.

---

##### `tokenRequests`<sup>Optional</sup> <a name="tokenRequests" id="cdk8s-metaflow.k8s.CsiDriverSpec.property.tokenRequests"></a>

```typescript
public readonly tokenRequests: TokenRequest[];
```

- *Type:* cdk8s-metaflow.k8s.TokenRequest[]

TokenRequests indicates the CSI driver needs pods' service account tokens it is mounting volume for to do necessary authentication.

Kubelet will pass the tokens in VolumeContext in the CSI NodePublishVolume calls. The CSI driver should parse and validate the following VolumeContext: "csi.storage.k8s.io/serviceAccount.tokens": {
"<audience>": {
"token": <token>,
"expirationTimestamp": <expiration timestamp in RFC3339>,
},
...
}

Note: Audience in each TokenRequest should be different and at most one token is empty string. To receive a new token after expiry, RequiresRepublish can be used to trigger NodePublishVolume periodically.

---

##### `volumeLifecycleModes`<sup>Optional</sup> <a name="volumeLifecycleModes" id="cdk8s-metaflow.k8s.CsiDriverSpec.property.volumeLifecycleModes"></a>

```typescript
public readonly volumeLifecycleModes: string[];
```

- *Type:* string[]

volumeLifecycleModes defines what kind of volumes this CSI volume driver supports.

The default if the list is empty is "Persistent", which is the usage defined by the CSI specification and implemented in Kubernetes via the usual PV/PVC mechanism. The other mode is "Ephemeral". In this mode, volumes are defined inline inside the pod spec with CSIVolumeSource and their lifecycle is tied to the lifecycle of that pod. A driver has to be aware of this because it is only going to get a NodePublishVolume call for such a volume. For more information about implementing this mode, see https://kubernetes-csi.github.io/docs/ephemeral-local-volumes.html A driver can support one or more of these modes and more modes may be added in the future. This field is beta.

This field is immutable.

---

### CsiNodeDriver <a name="CsiNodeDriver" id="cdk8s-metaflow.k8s.CsiNodeDriver"></a>

CSINodeDriver holds information about the specification of one CSI driver installed on a node.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CsiNodeDriver.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const csiNodeDriver: k8s.CsiNodeDriver = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeDriver.property.name">name</a></code> | <code>string</code> | This is the name of the CSI driver that this object refers to. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeDriver.property.nodeId">nodeId</a></code> | <code>string</code> | nodeID of the node from the driver point of view. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeDriver.property.allocatable">allocatable</a></code> | <code>cdk8s-metaflow.k8s.VolumeNodeResources</code> | allocatable represents the volume resources of a node that are available for scheduling. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeDriver.property.topologyKeys">topologyKeys</a></code> | <code>string[]</code> | topologyKeys is the list of keys supported by the driver. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CsiNodeDriver.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

This is the name of the CSI driver that this object refers to.

This MUST be the same name returned by the CSI GetPluginName() call for that driver.

---

##### `nodeId`<sup>Required</sup> <a name="nodeId" id="cdk8s-metaflow.k8s.CsiNodeDriver.property.nodeId"></a>

```typescript
public readonly nodeId: string;
```

- *Type:* string

nodeID of the node from the driver point of view.

This field enables Kubernetes to communicate with storage systems that do not share the same nomenclature for nodes. For example, Kubernetes may refer to a given node as "node1", but the storage system may refer to the same node as "nodeA". When Kubernetes issues a command to the storage system to attach a volume to a specific node, it can use this field to refer to the node name using the ID that the storage system will understand, e.g. "nodeA" instead of "node1". This field is required.

---

##### `allocatable`<sup>Optional</sup> <a name="allocatable" id="cdk8s-metaflow.k8s.CsiNodeDriver.property.allocatable"></a>

```typescript
public readonly allocatable: VolumeNodeResources;
```

- *Type:* cdk8s-metaflow.k8s.VolumeNodeResources

allocatable represents the volume resources of a node that are available for scheduling.

This field is beta.

---

##### `topologyKeys`<sup>Optional</sup> <a name="topologyKeys" id="cdk8s-metaflow.k8s.CsiNodeDriver.property.topologyKeys"></a>

```typescript
public readonly topologyKeys: string[];
```

- *Type:* string[]

topologyKeys is the list of keys supported by the driver.

When a driver is initialized on a cluster, it provides a set of topology keys that it understands (e.g. "company.com/zone", "company.com/region"). When a driver is initialized on a node, it provides the same topology keys along with values. Kubelet will expose these topology keys as labels on its own node object. When Kubernetes does topology aware provisioning, it can use this list to determine which labels it should retrieve from the node object and pass back to the driver. It is possible for different nodes to use different topology keys. This can be empty if driver does not support topology.

---

### CsiNodeListProps <a name="CsiNodeListProps" id="cdk8s-metaflow.k8s.CsiNodeListProps"></a>

CSINodeList is a collection of CSINode objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CsiNodeListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const csiNodeListProps: k8s.CsiNodeListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.CsiNode[]</code> | items is the list of CSINode. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.CsiNodeListProps.property.items"></a>

```typescript
public readonly items: CsiNode[];
```

- *Type:* cdk8s-metaflow.k8s.CsiNode[]

items is the list of CSINode.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CsiNodeListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

### CsiNodeProps <a name="CsiNodeProps" id="cdk8s-metaflow.k8s.CsiNodeProps"></a>

CSINode holds information about all CSI drivers installed on a node.

CSI drivers do not need to create the CSINode object directly. As long as they use the node-driver-registrar sidecar container, the kubelet will automatically populate the CSINode object for the CSI driver as part of kubelet plugin registration. CSINode has the same name as a node. If the object is missing, it means either there are no CSI Drivers available on the node, or the Kubelet version is low enough that it doesn't create this object. CSINode has an OwnerReference that points to the corresponding node object.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CsiNodeProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const csiNodeProps: k8s.CsiNodeProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.CsiNodeSpec</code> | spec is the specification of CSINode. |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | metadata.name must be the Kubernetes node name. |

---

##### `spec`<sup>Required</sup> <a name="spec" id="cdk8s-metaflow.k8s.CsiNodeProps.property.spec"></a>

```typescript
public readonly spec: CsiNodeSpec;
```

- *Type:* cdk8s-metaflow.k8s.CsiNodeSpec

spec is the specification of CSINode.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CsiNodeProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

metadata.name must be the Kubernetes node name.

---

### CsiNodeSpec <a name="CsiNodeSpec" id="cdk8s-metaflow.k8s.CsiNodeSpec"></a>

CSINodeSpec holds information about the specification of all CSI drivers installed on a node.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CsiNodeSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const csiNodeSpec: k8s.CsiNodeSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiNodeSpec.property.drivers">drivers</a></code> | <code>cdk8s-metaflow.k8s.CsiNodeDriver[]</code> | drivers is a list of information of all CSI Drivers existing on a node. |

---

##### `drivers`<sup>Required</sup> <a name="drivers" id="cdk8s-metaflow.k8s.CsiNodeSpec.property.drivers"></a>

```typescript
public readonly drivers: CsiNodeDriver[];
```

- *Type:* cdk8s-metaflow.k8s.CsiNodeDriver[]

drivers is a list of information of all CSI Drivers existing on a node.

If all drivers in the list are uninstalled, this can become empty.

---

### CsiPersistentVolumeSource <a name="CsiPersistentVolumeSource" id="cdk8s-metaflow.k8s.CsiPersistentVolumeSource"></a>

Represents storage that is managed by an external CSI volume driver (Beta feature).

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CsiPersistentVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const csiPersistentVolumeSource: k8s.CsiPersistentVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.driver">driver</a></code> | <code>string</code> | Driver is the name of the driver to use for this volume. |
| <code><a href="#cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.volumeHandle">volumeHandle</a></code> | <code>string</code> | VolumeHandle is the unique volume name returned by the CSI volume plugin’s CreateVolume to refer to the volume on all subsequent calls. |
| <code><a href="#cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.controllerExpandSecretRef">controllerExpandSecretRef</a></code> | <code>cdk8s-metaflow.k8s.SecretReference</code> | ControllerExpandSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI ControllerExpandVolume call. |
| <code><a href="#cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.controllerPublishSecretRef">controllerPublishSecretRef</a></code> | <code>cdk8s-metaflow.k8s.SecretReference</code> | ControllerPublishSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI ControllerPublishVolume and ControllerUnpublishVolume calls. |
| <code><a href="#cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type to mount. |
| <code><a href="#cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.nodePublishSecretRef">nodePublishSecretRef</a></code> | <code>cdk8s-metaflow.k8s.SecretReference</code> | NodePublishSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI NodePublishVolume and NodeUnpublishVolume calls. |
| <code><a href="#cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.nodeStageSecretRef">nodeStageSecretRef</a></code> | <code>cdk8s-metaflow.k8s.SecretReference</code> | NodeStageSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI NodeStageVolume and NodeStageVolume and NodeUnstageVolume calls. |
| <code><a href="#cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Optional: The value to pass to ControllerPublishVolumeRequest. |
| <code><a href="#cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.volumeAttributes">volumeAttributes</a></code> | <code>{[ key: string ]: string}</code> | Attributes of the volume to publish. |

---

##### `driver`<sup>Required</sup> <a name="driver" id="cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.driver"></a>

```typescript
public readonly driver: string;
```

- *Type:* string

Driver is the name of the driver to use for this volume.

Required.

---

##### `volumeHandle`<sup>Required</sup> <a name="volumeHandle" id="cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.volumeHandle"></a>

```typescript
public readonly volumeHandle: string;
```

- *Type:* string

VolumeHandle is the unique volume name returned by the CSI volume plugin’s CreateVolume to refer to the volume on all subsequent calls.

Required.

---

##### `controllerExpandSecretRef`<sup>Optional</sup> <a name="controllerExpandSecretRef" id="cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.controllerExpandSecretRef"></a>

```typescript
public readonly controllerExpandSecretRef: SecretReference;
```

- *Type:* cdk8s-metaflow.k8s.SecretReference

ControllerExpandSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI ControllerExpandVolume call.

This is an alpha field and requires enabling ExpandCSIVolumes feature gate. This field is optional, and may be empty if no secret is required. If the secret object contains more than one secret, all secrets are passed.

---

##### `controllerPublishSecretRef`<sup>Optional</sup> <a name="controllerPublishSecretRef" id="cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.controllerPublishSecretRef"></a>

```typescript
public readonly controllerPublishSecretRef: SecretReference;
```

- *Type:* cdk8s-metaflow.k8s.SecretReference

ControllerPublishSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI ControllerPublishVolume and ControllerUnpublishVolume calls.

This field is optional, and may be empty if no secret is required. If the secret object contains more than one secret, all secrets are passed.

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type to mount.

Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs".

---

##### `nodePublishSecretRef`<sup>Optional</sup> <a name="nodePublishSecretRef" id="cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.nodePublishSecretRef"></a>

```typescript
public readonly nodePublishSecretRef: SecretReference;
```

- *Type:* cdk8s-metaflow.k8s.SecretReference

NodePublishSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI NodePublishVolume and NodeUnpublishVolume calls.

This field is optional, and may be empty if no secret is required. If the secret object contains more than one secret, all secrets are passed.

---

##### `nodeStageSecretRef`<sup>Optional</sup> <a name="nodeStageSecretRef" id="cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.nodeStageSecretRef"></a>

```typescript
public readonly nodeStageSecretRef: SecretReference;
```

- *Type:* cdk8s-metaflow.k8s.SecretReference

NodeStageSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI NodeStageVolume and NodeStageVolume and NodeUnstageVolume calls.

This field is optional, and may be empty if no secret is required. If the secret object contains more than one secret, all secrets are passed.

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false (read/write).

Optional: The value to pass to ControllerPublishVolumeRequest.

Defaults to false (read/write).

---

##### `volumeAttributes`<sup>Optional</sup> <a name="volumeAttributes" id="cdk8s-metaflow.k8s.CsiPersistentVolumeSource.property.volumeAttributes"></a>

```typescript
public readonly volumeAttributes: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

Attributes of the volume to publish.

---

### CsiStorageCapacityListV1Alpha1Props <a name="CsiStorageCapacityListV1Alpha1Props" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1Props"></a>

CSIStorageCapacityList is a collection of CSIStorageCapacity objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const csiStorageCapacityListV1Alpha1Props: k8s.CsiStorageCapacityListV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1[]</code> | Items is the list of CSIStorageCapacity objects. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1Props.property.items"></a>

```typescript
public readonly items: CsiStorageCapacityV1Alpha1[];
```

- *Type:* cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1[]

Items is the list of CSIStorageCapacity objects.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

### CsiStorageCapacityListV1Beta1Props <a name="CsiStorageCapacityListV1Beta1Props" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1Props"></a>

CSIStorageCapacityList is a collection of CSIStorageCapacity objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const csiStorageCapacityListV1Beta1Props: k8s.CsiStorageCapacityListV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1[]</code> | Items is the list of CSIStorageCapacity objects. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1Props.property.items"></a>

```typescript
public readonly items: CsiStorageCapacityV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1[]

Items is the list of CSIStorageCapacity objects.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CsiStorageCapacityListV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

### CsiStorageCapacityV1Alpha1Props <a name="CsiStorageCapacityV1Alpha1Props" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1Props"></a>

CSIStorageCapacity stores the result of one CSI GetCapacity call.

For a given StorageClass, this describes the available capacity in a particular topology segment.  This can be used when considering where to instantiate new PersistentVolumes.

For example this can express things like: - StorageClass "standard" has "1234 GiB" available in "topology.kubernetes.io/zone=us-east1" - StorageClass "localssd" has "10 GiB" available in "kubernetes.io/hostname=knode-abc123"

The following three cases all imply that no capacity is available for a certain combination: - no object exists with suitable topology and storage class name - such an object exists, but the capacity is unset - such an object exists, but the capacity is zero

The producer of these objects can decide which approach is more suitable.

They are consumed by the kube-scheduler if the CSIStorageCapacity beta feature gate is enabled there and a CSI driver opts into capacity-aware scheduling with CSIDriver.StorageCapacity.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const csiStorageCapacityV1Alpha1Props: k8s.CsiStorageCapacityV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1Props.property.storageClassName">storageClassName</a></code> | <code>string</code> | The name of the StorageClass that the reported capacity applies to. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1Props.property.capacity">capacity</a></code> | <code>cdk8s-metaflow.k8s.Quantity</code> | Capacity is the value reported by the CSI driver in its GetCapacityResponse for a GetCapacityRequest with topology and parameters that match the previous fields. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1Props.property.maximumVolumeSize">maximumVolumeSize</a></code> | <code>cdk8s-metaflow.k8s.Quantity</code> | MaximumVolumeSize is the value reported by the CSI driver in its GetCapacityResponse for a GetCapacityRequest with topology and parameters that match the previous fields. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1Props.property.nodeTopology">nodeTopology</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | NodeTopology defines which nodes have access to the storage for which capacity was reported. |

---

##### `storageClassName`<sup>Required</sup> <a name="storageClassName" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1Props.property.storageClassName"></a>

```typescript
public readonly storageClassName: string;
```

- *Type:* string

The name of the StorageClass that the reported capacity applies to.

It must meet the same requirements as the name of a StorageClass object (non-empty, DNS subdomain). If that object no longer exists, the CSIStorageCapacity object is obsolete and should be removed by its creator. This field is immutable.

---

##### `capacity`<sup>Optional</sup> <a name="capacity" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1Props.property.capacity"></a>

```typescript
public readonly capacity: Quantity;
```

- *Type:* cdk8s-metaflow.k8s.Quantity

Capacity is the value reported by the CSI driver in its GetCapacityResponse for a GetCapacityRequest with topology and parameters that match the previous fields.

The semantic is currently (CSI spec 1.2) defined as: The available capacity, in bytes, of the storage that can be used to provision volumes. If not set, that information is currently unavailable and treated like zero capacity.

---

##### `maximumVolumeSize`<sup>Optional</sup> <a name="maximumVolumeSize" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1Props.property.maximumVolumeSize"></a>

```typescript
public readonly maximumVolumeSize: Quantity;
```

- *Type:* cdk8s-metaflow.k8s.Quantity

MaximumVolumeSize is the value reported by the CSI driver in its GetCapacityResponse for a GetCapacityRequest with topology and parameters that match the previous fields.

This is defined since CSI spec 1.4.0 as the largest size that may be used in a CreateVolumeRequest.capacity_range.required_bytes field to create a volume with the same parameters as those in GetCapacityRequest. The corresponding value in the Kubernetes API is ResourceRequirements.Requests in a volume claim.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

The name has no particular meaning. It must be be a DNS subdomain (dots allowed, 253 characters). To ensure that there are no conflicts with other CSI drivers on the cluster, the recommendation is to use csisc-<uuid>, a generated name, or a reverse-domain name which ends with the unique CSI driver name.

Objects are namespaced.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `nodeTopology`<sup>Optional</sup> <a name="nodeTopology" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Alpha1Props.property.nodeTopology"></a>

```typescript
public readonly nodeTopology: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

NodeTopology defines which nodes have access to the storage for which capacity was reported.

If not set, the storage is not accessible from any node in the cluster. If empty, the storage is accessible from all nodes. This field is immutable.

---

### CsiStorageCapacityV1Beta1Props <a name="CsiStorageCapacityV1Beta1Props" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1Props"></a>

CSIStorageCapacity stores the result of one CSI GetCapacity call.

For a given StorageClass, this describes the available capacity in a particular topology segment.  This can be used when considering where to instantiate new PersistentVolumes.

For example this can express things like: - StorageClass "standard" has "1234 GiB" available in "topology.kubernetes.io/zone=us-east1" - StorageClass "localssd" has "10 GiB" available in "kubernetes.io/hostname=knode-abc123"

The following three cases all imply that no capacity is available for a certain combination: - no object exists with suitable topology and storage class name - such an object exists, but the capacity is unset - such an object exists, but the capacity is zero

The producer of these objects can decide which approach is more suitable.

They are consumed by the kube-scheduler if the CSIStorageCapacity beta feature gate is enabled there and a CSI driver opts into capacity-aware scheduling with CSIDriver.StorageCapacity.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const csiStorageCapacityV1Beta1Props: k8s.CsiStorageCapacityV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1Props.property.storageClassName">storageClassName</a></code> | <code>string</code> | The name of the StorageClass that the reported capacity applies to. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1Props.property.capacity">capacity</a></code> | <code>cdk8s-metaflow.k8s.Quantity</code> | Capacity is the value reported by the CSI driver in its GetCapacityResponse for a GetCapacityRequest with topology and parameters that match the previous fields. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1Props.property.maximumVolumeSize">maximumVolumeSize</a></code> | <code>cdk8s-metaflow.k8s.Quantity</code> | MaximumVolumeSize is the value reported by the CSI driver in its GetCapacityResponse for a GetCapacityRequest with topology and parameters that match the previous fields. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1Props.property.nodeTopology">nodeTopology</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | NodeTopology defines which nodes have access to the storage for which capacity was reported. |

---

##### `storageClassName`<sup>Required</sup> <a name="storageClassName" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1Props.property.storageClassName"></a>

```typescript
public readonly storageClassName: string;
```

- *Type:* string

The name of the StorageClass that the reported capacity applies to.

It must meet the same requirements as the name of a StorageClass object (non-empty, DNS subdomain). If that object no longer exists, the CSIStorageCapacity object is obsolete and should be removed by its creator. This field is immutable.

---

##### `capacity`<sup>Optional</sup> <a name="capacity" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1Props.property.capacity"></a>

```typescript
public readonly capacity: Quantity;
```

- *Type:* cdk8s-metaflow.k8s.Quantity

Capacity is the value reported by the CSI driver in its GetCapacityResponse for a GetCapacityRequest with topology and parameters that match the previous fields.

The semantic is currently (CSI spec 1.2) defined as: The available capacity, in bytes, of the storage that can be used to provision volumes. If not set, that information is currently unavailable and treated like zero capacity.

---

##### `maximumVolumeSize`<sup>Optional</sup> <a name="maximumVolumeSize" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1Props.property.maximumVolumeSize"></a>

```typescript
public readonly maximumVolumeSize: Quantity;
```

- *Type:* cdk8s-metaflow.k8s.Quantity

MaximumVolumeSize is the value reported by the CSI driver in its GetCapacityResponse for a GetCapacityRequest with topology and parameters that match the previous fields.

This is defined since CSI spec 1.4.0 as the largest size that may be used in a CreateVolumeRequest.capacity_range.required_bytes field to create a volume with the same parameters as those in GetCapacityRequest. The corresponding value in the Kubernetes API is ResourceRequirements.Requests in a volume claim.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

The name has no particular meaning. It must be be a DNS subdomain (dots allowed, 253 characters). To ensure that there are no conflicts with other CSI drivers on the cluster, the recommendation is to use csisc-<uuid>, a generated name, or a reverse-domain name which ends with the unique CSI driver name.

Objects are namespaced.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `nodeTopology`<sup>Optional</sup> <a name="nodeTopology" id="cdk8s-metaflow.k8s.CsiStorageCapacityV1Beta1Props.property.nodeTopology"></a>

```typescript
public readonly nodeTopology: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

NodeTopology defines which nodes have access to the storage for which capacity was reported.

If not set, the storage is not accessible from any node in the cluster. If empty, the storage is accessible from all nodes. This field is immutable.

---

### CsiVolumeSource <a name="CsiVolumeSource" id="cdk8s-metaflow.k8s.CsiVolumeSource"></a>

Represents a source location of a volume to mount, managed by an external CSI driver.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CsiVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const csiVolumeSource: k8s.CsiVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CsiVolumeSource.property.driver">driver</a></code> | <code>string</code> | Driver is the name of the CSI driver that handles this volume. |
| <code><a href="#cdk8s-metaflow.k8s.CsiVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type to mount. |
| <code><a href="#cdk8s-metaflow.k8s.CsiVolumeSource.property.nodePublishSecretRef">nodePublishSecretRef</a></code> | <code>cdk8s-metaflow.k8s.LocalObjectReference</code> | NodePublishSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI NodePublishVolume and NodeUnpublishVolume calls. |
| <code><a href="#cdk8s-metaflow.k8s.CsiVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Specifies a read-only configuration for the volume. |
| <code><a href="#cdk8s-metaflow.k8s.CsiVolumeSource.property.volumeAttributes">volumeAttributes</a></code> | <code>{[ key: string ]: string}</code> | VolumeAttributes stores driver-specific properties that are passed to the CSI driver. |

---

##### `driver`<sup>Required</sup> <a name="driver" id="cdk8s-metaflow.k8s.CsiVolumeSource.property.driver"></a>

```typescript
public readonly driver: string;
```

- *Type:* string

Driver is the name of the CSI driver that handles this volume.

Consult with your admin for the correct name as registered in the cluster.

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.CsiVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type to mount.

Ex. "ext4", "xfs", "ntfs". If not provided, the empty value is passed to the associated CSI driver which will determine the default filesystem to apply.

---

##### `nodePublishSecretRef`<sup>Optional</sup> <a name="nodePublishSecretRef" id="cdk8s-metaflow.k8s.CsiVolumeSource.property.nodePublishSecretRef"></a>

```typescript
public readonly nodePublishSecretRef: LocalObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.LocalObjectReference

NodePublishSecretRef is a reference to the secret object containing sensitive information to pass to the CSI driver to complete the CSI NodePublishVolume and NodeUnpublishVolume calls.

This field is optional, and  may be empty if no secret is required. If the secret object contains more than one secret, all secret references are passed.

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.CsiVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false (read/write).

Specifies a read-only configuration for the volume.

Defaults to false (read/write).

---

##### `volumeAttributes`<sup>Optional</sup> <a name="volumeAttributes" id="cdk8s-metaflow.k8s.CsiVolumeSource.property.volumeAttributes"></a>

```typescript
public readonly volumeAttributes: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

VolumeAttributes stores driver-specific properties that are passed to the CSI driver.

Consult your driver's documentation for supported values.

---

### CustomResourceColumnDefinition <a name="CustomResourceColumnDefinition" id="cdk8s-metaflow.k8s.CustomResourceColumnDefinition"></a>

CustomResourceColumnDefinition specifies a column for server side printing.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CustomResourceColumnDefinition.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const customResourceColumnDefinition: k8s.CustomResourceColumnDefinition = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceColumnDefinition.property.jsonPath">jsonPath</a></code> | <code>string</code> | jsonPath is a simple JSON path (i.e. with array notation) which is evaluated against each custom resource to produce the value for this column. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceColumnDefinition.property.name">name</a></code> | <code>string</code> | name is a human readable name for the column. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceColumnDefinition.property.type">type</a></code> | <code>string</code> | type is an OpenAPI type definition for this column. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceColumnDefinition.property.description">description</a></code> | <code>string</code> | description is a human readable description of this column. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceColumnDefinition.property.format">format</a></code> | <code>string</code> | format is an optional OpenAPI type definition for this column. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceColumnDefinition.property.priority">priority</a></code> | <code>number</code> | priority is an integer defining the relative importance of this column compared to others. |

---

##### `jsonPath`<sup>Required</sup> <a name="jsonPath" id="cdk8s-metaflow.k8s.CustomResourceColumnDefinition.property.jsonPath"></a>

```typescript
public readonly jsonPath: string;
```

- *Type:* string

jsonPath is a simple JSON path (i.e. with array notation) which is evaluated against each custom resource to produce the value for this column.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CustomResourceColumnDefinition.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

name is a human readable name for the column.

---

##### `type`<sup>Required</sup> <a name="type" id="cdk8s-metaflow.k8s.CustomResourceColumnDefinition.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

type is an OpenAPI type definition for this column.

See https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#data-types for details.

---

##### `description`<sup>Optional</sup> <a name="description" id="cdk8s-metaflow.k8s.CustomResourceColumnDefinition.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* string

description is a human readable description of this column.

---

##### `format`<sup>Optional</sup> <a name="format" id="cdk8s-metaflow.k8s.CustomResourceColumnDefinition.property.format"></a>

```typescript
public readonly format: string;
```

- *Type:* string

format is an optional OpenAPI type definition for this column.

The 'name' format is applied to the primary identifier column to assist in clients identifying column is the resource name. See https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#data-types for details.

---

##### `priority`<sup>Optional</sup> <a name="priority" id="cdk8s-metaflow.k8s.CustomResourceColumnDefinition.property.priority"></a>

```typescript
public readonly priority: number;
```

- *Type:* number

priority is an integer defining the relative importance of this column compared to others.

Lower numbers are considered higher priority. Columns that may be omitted in limited space scenarios should be given a priority greater than 0.

---

### CustomResourceConversion <a name="CustomResourceConversion" id="cdk8s-metaflow.k8s.CustomResourceConversion"></a>

CustomResourceConversion describes how to convert different versions of a CR.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CustomResourceConversion.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const customResourceConversion: k8s.CustomResourceConversion = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceConversion.property.strategy">strategy</a></code> | <code>string</code> | strategy specifies how custom resources are converted between versions. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceConversion.property.webhook">webhook</a></code> | <code>cdk8s-metaflow.k8s.WebhookConversion</code> | webhook describes how to call the conversion webhook. |

---

##### `strategy`<sup>Required</sup> <a name="strategy" id="cdk8s-metaflow.k8s.CustomResourceConversion.property.strategy"></a>

```typescript
public readonly strategy: string;
```

- *Type:* string

strategy specifies how custom resources are converted between versions.

Allowed values are: - `None`: The converter only change the apiVersion and would not touch any other field in the custom resource. - `Webhook`: API Server will call to an external webhook to do the conversion. Additional information
is needed for this option. This requires spec.preserveUnknownFields to be false, and spec.conversion.webhook to be set.

---

##### `webhook`<sup>Optional</sup> <a name="webhook" id="cdk8s-metaflow.k8s.CustomResourceConversion.property.webhook"></a>

```typescript
public readonly webhook: WebhookConversion;
```

- *Type:* cdk8s-metaflow.k8s.WebhookConversion

webhook describes how to call the conversion webhook.

Required when `strategy` is set to `Webhook`.

---

### CustomResourceDefinitionListProps <a name="CustomResourceDefinitionListProps" id="cdk8s-metaflow.k8s.CustomResourceDefinitionListProps"></a>

CustomResourceDefinitionList is a list of CustomResourceDefinition objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CustomResourceDefinitionListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const customResourceDefinitionListProps: k8s.CustomResourceDefinitionListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.CustomResourceDefinition[]</code> | items list individual CustomResourceDefinition objects. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard object's metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.CustomResourceDefinitionListProps.property.items"></a>

```typescript
public readonly items: CustomResourceDefinition[];
```

- *Type:* cdk8s-metaflow.k8s.CustomResourceDefinition[]

items list individual CustomResourceDefinition objects.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CustomResourceDefinitionListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard object's metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

### CustomResourceDefinitionNames <a name="CustomResourceDefinitionNames" id="cdk8s-metaflow.k8s.CustomResourceDefinitionNames"></a>

CustomResourceDefinitionNames indicates the names to serve this CustomResourceDefinition.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CustomResourceDefinitionNames.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const customResourceDefinitionNames: k8s.CustomResourceDefinitionNames = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionNames.property.kind">kind</a></code> | <code>string</code> | kind is the serialized kind of the resource. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionNames.property.plural">plural</a></code> | <code>string</code> | plural is the plural name of the resource to serve. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionNames.property.categories">categories</a></code> | <code>string[]</code> | categories is a list of grouped resources this custom resource belongs to (e.g. 'all'). This is published in API discovery documents, and used by clients to support invocations like `kubectl get all`. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionNames.property.listKind">listKind</a></code> | <code>string</code> | listKind is the serialized kind of the list for this resource. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionNames.property.shortNames">shortNames</a></code> | <code>string[]</code> | shortNames are short names for the resource, exposed in API discovery documents, and used by clients to support invocations like `kubectl get <shortname>`. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionNames.property.singular">singular</a></code> | <code>string</code> | singular is the singular name of the resource. |

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.CustomResourceDefinitionNames.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

kind is the serialized kind of the resource.

It is normally CamelCase and singular. Custom resource instances will use this value as the `kind` attribute in API calls.

---

##### `plural`<sup>Required</sup> <a name="plural" id="cdk8s-metaflow.k8s.CustomResourceDefinitionNames.property.plural"></a>

```typescript
public readonly plural: string;
```

- *Type:* string

plural is the plural name of the resource to serve.

The custom resources are served under `/apis/<group>/<version>/.../<plural>`. Must match the name of the CustomResourceDefinition (in the form `<names.plural>.<group>`). Must be all lowercase.

---

##### `categories`<sup>Optional</sup> <a name="categories" id="cdk8s-metaflow.k8s.CustomResourceDefinitionNames.property.categories"></a>

```typescript
public readonly categories: string[];
```

- *Type:* string[]

categories is a list of grouped resources this custom resource belongs to (e.g. 'all'). This is published in API discovery documents, and used by clients to support invocations like `kubectl get all`.

---

##### `listKind`<sup>Optional</sup> <a name="listKind" id="cdk8s-metaflow.k8s.CustomResourceDefinitionNames.property.listKind"></a>

```typescript
public readonly listKind: string;
```

- *Type:* string
- *Default:* kind`List".

listKind is the serialized kind of the list for this resource.

Defaults to "`kind`List".

---

##### `shortNames`<sup>Optional</sup> <a name="shortNames" id="cdk8s-metaflow.k8s.CustomResourceDefinitionNames.property.shortNames"></a>

```typescript
public readonly shortNames: string[];
```

- *Type:* string[]

shortNames are short names for the resource, exposed in API discovery documents, and used by clients to support invocations like `kubectl get <shortname>`.

It must be all lowercase.

---

##### `singular`<sup>Optional</sup> <a name="singular" id="cdk8s-metaflow.k8s.CustomResourceDefinitionNames.property.singular"></a>

```typescript
public readonly singular: string;
```

- *Type:* string
- *Default:* lowercased `kind`.

singular is the singular name of the resource.

It must be all lowercase. Defaults to lowercased `kind`.

---

### CustomResourceDefinitionProps <a name="CustomResourceDefinitionProps" id="cdk8s-metaflow.k8s.CustomResourceDefinitionProps"></a>

CustomResourceDefinition represents a resource that should be exposed on the API server.

Its name MUST be in the format <.spec.name>.<.spec.group>.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CustomResourceDefinitionProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const customResourceDefinitionProps: k8s.CustomResourceDefinitionProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.CustomResourceDefinitionSpec</code> | spec describes how the user wants the resources to appear. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |

---

##### `spec`<sup>Required</sup> <a name="spec" id="cdk8s-metaflow.k8s.CustomResourceDefinitionProps.property.spec"></a>

```typescript
public readonly spec: CustomResourceDefinitionSpec;
```

- *Type:* cdk8s-metaflow.k8s.CustomResourceDefinitionSpec

spec describes how the user wants the resources to appear.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.CustomResourceDefinitionProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

### CustomResourceDefinitionSpec <a name="CustomResourceDefinitionSpec" id="cdk8s-metaflow.k8s.CustomResourceDefinitionSpec"></a>

CustomResourceDefinitionSpec describes how a user wants their resource to appear.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CustomResourceDefinitionSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const customResourceDefinitionSpec: k8s.CustomResourceDefinitionSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionSpec.property.group">group</a></code> | <code>string</code> | group is the API group of the defined custom resource. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionSpec.property.names">names</a></code> | <code>cdk8s-metaflow.k8s.CustomResourceDefinitionNames</code> | names specify the resource and kind names for the custom resource. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionSpec.property.scope">scope</a></code> | <code>string</code> | scope indicates whether the defined custom resource is cluster- or namespace-scoped. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionSpec.property.versions">versions</a></code> | <code>cdk8s-metaflow.k8s.CustomResourceDefinitionVersion[]</code> | versions is the list of all API versions of the defined custom resource. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionSpec.property.conversion">conversion</a></code> | <code>cdk8s-metaflow.k8s.CustomResourceConversion</code> | conversion defines conversion settings for the CRD. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionSpec.property.preserveUnknownFields">preserveUnknownFields</a></code> | <code>boolean</code> | preserveUnknownFields indicates that object fields which are not specified in the OpenAPI schema should be preserved when persisting to storage. |

---

##### `group`<sup>Required</sup> <a name="group" id="cdk8s-metaflow.k8s.CustomResourceDefinitionSpec.property.group"></a>

```typescript
public readonly group: string;
```

- *Type:* string

group is the API group of the defined custom resource.

The custom resources are served under `/apis/<group>/...`. Must match the name of the CustomResourceDefinition (in the form `<names.plural>.<group>`).

---

##### `names`<sup>Required</sup> <a name="names" id="cdk8s-metaflow.k8s.CustomResourceDefinitionSpec.property.names"></a>

```typescript
public readonly names: CustomResourceDefinitionNames;
```

- *Type:* cdk8s-metaflow.k8s.CustomResourceDefinitionNames

names specify the resource and kind names for the custom resource.

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk8s-metaflow.k8s.CustomResourceDefinitionSpec.property.scope"></a>

```typescript
public readonly scope: string;
```

- *Type:* string

scope indicates whether the defined custom resource is cluster- or namespace-scoped.

Allowed values are `Cluster` and `Namespaced`.

---

##### `versions`<sup>Required</sup> <a name="versions" id="cdk8s-metaflow.k8s.CustomResourceDefinitionSpec.property.versions"></a>

```typescript
public readonly versions: CustomResourceDefinitionVersion[];
```

- *Type:* cdk8s-metaflow.k8s.CustomResourceDefinitionVersion[]

versions is the list of all API versions of the defined custom resource.

Version names are used to compute the order in which served versions are listed in API discovery. If the version string is "kube-like", it will sort above non "kube-like" version strings, which are ordered lexicographically. "Kube-like" versions start with a "v", then are followed by a number (the major version), then optionally the string "alpha" or "beta" and another number (the minor version). These are sorted first by GA > beta > alpha (where GA is a version with no suffix such as beta or alpha), and then by comparing major version, then minor version. An example sorted list of versions: v10, v2, v1, v11beta2, v10beta3, v3beta1, v12alpha1, v11alpha2, foo1, foo10.

---

##### `conversion`<sup>Optional</sup> <a name="conversion" id="cdk8s-metaflow.k8s.CustomResourceDefinitionSpec.property.conversion"></a>

```typescript
public readonly conversion: CustomResourceConversion;
```

- *Type:* cdk8s-metaflow.k8s.CustomResourceConversion

conversion defines conversion settings for the CRD.

---

##### `preserveUnknownFields`<sup>Optional</sup> <a name="preserveUnknownFields" id="cdk8s-metaflow.k8s.CustomResourceDefinitionSpec.property.preserveUnknownFields"></a>

```typescript
public readonly preserveUnknownFields: boolean;
```

- *Type:* boolean

preserveUnknownFields indicates that object fields which are not specified in the OpenAPI schema should be preserved when persisting to storage.

apiVersion, kind, metadata and known fields inside metadata are always preserved. This field is deprecated in favor of setting `x-preserve-unknown-fields` to true in `spec.versions[*].schema.openAPIV3Schema`. See https://kubernetes.io/docs/tasks/access-kubernetes-api/custom-resources/custom-resource-definitions/#pruning-versus-preserving-unknown-fields for details.

---

### CustomResourceDefinitionVersion <a name="CustomResourceDefinitionVersion" id="cdk8s-metaflow.k8s.CustomResourceDefinitionVersion"></a>

CustomResourceDefinitionVersion describes a version for CRD.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CustomResourceDefinitionVersion.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const customResourceDefinitionVersion: k8s.CustomResourceDefinitionVersion = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionVersion.property.name">name</a></code> | <code>string</code> | name is the version name, e.g. “v1”, “v2beta1”, etc. The custom resources are served under this version at `/apis/<group>/<version>/...` if `served` is true. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionVersion.property.served">served</a></code> | <code>boolean</code> | served is a flag enabling/disabling this version from being served via REST APIs. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionVersion.property.storage">storage</a></code> | <code>boolean</code> | storage indicates this version should be used when persisting custom resources to storage. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionVersion.property.additionalPrinterColumns">additionalPrinterColumns</a></code> | <code>cdk8s-metaflow.k8s.CustomResourceColumnDefinition[]</code> | additionalPrinterColumns specifies additional columns returned in Table output. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionVersion.property.deprecated">deprecated</a></code> | <code>boolean</code> | deprecated indicates this version of the custom resource API is deprecated. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionVersion.property.deprecationWarning">deprecationWarning</a></code> | <code>string</code> | deprecationWarning overrides the default warning returned to API clients. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionVersion.property.schema">schema</a></code> | <code>cdk8s-metaflow.k8s.CustomResourceValidation</code> | schema describes the schema used for validation, pruning, and defaulting of this version of the custom resource. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceDefinitionVersion.property.subresources">subresources</a></code> | <code>cdk8s-metaflow.k8s.CustomResourceSubresources</code> | subresources specify what subresources this version of the defined custom resource have. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.CustomResourceDefinitionVersion.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

name is the version name, e.g. “v1”, “v2beta1”, etc. The custom resources are served under this version at `/apis/<group>/<version>/...` if `served` is true.

---

##### `served`<sup>Required</sup> <a name="served" id="cdk8s-metaflow.k8s.CustomResourceDefinitionVersion.property.served"></a>

```typescript
public readonly served: boolean;
```

- *Type:* boolean

served is a flag enabling/disabling this version from being served via REST APIs.

---

##### `storage`<sup>Required</sup> <a name="storage" id="cdk8s-metaflow.k8s.CustomResourceDefinitionVersion.property.storage"></a>

```typescript
public readonly storage: boolean;
```

- *Type:* boolean

storage indicates this version should be used when persisting custom resources to storage.

There must be exactly one version with storage=true.

---

##### `additionalPrinterColumns`<sup>Optional</sup> <a name="additionalPrinterColumns" id="cdk8s-metaflow.k8s.CustomResourceDefinitionVersion.property.additionalPrinterColumns"></a>

```typescript
public readonly additionalPrinterColumns: CustomResourceColumnDefinition[];
```

- *Type:* cdk8s-metaflow.k8s.CustomResourceColumnDefinition[]

additionalPrinterColumns specifies additional columns returned in Table output.

See https://kubernetes.io/docs/reference/using-api/api-concepts/#receiving-resources-as-tables for details. If no columns are specified, a single column displaying the age of the custom resource is used.

---

##### `deprecated`<sup>Optional</sup> <a name="deprecated" id="cdk8s-metaflow.k8s.CustomResourceDefinitionVersion.property.deprecated"></a>

```typescript
public readonly deprecated: boolean;
```

- *Type:* boolean
- *Default:* false.

deprecated indicates this version of the custom resource API is deprecated.

When set to true, API requests to this version receive a warning header in the server response. Defaults to false.

---

##### `deprecationWarning`<sup>Optional</sup> <a name="deprecationWarning" id="cdk8s-metaflow.k8s.CustomResourceDefinitionVersion.property.deprecationWarning"></a>

```typescript
public readonly deprecationWarning: string;
```

- *Type:* string

deprecationWarning overrides the default warning returned to API clients.

May only be set when `deprecated` is true. The default warning indicates this version is deprecated and recommends use of the newest served version of equal or greater stability, if one exists.

---

##### `schema`<sup>Optional</sup> <a name="schema" id="cdk8s-metaflow.k8s.CustomResourceDefinitionVersion.property.schema"></a>

```typescript
public readonly schema: CustomResourceValidation;
```

- *Type:* cdk8s-metaflow.k8s.CustomResourceValidation

schema describes the schema used for validation, pruning, and defaulting of this version of the custom resource.

---

##### `subresources`<sup>Optional</sup> <a name="subresources" id="cdk8s-metaflow.k8s.CustomResourceDefinitionVersion.property.subresources"></a>

```typescript
public readonly subresources: CustomResourceSubresources;
```

- *Type:* cdk8s-metaflow.k8s.CustomResourceSubresources

subresources specify what subresources this version of the defined custom resource have.

---

### CustomResourceSubresources <a name="CustomResourceSubresources" id="cdk8s-metaflow.k8s.CustomResourceSubresources"></a>

CustomResourceSubresources defines the status and scale subresources for CustomResources.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CustomResourceSubresources.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const customResourceSubresources: k8s.CustomResourceSubresources = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceSubresources.property.scale">scale</a></code> | <code>cdk8s-metaflow.k8s.CustomResourceSubresourceScale</code> | scale indicates the custom resource should serve a `/scale` subresource that returns an `autoscaling/v1` Scale object. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceSubresources.property.status">status</a></code> | <code>any</code> | status indicates the custom resource should serve a `/status` subresource. |

---

##### `scale`<sup>Optional</sup> <a name="scale" id="cdk8s-metaflow.k8s.CustomResourceSubresources.property.scale"></a>

```typescript
public readonly scale: CustomResourceSubresourceScale;
```

- *Type:* cdk8s-metaflow.k8s.CustomResourceSubresourceScale

scale indicates the custom resource should serve a `/scale` subresource that returns an `autoscaling/v1` Scale object.

---

##### `status`<sup>Optional</sup> <a name="status" id="cdk8s-metaflow.k8s.CustomResourceSubresources.property.status"></a>

```typescript
public readonly status: any;
```

- *Type:* any

status indicates the custom resource should serve a `/status` subresource.

When enabled: 1. requests to the custom resource primary endpoint ignore changes to the `status` stanza of the object. 2. requests to the custom resource `/status` subresource ignore changes to anything other than the `status` stanza of the object.

---

### CustomResourceSubresourceScale <a name="CustomResourceSubresourceScale" id="cdk8s-metaflow.k8s.CustomResourceSubresourceScale"></a>

CustomResourceSubresourceScale defines how to serve the scale subresource for CustomResources.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CustomResourceSubresourceScale.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const customResourceSubresourceScale: k8s.CustomResourceSubresourceScale = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceSubresourceScale.property.specReplicasPath">specReplicasPath</a></code> | <code>string</code> | specReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `spec.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.spec`. If there is no value under the given path in the custom resource, the `/scale` subresource will return an error on GET. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceSubresourceScale.property.statusReplicasPath">statusReplicasPath</a></code> | <code>string</code> | statusReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `status.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status`. If there is no value under the given path in the custom resource, the `status.replicas` value in the `/scale` subresource will default to 0. |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceSubresourceScale.property.labelSelectorPath">labelSelectorPath</a></code> | <code>string</code> | labelSelectorPath defines the JSON path inside of a custom resource that corresponds to Scale `status.selector`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status` or `.spec`. Must be set to work with HorizontalPodAutoscaler. The field pointed by this JSON path must be a string field (not a complex selector struct) which contains a serialized label selector in string form. More info: https://kubernetes.io/docs/tasks/access-kubernetes-api/custom-resources/custom-resource-definitions#scale-subresource If there is no value under the given path in the custom resource, the `status.selector` value in the `/scale` subresource will default to the empty string. |

---

##### `specReplicasPath`<sup>Required</sup> <a name="specReplicasPath" id="cdk8s-metaflow.k8s.CustomResourceSubresourceScale.property.specReplicasPath"></a>

```typescript
public readonly specReplicasPath: string;
```

- *Type:* string

specReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `spec.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.spec`. If there is no value under the given path in the custom resource, the `/scale` subresource will return an error on GET.

---

##### `statusReplicasPath`<sup>Required</sup> <a name="statusReplicasPath" id="cdk8s-metaflow.k8s.CustomResourceSubresourceScale.property.statusReplicasPath"></a>

```typescript
public readonly statusReplicasPath: string;
```

- *Type:* string

statusReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `status.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status`. If there is no value under the given path in the custom resource, the `status.replicas` value in the `/scale` subresource will default to 0.

---

##### `labelSelectorPath`<sup>Optional</sup> <a name="labelSelectorPath" id="cdk8s-metaflow.k8s.CustomResourceSubresourceScale.property.labelSelectorPath"></a>

```typescript
public readonly labelSelectorPath: string;
```

- *Type:* string

labelSelectorPath defines the JSON path inside of a custom resource that corresponds to Scale `status.selector`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status` or `.spec`. Must be set to work with HorizontalPodAutoscaler. The field pointed by this JSON path must be a string field (not a complex selector struct) which contains a serialized label selector in string form. More info: https://kubernetes.io/docs/tasks/access-kubernetes-api/custom-resources/custom-resource-definitions#scale-subresource If there is no value under the given path in the custom resource, the `status.selector` value in the `/scale` subresource will default to the empty string.

---

### CustomResourceValidation <a name="CustomResourceValidation" id="cdk8s-metaflow.k8s.CustomResourceValidation"></a>

CustomResourceValidation is a list of validation methods for CustomResources.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.CustomResourceValidation.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const customResourceValidation: k8s.CustomResourceValidation = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.CustomResourceValidation.property.openApiv3Schema">openApiv3Schema</a></code> | <code>cdk8s-metaflow.k8s.JsonSchemaProps</code> | openAPIV3Schema is the OpenAPI v3 schema to use for validation and pruning. |

---

##### `openApiv3Schema`<sup>Optional</sup> <a name="openApiv3Schema" id="cdk8s-metaflow.k8s.CustomResourceValidation.property.openApiv3Schema"></a>

```typescript
public readonly openApiv3Schema: JsonSchemaProps;
```

- *Type:* cdk8s-metaflow.k8s.JsonSchemaProps

openAPIV3Schema is the OpenAPI v3 schema to use for validation and pruning.

---

### DaemonSetListProps <a name="DaemonSetListProps" id="cdk8s-metaflow.k8s.DaemonSetListProps"></a>

DaemonSetList is a collection of daemon sets.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.DaemonSetListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const daemonSetListProps: k8s.DaemonSetListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.DaemonSet[]</code> | A list of daemon sets. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.DaemonSetListProps.property.items"></a>

```typescript
public readonly items: DaemonSet[];
```

- *Type:* cdk8s-metaflow.k8s.DaemonSet[]

A list of daemon sets.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.DaemonSetListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### DaemonSetProps <a name="DaemonSetProps" id="cdk8s-metaflow.k8s.DaemonSetProps"></a>

DaemonSet represents the configuration of a daemon set.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.DaemonSetProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const daemonSetProps: k8s.DaemonSetProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.DaemonSetSpec</code> | The desired behavior of this daemon set. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.DaemonSetProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.DaemonSetProps.property.spec"></a>

```typescript
public readonly spec: DaemonSetSpec;
```

- *Type:* cdk8s-metaflow.k8s.DaemonSetSpec

The desired behavior of this daemon set.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### DaemonSetSpec <a name="DaemonSetSpec" id="cdk8s-metaflow.k8s.DaemonSetSpec"></a>

DaemonSetSpec is the specification of a daemon set.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.DaemonSetSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const daemonSetSpec: k8s.DaemonSetSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetSpec.property.selector">selector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | A label query over pods that are managed by the daemon set. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetSpec.property.template">template</a></code> | <code>cdk8s-metaflow.k8s.PodTemplateSpec</code> | An object that describes the pod that will be created. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetSpec.property.minReadySeconds">minReadySeconds</a></code> | <code>number</code> | The minimum number of seconds for which a newly created DaemonSet pod should be ready without any of its container crashing, for it to be considered available. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetSpec.property.revisionHistoryLimit">revisionHistoryLimit</a></code> | <code>number</code> | The number of old history to retain to allow rollback. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetSpec.property.updateStrategy">updateStrategy</a></code> | <code>cdk8s-metaflow.k8s.DaemonSetUpdateStrategy</code> | An update strategy to replace existing DaemonSet pods with new pods. |

---

##### `selector`<sup>Required</sup> <a name="selector" id="cdk8s-metaflow.k8s.DaemonSetSpec.property.selector"></a>

```typescript
public readonly selector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

A label query over pods that are managed by the daemon set.

Must match in order to be controlled. It must match the pod template's labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors

---

##### `template`<sup>Required</sup> <a name="template" id="cdk8s-metaflow.k8s.DaemonSetSpec.property.template"></a>

```typescript
public readonly template: PodTemplateSpec;
```

- *Type:* cdk8s-metaflow.k8s.PodTemplateSpec

An object that describes the pod that will be created.

The DaemonSet will create exactly one copy of this pod on every node that matches the template's node selector (or on every node if no node selector is specified). More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template

---

##### `minReadySeconds`<sup>Optional</sup> <a name="minReadySeconds" id="cdk8s-metaflow.k8s.DaemonSetSpec.property.minReadySeconds"></a>

```typescript
public readonly minReadySeconds: number;
```

- *Type:* number
- *Default:* 0 (pod will be considered available as soon as it is ready).

The minimum number of seconds for which a newly created DaemonSet pod should be ready without any of its container crashing, for it to be considered available.

Defaults to 0 (pod will be considered available as soon as it is ready).

---

##### `revisionHistoryLimit`<sup>Optional</sup> <a name="revisionHistoryLimit" id="cdk8s-metaflow.k8s.DaemonSetSpec.property.revisionHistoryLimit"></a>

```typescript
public readonly revisionHistoryLimit: number;
```

- *Type:* number
- *Default:* 10.

The number of old history to retain to allow rollback.

This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.

---

##### `updateStrategy`<sup>Optional</sup> <a name="updateStrategy" id="cdk8s-metaflow.k8s.DaemonSetSpec.property.updateStrategy"></a>

```typescript
public readonly updateStrategy: DaemonSetUpdateStrategy;
```

- *Type:* cdk8s-metaflow.k8s.DaemonSetUpdateStrategy

An update strategy to replace existing DaemonSet pods with new pods.

---

### DaemonSetUpdateStrategy <a name="DaemonSetUpdateStrategy" id="cdk8s-metaflow.k8s.DaemonSetUpdateStrategy"></a>

DaemonSetUpdateStrategy is a struct used to control the update strategy for a DaemonSet.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.DaemonSetUpdateStrategy.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const daemonSetUpdateStrategy: k8s.DaemonSetUpdateStrategy = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetUpdateStrategy.property.rollingUpdate">rollingUpdate</a></code> | <code>cdk8s-metaflow.k8s.RollingUpdateDaemonSet</code> | Rolling update config params. |
| <code><a href="#cdk8s-metaflow.k8s.DaemonSetUpdateStrategy.property.type">type</a></code> | <code>string</code> | Type of daemon set update. |

---

##### `rollingUpdate`<sup>Optional</sup> <a name="rollingUpdate" id="cdk8s-metaflow.k8s.DaemonSetUpdateStrategy.property.rollingUpdate"></a>

```typescript
public readonly rollingUpdate: RollingUpdateDaemonSet;
```

- *Type:* cdk8s-metaflow.k8s.RollingUpdateDaemonSet

Rolling update config params.

Present only if type = "RollingUpdate".

---

##### `type`<sup>Optional</sup> <a name="type" id="cdk8s-metaflow.k8s.DaemonSetUpdateStrategy.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string
- *Default:* RollingUpdate.

Type of daemon set update.

Can be "RollingUpdate" or "OnDelete". Default is RollingUpdate.

---

### DatabaseAuthOptions <a name="DatabaseAuthOptions" id="cdk8s-metaflow.DatabaseAuthOptions"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.DatabaseAuthOptions.Initializer"></a>

```typescript
import { DatabaseAuthOptions } from 'cdk8s-metaflow'

const databaseAuthOptions: DatabaseAuthOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.DatabaseAuthOptions.property.database">database</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.DatabaseAuthOptions.property.enablePostgresUser">enablePostgresUser</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.DatabaseAuthOptions.property.password">password</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.DatabaseAuthOptions.property.postgresPassword">postgresPassword</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.DatabaseAuthOptions.property.replicationPassword">replicationPassword</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.DatabaseAuthOptions.property.replicationUsername">replicationUsername</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.DatabaseAuthOptions.property.username">username</a></code> | <code>string</code> | *No description.* |

---

##### `database`<sup>Optional</sup> <a name="database" id="cdk8s-metaflow.DatabaseAuthOptions.property.database"></a>

```typescript
public readonly database: string;
```

- *Type:* string

---

##### `enablePostgresUser`<sup>Optional</sup> <a name="enablePostgresUser" id="cdk8s-metaflow.DatabaseAuthOptions.property.enablePostgresUser"></a>

```typescript
public readonly enablePostgresUser: boolean;
```

- *Type:* boolean

---

##### `password`<sup>Optional</sup> <a name="password" id="cdk8s-metaflow.DatabaseAuthOptions.property.password"></a>

```typescript
public readonly password: string;
```

- *Type:* string

---

##### `postgresPassword`<sup>Optional</sup> <a name="postgresPassword" id="cdk8s-metaflow.DatabaseAuthOptions.property.postgresPassword"></a>

```typescript
public readonly postgresPassword: string;
```

- *Type:* string

---

##### `replicationPassword`<sup>Optional</sup> <a name="replicationPassword" id="cdk8s-metaflow.DatabaseAuthOptions.property.replicationPassword"></a>

```typescript
public readonly replicationPassword: string;
```

- *Type:* string

---

##### `replicationUsername`<sup>Optional</sup> <a name="replicationUsername" id="cdk8s-metaflow.DatabaseAuthOptions.property.replicationUsername"></a>

```typescript
public readonly replicationUsername: string;
```

- *Type:* string

---

##### `username`<sup>Optional</sup> <a name="username" id="cdk8s-metaflow.DatabaseAuthOptions.property.username"></a>

```typescript
public readonly username: string;
```

- *Type:* string

---

### DatabaseMetricsOptions <a name="DatabaseMetricsOptions" id="cdk8s-metaflow.DatabaseMetricsOptions"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.DatabaseMetricsOptions.Initializer"></a>

```typescript
import { DatabaseMetricsOptions } from 'cdk8s-metaflow'

const databaseMetricsOptions: DatabaseMetricsOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.DatabaseMetricsOptions.property.enabled">enabled</a></code> | <code>boolean</code> | *No description.* |

---

##### `enabled`<sup>Optional</sup> <a name="enabled" id="cdk8s-metaflow.DatabaseMetricsOptions.property.enabled"></a>

```typescript
public readonly enabled: boolean;
```

- *Type:* boolean

---

### DatabaseReplicationOptions <a name="DatabaseReplicationOptions" id="cdk8s-metaflow.DatabaseReplicationOptions"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.DatabaseReplicationOptions.Initializer"></a>

```typescript
import { DatabaseReplicationOptions } from 'cdk8s-metaflow'

const databaseReplicationOptions: DatabaseReplicationOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.DatabaseReplicationOptions.property.enabled">enabled</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.DatabaseReplicationOptions.property.readReplicas">readReplicas</a></code> | <code>number</code> | *No description.* |

---

##### `enabled`<sup>Optional</sup> <a name="enabled" id="cdk8s-metaflow.DatabaseReplicationOptions.property.enabled"></a>

```typescript
public readonly enabled: boolean;
```

- *Type:* boolean

---

##### `readReplicas`<sup>Optional</sup> <a name="readReplicas" id="cdk8s-metaflow.DatabaseReplicationOptions.property.readReplicas"></a>

```typescript
public readonly readReplicas: number;
```

- *Type:* number

---

### DatabaseResourceRequestOptions <a name="DatabaseResourceRequestOptions" id="cdk8s-metaflow.DatabaseResourceRequestOptions"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.DatabaseResourceRequestOptions.Initializer"></a>

```typescript
import { DatabaseResourceRequestOptions } from 'cdk8s-metaflow'

const databaseResourceRequestOptions: DatabaseResourceRequestOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.DatabaseResourceRequestOptions.property.cpu">cpu</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.DatabaseResourceRequestOptions.property.memory">memory</a></code> | <code>string</code> | *No description.* |

---

##### `cpu`<sup>Optional</sup> <a name="cpu" id="cdk8s-metaflow.DatabaseResourceRequestOptions.property.cpu"></a>

```typescript
public readonly cpu: string;
```

- *Type:* string

---

##### `memory`<sup>Optional</sup> <a name="memory" id="cdk8s-metaflow.DatabaseResourceRequestOptions.property.memory"></a>

```typescript
public readonly memory: string;
```

- *Type:* string

---

### DatabaseResourcesOptions <a name="DatabaseResourcesOptions" id="cdk8s-metaflow.DatabaseResourcesOptions"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.DatabaseResourcesOptions.Initializer"></a>

```typescript
import { DatabaseResourcesOptions } from 'cdk8s-metaflow'

const databaseResourcesOptions: DatabaseResourcesOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.DatabaseResourcesOptions.property.requests">requests</a></code> | <code><a href="#cdk8s-metaflow.DatabaseResourceRequestOptions">DatabaseResourceRequestOptions</a></code> | *No description.* |

---

##### `requests`<sup>Optional</sup> <a name="requests" id="cdk8s-metaflow.DatabaseResourcesOptions.property.requests"></a>

```typescript
public readonly requests: DatabaseResourceRequestOptions;
```

- *Type:* <a href="#cdk8s-metaflow.DatabaseResourceRequestOptions">DatabaseResourceRequestOptions</a>

---

### DatabaseVolumePermissionsOptions <a name="DatabaseVolumePermissionsOptions" id="cdk8s-metaflow.DatabaseVolumePermissionsOptions"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.DatabaseVolumePermissionsOptions.Initializer"></a>

```typescript
import { DatabaseVolumePermissionsOptions } from 'cdk8s-metaflow'

const databaseVolumePermissionsOptions: DatabaseVolumePermissionsOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.DatabaseVolumePermissionsOptions.property.enabled">enabled</a></code> | <code>boolean</code> | *No description.* |

---

##### `enabled`<sup>Optional</sup> <a name="enabled" id="cdk8s-metaflow.DatabaseVolumePermissionsOptions.property.enabled"></a>

```typescript
public readonly enabled: boolean;
```

- *Type:* boolean

---

### DbMigrationOptions <a name="DbMigrationOptions" id="cdk8s-metaflow.DbMigrationOptions"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.DbMigrationOptions.Initializer"></a>

```typescript
import { DbMigrationOptions } from 'cdk8s-metaflow'

const dbMigrationOptions: DbMigrationOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.DbMigrationOptions.property.onlyIfDbEmpty">onlyIfDbEmpty</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.DbMigrationOptions.property.runOnStart">runOnStart</a></code> | <code>boolean</code> | *No description.* |

---

##### `onlyIfDbEmpty`<sup>Optional</sup> <a name="onlyIfDbEmpty" id="cdk8s-metaflow.DbMigrationOptions.property.onlyIfDbEmpty"></a>

```typescript
public readonly onlyIfDbEmpty: boolean;
```

- *Type:* boolean

---

##### `runOnStart`<sup>Optional</sup> <a name="runOnStart" id="cdk8s-metaflow.DbMigrationOptions.property.runOnStart"></a>

```typescript
public readonly runOnStart: boolean;
```

- *Type:* boolean

---

### DeleteOptions <a name="DeleteOptions" id="cdk8s-metaflow.k8s.DeleteOptions"></a>

DeleteOptions may be provided when deleting an API object.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.DeleteOptions.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const deleteOptions: k8s.DeleteOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DeleteOptions.property.apiVersion">apiVersion</a></code> | <code>string</code> | APIVersion defines the versioned schema of this representation of an object. |
| <code><a href="#cdk8s-metaflow.k8s.DeleteOptions.property.dryRun">dryRun</a></code> | <code>string[]</code> | When present, indicates that modifications should not be persisted. |
| <code><a href="#cdk8s-metaflow.k8s.DeleteOptions.property.gracePeriodSeconds">gracePeriodSeconds</a></code> | <code>number</code> | The duration in seconds before the object should be deleted. |
| <code><a href="#cdk8s-metaflow.k8s.DeleteOptions.property.kind">kind</a></code> | <code>cdk8s-metaflow.k8s.IoK8SApimachineryPkgApisMetaV1DeleteOptionsKind</code> | Kind is a string value representing the REST resource this object represents. |
| <code><a href="#cdk8s-metaflow.k8s.DeleteOptions.property.orphanDependents">orphanDependents</a></code> | <code>boolean</code> | Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. |
| <code><a href="#cdk8s-metaflow.k8s.DeleteOptions.property.preconditions">preconditions</a></code> | <code>cdk8s-metaflow.k8s.Preconditions</code> | Must be fulfilled before a deletion is carried out. |
| <code><a href="#cdk8s-metaflow.k8s.DeleteOptions.property.propagationPolicy">propagationPolicy</a></code> | <code>string</code> | Whether and how garbage collection will be performed. |

---

##### `apiVersion`<sup>Optional</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.DeleteOptions.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

APIVersion defines the versioned schema of this representation of an object.

Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources

---

##### `dryRun`<sup>Optional</sup> <a name="dryRun" id="cdk8s-metaflow.k8s.DeleteOptions.property.dryRun"></a>

```typescript
public readonly dryRun: string[];
```

- *Type:* string[]

When present, indicates that modifications should not be persisted.

An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed

---

##### `gracePeriodSeconds`<sup>Optional</sup> <a name="gracePeriodSeconds" id="cdk8s-metaflow.k8s.DeleteOptions.property.gracePeriodSeconds"></a>

```typescript
public readonly gracePeriodSeconds: number;
```

- *Type:* number
- *Default:* a per object value if not specified. zero means delete immediately.

The duration in seconds before the object should be deleted.

Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately.

---

##### `kind`<sup>Optional</sup> <a name="kind" id="cdk8s-metaflow.k8s.DeleteOptions.property.kind"></a>

```typescript
public readonly kind: IoK8SApimachineryPkgApisMetaV1DeleteOptionsKind;
```

- *Type:* cdk8s-metaflow.k8s.IoK8SApimachineryPkgApisMetaV1DeleteOptionsKind

Kind is a string value representing the REST resource this object represents.

Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

##### `orphanDependents`<sup>Optional</sup> <a name="orphanDependents" id="cdk8s-metaflow.k8s.DeleteOptions.property.orphanDependents"></a>

```typescript
public readonly orphanDependents: boolean;
```

- *Type:* boolean

Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both.

---

##### `preconditions`<sup>Optional</sup> <a name="preconditions" id="cdk8s-metaflow.k8s.DeleteOptions.property.preconditions"></a>

```typescript
public readonly preconditions: Preconditions;
```

- *Type:* cdk8s-metaflow.k8s.Preconditions

Must be fulfilled before a deletion is carried out.

If not possible, a 409 Conflict status will be returned.

---

##### `propagationPolicy`<sup>Optional</sup> <a name="propagationPolicy" id="cdk8s-metaflow.k8s.DeleteOptions.property.propagationPolicy"></a>

```typescript
public readonly propagationPolicy: string;
```

- *Type:* string

Whether and how garbage collection will be performed.

Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground.

---

### DeploymentListProps <a name="DeploymentListProps" id="cdk8s-metaflow.k8s.DeploymentListProps"></a>

DeploymentList is a list of Deployments.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.DeploymentListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const deploymentListProps: k8s.DeploymentListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.Deployment[]</code> | Items is the list of Deployments. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.DeploymentListProps.property.items"></a>

```typescript
public readonly items: Deployment[];
```

- *Type:* cdk8s-metaflow.k8s.Deployment[]

Items is the list of Deployments.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.DeploymentListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

---

### DeploymentProps <a name="DeploymentProps" id="cdk8s-metaflow.k8s.DeploymentProps"></a>

Deployment enables declarative updates for Pods and ReplicaSets.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.DeploymentProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const deploymentProps: k8s.DeploymentProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.DeploymentSpec</code> | Specification of the desired behavior of the Deployment. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.DeploymentProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.DeploymentProps.property.spec"></a>

```typescript
public readonly spec: DeploymentSpec;
```

- *Type:* cdk8s-metaflow.k8s.DeploymentSpec

Specification of the desired behavior of the Deployment.

---

### DeploymentSpec <a name="DeploymentSpec" id="cdk8s-metaflow.k8s.DeploymentSpec"></a>

DeploymentSpec is the specification of the desired behavior of the Deployment.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.DeploymentSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const deploymentSpec: k8s.DeploymentSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentSpec.property.selector">selector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | Label selector for pods. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentSpec.property.template">template</a></code> | <code>cdk8s-metaflow.k8s.PodTemplateSpec</code> | Template describes the pods that will be created. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentSpec.property.minReadySeconds">minReadySeconds</a></code> | <code>number</code> | Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentSpec.property.paused">paused</a></code> | <code>boolean</code> | Indicates that the deployment is paused. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentSpec.property.progressDeadlineSeconds">progressDeadlineSeconds</a></code> | <code>number</code> | The maximum time in seconds for a deployment to make progress before it is considered to be failed. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentSpec.property.replicas">replicas</a></code> | <code>number</code> | Number of desired pods. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentSpec.property.revisionHistoryLimit">revisionHistoryLimit</a></code> | <code>number</code> | The number of old ReplicaSets to retain to allow rollback. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentSpec.property.strategy">strategy</a></code> | <code>cdk8s-metaflow.k8s.DeploymentStrategy</code> | The deployment strategy to use to replace existing pods with new ones. |

---

##### `selector`<sup>Required</sup> <a name="selector" id="cdk8s-metaflow.k8s.DeploymentSpec.property.selector"></a>

```typescript
public readonly selector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

Label selector for pods.

Existing ReplicaSets whose pods are selected by this will be the ones affected by this deployment. It must match the pod template's labels.

---

##### `template`<sup>Required</sup> <a name="template" id="cdk8s-metaflow.k8s.DeploymentSpec.property.template"></a>

```typescript
public readonly template: PodTemplateSpec;
```

- *Type:* cdk8s-metaflow.k8s.PodTemplateSpec

Template describes the pods that will be created.

---

##### `minReadySeconds`<sup>Optional</sup> <a name="minReadySeconds" id="cdk8s-metaflow.k8s.DeploymentSpec.property.minReadySeconds"></a>

```typescript
public readonly minReadySeconds: number;
```

- *Type:* number
- *Default:* 0 (pod will be considered available as soon as it is ready)

Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available.

Defaults to 0 (pod will be considered available as soon as it is ready)

---

##### `paused`<sup>Optional</sup> <a name="paused" id="cdk8s-metaflow.k8s.DeploymentSpec.property.paused"></a>

```typescript
public readonly paused: boolean;
```

- *Type:* boolean

Indicates that the deployment is paused.

---

##### `progressDeadlineSeconds`<sup>Optional</sup> <a name="progressDeadlineSeconds" id="cdk8s-metaflow.k8s.DeploymentSpec.property.progressDeadlineSeconds"></a>

```typescript
public readonly progressDeadlineSeconds: number;
```

- *Type:* number
- *Default:* 600s.

The maximum time in seconds for a deployment to make progress before it is considered to be failed.

The deployment controller will continue to process failed deployments and a condition with a ProgressDeadlineExceeded reason will be surfaced in the deployment status. Note that progress will not be estimated during the time a deployment is paused. Defaults to 600s.

---

##### `replicas`<sup>Optional</sup> <a name="replicas" id="cdk8s-metaflow.k8s.DeploymentSpec.property.replicas"></a>

```typescript
public readonly replicas: number;
```

- *Type:* number
- *Default:* 1.

Number of desired pods.

This is a pointer to distinguish between explicit zero and not specified. Defaults to 1.

---

##### `revisionHistoryLimit`<sup>Optional</sup> <a name="revisionHistoryLimit" id="cdk8s-metaflow.k8s.DeploymentSpec.property.revisionHistoryLimit"></a>

```typescript
public readonly revisionHistoryLimit: number;
```

- *Type:* number
- *Default:* 10.

The number of old ReplicaSets to retain to allow rollback.

This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.

---

##### `strategy`<sup>Optional</sup> <a name="strategy" id="cdk8s-metaflow.k8s.DeploymentSpec.property.strategy"></a>

```typescript
public readonly strategy: DeploymentStrategy;
```

- *Type:* cdk8s-metaflow.k8s.DeploymentStrategy

The deployment strategy to use to replace existing pods with new ones.

---

### DeploymentStrategy <a name="DeploymentStrategy" id="cdk8s-metaflow.k8s.DeploymentStrategy"></a>

DeploymentStrategy describes how to replace existing pods with new ones.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.DeploymentStrategy.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const deploymentStrategy: k8s.DeploymentStrategy = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentStrategy.property.rollingUpdate">rollingUpdate</a></code> | <code>cdk8s-metaflow.k8s.RollingUpdateDeployment</code> | Rolling update config params. |
| <code><a href="#cdk8s-metaflow.k8s.DeploymentStrategy.property.type">type</a></code> | <code>string</code> | Type of deployment. |

---

##### `rollingUpdate`<sup>Optional</sup> <a name="rollingUpdate" id="cdk8s-metaflow.k8s.DeploymentStrategy.property.rollingUpdate"></a>

```typescript
public readonly rollingUpdate: RollingUpdateDeployment;
```

- *Type:* cdk8s-metaflow.k8s.RollingUpdateDeployment

Rolling update config params.

Present only if DeploymentStrategyType = RollingUpdate.

---

##### `type`<sup>Optional</sup> <a name="type" id="cdk8s-metaflow.k8s.DeploymentStrategy.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string
- *Default:* RollingUpdate.

Type of deployment.

Can be "Recreate" or "RollingUpdate". Default is RollingUpdate.

---

### DownwardApiProjection <a name="DownwardApiProjection" id="cdk8s-metaflow.k8s.DownwardApiProjection"></a>

Represents downward API info for projecting into a projected volume.

Note that this is identical to a downwardAPI volume source without the default mode.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.DownwardApiProjection.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const downwardApiProjection: k8s.DownwardApiProjection = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DownwardApiProjection.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.DownwardApiVolumeFile[]</code> | Items is a list of DownwardAPIVolume file. |

---

##### `items`<sup>Optional</sup> <a name="items" id="cdk8s-metaflow.k8s.DownwardApiProjection.property.items"></a>

```typescript
public readonly items: DownwardApiVolumeFile[];
```

- *Type:* cdk8s-metaflow.k8s.DownwardApiVolumeFile[]

Items is a list of DownwardAPIVolume file.

---

### DownwardApiVolumeFile <a name="DownwardApiVolumeFile" id="cdk8s-metaflow.k8s.DownwardApiVolumeFile"></a>

DownwardAPIVolumeFile represents information to create the file containing the pod field.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.DownwardApiVolumeFile.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const downwardApiVolumeFile: k8s.DownwardApiVolumeFile = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DownwardApiVolumeFile.property.path">path</a></code> | <code>string</code> | Required: Path is  the relative path name of the file to be created. |
| <code><a href="#cdk8s-metaflow.k8s.DownwardApiVolumeFile.property.fieldRef">fieldRef</a></code> | <code>cdk8s-metaflow.k8s.ObjectFieldSelector</code> | Required: Selects a field of the pod: only annotations, labels, name and namespace are supported. |
| <code><a href="#cdk8s-metaflow.k8s.DownwardApiVolumeFile.property.mode">mode</a></code> | <code>number</code> | Optional: mode bits used to set permissions on this file, must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. |
| <code><a href="#cdk8s-metaflow.k8s.DownwardApiVolumeFile.property.resourceFieldRef">resourceFieldRef</a></code> | <code>cdk8s-metaflow.k8s.ResourceFieldSelector</code> | Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, requests.cpu and requests.memory) are currently supported. |

---

##### `path`<sup>Required</sup> <a name="path" id="cdk8s-metaflow.k8s.DownwardApiVolumeFile.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* string

Required: Path is  the relative path name of the file to be created.

Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'

---

##### `fieldRef`<sup>Optional</sup> <a name="fieldRef" id="cdk8s-metaflow.k8s.DownwardApiVolumeFile.property.fieldRef"></a>

```typescript
public readonly fieldRef: ObjectFieldSelector;
```

- *Type:* cdk8s-metaflow.k8s.ObjectFieldSelector

Required: Selects a field of the pod: only annotations, labels, name and namespace are supported.

---

##### `mode`<sup>Optional</sup> <a name="mode" id="cdk8s-metaflow.k8s.DownwardApiVolumeFile.property.mode"></a>

```typescript
public readonly mode: number;
```

- *Type:* number

Optional: mode bits used to set permissions on this file, must be an octal value between 0000 and 0777 or a decimal value between 0 and 511.

YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.

---

##### `resourceFieldRef`<sup>Optional</sup> <a name="resourceFieldRef" id="cdk8s-metaflow.k8s.DownwardApiVolumeFile.property.resourceFieldRef"></a>

```typescript
public readonly resourceFieldRef: ResourceFieldSelector;
```

- *Type:* cdk8s-metaflow.k8s.ResourceFieldSelector

Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, requests.cpu and requests.memory) are currently supported.

---

### DownwardApiVolumeSource <a name="DownwardApiVolumeSource" id="cdk8s-metaflow.k8s.DownwardApiVolumeSource"></a>

DownwardAPIVolumeSource represents a volume containing downward API info.

Downward API volumes support ownership management and SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.DownwardApiVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const downwardApiVolumeSource: k8s.DownwardApiVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.DownwardApiVolumeSource.property.defaultMode">defaultMode</a></code> | <code>number</code> | Optional: mode bits to use on created files by default. |
| <code><a href="#cdk8s-metaflow.k8s.DownwardApiVolumeSource.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.DownwardApiVolumeFile[]</code> | Items is a list of downward API volume file. |

---

##### `defaultMode`<sup>Optional</sup> <a name="defaultMode" id="cdk8s-metaflow.k8s.DownwardApiVolumeSource.property.defaultMode"></a>

```typescript
public readonly defaultMode: number;
```

- *Type:* number
- *Default:* 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.

Optional: mode bits to use on created files by default.

Must be a Optional: mode bits used to set permissions on created files by default. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.

---

##### `items`<sup>Optional</sup> <a name="items" id="cdk8s-metaflow.k8s.DownwardApiVolumeSource.property.items"></a>

```typescript
public readonly items: DownwardApiVolumeFile[];
```

- *Type:* cdk8s-metaflow.k8s.DownwardApiVolumeFile[]

Items is a list of downward API volume file.

---

### EmptyDirVolumeSource <a name="EmptyDirVolumeSource" id="cdk8s-metaflow.k8s.EmptyDirVolumeSource"></a>

Represents an empty directory for a pod.

Empty directory volumes support ownership management and SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EmptyDirVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const emptyDirVolumeSource: k8s.EmptyDirVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EmptyDirVolumeSource.property.medium">medium</a></code> | <code>string</code> | What type of storage medium should back this directory. |
| <code><a href="#cdk8s-metaflow.k8s.EmptyDirVolumeSource.property.sizeLimit">sizeLimit</a></code> | <code>cdk8s-metaflow.k8s.Quantity</code> | Total amount of local storage required for this EmptyDir volume. |

---

##### `medium`<sup>Optional</sup> <a name="medium" id="cdk8s-metaflow.k8s.EmptyDirVolumeSource.property.medium"></a>

```typescript
public readonly medium: string;
```

- *Type:* string

What type of storage medium should back this directory.

The default is "" which means to use the node's default medium. Must be an empty string (default) or Memory. More info: https://kubernetes.io/docs/concepts/storage/volumes#emptydir

---

##### `sizeLimit`<sup>Optional</sup> <a name="sizeLimit" id="cdk8s-metaflow.k8s.EmptyDirVolumeSource.property.sizeLimit"></a>

```typescript
public readonly sizeLimit: Quantity;
```

- *Type:* cdk8s-metaflow.k8s.Quantity

Total amount of local storage required for this EmptyDir volume.

The size limit is also applicable for memory medium. The maximum usage on memory medium EmptyDir would be the minimum value between the SizeLimit specified here and the sum of memory limits of all containers in a pod. The default is nil which means that the limit is undefined. More info: http://kubernetes.io/docs/user-guide/volumes#emptydir

---

### Endpoint <a name="Endpoint" id="cdk8s-metaflow.k8s.Endpoint"></a>

Endpoint represents a single logical "backend" implementing a service.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.Endpoint.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const endpoint: k8s.Endpoint = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Endpoint.property.addresses">addresses</a></code> | <code>string[]</code> | addresses of this endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoint.property.conditions">conditions</a></code> | <code>cdk8s-metaflow.k8s.EndpointConditions</code> | conditions contains information about the current status of the endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoint.property.deprecatedTopology">deprecatedTopology</a></code> | <code>{[ key: string ]: string}</code> | deprecatedTopology contains topology information part of the v1beta1 API. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoint.property.hints">hints</a></code> | <code>cdk8s-metaflow.k8s.EndpointHints</code> | hints contains information associated with how an endpoint should be consumed. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoint.property.hostname">hostname</a></code> | <code>string</code> | hostname of this endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoint.property.nodeName">nodeName</a></code> | <code>string</code> | nodeName represents the name of the Node hosting this endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoint.property.targetRef">targetRef</a></code> | <code>cdk8s-metaflow.k8s.ObjectReference</code> | targetRef is a reference to a Kubernetes object that represents this endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.Endpoint.property.zone">zone</a></code> | <code>string</code> | zone is the name of the Zone this endpoint exists in. |

---

##### `addresses`<sup>Required</sup> <a name="addresses" id="cdk8s-metaflow.k8s.Endpoint.property.addresses"></a>

```typescript
public readonly addresses: string[];
```

- *Type:* string[]

addresses of this endpoint.

The contents of this field are interpreted according to the corresponding EndpointSlice addressType field. Consumers must handle different types of addresses in the context of their own capabilities. This must contain at least one address but no more than 100.

---

##### `conditions`<sup>Optional</sup> <a name="conditions" id="cdk8s-metaflow.k8s.Endpoint.property.conditions"></a>

```typescript
public readonly conditions: EndpointConditions;
```

- *Type:* cdk8s-metaflow.k8s.EndpointConditions

conditions contains information about the current status of the endpoint.

---

##### `deprecatedTopology`<sup>Optional</sup> <a name="deprecatedTopology" id="cdk8s-metaflow.k8s.Endpoint.property.deprecatedTopology"></a>

```typescript
public readonly deprecatedTopology: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

deprecatedTopology contains topology information part of the v1beta1 API.

This field is deprecated, and will be removed when the v1beta1 API is removed (no sooner than kubernetes v1.24).  While this field can hold values, it is not writable through the v1 API, and any attempts to write to it will be silently ignored. Topology information can be found in the zone and nodeName fields instead.

---

##### `hints`<sup>Optional</sup> <a name="hints" id="cdk8s-metaflow.k8s.Endpoint.property.hints"></a>

```typescript
public readonly hints: EndpointHints;
```

- *Type:* cdk8s-metaflow.k8s.EndpointHints

hints contains information associated with how an endpoint should be consumed.

---

##### `hostname`<sup>Optional</sup> <a name="hostname" id="cdk8s-metaflow.k8s.Endpoint.property.hostname"></a>

```typescript
public readonly hostname: string;
```

- *Type:* string

hostname of this endpoint.

This field may be used by consumers of endpoints to distinguish endpoints from each other (e.g. in DNS names). Multiple endpoints which use the same hostname should be considered fungible (e.g. multiple A values in DNS). Must be lowercase and pass DNS Label (RFC 1123) validation.

---

##### `nodeName`<sup>Optional</sup> <a name="nodeName" id="cdk8s-metaflow.k8s.Endpoint.property.nodeName"></a>

```typescript
public readonly nodeName: string;
```

- *Type:* string

nodeName represents the name of the Node hosting this endpoint.

This can be used to determine endpoints local to a Node. This field can be enabled with the EndpointSliceNodeName feature gate.

---

##### `targetRef`<sup>Optional</sup> <a name="targetRef" id="cdk8s-metaflow.k8s.Endpoint.property.targetRef"></a>

```typescript
public readonly targetRef: ObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.ObjectReference

targetRef is a reference to a Kubernetes object that represents this endpoint.

---

##### `zone`<sup>Optional</sup> <a name="zone" id="cdk8s-metaflow.k8s.Endpoint.property.zone"></a>

```typescript
public readonly zone: string;
```

- *Type:* string

zone is the name of the Zone this endpoint exists in.

---

### EndpointAddress <a name="EndpointAddress" id="cdk8s-metaflow.k8s.EndpointAddress"></a>

EndpointAddress is a tuple that describes single IP address.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EndpointAddress.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const endpointAddress: k8s.EndpointAddress = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointAddress.property.ip">ip</a></code> | <code>string</code> | The IP of this endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointAddress.property.hostname">hostname</a></code> | <code>string</code> | The Hostname of this endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointAddress.property.nodeName">nodeName</a></code> | <code>string</code> | Optional: Node hosting this endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointAddress.property.targetRef">targetRef</a></code> | <code>cdk8s-metaflow.k8s.ObjectReference</code> | Reference to object providing the endpoint. |

---

##### `ip`<sup>Required</sup> <a name="ip" id="cdk8s-metaflow.k8s.EndpointAddress.property.ip"></a>

```typescript
public readonly ip: string;
```

- *Type:* string

The IP of this endpoint.

May not be loopback (127.0.0.0/8), link-local (169.254.0.0/16), or link-local multicast ((224.0.0.0/24). IPv6 is also accepted but not fully supported on all platforms. Also, certain kubernetes components, like kube-proxy, are not IPv6 ready.

---

##### `hostname`<sup>Optional</sup> <a name="hostname" id="cdk8s-metaflow.k8s.EndpointAddress.property.hostname"></a>

```typescript
public readonly hostname: string;
```

- *Type:* string

The Hostname of this endpoint.

---

##### `nodeName`<sup>Optional</sup> <a name="nodeName" id="cdk8s-metaflow.k8s.EndpointAddress.property.nodeName"></a>

```typescript
public readonly nodeName: string;
```

- *Type:* string

Optional: Node hosting this endpoint.

This can be used to determine endpoints local to a node.

---

##### `targetRef`<sup>Optional</sup> <a name="targetRef" id="cdk8s-metaflow.k8s.EndpointAddress.property.targetRef"></a>

```typescript
public readonly targetRef: ObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.ObjectReference

Reference to object providing the endpoint.

---

### EndpointConditions <a name="EndpointConditions" id="cdk8s-metaflow.k8s.EndpointConditions"></a>

EndpointConditions represents the current condition of an endpoint.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EndpointConditions.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const endpointConditions: k8s.EndpointConditions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointConditions.property.ready">ready</a></code> | <code>boolean</code> | ready indicates that this endpoint is prepared to receive traffic, according to whatever system is managing the endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointConditions.property.serving">serving</a></code> | <code>boolean</code> | serving is identical to ready except that it is set regardless of the terminating state of endpoints. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointConditions.property.terminating">terminating</a></code> | <code>boolean</code> | terminating indicates that this endpoint is terminating. |

---

##### `ready`<sup>Optional</sup> <a name="ready" id="cdk8s-metaflow.k8s.EndpointConditions.property.ready"></a>

```typescript
public readonly ready: boolean;
```

- *Type:* boolean

ready indicates that this endpoint is prepared to receive traffic, according to whatever system is managing the endpoint.

A nil value indicates an unknown state. In most cases consumers should interpret this unknown state as ready. For compatibility reasons, ready should never be "true" for terminating endpoints.

---

##### `serving`<sup>Optional</sup> <a name="serving" id="cdk8s-metaflow.k8s.EndpointConditions.property.serving"></a>

```typescript
public readonly serving: boolean;
```

- *Type:* boolean

serving is identical to ready except that it is set regardless of the terminating state of endpoints.

This condition should be set to true for a ready endpoint that is terminating. If nil, consumers should defer to the ready condition. This field can be enabled with the EndpointSliceTerminatingCondition feature gate.

---

##### `terminating`<sup>Optional</sup> <a name="terminating" id="cdk8s-metaflow.k8s.EndpointConditions.property.terminating"></a>

```typescript
public readonly terminating: boolean;
```

- *Type:* boolean

terminating indicates that this endpoint is terminating.

A nil value indicates an unknown state. Consumers should interpret this unknown state to mean that the endpoint is not terminating. This field can be enabled with the EndpointSliceTerminatingCondition feature gate.

---

### EndpointConditionsV1Beta1 <a name="EndpointConditionsV1Beta1" id="cdk8s-metaflow.k8s.EndpointConditionsV1Beta1"></a>

EndpointConditions represents the current condition of an endpoint.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EndpointConditionsV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const endpointConditionsV1Beta1: k8s.EndpointConditionsV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointConditionsV1Beta1.property.ready">ready</a></code> | <code>boolean</code> | ready indicates that this endpoint is prepared to receive traffic, according to whatever system is managing the endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointConditionsV1Beta1.property.serving">serving</a></code> | <code>boolean</code> | serving is identical to ready except that it is set regardless of the terminating state of endpoints. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointConditionsV1Beta1.property.terminating">terminating</a></code> | <code>boolean</code> | terminating indicates that this endpoint is terminating. |

---

##### `ready`<sup>Optional</sup> <a name="ready" id="cdk8s-metaflow.k8s.EndpointConditionsV1Beta1.property.ready"></a>

```typescript
public readonly ready: boolean;
```

- *Type:* boolean

ready indicates that this endpoint is prepared to receive traffic, according to whatever system is managing the endpoint.

A nil value indicates an unknown state. In most cases consumers should interpret this unknown state as ready. For compatibility reasons, ready should never be "true" for terminating endpoints.

---

##### `serving`<sup>Optional</sup> <a name="serving" id="cdk8s-metaflow.k8s.EndpointConditionsV1Beta1.property.serving"></a>

```typescript
public readonly serving: boolean;
```

- *Type:* boolean

serving is identical to ready except that it is set regardless of the terminating state of endpoints.

This condition should be set to true for a ready endpoint that is terminating. If nil, consumers should defer to the ready condition. This field can be enabled with the EndpointSliceTerminatingCondition feature gate.

---

##### `terminating`<sup>Optional</sup> <a name="terminating" id="cdk8s-metaflow.k8s.EndpointConditionsV1Beta1.property.terminating"></a>

```typescript
public readonly terminating: boolean;
```

- *Type:* boolean

terminating indicates that this endpoint is terminating.

A nil value indicates an unknown state. Consumers should interpret this unknown state to mean that the endpoint is not terminating. This field can be enabled with the EndpointSliceTerminatingCondition feature gate.

---

### EndpointHints <a name="EndpointHints" id="cdk8s-metaflow.k8s.EndpointHints"></a>

EndpointHints provides hints describing how an endpoint should be consumed.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EndpointHints.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const endpointHints: k8s.EndpointHints = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointHints.property.forZones">forZones</a></code> | <code>cdk8s-metaflow.k8s.ForZone[]</code> | forZones indicates the zone(s) this endpoint should be consumed by to enable topology aware routing. |

---

##### `forZones`<sup>Optional</sup> <a name="forZones" id="cdk8s-metaflow.k8s.EndpointHints.property.forZones"></a>

```typescript
public readonly forZones: ForZone[];
```

- *Type:* cdk8s-metaflow.k8s.ForZone[]

forZones indicates the zone(s) this endpoint should be consumed by to enable topology aware routing.

---

### EndpointHintsV1Beta1 <a name="EndpointHintsV1Beta1" id="cdk8s-metaflow.k8s.EndpointHintsV1Beta1"></a>

EndpointHints provides hints describing how an endpoint should be consumed.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EndpointHintsV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const endpointHintsV1Beta1: k8s.EndpointHintsV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointHintsV1Beta1.property.forZones">forZones</a></code> | <code>cdk8s-metaflow.k8s.ForZoneV1Beta1[]</code> | forZones indicates the zone(s) this endpoint should be consumed by to enable topology aware routing. |

---

##### `forZones`<sup>Optional</sup> <a name="forZones" id="cdk8s-metaflow.k8s.EndpointHintsV1Beta1.property.forZones"></a>

```typescript
public readonly forZones: ForZoneV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.ForZoneV1Beta1[]

forZones indicates the zone(s) this endpoint should be consumed by to enable topology aware routing.

May contain a maximum of 8 entries.

---

### EndpointPort <a name="EndpointPort" id="cdk8s-metaflow.k8s.EndpointPort"></a>

EndpointPort is a tuple that describes a single port.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EndpointPort.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const endpointPort: k8s.EndpointPort = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointPort.property.port">port</a></code> | <code>number</code> | The port number of the endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointPort.property.appProtocol">appProtocol</a></code> | <code>string</code> | The application protocol for this port. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointPort.property.name">name</a></code> | <code>string</code> | The name of this port. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointPort.property.protocol">protocol</a></code> | <code>string</code> | The IP protocol for this port. |

---

##### `port`<sup>Required</sup> <a name="port" id="cdk8s-metaflow.k8s.EndpointPort.property.port"></a>

```typescript
public readonly port: number;
```

- *Type:* number

The port number of the endpoint.

---

##### `appProtocol`<sup>Optional</sup> <a name="appProtocol" id="cdk8s-metaflow.k8s.EndpointPort.property.appProtocol"></a>

```typescript
public readonly appProtocol: string;
```

- *Type:* string

The application protocol for this port.

This field follows standard Kubernetes label syntax. Un-prefixed names are reserved for IANA standard service names (as per RFC-6335 and http://www.iana.org/assignments/service-names). Non-standard protocols should use prefixed names such as mycompany.com/my-custom-protocol.

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.EndpointPort.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of this port.

This must match the 'name' field in the corresponding ServicePort. Must be a DNS_LABEL. Optional only if one port is defined.

---

##### `protocol`<sup>Optional</sup> <a name="protocol" id="cdk8s-metaflow.k8s.EndpointPort.property.protocol"></a>

```typescript
public readonly protocol: string;
```

- *Type:* string
- *Default:* TCP.

The IP protocol for this port.

Must be UDP, TCP, or SCTP. Default is TCP.

---

### EndpointPortV1Beta1 <a name="EndpointPortV1Beta1" id="cdk8s-metaflow.k8s.EndpointPortV1Beta1"></a>

EndpointPort represents a Port used by an EndpointSlice.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EndpointPortV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const endpointPortV1Beta1: k8s.EndpointPortV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointPortV1Beta1.property.appProtocol">appProtocol</a></code> | <code>string</code> | The application protocol for this port. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointPortV1Beta1.property.name">name</a></code> | <code>string</code> | The name of this port. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointPortV1Beta1.property.port">port</a></code> | <code>number</code> | The port number of the endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointPortV1Beta1.property.protocol">protocol</a></code> | <code>string</code> | The IP protocol for this port. |

---

##### `appProtocol`<sup>Optional</sup> <a name="appProtocol" id="cdk8s-metaflow.k8s.EndpointPortV1Beta1.property.appProtocol"></a>

```typescript
public readonly appProtocol: string;
```

- *Type:* string

The application protocol for this port.

This field follows standard Kubernetes label syntax. Un-prefixed names are reserved for IANA standard service names (as per RFC-6335 and http://www.iana.org/assignments/service-names). Non-standard protocols should use prefixed names such as mycompany.com/my-custom-protocol.

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.EndpointPortV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string
- *Default:* empty string.

The name of this port.

All ports in an EndpointSlice must have a unique name. If the EndpointSlice is dervied from a Kubernetes service, this corresponds to the Service.ports[].name. Name must either be an empty string or pass DNS_LABEL validation: * must be no more than 63 characters long. * must consist of lower case alphanumeric characters or '-'. * must start and end with an alphanumeric character. Default is empty string.

---

##### `port`<sup>Optional</sup> <a name="port" id="cdk8s-metaflow.k8s.EndpointPortV1Beta1.property.port"></a>

```typescript
public readonly port: number;
```

- *Type:* number

The port number of the endpoint.

If this is not specified, ports are not restricted and must be interpreted in the context of the specific consumer.

---

##### `protocol`<sup>Optional</sup> <a name="protocol" id="cdk8s-metaflow.k8s.EndpointPortV1Beta1.property.protocol"></a>

```typescript
public readonly protocol: string;
```

- *Type:* string
- *Default:* TCP.

The IP protocol for this port.

Must be UDP, TCP, or SCTP. Default is TCP.

---

### EndpointSliceListProps <a name="EndpointSliceListProps" id="cdk8s-metaflow.k8s.EndpointSliceListProps"></a>

EndpointSliceList represents a list of endpoint slices.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EndpointSliceListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const endpointSliceListProps: k8s.EndpointSliceListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.EndpointSlice[]</code> | List of endpoint slices. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.EndpointSliceListProps.property.items"></a>

```typescript
public readonly items: EndpointSlice[];
```

- *Type:* cdk8s-metaflow.k8s.EndpointSlice[]

List of endpoint slices.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EndpointSliceListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

---

### EndpointSliceListV1Beta1Props <a name="EndpointSliceListV1Beta1Props" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1Props"></a>

EndpointSliceList represents a list of endpoint slices.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const endpointSliceListV1Beta1Props: k8s.EndpointSliceListV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.EndpointSliceV1Beta1[]</code> | List of endpoint slices. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceListV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1Props.property.items"></a>

```typescript
public readonly items: EndpointSliceV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.EndpointSliceV1Beta1[]

List of endpoint slices.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EndpointSliceListV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

---

### EndpointSliceProps <a name="EndpointSliceProps" id="cdk8s-metaflow.k8s.EndpointSliceProps"></a>

EndpointSlice represents a subset of the endpoints that implement a service.

For a given service there may be multiple EndpointSlice objects, selected by labels, which must be joined to produce the full set of endpoints.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EndpointSliceProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const endpointSliceProps: k8s.EndpointSliceProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceProps.property.addressType">addressType</a></code> | <code>string</code> | addressType specifies the type of address carried by this EndpointSlice. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceProps.property.endpoints">endpoints</a></code> | <code>cdk8s-metaflow.k8s.Endpoint[]</code> | endpoints is a list of unique endpoints in this slice. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceProps.property.ports">ports</a></code> | <code>cdk8s-metaflow.k8s.EndpointPort[]</code> | ports specifies the list of network ports exposed by each endpoint in this slice. |

---

##### `addressType`<sup>Required</sup> <a name="addressType" id="cdk8s-metaflow.k8s.EndpointSliceProps.property.addressType"></a>

```typescript
public readonly addressType: string;
```

- *Type:* string

addressType specifies the type of address carried by this EndpointSlice.

All addresses in this slice must be the same type. This field is immutable after creation. The following address types are currently supported: * IPv4: Represents an IPv4 Address. * IPv6: Represents an IPv6 Address. * FQDN: Represents a Fully Qualified Domain Name.

---

##### `endpoints`<sup>Required</sup> <a name="endpoints" id="cdk8s-metaflow.k8s.EndpointSliceProps.property.endpoints"></a>

```typescript
public readonly endpoints: Endpoint[];
```

- *Type:* cdk8s-metaflow.k8s.Endpoint[]

endpoints is a list of unique endpoints in this slice.

Each slice may include a maximum of 1000 endpoints.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EndpointSliceProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

---

##### `ports`<sup>Optional</sup> <a name="ports" id="cdk8s-metaflow.k8s.EndpointSliceProps.property.ports"></a>

```typescript
public readonly ports: EndpointPort[];
```

- *Type:* cdk8s-metaflow.k8s.EndpointPort[]

ports specifies the list of network ports exposed by each endpoint in this slice.

Each port must have a unique name. When ports is empty, it indicates that there are no defined ports. When a port is defined with a nil port value, it indicates "all ports". Each slice may include a maximum of 100 ports.

---

### EndpointSliceV1Beta1Props <a name="EndpointSliceV1Beta1Props" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1Props"></a>

EndpointSlice represents a subset of the endpoints that implement a service.

For a given service there may be multiple EndpointSlice objects, selected by labels, which must be joined to produce the full set of endpoints.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const endpointSliceV1Beta1Props: k8s.EndpointSliceV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1Props.property.addressType">addressType</a></code> | <code>string</code> | addressType specifies the type of address carried by this EndpointSlice. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1Props.property.endpoints">endpoints</a></code> | <code>cdk8s-metaflow.k8s.EndpointV1Beta1[]</code> | endpoints is a list of unique endpoints in this slice. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSliceV1Beta1Props.property.ports">ports</a></code> | <code>cdk8s-metaflow.k8s.EndpointPortV1Beta1[]</code> | ports specifies the list of network ports exposed by each endpoint in this slice. |

---

##### `addressType`<sup>Required</sup> <a name="addressType" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1Props.property.addressType"></a>

```typescript
public readonly addressType: string;
```

- *Type:* string

addressType specifies the type of address carried by this EndpointSlice.

All addresses in this slice must be the same type. This field is immutable after creation. The following address types are currently supported: * IPv4: Represents an IPv4 Address. * IPv6: Represents an IPv6 Address. * FQDN: Represents a Fully Qualified Domain Name.

---

##### `endpoints`<sup>Required</sup> <a name="endpoints" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1Props.property.endpoints"></a>

```typescript
public readonly endpoints: EndpointV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.EndpointV1Beta1[]

endpoints is a list of unique endpoints in this slice.

Each slice may include a maximum of 1000 endpoints.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

---

##### `ports`<sup>Optional</sup> <a name="ports" id="cdk8s-metaflow.k8s.EndpointSliceV1Beta1Props.property.ports"></a>

```typescript
public readonly ports: EndpointPortV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.EndpointPortV1Beta1[]

ports specifies the list of network ports exposed by each endpoint in this slice.

Each port must have a unique name. When ports is empty, it indicates that there are no defined ports. When a port is defined with a nil port value, it indicates "all ports". Each slice may include a maximum of 100 ports.

---

### EndpointsListProps <a name="EndpointsListProps" id="cdk8s-metaflow.k8s.EndpointsListProps"></a>

EndpointsList is a list of endpoints.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EndpointsListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const endpointsListProps: k8s.EndpointsListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.Endpoints[]</code> | List of endpoints. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.EndpointsListProps.property.items"></a>

```typescript
public readonly items: Endpoints[];
```

- *Type:* cdk8s-metaflow.k8s.Endpoints[]

List of endpoints.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EndpointsListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

### EndpointsProps <a name="EndpointsProps" id="cdk8s-metaflow.k8s.EndpointsProps"></a>

Endpoints is a collection of endpoints that implement the actual service.

Example:
Name: "mysvc",
Subsets: [
{
Addresses: [{"ip": "10.10.1.1"}, {"ip": "10.10.2.2"}],
Ports: [{"name": "a", "port": 8675}, {"name": "b", "port": 309}]
},
{
Addresses: [{"ip": "10.10.3.3"}],
Ports: [{"name": "a", "port": 93}, {"name": "b", "port": 76}]
},
]

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EndpointsProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const endpointsProps: k8s.EndpointsProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointsProps.property.subsets">subsets</a></code> | <code>cdk8s-metaflow.k8s.EndpointSubset[]</code> | The set of all endpoints is the union of all subsets. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EndpointsProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `subsets`<sup>Optional</sup> <a name="subsets" id="cdk8s-metaflow.k8s.EndpointsProps.property.subsets"></a>

```typescript
public readonly subsets: EndpointSubset[];
```

- *Type:* cdk8s-metaflow.k8s.EndpointSubset[]

The set of all endpoints is the union of all subsets.

Addresses are placed into subsets according to the IPs they share. A single address with multiple ports, some of which are ready and some of which are not (because they come from different containers) will result in the address being displayed in different subsets for the different ports. No address will appear in both Addresses and NotReadyAddresses in the same subset. Sets of addresses and ports that comprise a service.

---

### EndpointSubset <a name="EndpointSubset" id="cdk8s-metaflow.k8s.EndpointSubset"></a>

EndpointSubset is a group of addresses with a common set of ports.

The expanded set of endpoints is the Cartesian product of Addresses x Ports. For example, given:
{
Addresses: [{"ip": "10.10.1.1"}, {"ip": "10.10.2.2"}],
Ports:     [{"name": "a", "port": 8675}, {"name": "b", "port": 309}]
}
The resulting set of endpoints can be viewed as:
a: [ 10.10.1.1:8675, 10.10.2.2:8675 ],
b: [ 10.10.1.1:309, 10.10.2.2:309 ]

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EndpointSubset.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const endpointSubset: k8s.EndpointSubset = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSubset.property.addresses">addresses</a></code> | <code>cdk8s-metaflow.k8s.EndpointAddress[]</code> | IP addresses which offer the related ports that are marked as ready. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSubset.property.notReadyAddresses">notReadyAddresses</a></code> | <code>cdk8s-metaflow.k8s.EndpointAddress[]</code> | IP addresses which offer the related ports but are not currently marked as ready because they have not yet finished starting, have recently failed a readiness check, or have recently failed a liveness check. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointSubset.property.ports">ports</a></code> | <code>cdk8s-metaflow.k8s.EndpointPort[]</code> | Port numbers available on the related IP addresses. |

---

##### `addresses`<sup>Optional</sup> <a name="addresses" id="cdk8s-metaflow.k8s.EndpointSubset.property.addresses"></a>

```typescript
public readonly addresses: EndpointAddress[];
```

- *Type:* cdk8s-metaflow.k8s.EndpointAddress[]

IP addresses which offer the related ports that are marked as ready.

These endpoints should be considered safe for load balancers and clients to utilize.

---

##### `notReadyAddresses`<sup>Optional</sup> <a name="notReadyAddresses" id="cdk8s-metaflow.k8s.EndpointSubset.property.notReadyAddresses"></a>

```typescript
public readonly notReadyAddresses: EndpointAddress[];
```

- *Type:* cdk8s-metaflow.k8s.EndpointAddress[]

IP addresses which offer the related ports but are not currently marked as ready because they have not yet finished starting, have recently failed a readiness check, or have recently failed a liveness check.

---

##### `ports`<sup>Optional</sup> <a name="ports" id="cdk8s-metaflow.k8s.EndpointSubset.property.ports"></a>

```typescript
public readonly ports: EndpointPort[];
```

- *Type:* cdk8s-metaflow.k8s.EndpointPort[]

Port numbers available on the related IP addresses.

---

### EndpointV1Beta1 <a name="EndpointV1Beta1" id="cdk8s-metaflow.k8s.EndpointV1Beta1"></a>

Endpoint represents a single logical "backend" implementing a service.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EndpointV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const endpointV1Beta1: k8s.EndpointV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EndpointV1Beta1.property.addresses">addresses</a></code> | <code>string[]</code> | addresses of this endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointV1Beta1.property.conditions">conditions</a></code> | <code>cdk8s-metaflow.k8s.EndpointConditionsV1Beta1</code> | conditions contains information about the current status of the endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointV1Beta1.property.hints">hints</a></code> | <code>cdk8s-metaflow.k8s.EndpointHintsV1Beta1</code> | hints contains information associated with how an endpoint should be consumed. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointV1Beta1.property.hostname">hostname</a></code> | <code>string</code> | hostname of this endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointV1Beta1.property.nodeName">nodeName</a></code> | <code>string</code> | nodeName represents the name of the Node hosting this endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointV1Beta1.property.targetRef">targetRef</a></code> | <code>cdk8s-metaflow.k8s.ObjectReference</code> | targetRef is a reference to a Kubernetes object that represents this endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.EndpointV1Beta1.property.topology">topology</a></code> | <code>{[ key: string ]: string}</code> | topology contains arbitrary topology information associated with the endpoint. |

---

##### `addresses`<sup>Required</sup> <a name="addresses" id="cdk8s-metaflow.k8s.EndpointV1Beta1.property.addresses"></a>

```typescript
public readonly addresses: string[];
```

- *Type:* string[]

addresses of this endpoint.

The contents of this field are interpreted according to the corresponding EndpointSlice addressType field. Consumers must handle different types of addresses in the context of their own capabilities. This must contain at least one address but no more than 100.

---

##### `conditions`<sup>Optional</sup> <a name="conditions" id="cdk8s-metaflow.k8s.EndpointV1Beta1.property.conditions"></a>

```typescript
public readonly conditions: EndpointConditionsV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.EndpointConditionsV1Beta1

conditions contains information about the current status of the endpoint.

---

##### `hints`<sup>Optional</sup> <a name="hints" id="cdk8s-metaflow.k8s.EndpointV1Beta1.property.hints"></a>

```typescript
public readonly hints: EndpointHintsV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.EndpointHintsV1Beta1

hints contains information associated with how an endpoint should be consumed.

---

##### `hostname`<sup>Optional</sup> <a name="hostname" id="cdk8s-metaflow.k8s.EndpointV1Beta1.property.hostname"></a>

```typescript
public readonly hostname: string;
```

- *Type:* string

hostname of this endpoint.

This field may be used by consumers of endpoints to distinguish endpoints from each other (e.g. in DNS names). Multiple endpoints which use the same hostname should be considered fungible (e.g. multiple A values in DNS). Must be lowercase and pass DNS Label (RFC 1123) validation.

---

##### `nodeName`<sup>Optional</sup> <a name="nodeName" id="cdk8s-metaflow.k8s.EndpointV1Beta1.property.nodeName"></a>

```typescript
public readonly nodeName: string;
```

- *Type:* string

nodeName represents the name of the Node hosting this endpoint.

This can be used to determine endpoints local to a Node. This field can be enabled with the EndpointSliceNodeName feature gate.

---

##### `targetRef`<sup>Optional</sup> <a name="targetRef" id="cdk8s-metaflow.k8s.EndpointV1Beta1.property.targetRef"></a>

```typescript
public readonly targetRef: ObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.ObjectReference

targetRef is a reference to a Kubernetes object that represents this endpoint.

---

##### `topology`<sup>Optional</sup> <a name="topology" id="cdk8s-metaflow.k8s.EndpointV1Beta1.property.topology"></a>

```typescript
public readonly topology: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

topology contains arbitrary topology information associated with the endpoint.

These key/value pairs must conform with the label format. https://kubernetes.io/docs/concepts/overview/working-with-objects/labels Topology may include a maximum of 16 key/value pairs. This includes, but is not limited to the following well known keys: * kubernetes.io/hostname: the value indicates the hostname of the node
where the endpoint is located. This should match the corresponding
node label.
* topology.kubernetes.io/zone: the value indicates the zone where the
endpoint is located. This should match the corresponding node label.
* topology.kubernetes.io/region: the value indicates the region where the
endpoint is located. This should match the corresponding node label.
This field is deprecated and will be removed in future api versions.

---

### EnvFromSource <a name="EnvFromSource" id="cdk8s-metaflow.k8s.EnvFromSource"></a>

EnvFromSource represents the source of a set of ConfigMaps.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EnvFromSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const envFromSource: k8s.EnvFromSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EnvFromSource.property.configMapRef">configMapRef</a></code> | <code>cdk8s-metaflow.k8s.ConfigMapEnvSource</code> | The ConfigMap to select from. |
| <code><a href="#cdk8s-metaflow.k8s.EnvFromSource.property.prefix">prefix</a></code> | <code>string</code> | An optional identifier to prepend to each key in the ConfigMap. |
| <code><a href="#cdk8s-metaflow.k8s.EnvFromSource.property.secretRef">secretRef</a></code> | <code>cdk8s-metaflow.k8s.SecretEnvSource</code> | The Secret to select from. |

---

##### `configMapRef`<sup>Optional</sup> <a name="configMapRef" id="cdk8s-metaflow.k8s.EnvFromSource.property.configMapRef"></a>

```typescript
public readonly configMapRef: ConfigMapEnvSource;
```

- *Type:* cdk8s-metaflow.k8s.ConfigMapEnvSource

The ConfigMap to select from.

---

##### `prefix`<sup>Optional</sup> <a name="prefix" id="cdk8s-metaflow.k8s.EnvFromSource.property.prefix"></a>

```typescript
public readonly prefix: string;
```

- *Type:* string

An optional identifier to prepend to each key in the ConfigMap.

Must be a C_IDENTIFIER.

---

##### `secretRef`<sup>Optional</sup> <a name="secretRef" id="cdk8s-metaflow.k8s.EnvFromSource.property.secretRef"></a>

```typescript
public readonly secretRef: SecretEnvSource;
```

- *Type:* cdk8s-metaflow.k8s.SecretEnvSource

The Secret to select from.

---

### EnvVar <a name="EnvVar" id="cdk8s-metaflow.k8s.EnvVar"></a>

EnvVar represents an environment variable present in a Container.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EnvVar.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const envVar: k8s.EnvVar = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EnvVar.property.name">name</a></code> | <code>string</code> | Name of the environment variable. |
| <code><a href="#cdk8s-metaflow.k8s.EnvVar.property.value">value</a></code> | <code>string</code> | Variable references $(VAR_NAME) are expanded using the previously defined environment variables in the container and any service environment variables. |
| <code><a href="#cdk8s-metaflow.k8s.EnvVar.property.valueFrom">valueFrom</a></code> | <code>cdk8s-metaflow.k8s.EnvVarSource</code> | Source for the environment variable's value. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.EnvVar.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the environment variable.

Must be a C_IDENTIFIER.

---

##### `value`<sup>Optional</sup> <a name="value" id="cdk8s-metaflow.k8s.EnvVar.property.value"></a>

```typescript
public readonly value: string;
```

- *Type:* string
- *Default:* .

Variable references $(VAR_NAME) are expanded using the previously defined environment variables in the container and any service environment variables.

If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".

---

##### `valueFrom`<sup>Optional</sup> <a name="valueFrom" id="cdk8s-metaflow.k8s.EnvVar.property.valueFrom"></a>

```typescript
public readonly valueFrom: EnvVarSource;
```

- *Type:* cdk8s-metaflow.k8s.EnvVarSource

Source for the environment variable's value.

Cannot be used if value is not empty.

---

### EnvVarSource <a name="EnvVarSource" id="cdk8s-metaflow.k8s.EnvVarSource"></a>

EnvVarSource represents a source for the value of an EnvVar.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EnvVarSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const envVarSource: k8s.EnvVarSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EnvVarSource.property.configMapKeyRef">configMapKeyRef</a></code> | <code>cdk8s-metaflow.k8s.ConfigMapKeySelector</code> | Selects a key of a ConfigMap. |
| <code><a href="#cdk8s-metaflow.k8s.EnvVarSource.property.fieldRef">fieldRef</a></code> | <code>cdk8s-metaflow.k8s.ObjectFieldSelector</code> | Selects a field of the pod: supports metadata.name, metadata.namespace, `metadata.labels['<KEY>']`, `metadata.annotations['<KEY>']`, spec.nodeName, spec.serviceAccountName, status.hostIP, status.podIP, status.podIPs. |
| <code><a href="#cdk8s-metaflow.k8s.EnvVarSource.property.resourceFieldRef">resourceFieldRef</a></code> | <code>cdk8s-metaflow.k8s.ResourceFieldSelector</code> | Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, limits.ephemeral-storage, requests.cpu, requests.memory and requests.ephemeral-storage) are currently supported. |
| <code><a href="#cdk8s-metaflow.k8s.EnvVarSource.property.secretKeyRef">secretKeyRef</a></code> | <code>cdk8s-metaflow.k8s.SecretKeySelector</code> | Selects a key of a secret in the pod's namespace. |

---

##### `configMapKeyRef`<sup>Optional</sup> <a name="configMapKeyRef" id="cdk8s-metaflow.k8s.EnvVarSource.property.configMapKeyRef"></a>

```typescript
public readonly configMapKeyRef: ConfigMapKeySelector;
```

- *Type:* cdk8s-metaflow.k8s.ConfigMapKeySelector

Selects a key of a ConfigMap.

---

##### `fieldRef`<sup>Optional</sup> <a name="fieldRef" id="cdk8s-metaflow.k8s.EnvVarSource.property.fieldRef"></a>

```typescript
public readonly fieldRef: ObjectFieldSelector;
```

- *Type:* cdk8s-metaflow.k8s.ObjectFieldSelector

Selects a field of the pod: supports metadata.name, metadata.namespace, `metadata.labels['<KEY>']`, `metadata.annotations['<KEY>']`, spec.nodeName, spec.serviceAccountName, status.hostIP, status.podIP, status.podIPs.

---

##### `resourceFieldRef`<sup>Optional</sup> <a name="resourceFieldRef" id="cdk8s-metaflow.k8s.EnvVarSource.property.resourceFieldRef"></a>

```typescript
public readonly resourceFieldRef: ResourceFieldSelector;
```

- *Type:* cdk8s-metaflow.k8s.ResourceFieldSelector

Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, limits.ephemeral-storage, requests.cpu, requests.memory and requests.ephemeral-storage) are currently supported.

---

##### `secretKeyRef`<sup>Optional</sup> <a name="secretKeyRef" id="cdk8s-metaflow.k8s.EnvVarSource.property.secretKeyRef"></a>

```typescript
public readonly secretKeyRef: SecretKeySelector;
```

- *Type:* cdk8s-metaflow.k8s.SecretKeySelector

Selects a key of a secret in the pod's namespace.

---

### EphemeralContainer <a name="EphemeralContainer" id="cdk8s-metaflow.k8s.EphemeralContainer"></a>

An EphemeralContainer is a container that may be added temporarily to an existing pod for user-initiated activities such as debugging.

Ephemeral containers have no resource or scheduling guarantees, and they will not be restarted when they exit or when a pod is removed or restarted. If an ephemeral container causes a pod to exceed its resource allocation, the pod may be evicted. Ephemeral containers may not be added by directly updating the pod spec. They must be added via the pod's ephemeralcontainers subresource, and they will appear in the pod spec once added. This is an alpha feature enabled by the EphemeralContainers feature flag.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EphemeralContainer.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const ephemeralContainer: k8s.EphemeralContainer = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.name">name</a></code> | <code>string</code> | Name of the ephemeral container specified as a DNS_LABEL. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.args">args</a></code> | <code>string[]</code> | Arguments to the entrypoint. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.command">command</a></code> | <code>string[]</code> | Entrypoint array. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.env">env</a></code> | <code>cdk8s-metaflow.k8s.EnvVar[]</code> | List of environment variables to set in the container. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.envFrom">envFrom</a></code> | <code>cdk8s-metaflow.k8s.EnvFromSource[]</code> | List of sources to populate environment variables in the container. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.image">image</a></code> | <code>string</code> | Docker image name. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.imagePullPolicy">imagePullPolicy</a></code> | <code>string</code> | Image pull policy. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.lifecycle">lifecycle</a></code> | <code>cdk8s-metaflow.k8s.Lifecycle</code> | Lifecycle is not allowed for ephemeral containers. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.livenessProbe">livenessProbe</a></code> | <code>cdk8s-metaflow.k8s.Probe</code> | Probes are not allowed for ephemeral containers. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.ports">ports</a></code> | <code>cdk8s-metaflow.k8s.ContainerPort[]</code> | Ports are not allowed for ephemeral containers. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.readinessProbe">readinessProbe</a></code> | <code>cdk8s-metaflow.k8s.Probe</code> | Probes are not allowed for ephemeral containers. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.resources">resources</a></code> | <code>cdk8s-metaflow.k8s.ResourceRequirements</code> | Resources are not allowed for ephemeral containers. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.securityContext">securityContext</a></code> | <code>cdk8s-metaflow.k8s.SecurityContext</code> | Optional: SecurityContext defines the security options the ephemeral container should be run with. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.startupProbe">startupProbe</a></code> | <code>cdk8s-metaflow.k8s.Probe</code> | Probes are not allowed for ephemeral containers. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.stdin">stdin</a></code> | <code>boolean</code> | Whether this container should allocate a buffer for stdin in the container runtime. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.stdinOnce">stdinOnce</a></code> | <code>boolean</code> | Whether the container runtime should close the stdin channel after it has been opened by a single attach. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.targetContainerName">targetContainerName</a></code> | <code>string</code> | If set, the name of the container from PodSpec that this ephemeral container targets. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.terminationMessagePath">terminationMessagePath</a></code> | <code>string</code> | Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.terminationMessagePolicy">terminationMessagePolicy</a></code> | <code>string</code> | Indicate how the termination message should be populated. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.tty">tty</a></code> | <code>boolean</code> | Whether this container should allocate a TTY for itself, also requires 'stdin' to be true. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.volumeDevices">volumeDevices</a></code> | <code>cdk8s-metaflow.k8s.VolumeDevice[]</code> | volumeDevices is the list of block devices to be used by the container. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.volumeMounts">volumeMounts</a></code> | <code>cdk8s-metaflow.k8s.VolumeMount[]</code> | Pod volumes to mount into the container's filesystem. |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralContainer.property.workingDir">workingDir</a></code> | <code>string</code> | Container's working directory. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.EphemeralContainer.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the ephemeral container specified as a DNS_LABEL.

This name must be unique among all containers, init containers and ephemeral containers.

---

##### `args`<sup>Optional</sup> <a name="args" id="cdk8s-metaflow.k8s.EphemeralContainer.property.args"></a>

```typescript
public readonly args: string[];
```

- *Type:* string[]

Arguments to the entrypoint.

The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell

---

##### `command`<sup>Optional</sup> <a name="command" id="cdk8s-metaflow.k8s.EphemeralContainer.property.command"></a>

```typescript
public readonly command: string[];
```

- *Type:* string[]

Entrypoint array.

Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell

---

##### `env`<sup>Optional</sup> <a name="env" id="cdk8s-metaflow.k8s.EphemeralContainer.property.env"></a>

```typescript
public readonly env: EnvVar[];
```

- *Type:* cdk8s-metaflow.k8s.EnvVar[]

List of environment variables to set in the container.

Cannot be updated.

---

##### `envFrom`<sup>Optional</sup> <a name="envFrom" id="cdk8s-metaflow.k8s.EphemeralContainer.property.envFrom"></a>

```typescript
public readonly envFrom: EnvFromSource[];
```

- *Type:* cdk8s-metaflow.k8s.EnvFromSource[]

List of sources to populate environment variables in the container.

The keys defined within a source must be a C_IDENTIFIER. All invalid keys will be reported as an event when the container is starting. When a key exists in multiple sources, the value associated with the last source will take precedence. Values defined by an Env with a duplicate key will take precedence. Cannot be updated.

---

##### `image`<sup>Optional</sup> <a name="image" id="cdk8s-metaflow.k8s.EphemeralContainer.property.image"></a>

```typescript
public readonly image: string;
```

- *Type:* string

Docker image name.

More info: https://kubernetes.io/docs/concepts/containers/images

---

##### `imagePullPolicy`<sup>Optional</sup> <a name="imagePullPolicy" id="cdk8s-metaflow.k8s.EphemeralContainer.property.imagePullPolicy"></a>

```typescript
public readonly imagePullPolicy: string;
```

- *Type:* string
- *Default:* Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: https://kubernetes.io/docs/concepts/containers/images#updating-images

Image pull policy.

One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: https://kubernetes.io/docs/concepts/containers/images#updating-images

---

##### `lifecycle`<sup>Optional</sup> <a name="lifecycle" id="cdk8s-metaflow.k8s.EphemeralContainer.property.lifecycle"></a>

```typescript
public readonly lifecycle: Lifecycle;
```

- *Type:* cdk8s-metaflow.k8s.Lifecycle

Lifecycle is not allowed for ephemeral containers.

---

##### `livenessProbe`<sup>Optional</sup> <a name="livenessProbe" id="cdk8s-metaflow.k8s.EphemeralContainer.property.livenessProbe"></a>

```typescript
public readonly livenessProbe: Probe;
```

- *Type:* cdk8s-metaflow.k8s.Probe

Probes are not allowed for ephemeral containers.

---

##### `ports`<sup>Optional</sup> <a name="ports" id="cdk8s-metaflow.k8s.EphemeralContainer.property.ports"></a>

```typescript
public readonly ports: ContainerPort[];
```

- *Type:* cdk8s-metaflow.k8s.ContainerPort[]

Ports are not allowed for ephemeral containers.

---

##### `readinessProbe`<sup>Optional</sup> <a name="readinessProbe" id="cdk8s-metaflow.k8s.EphemeralContainer.property.readinessProbe"></a>

```typescript
public readonly readinessProbe: Probe;
```

- *Type:* cdk8s-metaflow.k8s.Probe

Probes are not allowed for ephemeral containers.

---

##### `resources`<sup>Optional</sup> <a name="resources" id="cdk8s-metaflow.k8s.EphemeralContainer.property.resources"></a>

```typescript
public readonly resources: ResourceRequirements;
```

- *Type:* cdk8s-metaflow.k8s.ResourceRequirements

Resources are not allowed for ephemeral containers.

Ephemeral containers use spare resources already allocated to the pod.

---

##### `securityContext`<sup>Optional</sup> <a name="securityContext" id="cdk8s-metaflow.k8s.EphemeralContainer.property.securityContext"></a>

```typescript
public readonly securityContext: SecurityContext;
```

- *Type:* cdk8s-metaflow.k8s.SecurityContext

Optional: SecurityContext defines the security options the ephemeral container should be run with.

If set, the fields of SecurityContext override the equivalent fields of PodSecurityContext.

---

##### `startupProbe`<sup>Optional</sup> <a name="startupProbe" id="cdk8s-metaflow.k8s.EphemeralContainer.property.startupProbe"></a>

```typescript
public readonly startupProbe: Probe;
```

- *Type:* cdk8s-metaflow.k8s.Probe

Probes are not allowed for ephemeral containers.

---

##### `stdin`<sup>Optional</sup> <a name="stdin" id="cdk8s-metaflow.k8s.EphemeralContainer.property.stdin"></a>

```typescript
public readonly stdin: boolean;
```

- *Type:* boolean
- *Default:* false.

Whether this container should allocate a buffer for stdin in the container runtime.

If this is not set, reads from stdin in the container will always result in EOF. Default is false.

---

##### `stdinOnce`<sup>Optional</sup> <a name="stdinOnce" id="cdk8s-metaflow.k8s.EphemeralContainer.property.stdinOnce"></a>

```typescript
public readonly stdinOnce: boolean;
```

- *Type:* boolean
- *Default:* false

Whether the container runtime should close the stdin channel after it has been opened by a single attach.

When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF. Default is false

---

##### `targetContainerName`<sup>Optional</sup> <a name="targetContainerName" id="cdk8s-metaflow.k8s.EphemeralContainer.property.targetContainerName"></a>

```typescript
public readonly targetContainerName: string;
```

- *Type:* string

If set, the name of the container from PodSpec that this ephemeral container targets.

The ephemeral container will be run in the namespaces (IPC, PID, etc) of this container. If not set then the ephemeral container is run in whatever namespaces are shared for the pod. Note that the container runtime must support this feature.

---

##### `terminationMessagePath`<sup>Optional</sup> <a name="terminationMessagePath" id="cdk8s-metaflow.k8s.EphemeralContainer.property.terminationMessagePath"></a>

```typescript
public readonly terminationMessagePath: string;
```

- *Type:* string
- *Default:* dev/termination-log. Cannot be updated.

Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem.

Message written is intended to be brief final status, such as an assertion failure message. Will be truncated by the node if greater than 4096 bytes. The total message length across all containers will be limited to 12kb. Defaults to /dev/termination-log. Cannot be updated.

---

##### `terminationMessagePolicy`<sup>Optional</sup> <a name="terminationMessagePolicy" id="cdk8s-metaflow.k8s.EphemeralContainer.property.terminationMessagePolicy"></a>

```typescript
public readonly terminationMessagePolicy: string;
```

- *Type:* string
- *Default:* File. Cannot be updated.

Indicate how the termination message should be populated.

File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.

---

##### `tty`<sup>Optional</sup> <a name="tty" id="cdk8s-metaflow.k8s.EphemeralContainer.property.tty"></a>

```typescript
public readonly tty: boolean;
```

- *Type:* boolean
- *Default:* false.

Whether this container should allocate a TTY for itself, also requires 'stdin' to be true.

Default is false.

---

##### `volumeDevices`<sup>Optional</sup> <a name="volumeDevices" id="cdk8s-metaflow.k8s.EphemeralContainer.property.volumeDevices"></a>

```typescript
public readonly volumeDevices: VolumeDevice[];
```

- *Type:* cdk8s-metaflow.k8s.VolumeDevice[]

volumeDevices is the list of block devices to be used by the container.

---

##### `volumeMounts`<sup>Optional</sup> <a name="volumeMounts" id="cdk8s-metaflow.k8s.EphemeralContainer.property.volumeMounts"></a>

```typescript
public readonly volumeMounts: VolumeMount[];
```

- *Type:* cdk8s-metaflow.k8s.VolumeMount[]

Pod volumes to mount into the container's filesystem.

Cannot be updated.

---

##### `workingDir`<sup>Optional</sup> <a name="workingDir" id="cdk8s-metaflow.k8s.EphemeralContainer.property.workingDir"></a>

```typescript
public readonly workingDir: string;
```

- *Type:* string

Container's working directory.

If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.

---

### EphemeralVolumeSource <a name="EphemeralVolumeSource" id="cdk8s-metaflow.k8s.EphemeralVolumeSource"></a>

Represents an ephemeral volume that is handled by a normal storage driver.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EphemeralVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const ephemeralVolumeSource: k8s.EphemeralVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EphemeralVolumeSource.property.volumeClaimTemplate">volumeClaimTemplate</a></code> | <code>cdk8s-metaflow.k8s.PersistentVolumeClaimTemplate</code> | Will be used to create a stand-alone PVC to provision the volume. |

---

##### `volumeClaimTemplate`<sup>Optional</sup> <a name="volumeClaimTemplate" id="cdk8s-metaflow.k8s.EphemeralVolumeSource.property.volumeClaimTemplate"></a>

```typescript
public readonly volumeClaimTemplate: PersistentVolumeClaimTemplate;
```

- *Type:* cdk8s-metaflow.k8s.PersistentVolumeClaimTemplate

Will be used to create a stand-alone PVC to provision the volume.

The pod in which this EphemeralVolumeSource is embedded will be the owner of the PVC, i.e. the PVC will be deleted together with the pod.  The name of the PVC will be `<pod name>-<volume name>` where `<volume name>` is the name from the `PodSpec.Volumes` array entry. Pod validation will reject the pod if the concatenated name is not valid for a PVC (for example, too long).

An existing PVC with that name that is not owned by the pod will *not* be used for the pod to avoid using an unrelated volume by mistake. Starting the pod is then blocked until the unrelated PVC is removed. If such a pre-created PVC is meant to be used by the pod, the PVC has to updated with an owner reference to the pod once the pod exists. Normally this should not be necessary, but it may be useful when manually reconstructing a broken cluster.

This field is read-only and no changes will be made by Kubernetes to the PVC after it has been created.

Required, must not be nil.

---

### EventListProps <a name="EventListProps" id="cdk8s-metaflow.k8s.EventListProps"></a>

EventList is a list of Event objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EventListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const eventListProps: k8s.EventListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.Event[]</code> | items is a list of schema objects. |
| <code><a href="#cdk8s-metaflow.k8s.EventListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.EventListProps.property.items"></a>

```typescript
public readonly items: Event[];
```

- *Type:* cdk8s-metaflow.k8s.Event[]

items is a list of schema objects.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EventListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### EventListV1Beta1Props <a name="EventListV1Beta1Props" id="cdk8s-metaflow.k8s.EventListV1Beta1Props"></a>

EventList is a list of Event objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EventListV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const eventListV1Beta1Props: k8s.EventListV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.EventV1Beta1[]</code> | items is a list of schema objects. |
| <code><a href="#cdk8s-metaflow.k8s.EventListV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.EventListV1Beta1Props.property.items"></a>

```typescript
public readonly items: EventV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.EventV1Beta1[]

items is a list of schema objects.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EventListV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### EventProps <a name="EventProps" id="cdk8s-metaflow.k8s.EventProps"></a>

Event is a report of an event somewhere in the cluster.

It generally denotes some state change in the system. Events have a limited retention time and triggers and messages may evolve with time.  Event consumers should not rely on the timing of an event with a given Reason reflecting a consistent underlying trigger, or the continued existence of events with that Reason.  Events should be treated as informative, best-effort, supplemental data.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EventProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const eventProps: k8s.EventProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventProps.property.eventTime">eventTime</a></code> | <code>Date</code> | eventTime is the time when this Event was first observed. |
| <code><a href="#cdk8s-metaflow.k8s.EventProps.property.action">action</a></code> | <code>string</code> | action is what action was taken/failed regarding to the regarding object. |
| <code><a href="#cdk8s-metaflow.k8s.EventProps.property.deprecatedCount">deprecatedCount</a></code> | <code>number</code> | deprecatedCount is the deprecated field assuring backward compatibility with core.v1 Event type. |
| <code><a href="#cdk8s-metaflow.k8s.EventProps.property.deprecatedFirstTimestamp">deprecatedFirstTimestamp</a></code> | <code>Date</code> | deprecatedFirstTimestamp is the deprecated field assuring backward compatibility with core.v1 Event type. |
| <code><a href="#cdk8s-metaflow.k8s.EventProps.property.deprecatedLastTimestamp">deprecatedLastTimestamp</a></code> | <code>Date</code> | deprecatedLastTimestamp is the deprecated field assuring backward compatibility with core.v1 Event type. |
| <code><a href="#cdk8s-metaflow.k8s.EventProps.property.deprecatedSource">deprecatedSource</a></code> | <code>cdk8s-metaflow.k8s.EventSource</code> | deprecatedSource is the deprecated field assuring backward compatibility with core.v1 Event type. |
| <code><a href="#cdk8s-metaflow.k8s.EventProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.EventProps.property.note">note</a></code> | <code>string</code> | note is a human-readable description of the status of this operation. |
| <code><a href="#cdk8s-metaflow.k8s.EventProps.property.reason">reason</a></code> | <code>string</code> | reason is why the action was taken. |
| <code><a href="#cdk8s-metaflow.k8s.EventProps.property.regarding">regarding</a></code> | <code>cdk8s-metaflow.k8s.ObjectReference</code> | regarding contains the object this Event is about. |
| <code><a href="#cdk8s-metaflow.k8s.EventProps.property.related">related</a></code> | <code>cdk8s-metaflow.k8s.ObjectReference</code> | related is the optional secondary object for more complex actions. |
| <code><a href="#cdk8s-metaflow.k8s.EventProps.property.reportingController">reportingController</a></code> | <code>string</code> | reportingController is the name of the controller that emitted this Event, e.g. `kubernetes.io/kubelet`. This field cannot be empty for new Events. |
| <code><a href="#cdk8s-metaflow.k8s.EventProps.property.reportingInstance">reportingInstance</a></code> | <code>string</code> | reportingInstance is the ID of the controller instance, e.g. `kubelet-xyzf`. This field cannot be empty for new Events and it can have at most 128 characters. |
| <code><a href="#cdk8s-metaflow.k8s.EventProps.property.series">series</a></code> | <code>cdk8s-metaflow.k8s.EventSeries</code> | series is data about the Event series this event represents or nil if it's a singleton Event. |
| <code><a href="#cdk8s-metaflow.k8s.EventProps.property.type">type</a></code> | <code>string</code> | type is the type of this event (Normal, Warning), new types could be added in the future. |

---

##### `eventTime`<sup>Required</sup> <a name="eventTime" id="cdk8s-metaflow.k8s.EventProps.property.eventTime"></a>

```typescript
public readonly eventTime: Date;
```

- *Type:* Date

eventTime is the time when this Event was first observed.

It is required.

---

##### `action`<sup>Optional</sup> <a name="action" id="cdk8s-metaflow.k8s.EventProps.property.action"></a>

```typescript
public readonly action: string;
```

- *Type:* string

action is what action was taken/failed regarding to the regarding object.

It is machine-readable. This field cannot be empty for new Events and it can have at most 128 characters.

---

##### `deprecatedCount`<sup>Optional</sup> <a name="deprecatedCount" id="cdk8s-metaflow.k8s.EventProps.property.deprecatedCount"></a>

```typescript
public readonly deprecatedCount: number;
```

- *Type:* number

deprecatedCount is the deprecated field assuring backward compatibility with core.v1 Event type.

---

##### `deprecatedFirstTimestamp`<sup>Optional</sup> <a name="deprecatedFirstTimestamp" id="cdk8s-metaflow.k8s.EventProps.property.deprecatedFirstTimestamp"></a>

```typescript
public readonly deprecatedFirstTimestamp: Date;
```

- *Type:* Date

deprecatedFirstTimestamp is the deprecated field assuring backward compatibility with core.v1 Event type.

---

##### `deprecatedLastTimestamp`<sup>Optional</sup> <a name="deprecatedLastTimestamp" id="cdk8s-metaflow.k8s.EventProps.property.deprecatedLastTimestamp"></a>

```typescript
public readonly deprecatedLastTimestamp: Date;
```

- *Type:* Date

deprecatedLastTimestamp is the deprecated field assuring backward compatibility with core.v1 Event type.

---

##### `deprecatedSource`<sup>Optional</sup> <a name="deprecatedSource" id="cdk8s-metaflow.k8s.EventProps.property.deprecatedSource"></a>

```typescript
public readonly deprecatedSource: EventSource;
```

- *Type:* cdk8s-metaflow.k8s.EventSource

deprecatedSource is the deprecated field assuring backward compatibility with core.v1 Event type.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EventProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `note`<sup>Optional</sup> <a name="note" id="cdk8s-metaflow.k8s.EventProps.property.note"></a>

```typescript
public readonly note: string;
```

- *Type:* string

note is a human-readable description of the status of this operation.

Maximal length of the note is 1kB, but libraries should be prepared to handle values up to 64kB.

---

##### `reason`<sup>Optional</sup> <a name="reason" id="cdk8s-metaflow.k8s.EventProps.property.reason"></a>

```typescript
public readonly reason: string;
```

- *Type:* string

reason is why the action was taken.

It is human-readable. This field cannot be empty for new Events and it can have at most 128 characters.

---

##### `regarding`<sup>Optional</sup> <a name="regarding" id="cdk8s-metaflow.k8s.EventProps.property.regarding"></a>

```typescript
public readonly regarding: ObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.ObjectReference

regarding contains the object this Event is about.

In most cases it's an Object reporting controller implements, e.g. ReplicaSetController implements ReplicaSets and this event is emitted because it acts on some changes in a ReplicaSet object.

---

##### `related`<sup>Optional</sup> <a name="related" id="cdk8s-metaflow.k8s.EventProps.property.related"></a>

```typescript
public readonly related: ObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.ObjectReference

related is the optional secondary object for more complex actions.

E.g. when regarding object triggers a creation or deletion of related object.

---

##### `reportingController`<sup>Optional</sup> <a name="reportingController" id="cdk8s-metaflow.k8s.EventProps.property.reportingController"></a>

```typescript
public readonly reportingController: string;
```

- *Type:* string

reportingController is the name of the controller that emitted this Event, e.g. `kubernetes.io/kubelet`. This field cannot be empty for new Events.

---

##### `reportingInstance`<sup>Optional</sup> <a name="reportingInstance" id="cdk8s-metaflow.k8s.EventProps.property.reportingInstance"></a>

```typescript
public readonly reportingInstance: string;
```

- *Type:* string

reportingInstance is the ID of the controller instance, e.g. `kubelet-xyzf`. This field cannot be empty for new Events and it can have at most 128 characters.

---

##### `series`<sup>Optional</sup> <a name="series" id="cdk8s-metaflow.k8s.EventProps.property.series"></a>

```typescript
public readonly series: EventSeries;
```

- *Type:* cdk8s-metaflow.k8s.EventSeries

series is data about the Event series this event represents or nil if it's a singleton Event.

---

##### `type`<sup>Optional</sup> <a name="type" id="cdk8s-metaflow.k8s.EventProps.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

type is the type of this event (Normal, Warning), new types could be added in the future.

It is machine-readable. This field cannot be empty for new Events.

---

### EventSeries <a name="EventSeries" id="cdk8s-metaflow.k8s.EventSeries"></a>

EventSeries contain information on series of events, i.e. thing that was/is happening continuously for some time. How often to update the EventSeries is up to the event reporters. The default event reporter in "k8s.io/client-go/tools/events/event_broadcaster.go" shows how this struct is updated on heartbeats and can guide customized reporter implementations.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EventSeries.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const eventSeries: k8s.EventSeries = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventSeries.property.count">count</a></code> | <code>number</code> | count is the number of occurrences in this series up to the last heartbeat time. |
| <code><a href="#cdk8s-metaflow.k8s.EventSeries.property.lastObservedTime">lastObservedTime</a></code> | <code>Date</code> | lastObservedTime is the time when last Event from the series was seen before last heartbeat. |

---

##### `count`<sup>Required</sup> <a name="count" id="cdk8s-metaflow.k8s.EventSeries.property.count"></a>

```typescript
public readonly count: number;
```

- *Type:* number

count is the number of occurrences in this series up to the last heartbeat time.

---

##### `lastObservedTime`<sup>Required</sup> <a name="lastObservedTime" id="cdk8s-metaflow.k8s.EventSeries.property.lastObservedTime"></a>

```typescript
public readonly lastObservedTime: Date;
```

- *Type:* Date

lastObservedTime is the time when last Event from the series was seen before last heartbeat.

---

### EventSeriesV1Beta1 <a name="EventSeriesV1Beta1" id="cdk8s-metaflow.k8s.EventSeriesV1Beta1"></a>

EventSeries contain information on series of events, i.e. thing that was/is happening continuously for some time.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EventSeriesV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const eventSeriesV1Beta1: k8s.EventSeriesV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventSeriesV1Beta1.property.count">count</a></code> | <code>number</code> | count is the number of occurrences in this series up to the last heartbeat time. |
| <code><a href="#cdk8s-metaflow.k8s.EventSeriesV1Beta1.property.lastObservedTime">lastObservedTime</a></code> | <code>Date</code> | lastObservedTime is the time when last Event from the series was seen before last heartbeat. |

---

##### `count`<sup>Required</sup> <a name="count" id="cdk8s-metaflow.k8s.EventSeriesV1Beta1.property.count"></a>

```typescript
public readonly count: number;
```

- *Type:* number

count is the number of occurrences in this series up to the last heartbeat time.

---

##### `lastObservedTime`<sup>Required</sup> <a name="lastObservedTime" id="cdk8s-metaflow.k8s.EventSeriesV1Beta1.property.lastObservedTime"></a>

```typescript
public readonly lastObservedTime: Date;
```

- *Type:* Date

lastObservedTime is the time when last Event from the series was seen before last heartbeat.

---

### EventSource <a name="EventSource" id="cdk8s-metaflow.k8s.EventSource"></a>

EventSource contains information for an event.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EventSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const eventSource: k8s.EventSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventSource.property.component">component</a></code> | <code>string</code> | Component from which the event is generated. |
| <code><a href="#cdk8s-metaflow.k8s.EventSource.property.host">host</a></code> | <code>string</code> | Node name on which the event is generated. |

---

##### `component`<sup>Optional</sup> <a name="component" id="cdk8s-metaflow.k8s.EventSource.property.component"></a>

```typescript
public readonly component: string;
```

- *Type:* string

Component from which the event is generated.

---

##### `host`<sup>Optional</sup> <a name="host" id="cdk8s-metaflow.k8s.EventSource.property.host"></a>

```typescript
public readonly host: string;
```

- *Type:* string

Node name on which the event is generated.

---

### EventV1Beta1Props <a name="EventV1Beta1Props" id="cdk8s-metaflow.k8s.EventV1Beta1Props"></a>

Event is a report of an event somewhere in the cluster.

It generally denotes some state change in the system. Events have a limited retention time and triggers and messages may evolve with time.  Event consumers should not rely on the timing of an event with a given Reason reflecting a consistent underlying trigger, or the continued existence of events with that Reason.  Events should be treated as informative, best-effort, supplemental data.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EventV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const eventV1Beta1Props: k8s.EventV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1Props.property.eventTime">eventTime</a></code> | <code>Date</code> | eventTime is the time when this Event was first observed. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1Props.property.action">action</a></code> | <code>string</code> | action is what action was taken/failed regarding to the regarding object. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1Props.property.deprecatedCount">deprecatedCount</a></code> | <code>number</code> | deprecatedCount is the deprecated field assuring backward compatibility with core.v1 Event type. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1Props.property.deprecatedFirstTimestamp">deprecatedFirstTimestamp</a></code> | <code>Date</code> | deprecatedFirstTimestamp is the deprecated field assuring backward compatibility with core.v1 Event type. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1Props.property.deprecatedLastTimestamp">deprecatedLastTimestamp</a></code> | <code>Date</code> | deprecatedLastTimestamp is the deprecated field assuring backward compatibility with core.v1 Event type. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1Props.property.deprecatedSource">deprecatedSource</a></code> | <code>cdk8s-metaflow.k8s.EventSource</code> | deprecatedSource is the deprecated field assuring backward compatibility with core.v1 Event type. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1Props.property.note">note</a></code> | <code>string</code> | note is a human-readable description of the status of this operation. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1Props.property.reason">reason</a></code> | <code>string</code> | reason is why the action was taken. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1Props.property.regarding">regarding</a></code> | <code>cdk8s-metaflow.k8s.ObjectReference</code> | regarding contains the object this Event is about. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1Props.property.related">related</a></code> | <code>cdk8s-metaflow.k8s.ObjectReference</code> | related is the optional secondary object for more complex actions. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1Props.property.reportingController">reportingController</a></code> | <code>string</code> | reportingController is the name of the controller that emitted this Event, e.g. `kubernetes.io/kubelet`. This field cannot be empty for new Events. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1Props.property.reportingInstance">reportingInstance</a></code> | <code>string</code> | reportingInstance is the ID of the controller instance, e.g. `kubelet-xyzf`. This field cannot be empty for new Events and it can have at most 128 characters. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1Props.property.series">series</a></code> | <code>cdk8s-metaflow.k8s.EventSeriesV1Beta1</code> | series is data about the Event series this event represents or nil if it's a singleton Event. |
| <code><a href="#cdk8s-metaflow.k8s.EventV1Beta1Props.property.type">type</a></code> | <code>string</code> | type is the type of this event (Normal, Warning), new types could be added in the future. |

---

##### `eventTime`<sup>Required</sup> <a name="eventTime" id="cdk8s-metaflow.k8s.EventV1Beta1Props.property.eventTime"></a>

```typescript
public readonly eventTime: Date;
```

- *Type:* Date

eventTime is the time when this Event was first observed.

It is required.

---

##### `action`<sup>Optional</sup> <a name="action" id="cdk8s-metaflow.k8s.EventV1Beta1Props.property.action"></a>

```typescript
public readonly action: string;
```

- *Type:* string

action is what action was taken/failed regarding to the regarding object.

It is machine-readable. This field can have at most 128 characters.

---

##### `deprecatedCount`<sup>Optional</sup> <a name="deprecatedCount" id="cdk8s-metaflow.k8s.EventV1Beta1Props.property.deprecatedCount"></a>

```typescript
public readonly deprecatedCount: number;
```

- *Type:* number

deprecatedCount is the deprecated field assuring backward compatibility with core.v1 Event type.

---

##### `deprecatedFirstTimestamp`<sup>Optional</sup> <a name="deprecatedFirstTimestamp" id="cdk8s-metaflow.k8s.EventV1Beta1Props.property.deprecatedFirstTimestamp"></a>

```typescript
public readonly deprecatedFirstTimestamp: Date;
```

- *Type:* Date

deprecatedFirstTimestamp is the deprecated field assuring backward compatibility with core.v1 Event type.

---

##### `deprecatedLastTimestamp`<sup>Optional</sup> <a name="deprecatedLastTimestamp" id="cdk8s-metaflow.k8s.EventV1Beta1Props.property.deprecatedLastTimestamp"></a>

```typescript
public readonly deprecatedLastTimestamp: Date;
```

- *Type:* Date

deprecatedLastTimestamp is the deprecated field assuring backward compatibility with core.v1 Event type.

---

##### `deprecatedSource`<sup>Optional</sup> <a name="deprecatedSource" id="cdk8s-metaflow.k8s.EventV1Beta1Props.property.deprecatedSource"></a>

```typescript
public readonly deprecatedSource: EventSource;
```

- *Type:* cdk8s-metaflow.k8s.EventSource

deprecatedSource is the deprecated field assuring backward compatibility with core.v1 Event type.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EventV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `note`<sup>Optional</sup> <a name="note" id="cdk8s-metaflow.k8s.EventV1Beta1Props.property.note"></a>

```typescript
public readonly note: string;
```

- *Type:* string

note is a human-readable description of the status of this operation.

Maximal length of the note is 1kB, but libraries should be prepared to handle values up to 64kB.

---

##### `reason`<sup>Optional</sup> <a name="reason" id="cdk8s-metaflow.k8s.EventV1Beta1Props.property.reason"></a>

```typescript
public readonly reason: string;
```

- *Type:* string

reason is why the action was taken.

It is human-readable. This field can have at most 128 characters.

---

##### `regarding`<sup>Optional</sup> <a name="regarding" id="cdk8s-metaflow.k8s.EventV1Beta1Props.property.regarding"></a>

```typescript
public readonly regarding: ObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.ObjectReference

regarding contains the object this Event is about.

In most cases it's an Object reporting controller implements, e.g. ReplicaSetController implements ReplicaSets and this event is emitted because it acts on some changes in a ReplicaSet object.

---

##### `related`<sup>Optional</sup> <a name="related" id="cdk8s-metaflow.k8s.EventV1Beta1Props.property.related"></a>

```typescript
public readonly related: ObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.ObjectReference

related is the optional secondary object for more complex actions.

E.g. when regarding object triggers a creation or deletion of related object.

---

##### `reportingController`<sup>Optional</sup> <a name="reportingController" id="cdk8s-metaflow.k8s.EventV1Beta1Props.property.reportingController"></a>

```typescript
public readonly reportingController: string;
```

- *Type:* string

reportingController is the name of the controller that emitted this Event, e.g. `kubernetes.io/kubelet`. This field cannot be empty for new Events.

---

##### `reportingInstance`<sup>Optional</sup> <a name="reportingInstance" id="cdk8s-metaflow.k8s.EventV1Beta1Props.property.reportingInstance"></a>

```typescript
public readonly reportingInstance: string;
```

- *Type:* string

reportingInstance is the ID of the controller instance, e.g. `kubelet-xyzf`. This field cannot be empty for new Events and it can have at most 128 characters.

---

##### `series`<sup>Optional</sup> <a name="series" id="cdk8s-metaflow.k8s.EventV1Beta1Props.property.series"></a>

```typescript
public readonly series: EventSeriesV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.EventSeriesV1Beta1

series is data about the Event series this event represents or nil if it's a singleton Event.

---

##### `type`<sup>Optional</sup> <a name="type" id="cdk8s-metaflow.k8s.EventV1Beta1Props.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

type is the type of this event (Normal, Warning), new types could be added in the future.

It is machine-readable.

---

### EvictionProps <a name="EvictionProps" id="cdk8s-metaflow.k8s.EvictionProps"></a>

Eviction evicts a pod from its node subject to certain policies and safety constraints.

This is a subresource of Pod.  A request to cause such an eviction is created by POSTing to .../pods/<pod name>/evictions.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.EvictionProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const evictionProps: k8s.EvictionProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.EvictionProps.property.deleteOptions">deleteOptions</a></code> | <code>cdk8s-metaflow.k8s.DeleteOptions</code> | DeleteOptions may be provided. |
| <code><a href="#cdk8s-metaflow.k8s.EvictionProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | ObjectMeta describes the pod that is being evicted. |

---

##### `deleteOptions`<sup>Optional</sup> <a name="deleteOptions" id="cdk8s-metaflow.k8s.EvictionProps.property.deleteOptions"></a>

```typescript
public readonly deleteOptions: DeleteOptions;
```

- *Type:* cdk8s-metaflow.k8s.DeleteOptions

DeleteOptions may be provided.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.EvictionProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

ObjectMeta describes the pod that is being evicted.

---

### ExecAction <a name="ExecAction" id="cdk8s-metaflow.k8s.ExecAction"></a>

ExecAction describes a "run in container" action.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ExecAction.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const execAction: k8s.ExecAction = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ExecAction.property.command">command</a></code> | <code>string[]</code> | Command is the command line to execute inside the container, the working directory for the command  is root ('/') in the container's filesystem. |

---

##### `command`<sup>Optional</sup> <a name="command" id="cdk8s-metaflow.k8s.ExecAction.property.command"></a>

```typescript
public readonly command: string[];
```

- *Type:* string[]

Command is the command line to execute inside the container, the working directory for the command  is root ('/') in the container's filesystem.

The command is simply exec'd, it is not run inside a shell, so traditional shell instructions ('|', etc) won't work. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.

---

### ExternalDocumentation <a name="ExternalDocumentation" id="cdk8s-metaflow.k8s.ExternalDocumentation"></a>

ExternalDocumentation allows referencing an external resource for extended documentation.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ExternalDocumentation.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const externalDocumentation: k8s.ExternalDocumentation = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ExternalDocumentation.property.description">description</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.ExternalDocumentation.property.url">url</a></code> | <code>string</code> | *No description.* |

---

##### `description`<sup>Optional</sup> <a name="description" id="cdk8s-metaflow.k8s.ExternalDocumentation.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* string

---

##### `url`<sup>Optional</sup> <a name="url" id="cdk8s-metaflow.k8s.ExternalDocumentation.property.url"></a>

```typescript
public readonly url: string;
```

- *Type:* string

---

### ExternalMetricSourceV2Beta1 <a name="ExternalMetricSourceV2Beta1" id="cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta1"></a>

ExternalMetricSource indicates how to scale on a metric not associated with any Kubernetes object (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).

Exactly one "target" type should be set.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const externalMetricSourceV2Beta1: k8s.ExternalMetricSourceV2Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta1.property.metricName">metricName</a></code> | <code>string</code> | metricName is the name of the metric in question. |
| <code><a href="#cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta1.property.metricSelector">metricSelector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | metricSelector is used to identify a specific time series within a given metric. |
| <code><a href="#cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta1.property.targetAverageValue">targetAverageValue</a></code> | <code>cdk8s-metaflow.k8s.Quantity</code> | targetAverageValue is the target per-pod value of global metric (as a quantity). |
| <code><a href="#cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta1.property.targetValue">targetValue</a></code> | <code>cdk8s-metaflow.k8s.Quantity</code> | targetValue is the target value of the metric (as a quantity). |

---

##### `metricName`<sup>Required</sup> <a name="metricName" id="cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta1.property.metricName"></a>

```typescript
public readonly metricName: string;
```

- *Type:* string

metricName is the name of the metric in question.

---

##### `metricSelector`<sup>Optional</sup> <a name="metricSelector" id="cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta1.property.metricSelector"></a>

```typescript
public readonly metricSelector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

metricSelector is used to identify a specific time series within a given metric.

---

##### `targetAverageValue`<sup>Optional</sup> <a name="targetAverageValue" id="cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta1.property.targetAverageValue"></a>

```typescript
public readonly targetAverageValue: Quantity;
```

- *Type:* cdk8s-metaflow.k8s.Quantity

targetAverageValue is the target per-pod value of global metric (as a quantity).

Mutually exclusive with TargetValue.

---

##### `targetValue`<sup>Optional</sup> <a name="targetValue" id="cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta1.property.targetValue"></a>

```typescript
public readonly targetValue: Quantity;
```

- *Type:* cdk8s-metaflow.k8s.Quantity

targetValue is the target value of the metric (as a quantity).

Mutually exclusive with TargetAverageValue.

---

### ExternalMetricSourceV2Beta2 <a name="ExternalMetricSourceV2Beta2" id="cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta2"></a>

ExternalMetricSource indicates how to scale on a metric not associated with any Kubernetes object (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta2.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const externalMetricSourceV2Beta2: k8s.ExternalMetricSourceV2Beta2 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta2.property.metric">metric</a></code> | <code>cdk8s-metaflow.k8s.MetricIdentifierV2Beta2</code> | metric identifies the target metric by name and selector. |
| <code><a href="#cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta2.property.target">target</a></code> | <code>cdk8s-metaflow.k8s.MetricTargetV2Beta2</code> | target specifies the target value for the given metric. |

---

##### `metric`<sup>Required</sup> <a name="metric" id="cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta2.property.metric"></a>

```typescript
public readonly metric: MetricIdentifierV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.MetricIdentifierV2Beta2

metric identifies the target metric by name and selector.

---

##### `target`<sup>Required</sup> <a name="target" id="cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta2.property.target"></a>

```typescript
public readonly target: MetricTargetV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.MetricTargetV2Beta2

target specifies the target value for the given metric.

---

### FcVolumeSource <a name="FcVolumeSource" id="cdk8s-metaflow.k8s.FcVolumeSource"></a>

Represents a Fibre Channel volume.

Fibre Channel volumes can only be mounted as read/write once. Fibre Channel volumes support ownership management and SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.FcVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const fcVolumeSource: k8s.FcVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FcVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type to mount. |
| <code><a href="#cdk8s-metaflow.k8s.FcVolumeSource.property.lun">lun</a></code> | <code>number</code> | Optional: FC target lun number. |
| <code><a href="#cdk8s-metaflow.k8s.FcVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Optional: Defaults to false (read/write). |
| <code><a href="#cdk8s-metaflow.k8s.FcVolumeSource.property.targetWwNs">targetWwNs</a></code> | <code>string[]</code> | Optional: FC target worldwide names (WWNs). |
| <code><a href="#cdk8s-metaflow.k8s.FcVolumeSource.property.wwids">wwids</a></code> | <code>string[]</code> | Optional: FC volume world wide identifiers (wwids) Either wwids or combination of targetWWNs and lun must be set, but not both simultaneously. |

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.FcVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type to mount.

Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.

---

##### `lun`<sup>Optional</sup> <a name="lun" id="cdk8s-metaflow.k8s.FcVolumeSource.property.lun"></a>

```typescript
public readonly lun: number;
```

- *Type:* number

Optional: FC target lun number.

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.FcVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.

Optional: Defaults to false (read/write).

ReadOnly here will force the ReadOnly setting in VolumeMounts.

---

##### `targetWwNs`<sup>Optional</sup> <a name="targetWwNs" id="cdk8s-metaflow.k8s.FcVolumeSource.property.targetWwNs"></a>

```typescript
public readonly targetWwNs: string[];
```

- *Type:* string[]

Optional: FC target worldwide names (WWNs).

---

##### `wwids`<sup>Optional</sup> <a name="wwids" id="cdk8s-metaflow.k8s.FcVolumeSource.property.wwids"></a>

```typescript
public readonly wwids: string[];
```

- *Type:* string[]

Optional: FC volume world wide identifiers (wwids) Either wwids or combination of targetWWNs and lun must be set, but not both simultaneously.

---

### FlexPersistentVolumeSource <a name="FlexPersistentVolumeSource" id="cdk8s-metaflow.k8s.FlexPersistentVolumeSource"></a>

FlexPersistentVolumeSource represents a generic persistent volume resource that is provisioned/attached using an exec based plugin.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.FlexPersistentVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const flexPersistentVolumeSource: k8s.FlexPersistentVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FlexPersistentVolumeSource.property.driver">driver</a></code> | <code>string</code> | Driver is the name of the driver to use for this volume. |
| <code><a href="#cdk8s-metaflow.k8s.FlexPersistentVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type to mount. |
| <code><a href="#cdk8s-metaflow.k8s.FlexPersistentVolumeSource.property.options">options</a></code> | <code>{[ key: string ]: string}</code> | Optional: Extra command options if any. |
| <code><a href="#cdk8s-metaflow.k8s.FlexPersistentVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Optional: Defaults to false (read/write). |
| <code><a href="#cdk8s-metaflow.k8s.FlexPersistentVolumeSource.property.secretRef">secretRef</a></code> | <code>cdk8s-metaflow.k8s.SecretReference</code> | Optional: SecretRef is reference to the secret object containing sensitive information to pass to the plugin scripts. |

---

##### `driver`<sup>Required</sup> <a name="driver" id="cdk8s-metaflow.k8s.FlexPersistentVolumeSource.property.driver"></a>

```typescript
public readonly driver: string;
```

- *Type:* string

Driver is the name of the driver to use for this volume.

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.FlexPersistentVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type to mount.

Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script.

---

##### `options`<sup>Optional</sup> <a name="options" id="cdk8s-metaflow.k8s.FlexPersistentVolumeSource.property.options"></a>

```typescript
public readonly options: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

Optional: Extra command options if any.

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.FlexPersistentVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.

Optional: Defaults to false (read/write).

ReadOnly here will force the ReadOnly setting in VolumeMounts.

---

##### `secretRef`<sup>Optional</sup> <a name="secretRef" id="cdk8s-metaflow.k8s.FlexPersistentVolumeSource.property.secretRef"></a>

```typescript
public readonly secretRef: SecretReference;
```

- *Type:* cdk8s-metaflow.k8s.SecretReference

Optional: SecretRef is reference to the secret object containing sensitive information to pass to the plugin scripts.

This may be empty if no secret object is specified. If the secret object contains more than one secret, all secrets are passed to the plugin scripts.

---

### FlexVolumeSource <a name="FlexVolumeSource" id="cdk8s-metaflow.k8s.FlexVolumeSource"></a>

FlexVolume represents a generic volume resource that is provisioned/attached using an exec based plugin.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.FlexVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const flexVolumeSource: k8s.FlexVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FlexVolumeSource.property.driver">driver</a></code> | <code>string</code> | Driver is the name of the driver to use for this volume. |
| <code><a href="#cdk8s-metaflow.k8s.FlexVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type to mount. |
| <code><a href="#cdk8s-metaflow.k8s.FlexVolumeSource.property.options">options</a></code> | <code>{[ key: string ]: string}</code> | Optional: Extra command options if any. |
| <code><a href="#cdk8s-metaflow.k8s.FlexVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Optional: Defaults to false (read/write). |
| <code><a href="#cdk8s-metaflow.k8s.FlexVolumeSource.property.secretRef">secretRef</a></code> | <code>cdk8s-metaflow.k8s.LocalObjectReference</code> | Optional: SecretRef is reference to the secret object containing sensitive information to pass to the plugin scripts. |

---

##### `driver`<sup>Required</sup> <a name="driver" id="cdk8s-metaflow.k8s.FlexVolumeSource.property.driver"></a>

```typescript
public readonly driver: string;
```

- *Type:* string

Driver is the name of the driver to use for this volume.

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.FlexVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type to mount.

Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script.

---

##### `options`<sup>Optional</sup> <a name="options" id="cdk8s-metaflow.k8s.FlexVolumeSource.property.options"></a>

```typescript
public readonly options: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

Optional: Extra command options if any.

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.FlexVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.

Optional: Defaults to false (read/write).

ReadOnly here will force the ReadOnly setting in VolumeMounts.

---

##### `secretRef`<sup>Optional</sup> <a name="secretRef" id="cdk8s-metaflow.k8s.FlexVolumeSource.property.secretRef"></a>

```typescript
public readonly secretRef: LocalObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.LocalObjectReference

Optional: SecretRef is reference to the secret object containing sensitive information to pass to the plugin scripts.

This may be empty if no secret object is specified. If the secret object contains more than one secret, all secrets are passed to the plugin scripts.

---

### FlockerVolumeSource <a name="FlockerVolumeSource" id="cdk8s-metaflow.k8s.FlockerVolumeSource"></a>

Represents a Flocker volume mounted by the Flocker agent.

One and only one of datasetName and datasetUUID should be set. Flocker volumes do not support ownership management or SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.FlockerVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const flockerVolumeSource: k8s.FlockerVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FlockerVolumeSource.property.datasetName">datasetName</a></code> | <code>string</code> | Name of the dataset stored as metadata -> name on the dataset for Flocker should be considered as deprecated. |
| <code><a href="#cdk8s-metaflow.k8s.FlockerVolumeSource.property.datasetUuid">datasetUuid</a></code> | <code>string</code> | UUID of the dataset. |

---

##### `datasetName`<sup>Optional</sup> <a name="datasetName" id="cdk8s-metaflow.k8s.FlockerVolumeSource.property.datasetName"></a>

```typescript
public readonly datasetName: string;
```

- *Type:* string

Name of the dataset stored as metadata -> name on the dataset for Flocker should be considered as deprecated.

---

##### `datasetUuid`<sup>Optional</sup> <a name="datasetUuid" id="cdk8s-metaflow.k8s.FlockerVolumeSource.property.datasetUuid"></a>

```typescript
public readonly datasetUuid: string;
```

- *Type:* string

UUID of the dataset.

This is unique identifier of a Flocker dataset

---

### FlowDistinguisherMethodV1Beta1 <a name="FlowDistinguisherMethodV1Beta1" id="cdk8s-metaflow.k8s.FlowDistinguisherMethodV1Beta1"></a>

FlowDistinguisherMethod specifies the method of a flow distinguisher.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.FlowDistinguisherMethodV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const flowDistinguisherMethodV1Beta1: k8s.FlowDistinguisherMethodV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FlowDistinguisherMethodV1Beta1.property.type">type</a></code> | <code>string</code> | `type` is the type of flow distinguisher method The supported types are "ByUser" and "ByNamespace". |

---

##### `type`<sup>Required</sup> <a name="type" id="cdk8s-metaflow.k8s.FlowDistinguisherMethodV1Beta1.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

`type` is the type of flow distinguisher method The supported types are "ByUser" and "ByNamespace".

Required.

---

### FlowSchemaListV1Beta1Props <a name="FlowSchemaListV1Beta1Props" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1Props"></a>

FlowSchemaList is a list of FlowSchema objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const flowSchemaListV1Beta1Props: k8s.FlowSchemaListV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.FlowSchemaV1Beta1[]</code> | `items` is a list of FlowSchemas. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaListV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | `metadata` is the standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1Props.property.items"></a>

```typescript
public readonly items: FlowSchemaV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.FlowSchemaV1Beta1[]

`items` is a list of FlowSchemas.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.FlowSchemaListV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

`metadata` is the standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### FlowSchemaSpecV1Beta1 <a name="FlowSchemaSpecV1Beta1" id="cdk8s-metaflow.k8s.FlowSchemaSpecV1Beta1"></a>

FlowSchemaSpec describes how the FlowSchema's specification looks like.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.FlowSchemaSpecV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const flowSchemaSpecV1Beta1: k8s.FlowSchemaSpecV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaSpecV1Beta1.property.priorityLevelConfiguration">priorityLevelConfiguration</a></code> | <code>cdk8s-metaflow.k8s.PriorityLevelConfigurationReferenceV1Beta1</code> | `priorityLevelConfiguration` should reference a PriorityLevelConfiguration in the cluster. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaSpecV1Beta1.property.distinguisherMethod">distinguisherMethod</a></code> | <code>cdk8s-metaflow.k8s.FlowDistinguisherMethodV1Beta1</code> | `distinguisherMethod` defines how to compute the flow distinguisher for requests that match this schema. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaSpecV1Beta1.property.matchingPrecedence">matchingPrecedence</a></code> | <code>number</code> | `matchingPrecedence` is used to choose among the FlowSchemas that match a given request. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaSpecV1Beta1.property.rules">rules</a></code> | <code>cdk8s-metaflow.k8s.PolicyRulesWithSubjectsV1Beta1[]</code> | `rules` describes which requests will match this flow schema. |

---

##### `priorityLevelConfiguration`<sup>Required</sup> <a name="priorityLevelConfiguration" id="cdk8s-metaflow.k8s.FlowSchemaSpecV1Beta1.property.priorityLevelConfiguration"></a>

```typescript
public readonly priorityLevelConfiguration: PriorityLevelConfigurationReferenceV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.PriorityLevelConfigurationReferenceV1Beta1

`priorityLevelConfiguration` should reference a PriorityLevelConfiguration in the cluster.

If the reference cannot be resolved, the FlowSchema will be ignored and marked as invalid in its status. Required.

---

##### `distinguisherMethod`<sup>Optional</sup> <a name="distinguisherMethod" id="cdk8s-metaflow.k8s.FlowSchemaSpecV1Beta1.property.distinguisherMethod"></a>

```typescript
public readonly distinguisherMethod: FlowDistinguisherMethodV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.FlowDistinguisherMethodV1Beta1

`distinguisherMethod` defines how to compute the flow distinguisher for requests that match this schema.

`nil` specifies that the distinguisher is disabled and thus will always be the empty string.

---

##### `matchingPrecedence`<sup>Optional</sup> <a name="matchingPrecedence" id="cdk8s-metaflow.k8s.FlowSchemaSpecV1Beta1.property.matchingPrecedence"></a>

```typescript
public readonly matchingPrecedence: number;
```

- *Type:* number

`matchingPrecedence` is used to choose among the FlowSchemas that match a given request.

The chosen FlowSchema is among those with the numerically lowest (which we take to be logically highest) MatchingPrecedence.  Each MatchingPrecedence value must be ranged in [1,10000]. Note that if the precedence is not specified, it will be set to 1000 as default.

---

##### `rules`<sup>Optional</sup> <a name="rules" id="cdk8s-metaflow.k8s.FlowSchemaSpecV1Beta1.property.rules"></a>

```typescript
public readonly rules: PolicyRulesWithSubjectsV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.PolicyRulesWithSubjectsV1Beta1[]

`rules` describes which requests will match this flow schema.

This FlowSchema matches a request if and only if at least one member of rules matches the request. if it is an empty slice, there will be no requests matching the FlowSchema.

---

### FlowSchemaV1Beta1Props <a name="FlowSchemaV1Beta1Props" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1Props"></a>

FlowSchema defines the schema of a group of flows.

Note that a flow is made up of a set of inbound API requests with similar attributes and is identified by a pair of strings: the name of the FlowSchema and a "flow distinguisher".

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const flowSchemaV1Beta1Props: k8s.FlowSchemaV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | `metadata` is the standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.FlowSchemaV1Beta1Props.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.FlowSchemaSpecV1Beta1</code> | `spec` is the specification of the desired behavior of a FlowSchema. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

`metadata` is the standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.FlowSchemaV1Beta1Props.property.spec"></a>

```typescript
public readonly spec: FlowSchemaSpecV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.FlowSchemaSpecV1Beta1

`spec` is the specification of the desired behavior of a FlowSchema.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### ForZone <a name="ForZone" id="cdk8s-metaflow.k8s.ForZone"></a>

ForZone provides information about which zones should consume this endpoint.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ForZone.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const forZone: k8s.ForZone = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ForZone.property.name">name</a></code> | <code>string</code> | name represents the name of the zone. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ForZone.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

name represents the name of the zone.

---

### ForZoneV1Beta1 <a name="ForZoneV1Beta1" id="cdk8s-metaflow.k8s.ForZoneV1Beta1"></a>

ForZone provides information about which zones should consume this endpoint.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ForZoneV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const forZoneV1Beta1: k8s.ForZoneV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ForZoneV1Beta1.property.name">name</a></code> | <code>string</code> | name represents the name of the zone. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ForZoneV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

name represents the name of the zone.

---

### FsGroupStrategyOptionsV1Beta1 <a name="FsGroupStrategyOptionsV1Beta1" id="cdk8s-metaflow.k8s.FsGroupStrategyOptionsV1Beta1"></a>

FSGroupStrategyOptions defines the strategy type and options used to create the strategy.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.FsGroupStrategyOptionsV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const fsGroupStrategyOptionsV1Beta1: k8s.FsGroupStrategyOptionsV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.FsGroupStrategyOptionsV1Beta1.property.ranges">ranges</a></code> | <code>cdk8s-metaflow.k8s.IdRangeV1Beta1[]</code> | ranges are the allowed ranges of fs groups. |
| <code><a href="#cdk8s-metaflow.k8s.FsGroupStrategyOptionsV1Beta1.property.rule">rule</a></code> | <code>string</code> | rule is the strategy that will dictate what FSGroup is used in the SecurityContext. |

---

##### `ranges`<sup>Optional</sup> <a name="ranges" id="cdk8s-metaflow.k8s.FsGroupStrategyOptionsV1Beta1.property.ranges"></a>

```typescript
public readonly ranges: IdRangeV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.IdRangeV1Beta1[]

ranges are the allowed ranges of fs groups.

If you would like to force a single fs group then supply a single range with the same start and end. Required for MustRunAs.

---

##### `rule`<sup>Optional</sup> <a name="rule" id="cdk8s-metaflow.k8s.FsGroupStrategyOptionsV1Beta1.property.rule"></a>

```typescript
public readonly rule: string;
```

- *Type:* string

rule is the strategy that will dictate what FSGroup is used in the SecurityContext.

---

### GcePersistentDiskVolumeSource <a name="GcePersistentDiskVolumeSource" id="cdk8s-metaflow.k8s.GcePersistentDiskVolumeSource"></a>

Represents a Persistent Disk resource in Google Compute Engine.

A GCE PD must exist before mounting to a container. The disk must also be in the same GCE project and zone as the kubelet. A GCE PD can only be mounted as read/write once or read-only many times. GCE PDs support ownership management and SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.GcePersistentDiskVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const gcePersistentDiskVolumeSource: k8s.GcePersistentDiskVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.GcePersistentDiskVolumeSource.property.pdName">pdName</a></code> | <code>string</code> | Unique name of the PD resource in GCE. |
| <code><a href="#cdk8s-metaflow.k8s.GcePersistentDiskVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type of the volume that you want to mount. |
| <code><a href="#cdk8s-metaflow.k8s.GcePersistentDiskVolumeSource.property.partition">partition</a></code> | <code>number</code> | The partition in the volume that you want to mount. |
| <code><a href="#cdk8s-metaflow.k8s.GcePersistentDiskVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | ReadOnly here will force the ReadOnly setting in VolumeMounts. |

---

##### `pdName`<sup>Required</sup> <a name="pdName" id="cdk8s-metaflow.k8s.GcePersistentDiskVolumeSource.property.pdName"></a>

```typescript
public readonly pdName: string;
```

- *Type:* string

Unique name of the PD resource in GCE.

Used to identify the disk in GCE. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.GcePersistentDiskVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type of the volume that you want to mount.

Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk

---

##### `partition`<sup>Optional</sup> <a name="partition" id="cdk8s-metaflow.k8s.GcePersistentDiskVolumeSource.property.partition"></a>

```typescript
public readonly partition: number;
```

- *Type:* number

The partition in the volume that you want to mount.

If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty). More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.GcePersistentDiskVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk

ReadOnly here will force the ReadOnly setting in VolumeMounts.

Defaults to false. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk

---

### GitRepoVolumeSource <a name="GitRepoVolumeSource" id="cdk8s-metaflow.k8s.GitRepoVolumeSource"></a>

Represents a volume that is populated with the contents of a git repository.

Git repo volumes do not support ownership management. Git repo volumes support SELinux relabeling.

DEPRECATED: GitRepo is deprecated. To provision a container with a git repo, mount an EmptyDir into an InitContainer that clones the repo using git, then mount the EmptyDir into the Pod's container.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.GitRepoVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const gitRepoVolumeSource: k8s.GitRepoVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.GitRepoVolumeSource.property.repository">repository</a></code> | <code>string</code> | Repository URL. |
| <code><a href="#cdk8s-metaflow.k8s.GitRepoVolumeSource.property.directory">directory</a></code> | <code>string</code> | Target directory name. |
| <code><a href="#cdk8s-metaflow.k8s.GitRepoVolumeSource.property.revision">revision</a></code> | <code>string</code> | Commit hash for the specified revision. |

---

##### `repository`<sup>Required</sup> <a name="repository" id="cdk8s-metaflow.k8s.GitRepoVolumeSource.property.repository"></a>

```typescript
public readonly repository: string;
```

- *Type:* string

Repository URL.

---

##### `directory`<sup>Optional</sup> <a name="directory" id="cdk8s-metaflow.k8s.GitRepoVolumeSource.property.directory"></a>

```typescript
public readonly directory: string;
```

- *Type:* string

Target directory name.

Must not contain or start with '..'.  If '.' is supplied, the volume directory will be the git repository.  Otherwise, if specified, the volume will contain the git repository in the subdirectory with the given name.

---

##### `revision`<sup>Optional</sup> <a name="revision" id="cdk8s-metaflow.k8s.GitRepoVolumeSource.property.revision"></a>

```typescript
public readonly revision: string;
```

- *Type:* string

Commit hash for the specified revision.

---

### GlusterfsPersistentVolumeSource <a name="GlusterfsPersistentVolumeSource" id="cdk8s-metaflow.k8s.GlusterfsPersistentVolumeSource"></a>

Represents a Glusterfs mount that lasts the lifetime of a pod.

Glusterfs volumes do not support ownership management or SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.GlusterfsPersistentVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const glusterfsPersistentVolumeSource: k8s.GlusterfsPersistentVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.GlusterfsPersistentVolumeSource.property.endpoints">endpoints</a></code> | <code>string</code> | EndpointsName is the endpoint name that details Glusterfs topology. |
| <code><a href="#cdk8s-metaflow.k8s.GlusterfsPersistentVolumeSource.property.path">path</a></code> | <code>string</code> | Path is the Glusterfs volume path. |
| <code><a href="#cdk8s-metaflow.k8s.GlusterfsPersistentVolumeSource.property.endpointsNamespace">endpointsNamespace</a></code> | <code>string</code> | EndpointsNamespace is the namespace that contains Glusterfs endpoint. |
| <code><a href="#cdk8s-metaflow.k8s.GlusterfsPersistentVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | ReadOnly here will force the Glusterfs volume to be mounted with read-only permissions. |

---

##### `endpoints`<sup>Required</sup> <a name="endpoints" id="cdk8s-metaflow.k8s.GlusterfsPersistentVolumeSource.property.endpoints"></a>

```typescript
public readonly endpoints: string;
```

- *Type:* string

EndpointsName is the endpoint name that details Glusterfs topology.

More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod

---

##### `path`<sup>Required</sup> <a name="path" id="cdk8s-metaflow.k8s.GlusterfsPersistentVolumeSource.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* string

Path is the Glusterfs volume path.

More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod

---

##### `endpointsNamespace`<sup>Optional</sup> <a name="endpointsNamespace" id="cdk8s-metaflow.k8s.GlusterfsPersistentVolumeSource.property.endpointsNamespace"></a>

```typescript
public readonly endpointsNamespace: string;
```

- *Type:* string

EndpointsNamespace is the namespace that contains Glusterfs endpoint.

If this field is empty, the EndpointNamespace defaults to the same namespace as the bound PVC. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.GlusterfsPersistentVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod

ReadOnly here will force the Glusterfs volume to be mounted with read-only permissions.

Defaults to false. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod

---

### GlusterfsVolumeSource <a name="GlusterfsVolumeSource" id="cdk8s-metaflow.k8s.GlusterfsVolumeSource"></a>

Represents a Glusterfs mount that lasts the lifetime of a pod.

Glusterfs volumes do not support ownership management or SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.GlusterfsVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const glusterfsVolumeSource: k8s.GlusterfsVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.GlusterfsVolumeSource.property.endpoints">endpoints</a></code> | <code>string</code> | EndpointsName is the endpoint name that details Glusterfs topology. |
| <code><a href="#cdk8s-metaflow.k8s.GlusterfsVolumeSource.property.path">path</a></code> | <code>string</code> | Path is the Glusterfs volume path. |
| <code><a href="#cdk8s-metaflow.k8s.GlusterfsVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | ReadOnly here will force the Glusterfs volume to be mounted with read-only permissions. |

---

##### `endpoints`<sup>Required</sup> <a name="endpoints" id="cdk8s-metaflow.k8s.GlusterfsVolumeSource.property.endpoints"></a>

```typescript
public readonly endpoints: string;
```

- *Type:* string

EndpointsName is the endpoint name that details Glusterfs topology.

More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod

---

##### `path`<sup>Required</sup> <a name="path" id="cdk8s-metaflow.k8s.GlusterfsVolumeSource.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* string

Path is the Glusterfs volume path.

More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.GlusterfsVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod

ReadOnly here will force the Glusterfs volume to be mounted with read-only permissions.

Defaults to false. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod

---

### GroupSubjectV1Beta1 <a name="GroupSubjectV1Beta1" id="cdk8s-metaflow.k8s.GroupSubjectV1Beta1"></a>

GroupSubject holds detailed information for group-kind subject.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.GroupSubjectV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const groupSubjectV1Beta1: k8s.GroupSubjectV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.GroupSubjectV1Beta1.property.name">name</a></code> | <code>string</code> | name is the user group that matches, or "*" to match all user groups. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.GroupSubjectV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

name is the user group that matches, or "*" to match all user groups.

See https://github.com/kubernetes/apiserver/blob/master/pkg/authentication/user/user.go for some well-known group names. Required.

---

### Handler <a name="Handler" id="cdk8s-metaflow.k8s.Handler"></a>

Handler defines a specific action that should be taken.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.Handler.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const handler: k8s.Handler = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Handler.property.exec">exec</a></code> | <code>cdk8s-metaflow.k8s.ExecAction</code> | One and only one of the following should be specified. |
| <code><a href="#cdk8s-metaflow.k8s.Handler.property.httpGet">httpGet</a></code> | <code>cdk8s-metaflow.k8s.HttpGetAction</code> | HTTPGet specifies the http request to perform. |
| <code><a href="#cdk8s-metaflow.k8s.Handler.property.tcpSocket">tcpSocket</a></code> | <code>cdk8s-metaflow.k8s.TcpSocketAction</code> | TCPSocket specifies an action involving a TCP port. |

---

##### `exec`<sup>Optional</sup> <a name="exec" id="cdk8s-metaflow.k8s.Handler.property.exec"></a>

```typescript
public readonly exec: ExecAction;
```

- *Type:* cdk8s-metaflow.k8s.ExecAction

One and only one of the following should be specified.

Exec specifies the action to take.

---

##### `httpGet`<sup>Optional</sup> <a name="httpGet" id="cdk8s-metaflow.k8s.Handler.property.httpGet"></a>

```typescript
public readonly httpGet: HttpGetAction;
```

- *Type:* cdk8s-metaflow.k8s.HttpGetAction

HTTPGet specifies the http request to perform.

---

##### `tcpSocket`<sup>Optional</sup> <a name="tcpSocket" id="cdk8s-metaflow.k8s.Handler.property.tcpSocket"></a>

```typescript
public readonly tcpSocket: TcpSocketAction;
```

- *Type:* cdk8s-metaflow.k8s.TcpSocketAction

TCPSocket specifies an action involving a TCP port.

TCP hooks not yet supported

---

### HorizontalPodAutoscalerBehaviorV2Beta2 <a name="HorizontalPodAutoscalerBehaviorV2Beta2" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerBehaviorV2Beta2"></a>

HorizontalPodAutoscalerBehavior configures the scaling behavior of the target in both Up and Down directions (scaleUp and scaleDown fields respectively).

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerBehaviorV2Beta2.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const horizontalPodAutoscalerBehaviorV2Beta2: k8s.HorizontalPodAutoscalerBehaviorV2Beta2 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerBehaviorV2Beta2.property.scaleDown">scaleDown</a></code> | <code>cdk8s-metaflow.k8s.HpaScalingRulesV2Beta2</code> | scaleDown is scaling policy for scaling Down. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerBehaviorV2Beta2.property.scaleUp">scaleUp</a></code> | <code>cdk8s-metaflow.k8s.HpaScalingRulesV2Beta2</code> | scaleUp is scaling policy for scaling Up. |

---

##### `scaleDown`<sup>Optional</sup> <a name="scaleDown" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerBehaviorV2Beta2.property.scaleDown"></a>

```typescript
public readonly scaleDown: HpaScalingRulesV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.HpaScalingRulesV2Beta2

scaleDown is scaling policy for scaling Down.

If not set, the default value is to allow to scale down to minReplicas pods, with a 300 second stabilization window (i.e., the highest recommendation for the last 300sec is used).

---

##### `scaleUp`<sup>Optional</sup> <a name="scaleUp" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerBehaviorV2Beta2.property.scaleUp"></a>

```typescript
public readonly scaleUp: HpaScalingRulesV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.HpaScalingRulesV2Beta2

scaleUp is scaling policy for scaling Up.

If not set, the default value is the higher of:
* increase no more than 4 pods per 60 seconds
* double the number of pods per 60 seconds
No stabilization is used.

---

### HorizontalPodAutoscalerListProps <a name="HorizontalPodAutoscalerListProps" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListProps"></a>

list of horizontal pod autoscaler objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const horizontalPodAutoscalerListProps: k8s.HorizontalPodAutoscalerListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.HorizontalPodAutoscaler[]</code> | list of horizontal pod autoscaler objects. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListProps.property.items"></a>

```typescript
public readonly items: HorizontalPodAutoscaler[];
```

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscaler[]

list of horizontal pod autoscaler objects.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

---

### HorizontalPodAutoscalerListV2Beta1Props <a name="HorizontalPodAutoscalerListV2Beta1Props" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1Props"></a>

HorizontalPodAutoscaler is a list of horizontal pod autoscaler objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const horizontalPodAutoscalerListV2Beta1Props: k8s.HorizontalPodAutoscalerListV2Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1[]</code> | items is the list of horizontal pod autoscaler objects. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | metadata is the standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1Props.property.items"></a>

```typescript
public readonly items: HorizontalPodAutoscalerV2Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1[]

items is the list of horizontal pod autoscaler objects.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

metadata is the standard list metadata.

---

### HorizontalPodAutoscalerListV2Beta2Props <a name="HorizontalPodAutoscalerListV2Beta2Props" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2Props"></a>

HorizontalPodAutoscalerList is a list of horizontal pod autoscaler objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const horizontalPodAutoscalerListV2Beta2Props: k8s.HorizontalPodAutoscalerListV2Beta2Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2[]</code> | items is the list of horizontal pod autoscaler objects. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | metadata is the standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2Props.property.items"></a>

```typescript
public readonly items: HorizontalPodAutoscalerV2Beta2[];
```

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2[]

items is the list of horizontal pod autoscaler objects.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerListV2Beta2Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

metadata is the standard list metadata.

---

### HorizontalPodAutoscalerProps <a name="HorizontalPodAutoscalerProps" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerProps"></a>

configuration of a horizontal pod autoscaler.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const horizontalPodAutoscalerProps: k8s.HorizontalPodAutoscalerProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object metadata. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpec</code> | behaviour of autoscaler. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerProps.property.spec"></a>

```typescript
public readonly spec: HorizontalPodAutoscalerSpec;
```

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpec

behaviour of autoscaler.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status.

---

### HorizontalPodAutoscalerSpec <a name="HorizontalPodAutoscalerSpec" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpec"></a>

specification of a horizontal pod autoscaler.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const horizontalPodAutoscalerSpec: k8s.HorizontalPodAutoscalerSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpec.property.maxReplicas">maxReplicas</a></code> | <code>number</code> | upper limit for the number of pods that can be set by the autoscaler; |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpec.property.scaleTargetRef">scaleTargetRef</a></code> | <code>cdk8s-metaflow.k8s.CrossVersionObjectReference</code> | reference to scaled resource; |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpec.property.minReplicas">minReplicas</a></code> | <code>number</code> | minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpec.property.targetCpuUtilizationPercentage">targetCpuUtilizationPercentage</a></code> | <code>number</code> | target average CPU utilization (represented as a percentage of requested CPU) over all the pods; |

---

##### `maxReplicas`<sup>Required</sup> <a name="maxReplicas" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpec.property.maxReplicas"></a>

```typescript
public readonly maxReplicas: number;
```

- *Type:* number

upper limit for the number of pods that can be set by the autoscaler;

cannot be smaller than MinReplicas.

---

##### `scaleTargetRef`<sup>Required</sup> <a name="scaleTargetRef" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpec.property.scaleTargetRef"></a>

```typescript
public readonly scaleTargetRef: CrossVersionObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.CrossVersionObjectReference

reference to scaled resource;

horizontal pod autoscaler will learn the current resource consumption and will set the desired number of pods by using its Scale subresource.

---

##### `minReplicas`<sup>Optional</sup> <a name="minReplicas" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpec.property.minReplicas"></a>

```typescript
public readonly minReplicas: number;
```

- *Type:* number

minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.

It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available.

---

##### `targetCpuUtilizationPercentage`<sup>Optional</sup> <a name="targetCpuUtilizationPercentage" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpec.property.targetCpuUtilizationPercentage"></a>

```typescript
public readonly targetCpuUtilizationPercentage: number;
```

- *Type:* number

target average CPU utilization (represented as a percentage of requested CPU) over all the pods;

if not specified the default autoscaling policy will be used.

---

### HorizontalPodAutoscalerSpecV2Beta1 <a name="HorizontalPodAutoscalerSpecV2Beta1" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta1"></a>

HorizontalPodAutoscalerSpec describes the desired functionality of the HorizontalPodAutoscaler.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const horizontalPodAutoscalerSpecV2Beta1: k8s.HorizontalPodAutoscalerSpecV2Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta1.property.maxReplicas">maxReplicas</a></code> | <code>number</code> | maxReplicas is the upper limit for the number of replicas to which the autoscaler can scale up. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta1.property.scaleTargetRef">scaleTargetRef</a></code> | <code>cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta1</code> | scaleTargetRef points to the target resource to scale, and is used to the pods for which metrics should be collected, as well as to actually change the replica count. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta1.property.metrics">metrics</a></code> | <code>cdk8s-metaflow.k8s.MetricSpecV2Beta1[]</code> | metrics contains the specifications for which to use to calculate the desired replica count (the maximum replica count across all metrics will be used). |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta1.property.minReplicas">minReplicas</a></code> | <code>number</code> | minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down. |

---

##### `maxReplicas`<sup>Required</sup> <a name="maxReplicas" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta1.property.maxReplicas"></a>

```typescript
public readonly maxReplicas: number;
```

- *Type:* number

maxReplicas is the upper limit for the number of replicas to which the autoscaler can scale up.

It cannot be less that minReplicas.

---

##### `scaleTargetRef`<sup>Required</sup> <a name="scaleTargetRef" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta1.property.scaleTargetRef"></a>

```typescript
public readonly scaleTargetRef: CrossVersionObjectReferenceV2Beta1;
```

- *Type:* cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta1

scaleTargetRef points to the target resource to scale, and is used to the pods for which metrics should be collected, as well as to actually change the replica count.

---

##### `metrics`<sup>Optional</sup> <a name="metrics" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta1.property.metrics"></a>

```typescript
public readonly metrics: MetricSpecV2Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.MetricSpecV2Beta1[]

metrics contains the specifications for which to use to calculate the desired replica count (the maximum replica count across all metrics will be used).

The desired replica count is calculated multiplying the ratio between the target value and the current value by the current number of pods.  Ergo, metrics used must decrease as the pod count is increased, and vice-versa.  See the individual metric source types for more information about how each type of metric must respond.

---

##### `minReplicas`<sup>Optional</sup> <a name="minReplicas" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta1.property.minReplicas"></a>

```typescript
public readonly minReplicas: number;
```

- *Type:* number

minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.

It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available.

---

### HorizontalPodAutoscalerSpecV2Beta2 <a name="HorizontalPodAutoscalerSpecV2Beta2" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta2"></a>

HorizontalPodAutoscalerSpec describes the desired functionality of the HorizontalPodAutoscaler.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta2.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const horizontalPodAutoscalerSpecV2Beta2: k8s.HorizontalPodAutoscalerSpecV2Beta2 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta2.property.maxReplicas">maxReplicas</a></code> | <code>number</code> | maxReplicas is the upper limit for the number of replicas to which the autoscaler can scale up. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta2.property.scaleTargetRef">scaleTargetRef</a></code> | <code>cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta2</code> | scaleTargetRef points to the target resource to scale, and is used to the pods for which metrics should be collected, as well as to actually change the replica count. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta2.property.behavior">behavior</a></code> | <code>cdk8s-metaflow.k8s.HorizontalPodAutoscalerBehaviorV2Beta2</code> | behavior configures the scaling behavior of the target in both Up and Down directions (scaleUp and scaleDown fields respectively). |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta2.property.metrics">metrics</a></code> | <code>cdk8s-metaflow.k8s.MetricSpecV2Beta2[]</code> | metrics contains the specifications for which to use to calculate the desired replica count (the maximum replica count across all metrics will be used). |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta2.property.minReplicas">minReplicas</a></code> | <code>number</code> | minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down. |

---

##### `maxReplicas`<sup>Required</sup> <a name="maxReplicas" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta2.property.maxReplicas"></a>

```typescript
public readonly maxReplicas: number;
```

- *Type:* number

maxReplicas is the upper limit for the number of replicas to which the autoscaler can scale up.

It cannot be less that minReplicas.

---

##### `scaleTargetRef`<sup>Required</sup> <a name="scaleTargetRef" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta2.property.scaleTargetRef"></a>

```typescript
public readonly scaleTargetRef: CrossVersionObjectReferenceV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta2

scaleTargetRef points to the target resource to scale, and is used to the pods for which metrics should be collected, as well as to actually change the replica count.

---

##### `behavior`<sup>Optional</sup> <a name="behavior" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta2.property.behavior"></a>

```typescript
public readonly behavior: HorizontalPodAutoscalerBehaviorV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerBehaviorV2Beta2

behavior configures the scaling behavior of the target in both Up and Down directions (scaleUp and scaleDown fields respectively).

If not set, the default HPAScalingRules for scale up and scale down are used.

---

##### `metrics`<sup>Optional</sup> <a name="metrics" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta2.property.metrics"></a>

```typescript
public readonly metrics: MetricSpecV2Beta2[];
```

- *Type:* cdk8s-metaflow.k8s.MetricSpecV2Beta2[]

metrics contains the specifications for which to use to calculate the desired replica count (the maximum replica count across all metrics will be used).

The desired replica count is calculated multiplying the ratio between the target value and the current value by the current number of pods.  Ergo, metrics used must decrease as the pod count is increased, and vice-versa.  See the individual metric source types for more information about how each type of metric must respond. If not set, the default metric will be set to 80% average CPU utilization.

---

##### `minReplicas`<sup>Optional</sup> <a name="minReplicas" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta2.property.minReplicas"></a>

```typescript
public readonly minReplicas: number;
```

- *Type:* number

minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.

It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available.

---

### HorizontalPodAutoscalerV2Beta1Props <a name="HorizontalPodAutoscalerV2Beta1Props" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1Props"></a>

HorizontalPodAutoscaler is the configuration for a horizontal pod autoscaler, which automatically manages the replica count of any resource implementing the scale subresource based on the metrics specified.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const horizontalPodAutoscalerV2Beta1Props: k8s.HorizontalPodAutoscalerV2Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | metadata is the standard object metadata. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1Props.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta1</code> | spec is the specification for the behaviour of the autoscaler. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

metadata is the standard object metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta1Props.property.spec"></a>

```typescript
public readonly spec: HorizontalPodAutoscalerSpecV2Beta1;
```

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta1

spec is the specification for the behaviour of the autoscaler.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status.

---

### HorizontalPodAutoscalerV2Beta2Props <a name="HorizontalPodAutoscalerV2Beta2Props" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2Props"></a>

HorizontalPodAutoscaler is the configuration for a horizontal pod autoscaler, which automatically manages the replica count of any resource implementing the scale subresource based on the metrics specified.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const horizontalPodAutoscalerV2Beta2Props: k8s.HorizontalPodAutoscalerV2Beta2Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | metadata is the standard object metadata. |
| <code><a href="#cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2Props.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta2</code> | spec is the specification for the behaviour of the autoscaler. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

metadata is the standard object metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.HorizontalPodAutoscalerV2Beta2Props.property.spec"></a>

```typescript
public readonly spec: HorizontalPodAutoscalerSpecV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.HorizontalPodAutoscalerSpecV2Beta2

spec is the specification for the behaviour of the autoscaler.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status.

---

### HostAlias <a name="HostAlias" id="cdk8s-metaflow.k8s.HostAlias"></a>

HostAlias holds the mapping between IP and hostnames that will be injected as an entry in the pod's hosts file.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HostAlias.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const hostAlias: k8s.HostAlias = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HostAlias.property.hostnames">hostnames</a></code> | <code>string[]</code> | Hostnames for the above IP address. |
| <code><a href="#cdk8s-metaflow.k8s.HostAlias.property.ip">ip</a></code> | <code>string</code> | IP address of the host file entry. |

---

##### `hostnames`<sup>Optional</sup> <a name="hostnames" id="cdk8s-metaflow.k8s.HostAlias.property.hostnames"></a>

```typescript
public readonly hostnames: string[];
```

- *Type:* string[]

Hostnames for the above IP address.

---

##### `ip`<sup>Optional</sup> <a name="ip" id="cdk8s-metaflow.k8s.HostAlias.property.ip"></a>

```typescript
public readonly ip: string;
```

- *Type:* string

IP address of the host file entry.

---

### HostOptions <a name="HostOptions" id="cdk8s-metaflow.HostOptions"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.HostOptions.Initializer"></a>

```typescript
import { HostOptions } from 'cdk8s-metaflow'

const hostOptions: HostOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.HostOptions.property.host">host</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.HostOptions.property.paths">paths</a></code> | <code><a href="#cdk8s-metaflow.HttpIngressPath">HttpIngressPath</a>[]</code> | *No description.* |

---

##### `host`<sup>Optional</sup> <a name="host" id="cdk8s-metaflow.HostOptions.property.host"></a>

```typescript
public readonly host: string;
```

- *Type:* string

---

##### `paths`<sup>Optional</sup> <a name="paths" id="cdk8s-metaflow.HostOptions.property.paths"></a>

```typescript
public readonly paths: HttpIngressPath[];
```

- *Type:* <a href="#cdk8s-metaflow.HttpIngressPath">HttpIngressPath</a>[]

---

### HostPathVolumeSource <a name="HostPathVolumeSource" id="cdk8s-metaflow.k8s.HostPathVolumeSource"></a>

Represents a host path mapped into a pod.

Host path volumes do not support ownership management or SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HostPathVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const hostPathVolumeSource: k8s.HostPathVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HostPathVolumeSource.property.path">path</a></code> | <code>string</code> | Path of the directory on the host. |
| <code><a href="#cdk8s-metaflow.k8s.HostPathVolumeSource.property.type">type</a></code> | <code>string</code> | Type for HostPath Volume Defaults to "" More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath. |

---

##### `path`<sup>Required</sup> <a name="path" id="cdk8s-metaflow.k8s.HostPathVolumeSource.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* string

Path of the directory on the host.

If the path is a symlink, it will follow the link to the real path. More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath

---

##### `type`<sup>Optional</sup> <a name="type" id="cdk8s-metaflow.k8s.HostPathVolumeSource.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string
- *Default:* More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath

Type for HostPath Volume Defaults to "" More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath.

---

### HostPortRangeV1Beta1 <a name="HostPortRangeV1Beta1" id="cdk8s-metaflow.k8s.HostPortRangeV1Beta1"></a>

HostPortRange defines a range of host ports that will be enabled by a policy for pods to use.

It requires both the start and end to be defined.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HostPortRangeV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const hostPortRangeV1Beta1: k8s.HostPortRangeV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HostPortRangeV1Beta1.property.max">max</a></code> | <code>number</code> | max is the end of the range, inclusive. |
| <code><a href="#cdk8s-metaflow.k8s.HostPortRangeV1Beta1.property.min">min</a></code> | <code>number</code> | min is the start of the range, inclusive. |

---

##### `max`<sup>Required</sup> <a name="max" id="cdk8s-metaflow.k8s.HostPortRangeV1Beta1.property.max"></a>

```typescript
public readonly max: number;
```

- *Type:* number

max is the end of the range, inclusive.

---

##### `min`<sup>Required</sup> <a name="min" id="cdk8s-metaflow.k8s.HostPortRangeV1Beta1.property.min"></a>

```typescript
public readonly min: number;
```

- *Type:* number

min is the start of the range, inclusive.

---

### HpaScalingPolicyV2Beta2 <a name="HpaScalingPolicyV2Beta2" id="cdk8s-metaflow.k8s.HpaScalingPolicyV2Beta2"></a>

HPAScalingPolicy is a single policy which must hold true for a specified past interval.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HpaScalingPolicyV2Beta2.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const hpaScalingPolicyV2Beta2: k8s.HpaScalingPolicyV2Beta2 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HpaScalingPolicyV2Beta2.property.periodSeconds">periodSeconds</a></code> | <code>number</code> | PeriodSeconds specifies the window of time for which the policy should hold true. |
| <code><a href="#cdk8s-metaflow.k8s.HpaScalingPolicyV2Beta2.property.type">type</a></code> | <code>string</code> | Type is used to specify the scaling policy. |
| <code><a href="#cdk8s-metaflow.k8s.HpaScalingPolicyV2Beta2.property.value">value</a></code> | <code>number</code> | Value contains the amount of change which is permitted by the policy. |

---

##### `periodSeconds`<sup>Required</sup> <a name="periodSeconds" id="cdk8s-metaflow.k8s.HpaScalingPolicyV2Beta2.property.periodSeconds"></a>

```typescript
public readonly periodSeconds: number;
```

- *Type:* number

PeriodSeconds specifies the window of time for which the policy should hold true.

PeriodSeconds must be greater than zero and less than or equal to 1800 (30 min).

---

##### `type`<sup>Required</sup> <a name="type" id="cdk8s-metaflow.k8s.HpaScalingPolicyV2Beta2.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

Type is used to specify the scaling policy.

---

##### `value`<sup>Required</sup> <a name="value" id="cdk8s-metaflow.k8s.HpaScalingPolicyV2Beta2.property.value"></a>

```typescript
public readonly value: number;
```

- *Type:* number

Value contains the amount of change which is permitted by the policy.

It must be greater than zero

---

### HpaScalingRulesV2Beta2 <a name="HpaScalingRulesV2Beta2" id="cdk8s-metaflow.k8s.HpaScalingRulesV2Beta2"></a>

HPAScalingRules configures the scaling behavior for one direction.

These Rules are applied after calculating DesiredReplicas from metrics for the HPA. They can limit the scaling velocity by specifying scaling policies. They can prevent flapping by specifying the stabilization window, so that the number of replicas is not set instantly, instead, the safest value from the stabilization window is chosen.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HpaScalingRulesV2Beta2.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const hpaScalingRulesV2Beta2: k8s.HpaScalingRulesV2Beta2 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HpaScalingRulesV2Beta2.property.policies">policies</a></code> | <code>cdk8s-metaflow.k8s.HpaScalingPolicyV2Beta2[]</code> | policies is a list of potential scaling polices which can be used during scaling. |
| <code><a href="#cdk8s-metaflow.k8s.HpaScalingRulesV2Beta2.property.selectPolicy">selectPolicy</a></code> | <code>string</code> | selectPolicy is used to specify which policy should be used. |
| <code><a href="#cdk8s-metaflow.k8s.HpaScalingRulesV2Beta2.property.stabilizationWindowSeconds">stabilizationWindowSeconds</a></code> | <code>number</code> | StabilizationWindowSeconds is the number of seconds for which past recommendations should be considered while scaling up or scaling down. |

---

##### `policies`<sup>Optional</sup> <a name="policies" id="cdk8s-metaflow.k8s.HpaScalingRulesV2Beta2.property.policies"></a>

```typescript
public readonly policies: HpaScalingPolicyV2Beta2[];
```

- *Type:* cdk8s-metaflow.k8s.HpaScalingPolicyV2Beta2[]

policies is a list of potential scaling polices which can be used during scaling.

At least one policy must be specified, otherwise the HPAScalingRules will be discarded as invalid

---

##### `selectPolicy`<sup>Optional</sup> <a name="selectPolicy" id="cdk8s-metaflow.k8s.HpaScalingRulesV2Beta2.property.selectPolicy"></a>

```typescript
public readonly selectPolicy: string;
```

- *Type:* string

selectPolicy is used to specify which policy should be used.

If not set, the default value MaxPolicySelect is used.

---

##### `stabilizationWindowSeconds`<sup>Optional</sup> <a name="stabilizationWindowSeconds" id="cdk8s-metaflow.k8s.HpaScalingRulesV2Beta2.property.stabilizationWindowSeconds"></a>

```typescript
public readonly stabilizationWindowSeconds: number;
```

- *Type:* number

StabilizationWindowSeconds is the number of seconds for which past recommendations should be considered while scaling up or scaling down.

StabilizationWindowSeconds must be greater than or equal to zero and less than or equal to 3600 (one hour). If not set, use the default values: - For scale up: 0 (i.e. no stabilization is done). - For scale down: 300 (i.e. the stabilization window is 300 seconds long).

---

### HttpGetAction <a name="HttpGetAction" id="cdk8s-metaflow.k8s.HttpGetAction"></a>

HTTPGetAction describes an action based on HTTP Get requests.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HttpGetAction.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const httpGetAction: k8s.HttpGetAction = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HttpGetAction.property.port">port</a></code> | <code>cdk8s-metaflow.k8s.IntOrString</code> | Name or number of the port to access on the container. |
| <code><a href="#cdk8s-metaflow.k8s.HttpGetAction.property.host">host</a></code> | <code>string</code> | Host name to connect to, defaults to the pod IP. |
| <code><a href="#cdk8s-metaflow.k8s.HttpGetAction.property.httpHeaders">httpHeaders</a></code> | <code>cdk8s-metaflow.k8s.HttpHeader[]</code> | Custom headers to set in the request. |
| <code><a href="#cdk8s-metaflow.k8s.HttpGetAction.property.path">path</a></code> | <code>string</code> | Path to access on the HTTP server. |
| <code><a href="#cdk8s-metaflow.k8s.HttpGetAction.property.scheme">scheme</a></code> | <code>string</code> | Scheme to use for connecting to the host. |

---

##### `port`<sup>Required</sup> <a name="port" id="cdk8s-metaflow.k8s.HttpGetAction.property.port"></a>

```typescript
public readonly port: IntOrString;
```

- *Type:* cdk8s-metaflow.k8s.IntOrString

Name or number of the port to access on the container.

Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.

---

##### `host`<sup>Optional</sup> <a name="host" id="cdk8s-metaflow.k8s.HttpGetAction.property.host"></a>

```typescript
public readonly host: string;
```

- *Type:* string

Host name to connect to, defaults to the pod IP.

You probably want to set "Host" in httpHeaders instead.

---

##### `httpHeaders`<sup>Optional</sup> <a name="httpHeaders" id="cdk8s-metaflow.k8s.HttpGetAction.property.httpHeaders"></a>

```typescript
public readonly httpHeaders: HttpHeader[];
```

- *Type:* cdk8s-metaflow.k8s.HttpHeader[]

Custom headers to set in the request.

HTTP allows repeated headers.

---

##### `path`<sup>Optional</sup> <a name="path" id="cdk8s-metaflow.k8s.HttpGetAction.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* string

Path to access on the HTTP server.

---

##### `scheme`<sup>Optional</sup> <a name="scheme" id="cdk8s-metaflow.k8s.HttpGetAction.property.scheme"></a>

```typescript
public readonly scheme: string;
```

- *Type:* string
- *Default:* HTTP.

Scheme to use for connecting to the host.

Defaults to HTTP.

---

### HttpHeader <a name="HttpHeader" id="cdk8s-metaflow.k8s.HttpHeader"></a>

HTTPHeader describes a custom header to be used in HTTP probes.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HttpHeader.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const httpHeader: k8s.HttpHeader = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HttpHeader.property.name">name</a></code> | <code>string</code> | The header field name. |
| <code><a href="#cdk8s-metaflow.k8s.HttpHeader.property.value">value</a></code> | <code>string</code> | The header field value. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.HttpHeader.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The header field name.

---

##### `value`<sup>Required</sup> <a name="value" id="cdk8s-metaflow.k8s.HttpHeader.property.value"></a>

```typescript
public readonly value: string;
```

- *Type:* string

The header field value.

---

### HttpIngressPath <a name="HttpIngressPath" id="cdk8s-metaflow.HttpIngressPath"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.HttpIngressPath.Initializer"></a>

```typescript
import { HttpIngressPath } from 'cdk8s-metaflow'

const httpIngressPath: HttpIngressPath = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.HttpIngressPath.property.path">path</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.HttpIngressPath.property.pathType">pathType</a></code> | <code><a href="#cdk8s-metaflow.HttpIngressPathType">HttpIngressPathType</a></code> | *No description.* |

---

##### `path`<sup>Optional</sup> <a name="path" id="cdk8s-metaflow.HttpIngressPath.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* string

---

##### `pathType`<sup>Optional</sup> <a name="pathType" id="cdk8s-metaflow.HttpIngressPath.property.pathType"></a>

```typescript
public readonly pathType: HttpIngressPathType;
```

- *Type:* <a href="#cdk8s-metaflow.HttpIngressPathType">HttpIngressPathType</a>

---

### HttpIngressPath <a name="HttpIngressPath" id="cdk8s-metaflow.k8s.HttpIngressPath"></a>

HTTPIngressPath associates a path with a backend.

Incoming urls matching the path are forwarded to the backend.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HttpIngressPath.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const httpIngressPath: k8s.HttpIngressPath = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HttpIngressPath.property.backend">backend</a></code> | <code>cdk8s-metaflow.k8s.IngressBackend</code> | Backend defines the referenced service endpoint to which the traffic will be forwarded to. |
| <code><a href="#cdk8s-metaflow.k8s.HttpIngressPath.property.pathType">pathType</a></code> | <code>string</code> | PathType determines the interpretation of the Path matching. |
| <code><a href="#cdk8s-metaflow.k8s.HttpIngressPath.property.path">path</a></code> | <code>string</code> | Path is matched against the path of an incoming request. |

---

##### `backend`<sup>Required</sup> <a name="backend" id="cdk8s-metaflow.k8s.HttpIngressPath.property.backend"></a>

```typescript
public readonly backend: IngressBackend;
```

- *Type:* cdk8s-metaflow.k8s.IngressBackend

Backend defines the referenced service endpoint to which the traffic will be forwarded to.

---

##### `pathType`<sup>Required</sup> <a name="pathType" id="cdk8s-metaflow.k8s.HttpIngressPath.property.pathType"></a>

```typescript
public readonly pathType: string;
```

- *Type:* string

PathType determines the interpretation of the Path matching.

PathType can be one of the following values: * Exact: Matches the URL path exactly. * Prefix: Matches based on a URL path prefix split by '/'. Matching is
done on a path element by element basis. A path element refers is the
list of labels in the path split by the '/' separator. A request is a
match for path p if every p is an element-wise prefix of p of the
request path. Note that if the last element of the path is a substring
of the last element in request path, it is not a match (e.g. /foo/bar
matches /foo/bar/baz, but does not match /foo/barbaz).
* ImplementationSpecific: Interpretation of the Path matching is up to
the IngressClass. Implementations can treat this as a separate PathType
or treat it identically to Prefix or Exact path types.
Implementations are required to support all path types.

---

##### `path`<sup>Optional</sup> <a name="path" id="cdk8s-metaflow.k8s.HttpIngressPath.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* string

Path is matched against the path of an incoming request.

Currently it can contain characters disallowed from the conventional "path" part of a URL as defined by RFC 3986. Paths must begin with a '/' and must be present when using PathType with value "Exact" or "Prefix".

---

### HttpIngressRuleValue <a name="HttpIngressRuleValue" id="cdk8s-metaflow.k8s.HttpIngressRuleValue"></a>

HTTPIngressRuleValue is a list of http selectors pointing to backends.

In the example: http://<host>/<path>?<searchpart> -> backend where where parts of the url correspond to RFC 3986, this resource will be used to match against everything after the last '/' and before the first '?' or '#'.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.HttpIngressRuleValue.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const httpIngressRuleValue: k8s.HttpIngressRuleValue = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.HttpIngressRuleValue.property.paths">paths</a></code> | <code>cdk8s-metaflow.k8s.HttpIngressPath[]</code> | A collection of paths that map requests to backends. |

---

##### `paths`<sup>Required</sup> <a name="paths" id="cdk8s-metaflow.k8s.HttpIngressRuleValue.property.paths"></a>

```typescript
public readonly paths: HttpIngressPath[];
```

- *Type:* cdk8s-metaflow.k8s.HttpIngressPath[]

A collection of paths that map requests to backends.

---

### IdRangeV1Beta1 <a name="IdRangeV1Beta1" id="cdk8s-metaflow.k8s.IdRangeV1Beta1"></a>

IDRange provides a min/max of an allowed range of IDs.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.IdRangeV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const idRangeV1Beta1: k8s.IdRangeV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IdRangeV1Beta1.property.max">max</a></code> | <code>number</code> | max is the end of the range, inclusive. |
| <code><a href="#cdk8s-metaflow.k8s.IdRangeV1Beta1.property.min">min</a></code> | <code>number</code> | min is the start of the range, inclusive. |

---

##### `max`<sup>Required</sup> <a name="max" id="cdk8s-metaflow.k8s.IdRangeV1Beta1.property.max"></a>

```typescript
public readonly max: number;
```

- *Type:* number

max is the end of the range, inclusive.

---

##### `min`<sup>Required</sup> <a name="min" id="cdk8s-metaflow.k8s.IdRangeV1Beta1.property.min"></a>

```typescript
public readonly min: number;
```

- *Type:* number

min is the start of the range, inclusive.

---

### ImageOptions <a name="ImageOptions" id="cdk8s-metaflow.ImageOptions"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.ImageOptions.Initializer"></a>

```typescript
import { ImageOptions } from 'cdk8s-metaflow'

const imageOptions: ImageOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.ImageOptions.property.pullPolicy">pullPolicy</a></code> | <code><a href="#cdk8s-metaflow.ImagePullPolicy">ImagePullPolicy</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.ImageOptions.property.repository">repository</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.ImageOptions.property.tag">tag</a></code> | <code>string</code> | *No description.* |

---

##### `pullPolicy`<sup>Optional</sup> <a name="pullPolicy" id="cdk8s-metaflow.ImageOptions.property.pullPolicy"></a>

```typescript
public readonly pullPolicy: ImagePullPolicy;
```

- *Type:* <a href="#cdk8s-metaflow.ImagePullPolicy">ImagePullPolicy</a>

---

##### `repository`<sup>Optional</sup> <a name="repository" id="cdk8s-metaflow.ImageOptions.property.repository"></a>

```typescript
public readonly repository: string;
```

- *Type:* string

---

##### `tag`<sup>Optional</sup> <a name="tag" id="cdk8s-metaflow.ImageOptions.property.tag"></a>

```typescript
public readonly tag: string;
```

- *Type:* string

---

### IngressBackend <a name="IngressBackend" id="cdk8s-metaflow.k8s.IngressBackend"></a>

IngressBackend describes all endpoints for a given service and port.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.IngressBackend.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const ingressBackend: k8s.IngressBackend = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressBackend.property.resource">resource</a></code> | <code>cdk8s-metaflow.k8s.TypedLocalObjectReference</code> | Resource is an ObjectRef to another Kubernetes resource in the namespace of the Ingress object. |
| <code><a href="#cdk8s-metaflow.k8s.IngressBackend.property.service">service</a></code> | <code>cdk8s-metaflow.k8s.IngressServiceBackend</code> | Service references a Service as a Backend. |

---

##### `resource`<sup>Optional</sup> <a name="resource" id="cdk8s-metaflow.k8s.IngressBackend.property.resource"></a>

```typescript
public readonly resource: TypedLocalObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.TypedLocalObjectReference

Resource is an ObjectRef to another Kubernetes resource in the namespace of the Ingress object.

If resource is specified, a service.Name and service.Port must not be specified. This is a mutually exclusive setting with "Service".

---

##### `service`<sup>Optional</sup> <a name="service" id="cdk8s-metaflow.k8s.IngressBackend.property.service"></a>

```typescript
public readonly service: IngressServiceBackend;
```

- *Type:* cdk8s-metaflow.k8s.IngressServiceBackend

Service references a Service as a Backend.

This is a mutually exclusive setting with "Resource".

---

### IngressClassListProps <a name="IngressClassListProps" id="cdk8s-metaflow.k8s.IngressClassListProps"></a>

IngressClassList is a collection of IngressClasses.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.IngressClassListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const ingressClassListProps: k8s.IngressClassListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.IngressClass[]</code> | Items is the list of IngressClasses. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.IngressClassListProps.property.items"></a>

```typescript
public readonly items: IngressClass[];
```

- *Type:* cdk8s-metaflow.k8s.IngressClass[]

Items is the list of IngressClasses.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.IngressClassListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

---

### IngressClassParametersReference <a name="IngressClassParametersReference" id="cdk8s-metaflow.k8s.IngressClassParametersReference"></a>

IngressClassParametersReference identifies an API object.

This can be used to specify a cluster or namespace-scoped resource.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.IngressClassParametersReference.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const ingressClassParametersReference: k8s.IngressClassParametersReference = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassParametersReference.property.kind">kind</a></code> | <code>string</code> | Kind is the type of resource being referenced. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassParametersReference.property.name">name</a></code> | <code>string</code> | Name is the name of resource being referenced. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassParametersReference.property.apiGroup">apiGroup</a></code> | <code>string</code> | APIGroup is the group for the resource being referenced. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassParametersReference.property.namespace">namespace</a></code> | <code>string</code> | Namespace is the namespace of the resource being referenced. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassParametersReference.property.scope">scope</a></code> | <code>string</code> | Scope represents if this refers to a cluster or namespace scoped resource. |

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.IngressClassParametersReference.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

Kind is the type of resource being referenced.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.IngressClassParametersReference.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name is the name of resource being referenced.

---

##### `apiGroup`<sup>Optional</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.IngressClassParametersReference.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

APIGroup is the group for the resource being referenced.

If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.

---

##### `namespace`<sup>Optional</sup> <a name="namespace" id="cdk8s-metaflow.k8s.IngressClassParametersReference.property.namespace"></a>

```typescript
public readonly namespace: string;
```

- *Type:* string

Namespace is the namespace of the resource being referenced.

This field is required when scope is set to "Namespace" and must be unset when scope is set to "Cluster".

---

##### `scope`<sup>Optional</sup> <a name="scope" id="cdk8s-metaflow.k8s.IngressClassParametersReference.property.scope"></a>

```typescript
public readonly scope: string;
```

- *Type:* string

Scope represents if this refers to a cluster or namespace scoped resource.

This may be set to "Cluster" (default) or "Namespace". Field can be enabled with IngressClassNamespacedParams feature gate.

---

### IngressClassProps <a name="IngressClassProps" id="cdk8s-metaflow.k8s.IngressClassProps"></a>

IngressClass represents the class of the Ingress, referenced by the Ingress Spec.

The `ingressclass.kubernetes.io/is-default-class` annotation can be used to indicate that an IngressClass should be considered default. When a single IngressClass resource has this annotation set to true, new Ingress resources without a class specified will be assigned this default class.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.IngressClassProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const ingressClassProps: k8s.IngressClassProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.IngressClassSpec</code> | Spec is the desired state of the IngressClass. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.IngressClassProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.IngressClassProps.property.spec"></a>

```typescript
public readonly spec: IngressClassSpec;
```

- *Type:* cdk8s-metaflow.k8s.IngressClassSpec

Spec is the desired state of the IngressClass.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### IngressClassSpec <a name="IngressClassSpec" id="cdk8s-metaflow.k8s.IngressClassSpec"></a>

IngressClassSpec provides information about the class of an Ingress.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.IngressClassSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const ingressClassSpec: k8s.IngressClassSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassSpec.property.controller">controller</a></code> | <code>string</code> | Controller refers to the name of the controller that should handle this class. |
| <code><a href="#cdk8s-metaflow.k8s.IngressClassSpec.property.parameters">parameters</a></code> | <code>cdk8s-metaflow.k8s.IngressClassParametersReference</code> | Parameters is a link to a custom resource containing additional configuration for the controller. |

---

##### `controller`<sup>Optional</sup> <a name="controller" id="cdk8s-metaflow.k8s.IngressClassSpec.property.controller"></a>

```typescript
public readonly controller: string;
```

- *Type:* string

Controller refers to the name of the controller that should handle this class.

This allows for different "flavors" that are controlled by the same controller. For example, you may have different Parameters for the same implementing controller. This should be specified as a domain-prefixed path no more than 250 characters in length, e.g. "acme.io/ingress-controller". This field is immutable.

---

##### `parameters`<sup>Optional</sup> <a name="parameters" id="cdk8s-metaflow.k8s.IngressClassSpec.property.parameters"></a>

```typescript
public readonly parameters: IngressClassParametersReference;
```

- *Type:* cdk8s-metaflow.k8s.IngressClassParametersReference

Parameters is a link to a custom resource containing additional configuration for the controller.

This is optional if the controller does not require extra parameters.

---

### IngressListProps <a name="IngressListProps" id="cdk8s-metaflow.k8s.IngressListProps"></a>

IngressList is a collection of Ingress.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.IngressListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const ingressListProps: k8s.IngressListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.Ingress[]</code> | Items is the list of Ingress. |
| <code><a href="#cdk8s-metaflow.k8s.IngressListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard object's metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.IngressListProps.property.items"></a>

```typescript
public readonly items: Ingress[];
```

- *Type:* cdk8s-metaflow.k8s.Ingress[]

Items is the list of Ingress.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.IngressListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### IngressOptions <a name="IngressOptions" id="cdk8s-metaflow.IngressOptions"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.IngressOptions.Initializer"></a>

```typescript
import { IngressOptions } from 'cdk8s-metaflow'

const ingressOptions: IngressOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.IngressOptions.property.annotations">annotations</a></code> | <code>{[ key: string ]: string}</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.IngressOptions.property.className">className</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.IngressOptions.property.enabled">enabled</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.IngressOptions.property.hosts">hosts</a></code> | <code><a href="#cdk8s-metaflow.HostOptions">HostOptions</a>[]</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.IngressOptions.property.tls">tls</a></code> | <code>cdk8s-metaflow.k8s.IngressTls</code> | *No description.* |

---

##### `annotations`<sup>Optional</sup> <a name="annotations" id="cdk8s-metaflow.IngressOptions.property.annotations"></a>

```typescript
public readonly annotations: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

---

##### `className`<sup>Optional</sup> <a name="className" id="cdk8s-metaflow.IngressOptions.property.className"></a>

```typescript
public readonly className: string;
```

- *Type:* string

---

##### `enabled`<sup>Optional</sup> <a name="enabled" id="cdk8s-metaflow.IngressOptions.property.enabled"></a>

```typescript
public readonly enabled: boolean;
```

- *Type:* boolean

---

##### `hosts`<sup>Optional</sup> <a name="hosts" id="cdk8s-metaflow.IngressOptions.property.hosts"></a>

```typescript
public readonly hosts: HostOptions[];
```

- *Type:* <a href="#cdk8s-metaflow.HostOptions">HostOptions</a>[]

---

##### `tls`<sup>Optional</sup> <a name="tls" id="cdk8s-metaflow.IngressOptions.property.tls"></a>

```typescript
public readonly tls: IngressTls;
```

- *Type:* cdk8s-metaflow.k8s.IngressTls

---

### IngressProps <a name="IngressProps" id="cdk8s-metaflow.k8s.IngressProps"></a>

Ingress is a collection of rules that allow inbound connections to reach the endpoints defined by a backend.

An Ingress can be configured to give services externally-reachable urls, load balance traffic, terminate SSL, offer name based virtual hosting etc.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.IngressProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const ingressProps: k8s.IngressProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.IngressProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.IngressSpec</code> | Spec is the desired state of the Ingress. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.IngressProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.IngressProps.property.spec"></a>

```typescript
public readonly spec: IngressSpec;
```

- *Type:* cdk8s-metaflow.k8s.IngressSpec

Spec is the desired state of the Ingress.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### IngressRule <a name="IngressRule" id="cdk8s-metaflow.k8s.IngressRule"></a>

IngressRule represents the rules mapping the paths under a specified host to the related backend services.

Incoming requests are first evaluated for a host match, then routed to the backend associated with the matching IngressRuleValue.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.IngressRule.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const ingressRule: k8s.IngressRule = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressRule.property.host">host</a></code> | <code>string</code> | Host is the fully qualified domain name of a network host, as defined by RFC 3986. |
| <code><a href="#cdk8s-metaflow.k8s.IngressRule.property.http">http</a></code> | <code>cdk8s-metaflow.k8s.HttpIngressRuleValue</code> | *No description.* |

---

##### `host`<sup>Optional</sup> <a name="host" id="cdk8s-metaflow.k8s.IngressRule.property.host"></a>

```typescript
public readonly host: string;
```

- *Type:* string

Host is the fully qualified domain name of a network host, as defined by RFC 3986.

Note the following deviations from the "host" part of the URI as defined in RFC 3986: 1. IPs are not allowed. Currently an IngressRuleValue can only apply to
the IP in the Spec of the parent Ingress.
2. The `:` delimiter is not respected because ports are not allowed.
Currently the port of an Ingress is implicitly :80 for http and
:443 for https.
Both these may change in the future. Incoming requests are matched against the host before the IngressRuleValue. If the host is unspecified, the Ingress routes all traffic based on the specified IngressRuleValue.

Host can be "precise" which is a domain name without the terminating dot of a network host (e.g. "foo.bar.com") or "wildcard", which is a domain name prefixed with a single wildcard label (e.g. "*.foo.com"). The wildcard character '*' must appear by itself as the first DNS label and matches only a single label. You cannot have a wildcard label by itself (e.g. Host == "*"). Requests will be matched against the Host field in the following way: 1. If Host is precise, the request matches this rule if the http host header is equal to Host. 2. If Host is a wildcard, then the request matches this rule if the http host header is to equal to the suffix (removing the first label) of the wildcard rule.

---

##### `http`<sup>Optional</sup> <a name="http" id="cdk8s-metaflow.k8s.IngressRule.property.http"></a>

```typescript
public readonly http: HttpIngressRuleValue;
```

- *Type:* cdk8s-metaflow.k8s.HttpIngressRuleValue

---

### IngressServiceBackend <a name="IngressServiceBackend" id="cdk8s-metaflow.k8s.IngressServiceBackend"></a>

IngressServiceBackend references a Kubernetes Service as a Backend.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.IngressServiceBackend.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const ingressServiceBackend: k8s.IngressServiceBackend = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressServiceBackend.property.name">name</a></code> | <code>string</code> | Name is the referenced service. |
| <code><a href="#cdk8s-metaflow.k8s.IngressServiceBackend.property.port">port</a></code> | <code>cdk8s-metaflow.k8s.ServiceBackendPort</code> | Port of the referenced service. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.IngressServiceBackend.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name is the referenced service.

The service must exist in the same namespace as the Ingress object.

---

##### `port`<sup>Optional</sup> <a name="port" id="cdk8s-metaflow.k8s.IngressServiceBackend.property.port"></a>

```typescript
public readonly port: ServiceBackendPort;
```

- *Type:* cdk8s-metaflow.k8s.ServiceBackendPort

Port of the referenced service.

A port name or port number is required for a IngressServiceBackend.

---

### IngressSpec <a name="IngressSpec" id="cdk8s-metaflow.k8s.IngressSpec"></a>

IngressSpec describes the Ingress the user wishes to exist.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.IngressSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const ingressSpec: k8s.IngressSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressSpec.property.defaultBackend">defaultBackend</a></code> | <code>cdk8s-metaflow.k8s.IngressBackend</code> | DefaultBackend is the backend that should handle requests that don't match any rule. |
| <code><a href="#cdk8s-metaflow.k8s.IngressSpec.property.ingressClassName">ingressClassName</a></code> | <code>string</code> | IngressClassName is the name of the IngressClass cluster resource. |
| <code><a href="#cdk8s-metaflow.k8s.IngressSpec.property.rules">rules</a></code> | <code>cdk8s-metaflow.k8s.IngressRule[]</code> | A list of host rules used to configure the Ingress. |
| <code><a href="#cdk8s-metaflow.k8s.IngressSpec.property.tls">tls</a></code> | <code>cdk8s-metaflow.k8s.IngressTls[]</code> | TLS configuration. |

---

##### `defaultBackend`<sup>Optional</sup> <a name="defaultBackend" id="cdk8s-metaflow.k8s.IngressSpec.property.defaultBackend"></a>

```typescript
public readonly defaultBackend: IngressBackend;
```

- *Type:* cdk8s-metaflow.k8s.IngressBackend

DefaultBackend is the backend that should handle requests that don't match any rule.

If Rules are not specified, DefaultBackend must be specified. If DefaultBackend is not set, the handling of requests that do not match any of the rules will be up to the Ingress controller.

---

##### `ingressClassName`<sup>Optional</sup> <a name="ingressClassName" id="cdk8s-metaflow.k8s.IngressSpec.property.ingressClassName"></a>

```typescript
public readonly ingressClassName: string;
```

- *Type:* string

IngressClassName is the name of the IngressClass cluster resource.

The associated IngressClass defines which controller will implement the resource. This replaces the deprecated `kubernetes.io/ingress.class` annotation. For backwards compatibility, when that annotation is set, it must be given precedence over this field. The controller may emit a warning if the field and annotation have different values. Implementations of this API should ignore Ingresses without a class specified. An IngressClass resource may be marked as default, which can be used to set a default value for this field. For more information, refer to the IngressClass documentation.

---

##### `rules`<sup>Optional</sup> <a name="rules" id="cdk8s-metaflow.k8s.IngressSpec.property.rules"></a>

```typescript
public readonly rules: IngressRule[];
```

- *Type:* cdk8s-metaflow.k8s.IngressRule[]

A list of host rules used to configure the Ingress.

If unspecified, or no rule matches, all traffic is sent to the default backend.

---

##### `tls`<sup>Optional</sup> <a name="tls" id="cdk8s-metaflow.k8s.IngressSpec.property.tls"></a>

```typescript
public readonly tls: IngressTls[];
```

- *Type:* cdk8s-metaflow.k8s.IngressTls[]

TLS configuration.

Currently the Ingress only supports a single TLS port, 443. If multiple members of this list specify different hosts, they will be multiplexed on the same port according to the hostname specified through the SNI TLS extension, if the ingress controller fulfilling the ingress supports SNI.

---

### IngressTls <a name="IngressTls" id="cdk8s-metaflow.k8s.IngressTls"></a>

IngressTLS describes the transport layer security associated with an Ingress.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.IngressTls.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const ingressTls: k8s.IngressTls = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IngressTls.property.hosts">hosts</a></code> | <code>string[]</code> | Hosts are a list of hosts included in the TLS certificate. |
| <code><a href="#cdk8s-metaflow.k8s.IngressTls.property.secretName">secretName</a></code> | <code>string</code> | SecretName is the name of the secret used to terminate TLS traffic on port 443. |

---

##### `hosts`<sup>Optional</sup> <a name="hosts" id="cdk8s-metaflow.k8s.IngressTls.property.hosts"></a>

```typescript
public readonly hosts: string[];
```

- *Type:* string[]
- *Default:* the wildcard host setting for the loadbalancer controller fulfilling this Ingress, if left unspecified.

Hosts are a list of hosts included in the TLS certificate.

The values in this list must match the name/s used in the tlsSecret. Defaults to the wildcard host setting for the loadbalancer controller fulfilling this Ingress, if left unspecified.

---

##### `secretName`<sup>Optional</sup> <a name="secretName" id="cdk8s-metaflow.k8s.IngressTls.property.secretName"></a>

```typescript
public readonly secretName: string;
```

- *Type:* string

SecretName is the name of the secret used to terminate TLS traffic on port 443.

Field is left optional to allow TLS routing based on SNI hostname alone. If the SNI host in a listener conflicts with the "Host" header field used by an IngressRule, the SNI host is used for termination and value of the Host header is used for routing.

---

### IpBlock <a name="IpBlock" id="cdk8s-metaflow.k8s.IpBlock"></a>

IPBlock describes a particular CIDR (Ex.

"192.168.1.1/24","2001:db9::/64") that is allowed to the pods matched by a NetworkPolicySpec's podSelector. The except entry describes CIDRs that should not be included within this rule.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.IpBlock.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const ipBlock: k8s.IpBlock = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IpBlock.property.cidr">cidr</a></code> | <code>string</code> | CIDR is a string representing the IP Block Valid examples are "192.168.1.1/24" or "2001:db9::/64". |
| <code><a href="#cdk8s-metaflow.k8s.IpBlock.property.except">except</a></code> | <code>string[]</code> | Except is a slice of CIDRs that should not be included within an IP Block Valid examples are "192.168.1.1/24" or "2001:db9::/64" Except values will be rejected if they are outside the CIDR range. |

---

##### `cidr`<sup>Required</sup> <a name="cidr" id="cdk8s-metaflow.k8s.IpBlock.property.cidr"></a>

```typescript
public readonly cidr: string;
```

- *Type:* string

CIDR is a string representing the IP Block Valid examples are "192.168.1.1/24" or "2001:db9::/64".

---

##### `except`<sup>Optional</sup> <a name="except" id="cdk8s-metaflow.k8s.IpBlock.property.except"></a>

```typescript
public readonly except: string[];
```

- *Type:* string[]

Except is a slice of CIDRs that should not be included within an IP Block Valid examples are "192.168.1.1/24" or "2001:db9::/64" Except values will be rejected if they are outside the CIDR range.

---

### IscsiPersistentVolumeSource <a name="IscsiPersistentVolumeSource" id="cdk8s-metaflow.k8s.IscsiPersistentVolumeSource"></a>

ISCSIPersistentVolumeSource represents an ISCSI disk.

ISCSI volumes can only be mounted as read/write once. ISCSI volumes support ownership management and SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const iscsiPersistentVolumeSource: k8s.IscsiPersistentVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.iqn">iqn</a></code> | <code>string</code> | Target iSCSI Qualified Name. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.lun">lun</a></code> | <code>number</code> | iSCSI Target Lun number. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.targetPortal">targetPortal</a></code> | <code>string</code> | iSCSI Target Portal. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.chapAuthDiscovery">chapAuthDiscovery</a></code> | <code>boolean</code> | whether support iSCSI Discovery CHAP authentication. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.chapAuthSession">chapAuthSession</a></code> | <code>boolean</code> | whether support iSCSI Session CHAP authentication. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type of the volume that you want to mount. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.initiatorName">initiatorName</a></code> | <code>string</code> | Custom iSCSI Initiator Name. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.iscsiInterface">iscsiInterface</a></code> | <code>string</code> | iSCSI Interface Name that uses an iSCSI transport. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.portals">portals</a></code> | <code>string[]</code> | iSCSI Target Portal List. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | ReadOnly here will force the ReadOnly setting in VolumeMounts. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.secretRef">secretRef</a></code> | <code>cdk8s-metaflow.k8s.SecretReference</code> | CHAP Secret for iSCSI target and initiator authentication. |

---

##### `iqn`<sup>Required</sup> <a name="iqn" id="cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.iqn"></a>

```typescript
public readonly iqn: string;
```

- *Type:* string

Target iSCSI Qualified Name.

---

##### `lun`<sup>Required</sup> <a name="lun" id="cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.lun"></a>

```typescript
public readonly lun: number;
```

- *Type:* number

iSCSI Target Lun number.

---

##### `targetPortal`<sup>Required</sup> <a name="targetPortal" id="cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.targetPortal"></a>

```typescript
public readonly targetPortal: string;
```

- *Type:* string

iSCSI Target Portal.

The Portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).

---

##### `chapAuthDiscovery`<sup>Optional</sup> <a name="chapAuthDiscovery" id="cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.chapAuthDiscovery"></a>

```typescript
public readonly chapAuthDiscovery: boolean;
```

- *Type:* boolean

whether support iSCSI Discovery CHAP authentication.

---

##### `chapAuthSession`<sup>Optional</sup> <a name="chapAuthSession" id="cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.chapAuthSession"></a>

```typescript
public readonly chapAuthSession: boolean;
```

- *Type:* boolean

whether support iSCSI Session CHAP authentication.

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type of the volume that you want to mount.

Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#iscsi

---

##### `initiatorName`<sup>Optional</sup> <a name="initiatorName" id="cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.initiatorName"></a>

```typescript
public readonly initiatorName: string;
```

- *Type:* string

Custom iSCSI Initiator Name.

If initiatorName is specified with iscsiInterface simultaneously, new iSCSI interface <target portal>:<volume name> will be created for the connection.

---

##### `iscsiInterface`<sup>Optional</sup> <a name="iscsiInterface" id="cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.iscsiInterface"></a>

```typescript
public readonly iscsiInterface: string;
```

- *Type:* string
- *Default:* default' (tcp).

iSCSI Interface Name that uses an iSCSI transport.

Defaults to 'default' (tcp).

---

##### `portals`<sup>Optional</sup> <a name="portals" id="cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.portals"></a>

```typescript
public readonly portals: string[];
```

- *Type:* string[]

iSCSI Target Portal List.

The Portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false.

ReadOnly here will force the ReadOnly setting in VolumeMounts.

Defaults to false.

---

##### `secretRef`<sup>Optional</sup> <a name="secretRef" id="cdk8s-metaflow.k8s.IscsiPersistentVolumeSource.property.secretRef"></a>

```typescript
public readonly secretRef: SecretReference;
```

- *Type:* cdk8s-metaflow.k8s.SecretReference

CHAP Secret for iSCSI target and initiator authentication.

---

### IscsiVolumeSource <a name="IscsiVolumeSource" id="cdk8s-metaflow.k8s.IscsiVolumeSource"></a>

Represents an ISCSI disk.

ISCSI volumes can only be mounted as read/write once. ISCSI volumes support ownership management and SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.IscsiVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const iscsiVolumeSource: k8s.IscsiVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IscsiVolumeSource.property.iqn">iqn</a></code> | <code>string</code> | Target iSCSI Qualified Name. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiVolumeSource.property.lun">lun</a></code> | <code>number</code> | iSCSI Target Lun number. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiVolumeSource.property.targetPortal">targetPortal</a></code> | <code>string</code> | iSCSI Target Portal. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiVolumeSource.property.chapAuthDiscovery">chapAuthDiscovery</a></code> | <code>boolean</code> | whether support iSCSI Discovery CHAP authentication. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiVolumeSource.property.chapAuthSession">chapAuthSession</a></code> | <code>boolean</code> | whether support iSCSI Session CHAP authentication. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type of the volume that you want to mount. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiVolumeSource.property.initiatorName">initiatorName</a></code> | <code>string</code> | Custom iSCSI Initiator Name. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiVolumeSource.property.iscsiInterface">iscsiInterface</a></code> | <code>string</code> | iSCSI Interface Name that uses an iSCSI transport. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiVolumeSource.property.portals">portals</a></code> | <code>string[]</code> | iSCSI Target Portal List. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | ReadOnly here will force the ReadOnly setting in VolumeMounts. |
| <code><a href="#cdk8s-metaflow.k8s.IscsiVolumeSource.property.secretRef">secretRef</a></code> | <code>cdk8s-metaflow.k8s.LocalObjectReference</code> | CHAP Secret for iSCSI target and initiator authentication. |

---

##### `iqn`<sup>Required</sup> <a name="iqn" id="cdk8s-metaflow.k8s.IscsiVolumeSource.property.iqn"></a>

```typescript
public readonly iqn: string;
```

- *Type:* string

Target iSCSI Qualified Name.

---

##### `lun`<sup>Required</sup> <a name="lun" id="cdk8s-metaflow.k8s.IscsiVolumeSource.property.lun"></a>

```typescript
public readonly lun: number;
```

- *Type:* number

iSCSI Target Lun number.

---

##### `targetPortal`<sup>Required</sup> <a name="targetPortal" id="cdk8s-metaflow.k8s.IscsiVolumeSource.property.targetPortal"></a>

```typescript
public readonly targetPortal: string;
```

- *Type:* string

iSCSI Target Portal.

The Portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).

---

##### `chapAuthDiscovery`<sup>Optional</sup> <a name="chapAuthDiscovery" id="cdk8s-metaflow.k8s.IscsiVolumeSource.property.chapAuthDiscovery"></a>

```typescript
public readonly chapAuthDiscovery: boolean;
```

- *Type:* boolean

whether support iSCSI Discovery CHAP authentication.

---

##### `chapAuthSession`<sup>Optional</sup> <a name="chapAuthSession" id="cdk8s-metaflow.k8s.IscsiVolumeSource.property.chapAuthSession"></a>

```typescript
public readonly chapAuthSession: boolean;
```

- *Type:* boolean

whether support iSCSI Session CHAP authentication.

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.IscsiVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type of the volume that you want to mount.

Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#iscsi

---

##### `initiatorName`<sup>Optional</sup> <a name="initiatorName" id="cdk8s-metaflow.k8s.IscsiVolumeSource.property.initiatorName"></a>

```typescript
public readonly initiatorName: string;
```

- *Type:* string

Custom iSCSI Initiator Name.

If initiatorName is specified with iscsiInterface simultaneously, new iSCSI interface <target portal>:<volume name> will be created for the connection.

---

##### `iscsiInterface`<sup>Optional</sup> <a name="iscsiInterface" id="cdk8s-metaflow.k8s.IscsiVolumeSource.property.iscsiInterface"></a>

```typescript
public readonly iscsiInterface: string;
```

- *Type:* string
- *Default:* default' (tcp).

iSCSI Interface Name that uses an iSCSI transport.

Defaults to 'default' (tcp).

---

##### `portals`<sup>Optional</sup> <a name="portals" id="cdk8s-metaflow.k8s.IscsiVolumeSource.property.portals"></a>

```typescript
public readonly portals: string[];
```

- *Type:* string[]

iSCSI Target Portal List.

The portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.IscsiVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false.

ReadOnly here will force the ReadOnly setting in VolumeMounts.

Defaults to false.

---

##### `secretRef`<sup>Optional</sup> <a name="secretRef" id="cdk8s-metaflow.k8s.IscsiVolumeSource.property.secretRef"></a>

```typescript
public readonly secretRef: LocalObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.LocalObjectReference

CHAP Secret for iSCSI target and initiator authentication.

---

### JobListProps <a name="JobListProps" id="cdk8s-metaflow.k8s.JobListProps"></a>

JobList is a collection of jobs.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.JobListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const jobListProps: k8s.JobListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.JobListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.Job[]</code> | items is the list of Jobs. |
| <code><a href="#cdk8s-metaflow.k8s.JobListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.JobListProps.property.items"></a>

```typescript
public readonly items: Job[];
```

- *Type:* cdk8s-metaflow.k8s.Job[]

items is the list of Jobs.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.JobListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### JobProps <a name="JobProps" id="cdk8s-metaflow.k8s.JobProps"></a>

Job represents the configuration of a single job.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.JobProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const jobProps: k8s.JobProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.JobProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.JobProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.JobSpec</code> | Specification of the desired behavior of a job. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.JobProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.JobProps.property.spec"></a>

```typescript
public readonly spec: JobSpec;
```

- *Type:* cdk8s-metaflow.k8s.JobSpec

Specification of the desired behavior of a job.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### JobSpec <a name="JobSpec" id="cdk8s-metaflow.k8s.JobSpec"></a>

JobSpec describes how the job execution will look like.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.JobSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const jobSpec: k8s.JobSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.JobSpec.property.template">template</a></code> | <code>cdk8s-metaflow.k8s.PodTemplateSpec</code> | Describes the pod that will be created when executing a job. |
| <code><a href="#cdk8s-metaflow.k8s.JobSpec.property.activeDeadlineSeconds">activeDeadlineSeconds</a></code> | <code>number</code> | Specifies the duration in seconds relative to the startTime that the job may be continuously active before the system tries to terminate it; |
| <code><a href="#cdk8s-metaflow.k8s.JobSpec.property.backoffLimit">backoffLimit</a></code> | <code>number</code> | Specifies the number of retries before marking this job failed. |
| <code><a href="#cdk8s-metaflow.k8s.JobSpec.property.completionMode">completionMode</a></code> | <code>string</code> | CompletionMode specifies how Pod completions are tracked. It can be `NonIndexed` (default) or `Indexed`. |
| <code><a href="#cdk8s-metaflow.k8s.JobSpec.property.completions">completions</a></code> | <code>number</code> | Specifies the desired number of successfully finished pods the job should be run with. |
| <code><a href="#cdk8s-metaflow.k8s.JobSpec.property.manualSelector">manualSelector</a></code> | <code>boolean</code> | manualSelector controls generation of pod labels and pod selectors. |
| <code><a href="#cdk8s-metaflow.k8s.JobSpec.property.parallelism">parallelism</a></code> | <code>number</code> | Specifies the maximum desired number of pods the job should run at any given time. |
| <code><a href="#cdk8s-metaflow.k8s.JobSpec.property.selector">selector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | A label query over pods that should match the pod count. |
| <code><a href="#cdk8s-metaflow.k8s.JobSpec.property.suspend">suspend</a></code> | <code>boolean</code> | Suspend specifies whether the Job controller should create Pods or not. |
| <code><a href="#cdk8s-metaflow.k8s.JobSpec.property.ttlSecondsAfterFinished">ttlSecondsAfterFinished</a></code> | <code>number</code> | ttlSecondsAfterFinished limits the lifetime of a Job that has finished execution (either Complete or Failed). |

---

##### `template`<sup>Required</sup> <a name="template" id="cdk8s-metaflow.k8s.JobSpec.property.template"></a>

```typescript
public readonly template: PodTemplateSpec;
```

- *Type:* cdk8s-metaflow.k8s.PodTemplateSpec

Describes the pod that will be created when executing a job.

More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/

---

##### `activeDeadlineSeconds`<sup>Optional</sup> <a name="activeDeadlineSeconds" id="cdk8s-metaflow.k8s.JobSpec.property.activeDeadlineSeconds"></a>

```typescript
public readonly activeDeadlineSeconds: number;
```

- *Type:* number

Specifies the duration in seconds relative to the startTime that the job may be continuously active before the system tries to terminate it;

value must be positive integer. If a Job is suspended (at creation or through an update), this timer will effectively be stopped and reset when the Job is resumed again.

---

##### `backoffLimit`<sup>Optional</sup> <a name="backoffLimit" id="cdk8s-metaflow.k8s.JobSpec.property.backoffLimit"></a>

```typescript
public readonly backoffLimit: number;
```

- *Type:* number
- *Default:* 6

Specifies the number of retries before marking this job failed.

Defaults to 6

---

##### `completionMode`<sup>Optional</sup> <a name="completionMode" id="cdk8s-metaflow.k8s.JobSpec.property.completionMode"></a>

```typescript
public readonly completionMode: string;
```

- *Type:* string

CompletionMode specifies how Pod completions are tracked. It can be `NonIndexed` (default) or `Indexed`.

`NonIndexed` means that the Job is considered complete when there have been .spec.completions successfully completed Pods. Each Pod completion is homologous to each other.

`Indexed` means that the Pods of a Job get an associated completion index from 0 to (.spec.completions - 1), available in the annotation batch.kubernetes.io/job-completion-index. The Job is considered complete when there is one successfully completed Pod for each index. When value is `Indexed`, .spec.completions must be specified and `.spec.parallelism` must be less than or equal to 10^5. In addition, The Pod name takes the form `$(job-name)-$(index)-$(random-string)`, the Pod hostname takes the form `$(job-name)-$(index)`.

This field is beta-level. More completion modes can be added in the future. If the Job controller observes a mode that it doesn't recognize, the controller skips updates for the Job.

---

##### `completions`<sup>Optional</sup> <a name="completions" id="cdk8s-metaflow.k8s.JobSpec.property.completions"></a>

```typescript
public readonly completions: number;
```

- *Type:* number

Specifies the desired number of successfully finished pods the job should be run with.

Setting to nil means that the success of any pod signals the success of all pods, and allows parallelism to have any positive value.  Setting to 1 means that parallelism is limited to 1 and the success of that pod signals the success of the job. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/

---

##### `manualSelector`<sup>Optional</sup> <a name="manualSelector" id="cdk8s-metaflow.k8s.JobSpec.property.manualSelector"></a>

```typescript
public readonly manualSelector: boolean;
```

- *Type:* boolean

manualSelector controls generation of pod labels and pod selectors.

Leave `manualSelector` unset unless you are certain what you are doing. When false or unset, the system pick labels unique to this job and appends those labels to the pod template.  When true, the user is responsible for picking unique labels and specifying the selector.  Failure to pick a unique label may cause this and other jobs to not function correctly.  However, You may see `manualSelector=true` in jobs that were created with the old `extensions/v1beta1` API. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/#specifying-your-own-pod-selector

---

##### `parallelism`<sup>Optional</sup> <a name="parallelism" id="cdk8s-metaflow.k8s.JobSpec.property.parallelism"></a>

```typescript
public readonly parallelism: number;
```

- *Type:* number

Specifies the maximum desired number of pods the job should run at any given time.

The actual number of pods running in steady state will be less than this number when ((.spec.completions - .status.successful) < .spec.parallelism), i.e. when the work left to do is less than max parallelism. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/

---

##### `selector`<sup>Optional</sup> <a name="selector" id="cdk8s-metaflow.k8s.JobSpec.property.selector"></a>

```typescript
public readonly selector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

A label query over pods that should match the pod count.

Normally, the system sets this field for you. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors

---

##### `suspend`<sup>Optional</sup> <a name="suspend" id="cdk8s-metaflow.k8s.JobSpec.property.suspend"></a>

```typescript
public readonly suspend: boolean;
```

- *Type:* boolean
- *Default:* false.

Suspend specifies whether the Job controller should create Pods or not.

If a Job is created with suspend set to true, no Pods are created by the Job controller. If a Job is suspended after creation (i.e. the flag goes from false to true), the Job controller will delete all active Pods associated with this Job. Users must design their workload to gracefully handle this. Suspending a Job will reset the StartTime field of the Job, effectively resetting the ActiveDeadlineSeconds timer too. Defaults to false.

This field is beta-level, gated by SuspendJob feature flag (enabled by default).

---

##### `ttlSecondsAfterFinished`<sup>Optional</sup> <a name="ttlSecondsAfterFinished" id="cdk8s-metaflow.k8s.JobSpec.property.ttlSecondsAfterFinished"></a>

```typescript
public readonly ttlSecondsAfterFinished: number;
```

- *Type:* number

ttlSecondsAfterFinished limits the lifetime of a Job that has finished execution (either Complete or Failed).

If this field is set, ttlSecondsAfterFinished after the Job finishes, it is eligible to be automatically deleted. When the Job is being deleted, its lifecycle guarantees (e.g. finalizers) will be honored. If this field is unset, the Job won't be automatically deleted. If this field is set to zero, the Job becomes eligible to be deleted immediately after it finishes. This field is alpha-level and is only honored by servers that enable the TTLAfterFinished feature.

---

### JobTemplateSpec <a name="JobTemplateSpec" id="cdk8s-metaflow.k8s.JobTemplateSpec"></a>

JobTemplateSpec describes the data a Job should have when created from a template.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.JobTemplateSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const jobTemplateSpec: k8s.JobTemplateSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.JobTemplateSpec.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata of the jobs created from this template. |
| <code><a href="#cdk8s-metaflow.k8s.JobTemplateSpec.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.JobSpec</code> | Specification of the desired behavior of the job. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.JobTemplateSpec.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata of the jobs created from this template.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.JobTemplateSpec.property.spec"></a>

```typescript
public readonly spec: JobSpec;
```

- *Type:* cdk8s-metaflow.k8s.JobSpec

Specification of the desired behavior of the job.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### JobTemplateSpecV1Beta1 <a name="JobTemplateSpecV1Beta1" id="cdk8s-metaflow.k8s.JobTemplateSpecV1Beta1"></a>

JobTemplateSpec describes the data a Job should have when created from a template.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.JobTemplateSpecV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const jobTemplateSpecV1Beta1: k8s.JobTemplateSpecV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.JobTemplateSpecV1Beta1.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata of the jobs created from this template. |
| <code><a href="#cdk8s-metaflow.k8s.JobTemplateSpecV1Beta1.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.JobSpec</code> | Specification of the desired behavior of the job. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.JobTemplateSpecV1Beta1.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata of the jobs created from this template.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.JobTemplateSpecV1Beta1.property.spec"></a>

```typescript
public readonly spec: JobSpec;
```

- *Type:* cdk8s-metaflow.k8s.JobSpec

Specification of the desired behavior of the job.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### JsonSchemaProps <a name="JsonSchemaProps" id="cdk8s-metaflow.k8s.JsonSchemaProps"></a>

JSONSchemaProps is a JSON-Schema following Specification Draft 4 (http://json-schema.org/).

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.JsonSchemaProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const jsonSchemaProps: k8s.JsonSchemaProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.additionalItems">additionalItems</a></code> | <code>any</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.additionalProperties">additionalProperties</a></code> | <code>any</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.allOf">allOf</a></code> | <code>cdk8s-metaflow.k8s.JsonSchemaProps[]</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.anyOf">anyOf</a></code> | <code>cdk8s-metaflow.k8s.JsonSchemaProps[]</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.default">default</a></code> | <code>any</code> | default is a default value for undefined object fields. |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.definitions">definitions</a></code> | <code>{[ key: string ]: cdk8s-metaflow.k8s.JsonSchemaProps}</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.dependencies">dependencies</a></code> | <code>{[ key: string ]: any}</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.description">description</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.enum">enum</a></code> | <code>any[]</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.example">example</a></code> | <code>any</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.exclusiveMaximum">exclusiveMaximum</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.exclusiveMinimum">exclusiveMinimum</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.externalDocs">externalDocs</a></code> | <code>cdk8s-metaflow.k8s.ExternalDocumentation</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.format">format</a></code> | <code>string</code> | format is an OpenAPI v3 format string. Unknown formats are ignored. The following formats are validated:. |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.items">items</a></code> | <code>any</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.maximum">maximum</a></code> | <code>number</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.maxItems">maxItems</a></code> | <code>number</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.maxLength">maxLength</a></code> | <code>number</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.maxProperties">maxProperties</a></code> | <code>number</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.minimum">minimum</a></code> | <code>number</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.minItems">minItems</a></code> | <code>number</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.minLength">minLength</a></code> | <code>number</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.minProperties">minProperties</a></code> | <code>number</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.multipleOf">multipleOf</a></code> | <code>number</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.not">not</a></code> | <code>cdk8s-metaflow.k8s.JsonSchemaProps</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.nullable">nullable</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.oneOf">oneOf</a></code> | <code>cdk8s-metaflow.k8s.JsonSchemaProps[]</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.pattern">pattern</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.patternProperties">patternProperties</a></code> | <code>{[ key: string ]: cdk8s-metaflow.k8s.JsonSchemaProps}</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.properties">properties</a></code> | <code>{[ key: string ]: cdk8s-metaflow.k8s.JsonSchemaProps}</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.ref">ref</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.required">required</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.schema">schema</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.title">title</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.type">type</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.uniqueItems">uniqueItems</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.xKubernetesEmbeddedResource">xKubernetesEmbeddedResource</a></code> | <code>boolean</code> | x-kubernetes-embedded-resource defines that the value is an embedded Kubernetes runtime.Object, with TypeMeta and ObjectMeta. The type must be object. It is allowed to further restrict the embedded object. kind, apiVersion and metadata are validated automatically. x-kubernetes-preserve-unknown-fields is allowed to be true, but does not have to be if the object is fully specified (up to kind, apiVersion, metadata). |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.xKubernetesIntOrString">xKubernetesIntOrString</a></code> | <code>boolean</code> | x-kubernetes-int-or-string specifies that this value is either an integer or a string. |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.xKubernetesListMapKeys">xKubernetesListMapKeys</a></code> | <code>string[]</code> | x-kubernetes-list-map-keys annotates an array with the x-kubernetes-list-type `map` by specifying the keys used as the index of the map. |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.xKubernetesListType">xKubernetesListType</a></code> | <code>string</code> | x-kubernetes-list-type annotates an array to further describe its topology. |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.xKubernetesMapType">xKubernetesMapType</a></code> | <code>string</code> | x-kubernetes-map-type annotates an object to further describe its topology. |
| <code><a href="#cdk8s-metaflow.k8s.JsonSchemaProps.property.xKubernetesPreserveUnknownFields">xKubernetesPreserveUnknownFields</a></code> | <code>boolean</code> | x-kubernetes-preserve-unknown-fields stops the API server decoding step from pruning fields which are not specified in the validation schema. |

---

##### `additionalItems`<sup>Optional</sup> <a name="additionalItems" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.additionalItems"></a>

```typescript
public readonly additionalItems: any;
```

- *Type:* any

---

##### `additionalProperties`<sup>Optional</sup> <a name="additionalProperties" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.additionalProperties"></a>

```typescript
public readonly additionalProperties: any;
```

- *Type:* any

---

##### `allOf`<sup>Optional</sup> <a name="allOf" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.allOf"></a>

```typescript
public readonly allOf: JsonSchemaProps[];
```

- *Type:* cdk8s-metaflow.k8s.JsonSchemaProps[]

---

##### `anyOf`<sup>Optional</sup> <a name="anyOf" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.anyOf"></a>

```typescript
public readonly anyOf: JsonSchemaProps[];
```

- *Type:* cdk8s-metaflow.k8s.JsonSchemaProps[]

---

##### `default`<sup>Optional</sup> <a name="default" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.default"></a>

```typescript
public readonly default: any;
```

- *Type:* any

default is a default value for undefined object fields.

Defaulting is a beta feature under the CustomResourceDefaulting feature gate. Defaulting requires spec.preserveUnknownFields to be false.

---

##### `definitions`<sup>Optional</sup> <a name="definitions" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.definitions"></a>

```typescript
public readonly definitions: {[ key: string ]: JsonSchemaProps};
```

- *Type:* {[ key: string ]: cdk8s-metaflow.k8s.JsonSchemaProps}

---

##### `dependencies`<sup>Optional</sup> <a name="dependencies" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.dependencies"></a>

```typescript
public readonly dependencies: {[ key: string ]: any};
```

- *Type:* {[ key: string ]: any}

---

##### `description`<sup>Optional</sup> <a name="description" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* string

---

##### `enum`<sup>Optional</sup> <a name="enum" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.enum"></a>

```typescript
public readonly enum: any[];
```

- *Type:* any[]

---

##### `example`<sup>Optional</sup> <a name="example" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.example"></a>

```typescript
public readonly example: any;
```

- *Type:* any

---

##### `exclusiveMaximum`<sup>Optional</sup> <a name="exclusiveMaximum" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.exclusiveMaximum"></a>

```typescript
public readonly exclusiveMaximum: boolean;
```

- *Type:* boolean

---

##### `exclusiveMinimum`<sup>Optional</sup> <a name="exclusiveMinimum" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.exclusiveMinimum"></a>

```typescript
public readonly exclusiveMinimum: boolean;
```

- *Type:* boolean

---

##### `externalDocs`<sup>Optional</sup> <a name="externalDocs" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.externalDocs"></a>

```typescript
public readonly externalDocs: ExternalDocumentation;
```

- *Type:* cdk8s-metaflow.k8s.ExternalDocumentation

---

##### `format`<sup>Optional</sup> <a name="format" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.format"></a>

```typescript
public readonly format: string;
```

- *Type:* string

format is an OpenAPI v3 format string. Unknown formats are ignored. The following formats are validated:.

bsonobjectid: a bson object ID, i.e. a 24 characters hex string - uri: an URI as parsed by Golang net/url.ParseRequestURI - email: an email address as parsed by Golang net/mail.ParseAddress - hostname: a valid representation for an Internet host name, as defined by RFC 1034, section 3.1 [RFC1034]. - ipv4: an IPv4 IP as parsed by Golang net.ParseIP - ipv6: an IPv6 IP as parsed by Golang net.ParseIP - cidr: a CIDR as parsed by Golang net.ParseCIDR - mac: a MAC address as parsed by Golang net.ParseMAC - uuid: an UUID that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{12}$ - uuid3: an UUID3 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?3[0-9a-f]{3}-?[0-9a-f]{4}-?[0-9a-f]{12}$ - uuid4: an UUID4 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?4[0-9a-f]{3}-?[89ab][0-9a-f]{3}-?[0-9a-f]{12}$ - uuid5: an UUID5 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?5[0-9a-f]{3}-?[89ab][0-9a-f]{3}-?[0-9a-f]{12}$ - isbn: an ISBN10 or ISBN13 number string like "0321751043" or "978-0321751041" - isbn10: an ISBN10 number string like "0321751043" - isbn13: an ISBN13 number string like "978-0321751041" - creditcard: a credit card number defined by the regex ^(?:4[0-9]{12}(?:[0-9]{3})?|5[1-5][0-9]{14}|6(?:011|5[0-9][0-9])[0-9]{12}|3[47][0-9]{13}|3(?:0[0-5]|[68][0-9])[0-9]{11}|(?:2131|1800|35\d{3})\d{11})$ with any non digit characters mixed in - ssn: a U.S. social security number following the regex ^\d{3}[- ]?\d{2}[- ]?\d{4}$ - hexcolor: an hexadecimal color code like "#FFFFFF: following the regex ^#?([0-9a-fA-F]{3}|[0-9a-fA-F]{6})$ - rgbcolor: an RGB color code like rgb like "rgb(255,255,2559" - byte: base64 encoded binary data - password: any kind of string - date: a date string like "2006-01-02" as defined by full-date in RFC3339 - duration: a duration string like "22 ns" as parsed by Golang time.ParseDuration or compatible with Scala duration format - datetime: a date time string like "2014-12-15T19:30:20.000Z" as defined by date-time in RFC3339.

---

##### `id`<sup>Optional</sup> <a name="id" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

---

##### `items`<sup>Optional</sup> <a name="items" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.items"></a>

```typescript
public readonly items: any;
```

- *Type:* any

---

##### `maximum`<sup>Optional</sup> <a name="maximum" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.maximum"></a>

```typescript
public readonly maximum: number;
```

- *Type:* number

---

##### `maxItems`<sup>Optional</sup> <a name="maxItems" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.maxItems"></a>

```typescript
public readonly maxItems: number;
```

- *Type:* number

---

##### `maxLength`<sup>Optional</sup> <a name="maxLength" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.maxLength"></a>

```typescript
public readonly maxLength: number;
```

- *Type:* number

---

##### `maxProperties`<sup>Optional</sup> <a name="maxProperties" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.maxProperties"></a>

```typescript
public readonly maxProperties: number;
```

- *Type:* number

---

##### `minimum`<sup>Optional</sup> <a name="minimum" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.minimum"></a>

```typescript
public readonly minimum: number;
```

- *Type:* number

---

##### `minItems`<sup>Optional</sup> <a name="minItems" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.minItems"></a>

```typescript
public readonly minItems: number;
```

- *Type:* number

---

##### `minLength`<sup>Optional</sup> <a name="minLength" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.minLength"></a>

```typescript
public readonly minLength: number;
```

- *Type:* number

---

##### `minProperties`<sup>Optional</sup> <a name="minProperties" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.minProperties"></a>

```typescript
public readonly minProperties: number;
```

- *Type:* number

---

##### `multipleOf`<sup>Optional</sup> <a name="multipleOf" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.multipleOf"></a>

```typescript
public readonly multipleOf: number;
```

- *Type:* number

---

##### `not`<sup>Optional</sup> <a name="not" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.not"></a>

```typescript
public readonly not: JsonSchemaProps;
```

- *Type:* cdk8s-metaflow.k8s.JsonSchemaProps

---

##### `nullable`<sup>Optional</sup> <a name="nullable" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.nullable"></a>

```typescript
public readonly nullable: boolean;
```

- *Type:* boolean

---

##### `oneOf`<sup>Optional</sup> <a name="oneOf" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.oneOf"></a>

```typescript
public readonly oneOf: JsonSchemaProps[];
```

- *Type:* cdk8s-metaflow.k8s.JsonSchemaProps[]

---

##### `pattern`<sup>Optional</sup> <a name="pattern" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.pattern"></a>

```typescript
public readonly pattern: string;
```

- *Type:* string

---

##### `patternProperties`<sup>Optional</sup> <a name="patternProperties" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.patternProperties"></a>

```typescript
public readonly patternProperties: {[ key: string ]: JsonSchemaProps};
```

- *Type:* {[ key: string ]: cdk8s-metaflow.k8s.JsonSchemaProps}

---

##### `properties`<sup>Optional</sup> <a name="properties" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.properties"></a>

```typescript
public readonly properties: {[ key: string ]: JsonSchemaProps};
```

- *Type:* {[ key: string ]: cdk8s-metaflow.k8s.JsonSchemaProps}

---

##### `ref`<sup>Optional</sup> <a name="ref" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

---

##### `required`<sup>Optional</sup> <a name="required" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.required"></a>

```typescript
public readonly required: string[];
```

- *Type:* string[]

---

##### `schema`<sup>Optional</sup> <a name="schema" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.schema"></a>

```typescript
public readonly schema: string;
```

- *Type:* string

---

##### `title`<sup>Optional</sup> <a name="title" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.title"></a>

```typescript
public readonly title: string;
```

- *Type:* string

---

##### `type`<sup>Optional</sup> <a name="type" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

---

##### `uniqueItems`<sup>Optional</sup> <a name="uniqueItems" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.uniqueItems"></a>

```typescript
public readonly uniqueItems: boolean;
```

- *Type:* boolean

---

##### `xKubernetesEmbeddedResource`<sup>Optional</sup> <a name="xKubernetesEmbeddedResource" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.xKubernetesEmbeddedResource"></a>

```typescript
public readonly xKubernetesEmbeddedResource: boolean;
```

- *Type:* boolean

x-kubernetes-embedded-resource defines that the value is an embedded Kubernetes runtime.Object, with TypeMeta and ObjectMeta. The type must be object. It is allowed to further restrict the embedded object. kind, apiVersion and metadata are validated automatically. x-kubernetes-preserve-unknown-fields is allowed to be true, but does not have to be if the object is fully specified (up to kind, apiVersion, metadata).

---

##### `xKubernetesIntOrString`<sup>Optional</sup> <a name="xKubernetesIntOrString" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.xKubernetesIntOrString"></a>

```typescript
public readonly xKubernetesIntOrString: boolean;
```

- *Type:* boolean

x-kubernetes-int-or-string specifies that this value is either an integer or a string.

If this is true, an empty type is allowed and type as child of anyOf is permitted if following one of the following patterns:

1) anyOf:
- type: integer
- type: string
2) allOf:
- anyOf:
- type: integer
- type: string
- ... zero or more

---

##### `xKubernetesListMapKeys`<sup>Optional</sup> <a name="xKubernetesListMapKeys" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.xKubernetesListMapKeys"></a>

```typescript
public readonly xKubernetesListMapKeys: string[];
```

- *Type:* string[]

x-kubernetes-list-map-keys annotates an array with the x-kubernetes-list-type `map` by specifying the keys used as the index of the map.

This tag MUST only be used on lists that have the "x-kubernetes-list-type" extension set to "map". Also, the values specified for this attribute must be a scalar typed field of the child structure (no nesting is supported).

The properties specified must either be required or have a default value, to ensure those properties are present for all list items.

---

##### `xKubernetesListType`<sup>Optional</sup> <a name="xKubernetesListType" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.xKubernetesListType"></a>

```typescript
public readonly xKubernetesListType: string;
```

- *Type:* string
- *Default:* atomic for arrays.

x-kubernetes-list-type annotates an array to further describe its topology.

This extension must only be used on lists and may have 3 possible values:

1) `atomic`: the list is treated as a single entity, like a scalar.
Atomic lists will be entirely replaced when updated. This extension
may be used on any type of list (struct, scalar, ...).
2) `set`:
Sets are lists that must not have multiple items with the same value. Each
value must be a scalar, an object with x-kubernetes-map-type `atomic` or an
array with x-kubernetes-list-type `atomic`.
3) `map`:
These lists are like maps in that their elements have a non-index key
used to identify them. Order is preserved upon merge. The map tag
must only be used on a list with elements of type object.
Defaults to atomic for arrays.

---

##### `xKubernetesMapType`<sup>Optional</sup> <a name="xKubernetesMapType" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.xKubernetesMapType"></a>

```typescript
public readonly xKubernetesMapType: string;
```

- *Type:* string

x-kubernetes-map-type annotates an object to further describe its topology.

This extension must only be used when type is object and may have 2 possible values:

1) `granular`:
These maps are actual maps (key-value pairs) and each fields are independent
from each other (they can each be manipulated by separate actors). This is
the default behaviour for all maps.
2) `atomic`: the list is treated as a single entity, like a scalar.
Atomic maps will be entirely replaced when updated.

---

##### `xKubernetesPreserveUnknownFields`<sup>Optional</sup> <a name="xKubernetesPreserveUnknownFields" id="cdk8s-metaflow.k8s.JsonSchemaProps.property.xKubernetesPreserveUnknownFields"></a>

```typescript
public readonly xKubernetesPreserveUnknownFields: boolean;
```

- *Type:* boolean

x-kubernetes-preserve-unknown-fields stops the API server decoding step from pruning fields which are not specified in the validation schema.

This affects fields recursively, but switches back to normal pruning behaviour if nested properties or additionalProperties are specified in the schema. This can either be true or undefined. False is forbidden.

---

### KeyToPath <a name="KeyToPath" id="cdk8s-metaflow.k8s.KeyToPath"></a>

Maps a string key to a path within a volume.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.KeyToPath.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const keyToPath: k8s.KeyToPath = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.KeyToPath.property.key">key</a></code> | <code>string</code> | The key to project. |
| <code><a href="#cdk8s-metaflow.k8s.KeyToPath.property.path">path</a></code> | <code>string</code> | The relative path of the file to map the key to. |
| <code><a href="#cdk8s-metaflow.k8s.KeyToPath.property.mode">mode</a></code> | <code>number</code> | Optional: mode bits used to set permissions on this file. |

---

##### `key`<sup>Required</sup> <a name="key" id="cdk8s-metaflow.k8s.KeyToPath.property.key"></a>

```typescript
public readonly key: string;
```

- *Type:* string

The key to project.

---

##### `path`<sup>Required</sup> <a name="path" id="cdk8s-metaflow.k8s.KeyToPath.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* string

The relative path of the file to map the key to.

May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.

---

##### `mode`<sup>Optional</sup> <a name="mode" id="cdk8s-metaflow.k8s.KeyToPath.property.mode"></a>

```typescript
public readonly mode: number;
```

- *Type:* number

Optional: mode bits used to set permissions on this file.

Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.

---

### LabelSelector <a name="LabelSelector" id="cdk8s-metaflow.k8s.LabelSelector"></a>

A label selector is a label query over a set of resources.

The result of matchLabels and matchExpressions are ANDed. An empty label selector matches all objects. A null label selector matches no objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.LabelSelector.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const labelSelector: k8s.LabelSelector = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LabelSelector.property.matchExpressions">matchExpressions</a></code> | <code>cdk8s-metaflow.k8s.LabelSelectorRequirement[]</code> | matchExpressions is a list of label selector requirements. |
| <code><a href="#cdk8s-metaflow.k8s.LabelSelector.property.matchLabels">matchLabels</a></code> | <code>{[ key: string ]: string}</code> | matchLabels is a map of {key,value} pairs. |

---

##### `matchExpressions`<sup>Optional</sup> <a name="matchExpressions" id="cdk8s-metaflow.k8s.LabelSelector.property.matchExpressions"></a>

```typescript
public readonly matchExpressions: LabelSelectorRequirement[];
```

- *Type:* cdk8s-metaflow.k8s.LabelSelectorRequirement[]

matchExpressions is a list of label selector requirements.

The requirements are ANDed.

---

##### `matchLabels`<sup>Optional</sup> <a name="matchLabels" id="cdk8s-metaflow.k8s.LabelSelector.property.matchLabels"></a>

```typescript
public readonly matchLabels: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

matchLabels is a map of {key,value} pairs.

A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.

---

### LabelSelectorRequirement <a name="LabelSelectorRequirement" id="cdk8s-metaflow.k8s.LabelSelectorRequirement"></a>

A label selector requirement is a selector that contains values, a key, and an operator that relates the key and values.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.LabelSelectorRequirement.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const labelSelectorRequirement: k8s.LabelSelectorRequirement = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LabelSelectorRequirement.property.key">key</a></code> | <code>string</code> | key is the label key that the selector applies to. |
| <code><a href="#cdk8s-metaflow.k8s.LabelSelectorRequirement.property.operator">operator</a></code> | <code>string</code> | operator represents a key's relationship to a set of values. |
| <code><a href="#cdk8s-metaflow.k8s.LabelSelectorRequirement.property.values">values</a></code> | <code>string[]</code> | values is an array of string values. |

---

##### `key`<sup>Required</sup> <a name="key" id="cdk8s-metaflow.k8s.LabelSelectorRequirement.property.key"></a>

```typescript
public readonly key: string;
```

- *Type:* string

key is the label key that the selector applies to.

---

##### `operator`<sup>Required</sup> <a name="operator" id="cdk8s-metaflow.k8s.LabelSelectorRequirement.property.operator"></a>

```typescript
public readonly operator: string;
```

- *Type:* string

operator represents a key's relationship to a set of values.

Valid operators are In, NotIn, Exists and DoesNotExist.

---

##### `values`<sup>Optional</sup> <a name="values" id="cdk8s-metaflow.k8s.LabelSelectorRequirement.property.values"></a>

```typescript
public readonly values: string[];
```

- *Type:* string[]

values is an array of string values.

If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.

---

### LeaseListProps <a name="LeaseListProps" id="cdk8s-metaflow.k8s.LeaseListProps"></a>

LeaseList is a list of Lease objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.LeaseListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const leaseListProps: k8s.LeaseListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LeaseListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.Lease[]</code> | Items is a list of schema objects. |
| <code><a href="#cdk8s-metaflow.k8s.LeaseListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.LeaseListProps.property.items"></a>

```typescript
public readonly items: Lease[];
```

- *Type:* cdk8s-metaflow.k8s.Lease[]

Items is a list of schema objects.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.LeaseListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### LeaseProps <a name="LeaseProps" id="cdk8s-metaflow.k8s.LeaseProps"></a>

Lease defines a lease concept.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.LeaseProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const leaseProps: k8s.LeaseProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LeaseProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |
| <code><a href="#cdk8s-metaflow.k8s.LeaseProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.LeaseSpec</code> | Specification of the Lease. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.LeaseProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.LeaseProps.property.spec"></a>

```typescript
public readonly spec: LeaseSpec;
```

- *Type:* cdk8s-metaflow.k8s.LeaseSpec

Specification of the Lease.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### LeaseSpec <a name="LeaseSpec" id="cdk8s-metaflow.k8s.LeaseSpec"></a>

LeaseSpec is a specification of a Lease.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.LeaseSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const leaseSpec: k8s.LeaseSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LeaseSpec.property.acquireTime">acquireTime</a></code> | <code>Date</code> | acquireTime is a time when the current lease was acquired. |
| <code><a href="#cdk8s-metaflow.k8s.LeaseSpec.property.holderIdentity">holderIdentity</a></code> | <code>string</code> | holderIdentity contains the identity of the holder of a current lease. |
| <code><a href="#cdk8s-metaflow.k8s.LeaseSpec.property.leaseDurationSeconds">leaseDurationSeconds</a></code> | <code>number</code> | leaseDurationSeconds is a duration that candidates for a lease need to wait to force acquire it. |
| <code><a href="#cdk8s-metaflow.k8s.LeaseSpec.property.leaseTransitions">leaseTransitions</a></code> | <code>number</code> | leaseTransitions is the number of transitions of a lease between holders. |
| <code><a href="#cdk8s-metaflow.k8s.LeaseSpec.property.renewTime">renewTime</a></code> | <code>Date</code> | renewTime is a time when the current holder of a lease has last updated the lease. |

---

##### `acquireTime`<sup>Optional</sup> <a name="acquireTime" id="cdk8s-metaflow.k8s.LeaseSpec.property.acquireTime"></a>

```typescript
public readonly acquireTime: Date;
```

- *Type:* Date

acquireTime is a time when the current lease was acquired.

---

##### `holderIdentity`<sup>Optional</sup> <a name="holderIdentity" id="cdk8s-metaflow.k8s.LeaseSpec.property.holderIdentity"></a>

```typescript
public readonly holderIdentity: string;
```

- *Type:* string

holderIdentity contains the identity of the holder of a current lease.

---

##### `leaseDurationSeconds`<sup>Optional</sup> <a name="leaseDurationSeconds" id="cdk8s-metaflow.k8s.LeaseSpec.property.leaseDurationSeconds"></a>

```typescript
public readonly leaseDurationSeconds: number;
```

- *Type:* number

leaseDurationSeconds is a duration that candidates for a lease need to wait to force acquire it.

This is measure against time of last observed RenewTime.

---

##### `leaseTransitions`<sup>Optional</sup> <a name="leaseTransitions" id="cdk8s-metaflow.k8s.LeaseSpec.property.leaseTransitions"></a>

```typescript
public readonly leaseTransitions: number;
```

- *Type:* number

leaseTransitions is the number of transitions of a lease between holders.

---

##### `renewTime`<sup>Optional</sup> <a name="renewTime" id="cdk8s-metaflow.k8s.LeaseSpec.property.renewTime"></a>

```typescript
public readonly renewTime: Date;
```

- *Type:* Date

renewTime is a time when the current holder of a lease has last updated the lease.

---

### Lifecycle <a name="Lifecycle" id="cdk8s-metaflow.k8s.Lifecycle"></a>

Lifecycle describes actions that the management system should take in response to container lifecycle events.

For the PostStart and PreStop lifecycle handlers, management of the container blocks until the action is complete, unless the container process fails, in which case the handler is aborted.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.Lifecycle.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const lifecycle: k8s.Lifecycle = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Lifecycle.property.postStart">postStart</a></code> | <code>cdk8s-metaflow.k8s.Handler</code> | PostStart is called immediately after a container is created. |
| <code><a href="#cdk8s-metaflow.k8s.Lifecycle.property.preStop">preStop</a></code> | <code>cdk8s-metaflow.k8s.Handler</code> | PreStop is called immediately before a container is terminated due to an API request or management event such as liveness/startup probe failure, preemption, resource contention, etc. |

---

##### `postStart`<sup>Optional</sup> <a name="postStart" id="cdk8s-metaflow.k8s.Lifecycle.property.postStart"></a>

```typescript
public readonly postStart: Handler;
```

- *Type:* cdk8s-metaflow.k8s.Handler

PostStart is called immediately after a container is created.

If the handler fails, the container is terminated and restarted according to its restart policy. Other management of the container blocks until the hook completes. More info: https://kubernetes.io/docs/concepts/containers/container-lifecycle-hooks/#container-hooks

---

##### `preStop`<sup>Optional</sup> <a name="preStop" id="cdk8s-metaflow.k8s.Lifecycle.property.preStop"></a>

```typescript
public readonly preStop: Handler;
```

- *Type:* cdk8s-metaflow.k8s.Handler

PreStop is called immediately before a container is terminated due to an API request or management event such as liveness/startup probe failure, preemption, resource contention, etc.

The handler is not called if the container crashes or exits. The reason for termination is passed to the handler. The Pod's termination grace period countdown begins before the PreStop hooked is executed. Regardless of the outcome of the handler, the container will eventually terminate within the Pod's termination grace period. Other management of the container blocks until the hook completes or until the termination grace period is reached. More info: https://kubernetes.io/docs/concepts/containers/container-lifecycle-hooks/#container-hooks

---

### LimitedPriorityLevelConfigurationV1Beta1 <a name="LimitedPriorityLevelConfigurationV1Beta1" id="cdk8s-metaflow.k8s.LimitedPriorityLevelConfigurationV1Beta1"></a>

LimitedPriorityLevelConfiguration specifies how to handle requests that are subject to limits.

It addresses two issues:
* How are requests for this priority level limited?
* What should be done with requests that exceed the limit?

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.LimitedPriorityLevelConfigurationV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const limitedPriorityLevelConfigurationV1Beta1: k8s.LimitedPriorityLevelConfigurationV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LimitedPriorityLevelConfigurationV1Beta1.property.assuredConcurrencyShares">assuredConcurrencyShares</a></code> | <code>number</code> | `assuredConcurrencyShares` (ACS) configures the execution limit, which is a limit on the number of requests of this priority level that may be exeucting at a given time. |
| <code><a href="#cdk8s-metaflow.k8s.LimitedPriorityLevelConfigurationV1Beta1.property.limitResponse">limitResponse</a></code> | <code>cdk8s-metaflow.k8s.LimitResponseV1Beta1</code> | `limitResponse` indicates what to do with requests that can not be executed right now. |

---

##### `assuredConcurrencyShares`<sup>Optional</sup> <a name="assuredConcurrencyShares" id="cdk8s-metaflow.k8s.LimitedPriorityLevelConfigurationV1Beta1.property.assuredConcurrencyShares"></a>

```typescript
public readonly assuredConcurrencyShares: number;
```

- *Type:* number

`assuredConcurrencyShares` (ACS) configures the execution limit, which is a limit on the number of requests of this priority level that may be exeucting at a given time.

ACS must be a positive number. The server's concurrency limit (SCL) is divided among the concurrency-controlled priority levels in proportion to their assured concurrency shares. This produces the assured concurrency value (ACV) --- the number of requests that may be executing at a time --- for each such priority level:

ACV(l) = ceil( SCL * ACS(l) / ( sum[priority levels k] ACS(k) ) )

bigger numbers of ACS mean more reserved concurrent requests (at the expense of every other PL). This field has a default value of 30.

---

##### `limitResponse`<sup>Optional</sup> <a name="limitResponse" id="cdk8s-metaflow.k8s.LimitedPriorityLevelConfigurationV1Beta1.property.limitResponse"></a>

```typescript
public readonly limitResponse: LimitResponseV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.LimitResponseV1Beta1

`limitResponse` indicates what to do with requests that can not be executed right now.

---

### LimitRangeItem <a name="LimitRangeItem" id="cdk8s-metaflow.k8s.LimitRangeItem"></a>

LimitRangeItem defines a min/max usage limit for any resource that matches on kind.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.LimitRangeItem.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const limitRangeItem: k8s.LimitRangeItem = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeItem.property.type">type</a></code> | <code>string</code> | Type of resource that this limit applies to. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeItem.property.default">default</a></code> | <code>{[ key: string ]: cdk8s-metaflow.k8s.Quantity}</code> | Default resource requirement limit value by resource name if resource limit is omitted. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeItem.property.defaultRequest">defaultRequest</a></code> | <code>{[ key: string ]: cdk8s-metaflow.k8s.Quantity}</code> | DefaultRequest is the default resource requirement request value by resource name if resource request is omitted. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeItem.property.max">max</a></code> | <code>{[ key: string ]: cdk8s-metaflow.k8s.Quantity}</code> | Max usage constraints on this kind by resource name. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeItem.property.maxLimitRequestRatio">maxLimitRequestRatio</a></code> | <code>{[ key: string ]: cdk8s-metaflow.k8s.Quantity}</code> | MaxLimitRequestRatio if specified, the named resource must have a request and limit that are both non-zero where limit divided by request is less than or equal to the enumerated value; |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeItem.property.min">min</a></code> | <code>{[ key: string ]: cdk8s-metaflow.k8s.Quantity}</code> | Min usage constraints on this kind by resource name. |

---

##### `type`<sup>Required</sup> <a name="type" id="cdk8s-metaflow.k8s.LimitRangeItem.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

Type of resource that this limit applies to.

---

##### `default`<sup>Optional</sup> <a name="default" id="cdk8s-metaflow.k8s.LimitRangeItem.property.default"></a>

```typescript
public readonly default: {[ key: string ]: Quantity};
```

- *Type:* {[ key: string ]: cdk8s-metaflow.k8s.Quantity}

Default resource requirement limit value by resource name if resource limit is omitted.

---

##### `defaultRequest`<sup>Optional</sup> <a name="defaultRequest" id="cdk8s-metaflow.k8s.LimitRangeItem.property.defaultRequest"></a>

```typescript
public readonly defaultRequest: {[ key: string ]: Quantity};
```

- *Type:* {[ key: string ]: cdk8s-metaflow.k8s.Quantity}

DefaultRequest is the default resource requirement request value by resource name if resource request is omitted.

---

##### `max`<sup>Optional</sup> <a name="max" id="cdk8s-metaflow.k8s.LimitRangeItem.property.max"></a>

```typescript
public readonly max: {[ key: string ]: Quantity};
```

- *Type:* {[ key: string ]: cdk8s-metaflow.k8s.Quantity}

Max usage constraints on this kind by resource name.

---

##### `maxLimitRequestRatio`<sup>Optional</sup> <a name="maxLimitRequestRatio" id="cdk8s-metaflow.k8s.LimitRangeItem.property.maxLimitRequestRatio"></a>

```typescript
public readonly maxLimitRequestRatio: {[ key: string ]: Quantity};
```

- *Type:* {[ key: string ]: cdk8s-metaflow.k8s.Quantity}

MaxLimitRequestRatio if specified, the named resource must have a request and limit that are both non-zero where limit divided by request is less than or equal to the enumerated value;

this represents the max burst for the named resource.

---

##### `min`<sup>Optional</sup> <a name="min" id="cdk8s-metaflow.k8s.LimitRangeItem.property.min"></a>

```typescript
public readonly min: {[ key: string ]: Quantity};
```

- *Type:* {[ key: string ]: cdk8s-metaflow.k8s.Quantity}

Min usage constraints on this kind by resource name.

---

### LimitRangeListProps <a name="LimitRangeListProps" id="cdk8s-metaflow.k8s.LimitRangeListProps"></a>

LimitRangeList is a list of LimitRange items.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.LimitRangeListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const limitRangeListProps: k8s.LimitRangeListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.LimitRange[]</code> | Items is a list of LimitRange objects. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.LimitRangeListProps.property.items"></a>

```typescript
public readonly items: LimitRange[];
```

- *Type:* cdk8s-metaflow.k8s.LimitRange[]

Items is a list of LimitRange objects.

More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.LimitRangeListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

### LimitRangeProps <a name="LimitRangeProps" id="cdk8s-metaflow.k8s.LimitRangeProps"></a>

LimitRange sets resource usage limits for each kind of resource in a Namespace.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.LimitRangeProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const limitRangeProps: k8s.LimitRangeProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.LimitRangeSpec</code> | Spec defines the limits enforced. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.LimitRangeProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.LimitRangeProps.property.spec"></a>

```typescript
public readonly spec: LimitRangeSpec;
```

- *Type:* cdk8s-metaflow.k8s.LimitRangeSpec

Spec defines the limits enforced.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### LimitRangeSpec <a name="LimitRangeSpec" id="cdk8s-metaflow.k8s.LimitRangeSpec"></a>

LimitRangeSpec defines a min/max usage limit for resources that match on kind.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.LimitRangeSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const limitRangeSpec: k8s.LimitRangeSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LimitRangeSpec.property.limits">limits</a></code> | <code>cdk8s-metaflow.k8s.LimitRangeItem[]</code> | Limits is the list of LimitRangeItem objects that are enforced. |

---

##### `limits`<sup>Required</sup> <a name="limits" id="cdk8s-metaflow.k8s.LimitRangeSpec.property.limits"></a>

```typescript
public readonly limits: LimitRangeItem[];
```

- *Type:* cdk8s-metaflow.k8s.LimitRangeItem[]

Limits is the list of LimitRangeItem objects that are enforced.

---

### LimitResponseV1Beta1 <a name="LimitResponseV1Beta1" id="cdk8s-metaflow.k8s.LimitResponseV1Beta1"></a>

LimitResponse defines how to handle requests that can not be executed right now.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.LimitResponseV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const limitResponseV1Beta1: k8s.LimitResponseV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LimitResponseV1Beta1.property.type">type</a></code> | <code>string</code> | `type` is "Queue" or "Reject". |
| <code><a href="#cdk8s-metaflow.k8s.LimitResponseV1Beta1.property.queuing">queuing</a></code> | <code>cdk8s-metaflow.k8s.QueuingConfigurationV1Beta1</code> | `queuing` holds the configuration parameters for queuing. |

---

##### `type`<sup>Required</sup> <a name="type" id="cdk8s-metaflow.k8s.LimitResponseV1Beta1.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

`type` is "Queue" or "Reject".

"Queue" means that requests that can not be executed upon arrival are held in a queue until they can be executed or a queuing limit is reached. "Reject" means that requests that can not be executed upon arrival are rejected. Required.

---

##### `queuing`<sup>Optional</sup> <a name="queuing" id="cdk8s-metaflow.k8s.LimitResponseV1Beta1.property.queuing"></a>

```typescript
public readonly queuing: QueuingConfigurationV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.QueuingConfigurationV1Beta1

`queuing` holds the configuration parameters for queuing.

This field may be non-empty only if `type` is `"Queue"`.

---

### ListMeta <a name="ListMeta" id="cdk8s-metaflow.k8s.ListMeta"></a>

ListMeta describes metadata that synthetic resources must have, including lists and various status objects.

A resource may have only one of {ObjectMeta, ListMeta}.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ListMeta.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const listMeta: k8s.ListMeta = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ListMeta.property.continue">continue</a></code> | <code>string</code> | continue may be set if the user set a limit on the number of items returned, and indicates that the server has more data available. |
| <code><a href="#cdk8s-metaflow.k8s.ListMeta.property.remainingItemCount">remainingItemCount</a></code> | <code>number</code> | remainingItemCount is the number of subsequent items in the list which are not included in this list response. |
| <code><a href="#cdk8s-metaflow.k8s.ListMeta.property.resourceVersion">resourceVersion</a></code> | <code>string</code> | String that identifies the server's internal version of this object that can be used by clients to determine when objects have changed. |
| <code><a href="#cdk8s-metaflow.k8s.ListMeta.property.selfLink">selfLink</a></code> | <code>string</code> | selfLink is a URL representing this object. Populated by the system. Read-only. |

---

##### `continue`<sup>Optional</sup> <a name="continue" id="cdk8s-metaflow.k8s.ListMeta.property.continue"></a>

```typescript
public readonly continue: string;
```

- *Type:* string

continue may be set if the user set a limit on the number of items returned, and indicates that the server has more data available.

The value is opaque and may be used to issue another request to the endpoint that served this list to retrieve the next set of available objects. Continuing a consistent list may not be possible if the server configuration has changed or more than a few minutes have passed. The resourceVersion field returned when using this continue value will be identical to the value in the first response, unless you have received this token from an error message.

---

##### `remainingItemCount`<sup>Optional</sup> <a name="remainingItemCount" id="cdk8s-metaflow.k8s.ListMeta.property.remainingItemCount"></a>

```typescript
public readonly remainingItemCount: number;
```

- *Type:* number

remainingItemCount is the number of subsequent items in the list which are not included in this list response.

If the list request contained label or field selectors, then the number of remaining items is unknown and the field will be left unset and omitted during serialization. If the list is complete (either because it is not chunking or because this is the last chunk), then there are no more remaining items and this field will be left unset and omitted during serialization. Servers older than v1.15 do not set this field. The intended use of the remainingItemCount is *estimating* the size of a collection. Clients should not rely on the remainingItemCount to be set or to be exact.

---

##### `resourceVersion`<sup>Optional</sup> <a name="resourceVersion" id="cdk8s-metaflow.k8s.ListMeta.property.resourceVersion"></a>

```typescript
public readonly resourceVersion: string;
```

- *Type:* string

String that identifies the server's internal version of this object that can be used by clients to determine when objects have changed.

Value must be treated as opaque by clients and passed unmodified back to the server. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#concurrency-control-and-consistency

---

##### `selfLink`<sup>Optional</sup> <a name="selfLink" id="cdk8s-metaflow.k8s.ListMeta.property.selfLink"></a>

```typescript
public readonly selfLink: string;
```

- *Type:* string

selfLink is a URL representing this object. Populated by the system. Read-only.

DEPRECATED Kubernetes will stop propagating this field in 1.20 release and the field is planned to be removed in 1.21 release.

---

### LocalObjectReference <a name="LocalObjectReference" id="cdk8s-metaflow.k8s.LocalObjectReference"></a>

LocalObjectReference contains enough information to let you locate the referenced object inside the same namespace.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.LocalObjectReference.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const localObjectReference: k8s.LocalObjectReference = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LocalObjectReference.property.name">name</a></code> | <code>string</code> | Name of the referent. |

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.LocalObjectReference.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the referent.

More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names

---

### LocalSubjectAccessReviewProps <a name="LocalSubjectAccessReviewProps" id="cdk8s-metaflow.k8s.LocalSubjectAccessReviewProps"></a>

LocalSubjectAccessReview checks whether or not a user or group can perform an action in a given namespace.

Having a namespace scoped resource makes it much easier to grant namespace scoped policy that includes permissions checking.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.LocalSubjectAccessReviewProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const localSubjectAccessReviewProps: k8s.LocalSubjectAccessReviewProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReviewProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.SubjectAccessReviewSpec</code> | Spec holds information about the request being evaluated. |
| <code><a href="#cdk8s-metaflow.k8s.LocalSubjectAccessReviewProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard list metadata. |

---

##### `spec`<sup>Required</sup> <a name="spec" id="cdk8s-metaflow.k8s.LocalSubjectAccessReviewProps.property.spec"></a>

```typescript
public readonly spec: SubjectAccessReviewSpec;
```

- *Type:* cdk8s-metaflow.k8s.SubjectAccessReviewSpec

Spec holds information about the request being evaluated.

spec.namespace must be equal to the namespace you made the request against.  If empty, it is defaulted.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.LocalSubjectAccessReviewProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### LocalVolumeSource <a name="LocalVolumeSource" id="cdk8s-metaflow.k8s.LocalVolumeSource"></a>

Local represents directly-attached storage with node affinity (Beta feature).

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.LocalVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const localVolumeSource: k8s.LocalVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.LocalVolumeSource.property.path">path</a></code> | <code>string</code> | The full path to the volume on the node. |
| <code><a href="#cdk8s-metaflow.k8s.LocalVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type to mount. |

---

##### `path`<sup>Required</sup> <a name="path" id="cdk8s-metaflow.k8s.LocalVolumeSource.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* string

The full path to the volume on the node.

It can be either a directory or block device (disk, partition, ...).

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.LocalVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type to mount.

It applies only when the Path is a block device. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default value is to auto-select a fileystem if unspecified.

---

### ManagedFieldsEntry <a name="ManagedFieldsEntry" id="cdk8s-metaflow.k8s.ManagedFieldsEntry"></a>

ManagedFieldsEntry is a workflow-id, a FieldSet and the group version of the resource that the fieldset applies to.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ManagedFieldsEntry.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const managedFieldsEntry: k8s.ManagedFieldsEntry = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ManagedFieldsEntry.property.apiVersion">apiVersion</a></code> | <code>string</code> | APIVersion defines the version of this resource that this field set applies to. |
| <code><a href="#cdk8s-metaflow.k8s.ManagedFieldsEntry.property.fieldsType">fieldsType</a></code> | <code>string</code> | FieldsType is the discriminator for the different fields format and version. |
| <code><a href="#cdk8s-metaflow.k8s.ManagedFieldsEntry.property.fieldsV1">fieldsV1</a></code> | <code>any</code> | FieldsV1 holds the first JSON version format as described in the "FieldsV1" type. |
| <code><a href="#cdk8s-metaflow.k8s.ManagedFieldsEntry.property.manager">manager</a></code> | <code>string</code> | Manager is an identifier of the workflow managing these fields. |
| <code><a href="#cdk8s-metaflow.k8s.ManagedFieldsEntry.property.operation">operation</a></code> | <code>string</code> | Operation is the type of operation which lead to this ManagedFieldsEntry being created. |
| <code><a href="#cdk8s-metaflow.k8s.ManagedFieldsEntry.property.subresource">subresource</a></code> | <code>string</code> | Subresource is the name of the subresource used to update that object, or empty string if the object was updated through the main resource. |
| <code><a href="#cdk8s-metaflow.k8s.ManagedFieldsEntry.property.time">time</a></code> | <code>Date</code> | Time is timestamp of when these fields were set. |

---

##### `apiVersion`<sup>Optional</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ManagedFieldsEntry.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

APIVersion defines the version of this resource that this field set applies to.

The format is "group/version" just like the top-level APIVersion field. It is necessary to track the version of a field set because it cannot be automatically converted.

---

##### `fieldsType`<sup>Optional</sup> <a name="fieldsType" id="cdk8s-metaflow.k8s.ManagedFieldsEntry.property.fieldsType"></a>

```typescript
public readonly fieldsType: string;
```

- *Type:* string

FieldsType is the discriminator for the different fields format and version.

There is currently only one possible value: "FieldsV1"

---

##### `fieldsV1`<sup>Optional</sup> <a name="fieldsV1" id="cdk8s-metaflow.k8s.ManagedFieldsEntry.property.fieldsV1"></a>

```typescript
public readonly fieldsV1: any;
```

- *Type:* any

FieldsV1 holds the first JSON version format as described in the "FieldsV1" type.

---

##### `manager`<sup>Optional</sup> <a name="manager" id="cdk8s-metaflow.k8s.ManagedFieldsEntry.property.manager"></a>

```typescript
public readonly manager: string;
```

- *Type:* string

Manager is an identifier of the workflow managing these fields.

---

##### `operation`<sup>Optional</sup> <a name="operation" id="cdk8s-metaflow.k8s.ManagedFieldsEntry.property.operation"></a>

```typescript
public readonly operation: string;
```

- *Type:* string

Operation is the type of operation which lead to this ManagedFieldsEntry being created.

The only valid values for this field are 'Apply' and 'Update'.

---

##### `subresource`<sup>Optional</sup> <a name="subresource" id="cdk8s-metaflow.k8s.ManagedFieldsEntry.property.subresource"></a>

```typescript
public readonly subresource: string;
```

- *Type:* string

Subresource is the name of the subresource used to update that object, or empty string if the object was updated through the main resource.

The value of this field is used to distinguish between managers, even if they share the same name. For example, a status update will be distinct from a regular update using the same manager name. Note that the APIVersion field is not related to the Subresource field and it always corresponds to the version of the main resource.

---

##### `time`<sup>Optional</sup> <a name="time" id="cdk8s-metaflow.k8s.ManagedFieldsEntry.property.time"></a>

```typescript
public readonly time: Date;
```

- *Type:* Date

Time is timestamp of when these fields were set.

It should always be empty if Operation is 'Apply'

---

### MetadataDatabaseEnvOptions <a name="MetadataDatabaseEnvOptions" id="cdk8s-metaflow.MetadataDatabaseEnvOptions"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.MetadataDatabaseEnvOptions.Initializer"></a>

```typescript
import { MetadataDatabaseEnvOptions } from 'cdk8s-metaflow'

const metadataDatabaseEnvOptions: MetadataDatabaseEnvOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.MetadataDatabaseEnvOptions.property.host">host</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetadataDatabaseEnvOptions.property.password">password</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetadataDatabaseEnvOptions.property.port">port</a></code> | <code>number</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetadataDatabaseEnvOptions.property.user">user</a></code> | <code>string</code> | *No description.* |

---

##### `host`<sup>Optional</sup> <a name="host" id="cdk8s-metaflow.MetadataDatabaseEnvOptions.property.host"></a>

```typescript
public readonly host: string;
```

- *Type:* string

---

##### `password`<sup>Optional</sup> <a name="password" id="cdk8s-metaflow.MetadataDatabaseEnvOptions.property.password"></a>

```typescript
public readonly password: string;
```

- *Type:* string

---

##### `port`<sup>Optional</sup> <a name="port" id="cdk8s-metaflow.MetadataDatabaseEnvOptions.property.port"></a>

```typescript
public readonly port: number;
```

- *Type:* number

---

##### `user`<sup>Optional</sup> <a name="user" id="cdk8s-metaflow.MetadataDatabaseEnvOptions.property.user"></a>

```typescript
public readonly user: string;
```

- *Type:* string

---

### MetadataDatabaseOptions <a name="MetadataDatabaseOptions" id="cdk8s-metaflow.MetadataDatabaseOptions"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.MetadataDatabaseOptions.Initializer"></a>

```typescript
import { MetadataDatabaseOptions } from 'cdk8s-metaflow'

const metadataDatabaseOptions: MetadataDatabaseOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.MetadataDatabaseOptions.property.architecture">architecture</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetadataDatabaseOptions.property.auth">auth</a></code> | <code><a href="#cdk8s-metaflow.DatabaseAuthOptions">DatabaseAuthOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetadataDatabaseOptions.property.metrics">metrics</a></code> | <code><a href="#cdk8s-metaflow.DatabaseMetricsOptions">DatabaseMetricsOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetadataDatabaseOptions.property.replication">replication</a></code> | <code><a href="#cdk8s-metaflow.DatabaseReplicationOptions">DatabaseReplicationOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetadataDatabaseOptions.property.resources">resources</a></code> | <code><a href="#cdk8s-metaflow.DatabaseResourcesOptions">DatabaseResourcesOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetadataDatabaseOptions.property.volumePermissions">volumePermissions</a></code> | <code><a href="#cdk8s-metaflow.DatabaseVolumePermissionsOptions">DatabaseVolumePermissionsOptions</a></code> | *No description.* |

---

##### `architecture`<sup>Optional</sup> <a name="architecture" id="cdk8s-metaflow.MetadataDatabaseOptions.property.architecture"></a>

```typescript
public readonly architecture: string;
```

- *Type:* string

---

##### `auth`<sup>Optional</sup> <a name="auth" id="cdk8s-metaflow.MetadataDatabaseOptions.property.auth"></a>

```typescript
public readonly auth: DatabaseAuthOptions;
```

- *Type:* <a href="#cdk8s-metaflow.DatabaseAuthOptions">DatabaseAuthOptions</a>

---

##### `metrics`<sup>Optional</sup> <a name="metrics" id="cdk8s-metaflow.MetadataDatabaseOptions.property.metrics"></a>

```typescript
public readonly metrics: DatabaseMetricsOptions;
```

- *Type:* <a href="#cdk8s-metaflow.DatabaseMetricsOptions">DatabaseMetricsOptions</a>

---

##### `replication`<sup>Optional</sup> <a name="replication" id="cdk8s-metaflow.MetadataDatabaseOptions.property.replication"></a>

```typescript
public readonly replication: DatabaseReplicationOptions;
```

- *Type:* <a href="#cdk8s-metaflow.DatabaseReplicationOptions">DatabaseReplicationOptions</a>

---

##### `resources`<sup>Optional</sup> <a name="resources" id="cdk8s-metaflow.MetadataDatabaseOptions.property.resources"></a>

```typescript
public readonly resources: DatabaseResourcesOptions;
```

- *Type:* <a href="#cdk8s-metaflow.DatabaseResourcesOptions">DatabaseResourcesOptions</a>

---

##### `volumePermissions`<sup>Optional</sup> <a name="volumePermissions" id="cdk8s-metaflow.MetadataDatabaseOptions.property.volumePermissions"></a>

```typescript
public readonly volumePermissions: DatabaseVolumePermissionsOptions;
```

- *Type:* <a href="#cdk8s-metaflow.DatabaseVolumePermissionsOptions">DatabaseVolumePermissionsOptions</a>

---

### MetadataDatabaseProps <a name="MetadataDatabaseProps" id="cdk8s-metaflow.MetadataDatabaseProps"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.MetadataDatabaseProps.Initializer"></a>

```typescript
import { MetadataDatabaseProps } from 'cdk8s-metaflow'

const metadataDatabaseProps: MetadataDatabaseProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.MetadataDatabaseProps.property.chartVersion">chartVersion</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetadataDatabaseProps.property.chartValues">chartValues</a></code> | <code><a href="#cdk8s-metaflow.MetadataDatabaseOptions">MetadataDatabaseOptions</a></code> | *No description.* |

---

##### `chartVersion`<sup>Required</sup> <a name="chartVersion" id="cdk8s-metaflow.MetadataDatabaseProps.property.chartVersion"></a>

```typescript
public readonly chartVersion: string;
```

- *Type:* string

---

##### `chartValues`<sup>Optional</sup> <a name="chartValues" id="cdk8s-metaflow.MetadataDatabaseProps.property.chartValues"></a>

```typescript
public readonly chartValues: MetadataDatabaseOptions;
```

- *Type:* <a href="#cdk8s-metaflow.MetadataDatabaseOptions">MetadataDatabaseOptions</a>

---

### MetaflowServiceOptions <a name="MetaflowServiceOptions" id="cdk8s-metaflow.MetaflowServiceOptions"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.MetaflowServiceOptions.Initializer"></a>

```typescript
import { MetaflowServiceOptions } from 'cdk8s-metaflow'

const metaflowServiceOptions: MetaflowServiceOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.affinity">affinity</a></code> | <code>cdk8s-metaflow.k8s.Affinity</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.autoscaling">autoscaling</a></code> | <code><a href="#cdk8s-metaflow.AutoscalingOptions">AutoscalingOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.dbMigrations">dbMigrations</a></code> | <code><a href="#cdk8s-metaflow.DbMigrationOptions">DbMigrationOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.envFrom">envFrom</a></code> | <code>cdk8s-metaflow.k8s.EnvFromSource[]</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.fullnameOverride">fullnameOverride</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.image">image</a></code> | <code><a href="#cdk8s-metaflow.ImageOptions">ImageOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.imagePullSecrets">imagePullSecrets</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.ingress">ingress</a></code> | <code><a href="#cdk8s-metaflow.IngressOptions">IngressOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.metadatadb">metadatadb</a></code> | <code><a href="#cdk8s-metaflow.MetadataDatabaseEnvOptions">MetadataDatabaseEnvOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.nameOverride">nameOverride</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.nodeSelector">nodeSelector</a></code> | <code>{[ key: string ]: string}</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.podAnnotations">podAnnotations</a></code> | <code>{[ key: string ]: string}</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.podSecurityContext">podSecurityContext</a></code> | <code>{[ key: string ]: string}</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.replicaCount">replicaCount</a></code> | <code>number</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.resources">resources</a></code> | <code><a href="#cdk8s-metaflow.IApiResource">IApiResource</a>[]</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.securityContext">securityContext</a></code> | <code>cdk8s-metaflow.k8s.SecurityContext</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.service">service</a></code> | <code><a href="#cdk8s-metaflow.ServiceOptions">ServiceOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.serviceAccount">serviceAccount</a></code> | <code><a href="#cdk8s-metaflow.ServiceAccountOptions">ServiceAccountOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceOptions.property.tolerations">tolerations</a></code> | <code>cdk8s-metaflow.k8s.Toleration[]</code> | *No description.* |

---

##### `affinity`<sup>Optional</sup> <a name="affinity" id="cdk8s-metaflow.MetaflowServiceOptions.property.affinity"></a>

```typescript
public readonly affinity: Affinity;
```

- *Type:* cdk8s-metaflow.k8s.Affinity

---

##### `autoscaling`<sup>Optional</sup> <a name="autoscaling" id="cdk8s-metaflow.MetaflowServiceOptions.property.autoscaling"></a>

```typescript
public readonly autoscaling: AutoscalingOptions;
```

- *Type:* <a href="#cdk8s-metaflow.AutoscalingOptions">AutoscalingOptions</a>

---

##### `dbMigrations`<sup>Optional</sup> <a name="dbMigrations" id="cdk8s-metaflow.MetaflowServiceOptions.property.dbMigrations"></a>

```typescript
public readonly dbMigrations: DbMigrationOptions;
```

- *Type:* <a href="#cdk8s-metaflow.DbMigrationOptions">DbMigrationOptions</a>

---

##### `envFrom`<sup>Optional</sup> <a name="envFrom" id="cdk8s-metaflow.MetaflowServiceOptions.property.envFrom"></a>

```typescript
public readonly envFrom: EnvFromSource[];
```

- *Type:* cdk8s-metaflow.k8s.EnvFromSource[]

---

##### `fullnameOverride`<sup>Optional</sup> <a name="fullnameOverride" id="cdk8s-metaflow.MetaflowServiceOptions.property.fullnameOverride"></a>

```typescript
public readonly fullnameOverride: string;
```

- *Type:* string

---

##### `image`<sup>Optional</sup> <a name="image" id="cdk8s-metaflow.MetaflowServiceOptions.property.image"></a>

```typescript
public readonly image: ImageOptions;
```

- *Type:* <a href="#cdk8s-metaflow.ImageOptions">ImageOptions</a>

---

##### `imagePullSecrets`<sup>Optional</sup> <a name="imagePullSecrets" id="cdk8s-metaflow.MetaflowServiceOptions.property.imagePullSecrets"></a>

```typescript
public readonly imagePullSecrets: string[];
```

- *Type:* string[]

---

##### `ingress`<sup>Optional</sup> <a name="ingress" id="cdk8s-metaflow.MetaflowServiceOptions.property.ingress"></a>

```typescript
public readonly ingress: IngressOptions;
```

- *Type:* <a href="#cdk8s-metaflow.IngressOptions">IngressOptions</a>

---

##### `metadatadb`<sup>Optional</sup> <a name="metadatadb" id="cdk8s-metaflow.MetaflowServiceOptions.property.metadatadb"></a>

```typescript
public readonly metadatadb: MetadataDatabaseEnvOptions;
```

- *Type:* <a href="#cdk8s-metaflow.MetadataDatabaseEnvOptions">MetadataDatabaseEnvOptions</a>

---

##### `nameOverride`<sup>Optional</sup> <a name="nameOverride" id="cdk8s-metaflow.MetaflowServiceOptions.property.nameOverride"></a>

```typescript
public readonly nameOverride: string;
```

- *Type:* string

---

##### `nodeSelector`<sup>Optional</sup> <a name="nodeSelector" id="cdk8s-metaflow.MetaflowServiceOptions.property.nodeSelector"></a>

```typescript
public readonly nodeSelector: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

---

##### `podAnnotations`<sup>Optional</sup> <a name="podAnnotations" id="cdk8s-metaflow.MetaflowServiceOptions.property.podAnnotations"></a>

```typescript
public readonly podAnnotations: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

---

##### `podSecurityContext`<sup>Optional</sup> <a name="podSecurityContext" id="cdk8s-metaflow.MetaflowServiceOptions.property.podSecurityContext"></a>

```typescript
public readonly podSecurityContext: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

---

##### `replicaCount`<sup>Optional</sup> <a name="replicaCount" id="cdk8s-metaflow.MetaflowServiceOptions.property.replicaCount"></a>

```typescript
public readonly replicaCount: number;
```

- *Type:* number

---

##### `resources`<sup>Optional</sup> <a name="resources" id="cdk8s-metaflow.MetaflowServiceOptions.property.resources"></a>

```typescript
public readonly resources: IApiResource[];
```

- *Type:* <a href="#cdk8s-metaflow.IApiResource">IApiResource</a>[]

---

##### `securityContext`<sup>Optional</sup> <a name="securityContext" id="cdk8s-metaflow.MetaflowServiceOptions.property.securityContext"></a>

```typescript
public readonly securityContext: SecurityContext;
```

- *Type:* cdk8s-metaflow.k8s.SecurityContext

---

##### `service`<sup>Optional</sup> <a name="service" id="cdk8s-metaflow.MetaflowServiceOptions.property.service"></a>

```typescript
public readonly service: ServiceOptions;
```

- *Type:* <a href="#cdk8s-metaflow.ServiceOptions">ServiceOptions</a>

---

##### `serviceAccount`<sup>Optional</sup> <a name="serviceAccount" id="cdk8s-metaflow.MetaflowServiceOptions.property.serviceAccount"></a>

```typescript
public readonly serviceAccount: ServiceAccountOptions;
```

- *Type:* <a href="#cdk8s-metaflow.ServiceAccountOptions">ServiceAccountOptions</a>

---

##### `tolerations`<sup>Optional</sup> <a name="tolerations" id="cdk8s-metaflow.MetaflowServiceOptions.property.tolerations"></a>

```typescript
public readonly tolerations: Toleration[];
```

- *Type:* cdk8s-metaflow.k8s.Toleration[]

---

### MetaflowServiceProps <a name="MetaflowServiceProps" id="cdk8s-metaflow.MetaflowServiceProps"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.MetaflowServiceProps.Initializer"></a>

```typescript
import { MetaflowServiceProps } from 'cdk8s-metaflow'

const metaflowServiceProps: MetaflowServiceProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.MetaflowServiceProps.property.chartVersion">chartVersion</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowServiceProps.property.chartValues">chartValues</a></code> | <code><a href="#cdk8s-metaflow.MetaflowServiceOptions">MetaflowServiceOptions</a></code> | *No description.* |

---

##### `chartVersion`<sup>Required</sup> <a name="chartVersion" id="cdk8s-metaflow.MetaflowServiceProps.property.chartVersion"></a>

```typescript
public readonly chartVersion: string;
```

- *Type:* string

---

##### `chartValues`<sup>Optional</sup> <a name="chartValues" id="cdk8s-metaflow.MetaflowServiceProps.property.chartValues"></a>

```typescript
public readonly chartValues: MetaflowServiceOptions;
```

- *Type:* <a href="#cdk8s-metaflow.MetaflowServiceOptions">MetaflowServiceOptions</a>

---

### MetaflowUIOptions <a name="MetaflowUIOptions" id="cdk8s-metaflow.MetaflowUIOptions"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.MetaflowUIOptions.Initializer"></a>

```typescript
import { MetaflowUIOptions } from 'cdk8s-metaflow'

const metaflowUIOptions: MetaflowUIOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.affinity">affinity</a></code> | <code>cdk8s-metaflow.k8s.Affinity</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.autoscaling">autoscaling</a></code> | <code><a href="#cdk8s-metaflow.AutoscalingOptions">AutoscalingOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.env">env</a></code> | <code>{[ key: string ]: string}</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.envFrom">envFrom</a></code> | <code>cdk8s-metaflow.k8s.EnvFromSource[]</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.fullnameOverride">fullnameOverride</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.image">image</a></code> | <code><a href="#cdk8s-metaflow.ImageOptions">ImageOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.imagePullSecrets">imagePullSecrets</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.ingress">ingress</a></code> | <code><a href="#cdk8s-metaflow.IngressOptions">IngressOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.metadatadb">metadatadb</a></code> | <code><a href="#cdk8s-metaflow.MetadataDatabaseEnvOptions">MetadataDatabaseEnvOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.metaflowDatastoreSysrootS3">metaflowDatastoreSysrootS3</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.nameOverride">nameOverride</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.nodeSelector">nodeSelector</a></code> | <code>{[ key: string ]: string}</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.podAnnotations">podAnnotations</a></code> | <code>{[ key: string ]: string}</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.podSecurityContext">podSecurityContext</a></code> | <code>{[ key: string ]: string}</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.replicaCount">replicaCount</a></code> | <code>number</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.resources">resources</a></code> | <code><a href="#cdk8s-metaflow.IApiResource">IApiResource</a>[]</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.securityContext">securityContext</a></code> | <code>cdk8s-metaflow.k8s.SecurityContext</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.service">service</a></code> | <code><a href="#cdk8s-metaflow.ServiceOptions">ServiceOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.serviceAccount">serviceAccount</a></code> | <code><a href="#cdk8s-metaflow.ServiceAccountOptions">ServiceAccountOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.serviceStatic">serviceStatic</a></code> | <code><a href="#cdk8s-metaflow.ServiceOptions">ServiceOptions</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.tolerations">tolerations</a></code> | <code>cdk8s-metaflow.k8s.Toleration[]</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIOptions.property.uiImage">uiImage</a></code> | <code><a href="#cdk8s-metaflow.ImageOptions">ImageOptions</a></code> | *No description.* |

---

##### `affinity`<sup>Optional</sup> <a name="affinity" id="cdk8s-metaflow.MetaflowUIOptions.property.affinity"></a>

```typescript
public readonly affinity: Affinity;
```

- *Type:* cdk8s-metaflow.k8s.Affinity

---

##### `autoscaling`<sup>Optional</sup> <a name="autoscaling" id="cdk8s-metaflow.MetaflowUIOptions.property.autoscaling"></a>

```typescript
public readonly autoscaling: AutoscalingOptions;
```

- *Type:* <a href="#cdk8s-metaflow.AutoscalingOptions">AutoscalingOptions</a>

---

##### `env`<sup>Optional</sup> <a name="env" id="cdk8s-metaflow.MetaflowUIOptions.property.env"></a>

```typescript
public readonly env: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

---

##### `envFrom`<sup>Optional</sup> <a name="envFrom" id="cdk8s-metaflow.MetaflowUIOptions.property.envFrom"></a>

```typescript
public readonly envFrom: EnvFromSource[];
```

- *Type:* cdk8s-metaflow.k8s.EnvFromSource[]

---

##### `fullnameOverride`<sup>Optional</sup> <a name="fullnameOverride" id="cdk8s-metaflow.MetaflowUIOptions.property.fullnameOverride"></a>

```typescript
public readonly fullnameOverride: string;
```

- *Type:* string

---

##### `image`<sup>Optional</sup> <a name="image" id="cdk8s-metaflow.MetaflowUIOptions.property.image"></a>

```typescript
public readonly image: ImageOptions;
```

- *Type:* <a href="#cdk8s-metaflow.ImageOptions">ImageOptions</a>

---

##### `imagePullSecrets`<sup>Optional</sup> <a name="imagePullSecrets" id="cdk8s-metaflow.MetaflowUIOptions.property.imagePullSecrets"></a>

```typescript
public readonly imagePullSecrets: string[];
```

- *Type:* string[]

---

##### `ingress`<sup>Optional</sup> <a name="ingress" id="cdk8s-metaflow.MetaflowUIOptions.property.ingress"></a>

```typescript
public readonly ingress: IngressOptions;
```

- *Type:* <a href="#cdk8s-metaflow.IngressOptions">IngressOptions</a>

---

##### `metadatadb`<sup>Optional</sup> <a name="metadatadb" id="cdk8s-metaflow.MetaflowUIOptions.property.metadatadb"></a>

```typescript
public readonly metadatadb: MetadataDatabaseEnvOptions;
```

- *Type:* <a href="#cdk8s-metaflow.MetadataDatabaseEnvOptions">MetadataDatabaseEnvOptions</a>

---

##### `metaflowDatastoreSysrootS3`<sup>Optional</sup> <a name="metaflowDatastoreSysrootS3" id="cdk8s-metaflow.MetaflowUIOptions.property.metaflowDatastoreSysrootS3"></a>

```typescript
public readonly metaflowDatastoreSysrootS3: string;
```

- *Type:* string

---

##### `nameOverride`<sup>Optional</sup> <a name="nameOverride" id="cdk8s-metaflow.MetaflowUIOptions.property.nameOverride"></a>

```typescript
public readonly nameOverride: string;
```

- *Type:* string

---

##### `nodeSelector`<sup>Optional</sup> <a name="nodeSelector" id="cdk8s-metaflow.MetaflowUIOptions.property.nodeSelector"></a>

```typescript
public readonly nodeSelector: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

---

##### `podAnnotations`<sup>Optional</sup> <a name="podAnnotations" id="cdk8s-metaflow.MetaflowUIOptions.property.podAnnotations"></a>

```typescript
public readonly podAnnotations: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

---

##### `podSecurityContext`<sup>Optional</sup> <a name="podSecurityContext" id="cdk8s-metaflow.MetaflowUIOptions.property.podSecurityContext"></a>

```typescript
public readonly podSecurityContext: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

---

##### `replicaCount`<sup>Optional</sup> <a name="replicaCount" id="cdk8s-metaflow.MetaflowUIOptions.property.replicaCount"></a>

```typescript
public readonly replicaCount: number;
```

- *Type:* number

---

##### `resources`<sup>Optional</sup> <a name="resources" id="cdk8s-metaflow.MetaflowUIOptions.property.resources"></a>

```typescript
public readonly resources: IApiResource[];
```

- *Type:* <a href="#cdk8s-metaflow.IApiResource">IApiResource</a>[]

---

##### `securityContext`<sup>Optional</sup> <a name="securityContext" id="cdk8s-metaflow.MetaflowUIOptions.property.securityContext"></a>

```typescript
public readonly securityContext: SecurityContext;
```

- *Type:* cdk8s-metaflow.k8s.SecurityContext

---

##### `service`<sup>Optional</sup> <a name="service" id="cdk8s-metaflow.MetaflowUIOptions.property.service"></a>

```typescript
public readonly service: ServiceOptions;
```

- *Type:* <a href="#cdk8s-metaflow.ServiceOptions">ServiceOptions</a>

---

##### `serviceAccount`<sup>Optional</sup> <a name="serviceAccount" id="cdk8s-metaflow.MetaflowUIOptions.property.serviceAccount"></a>

```typescript
public readonly serviceAccount: ServiceAccountOptions;
```

- *Type:* <a href="#cdk8s-metaflow.ServiceAccountOptions">ServiceAccountOptions</a>

---

##### `serviceStatic`<sup>Optional</sup> <a name="serviceStatic" id="cdk8s-metaflow.MetaflowUIOptions.property.serviceStatic"></a>

```typescript
public readonly serviceStatic: ServiceOptions;
```

- *Type:* <a href="#cdk8s-metaflow.ServiceOptions">ServiceOptions</a>

---

##### `tolerations`<sup>Optional</sup> <a name="tolerations" id="cdk8s-metaflow.MetaflowUIOptions.property.tolerations"></a>

```typescript
public readonly tolerations: Toleration[];
```

- *Type:* cdk8s-metaflow.k8s.Toleration[]

---

##### `uiImage`<sup>Optional</sup> <a name="uiImage" id="cdk8s-metaflow.MetaflowUIOptions.property.uiImage"></a>

```typescript
public readonly uiImage: ImageOptions;
```

- *Type:* <a href="#cdk8s-metaflow.ImageOptions">ImageOptions</a>

---

### MetaflowUIProps <a name="MetaflowUIProps" id="cdk8s-metaflow.MetaflowUIProps"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.MetaflowUIProps.Initializer"></a>

```typescript
import { MetaflowUIProps } from 'cdk8s-metaflow'

const metaflowUIProps: MetaflowUIProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.MetaflowUIProps.property.chartVersion">chartVersion</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.MetaflowUIProps.property.chartValues">chartValues</a></code> | <code><a href="#cdk8s-metaflow.MetaflowUIOptions">MetaflowUIOptions</a></code> | *No description.* |

---

##### `chartVersion`<sup>Required</sup> <a name="chartVersion" id="cdk8s-metaflow.MetaflowUIProps.property.chartVersion"></a>

```typescript
public readonly chartVersion: string;
```

- *Type:* string

---

##### `chartValues`<sup>Optional</sup> <a name="chartValues" id="cdk8s-metaflow.MetaflowUIProps.property.chartValues"></a>

```typescript
public readonly chartValues: MetaflowUIOptions;
```

- *Type:* <a href="#cdk8s-metaflow.MetaflowUIOptions">MetaflowUIOptions</a>

---

### MetricIdentifierV2Beta2 <a name="MetricIdentifierV2Beta2" id="cdk8s-metaflow.k8s.MetricIdentifierV2Beta2"></a>

MetricIdentifier defines the name and optionally selector for a metric.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.MetricIdentifierV2Beta2.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const metricIdentifierV2Beta2: k8s.MetricIdentifierV2Beta2 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.MetricIdentifierV2Beta2.property.name">name</a></code> | <code>string</code> | name is the name of the given metric. |
| <code><a href="#cdk8s-metaflow.k8s.MetricIdentifierV2Beta2.property.selector">selector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | selector is the string-encoded form of a standard kubernetes label selector for the given metric When set, it is passed as an additional parameter to the metrics server for more specific metrics scoping. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.MetricIdentifierV2Beta2.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

name is the name of the given metric.

---

##### `selector`<sup>Optional</sup> <a name="selector" id="cdk8s-metaflow.k8s.MetricIdentifierV2Beta2.property.selector"></a>

```typescript
public readonly selector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

selector is the string-encoded form of a standard kubernetes label selector for the given metric When set, it is passed as an additional parameter to the metrics server for more specific metrics scoping.

When unset, just the metricName will be used to gather metrics.

---

### MetricSpecV2Beta1 <a name="MetricSpecV2Beta1" id="cdk8s-metaflow.k8s.MetricSpecV2Beta1"></a>

MetricSpec specifies how to scale based on a single metric (only `type` and one other matching field should be set at once).

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.MetricSpecV2Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const metricSpecV2Beta1: k8s.MetricSpecV2Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.MetricSpecV2Beta1.property.type">type</a></code> | <code>string</code> | type is the type of metric source. |
| <code><a href="#cdk8s-metaflow.k8s.MetricSpecV2Beta1.property.containerResource">containerResource</a></code> | <code>cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta1</code> | container resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing a single container in each pod of the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. This is an alpha feature and can be enabled by the HPAContainerMetrics feature flag. |
| <code><a href="#cdk8s-metaflow.k8s.MetricSpecV2Beta1.property.external">external</a></code> | <code>cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta1</code> | external refers to a global metric that is not associated with any Kubernetes object. |
| <code><a href="#cdk8s-metaflow.k8s.MetricSpecV2Beta1.property.object">object</a></code> | <code>cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta1</code> | object refers to a metric describing a single kubernetes object (for example, hits-per-second on an Ingress object). |
| <code><a href="#cdk8s-metaflow.k8s.MetricSpecV2Beta1.property.pods">pods</a></code> | <code>cdk8s-metaflow.k8s.PodsMetricSourceV2Beta1</code> | pods refers to a metric describing each pod in the current scale target (for example, transactions-processed-per-second). |
| <code><a href="#cdk8s-metaflow.k8s.MetricSpecV2Beta1.property.resource">resource</a></code> | <code>cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta1</code> | resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing each pod in the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. |

---

##### `type`<sup>Required</sup> <a name="type" id="cdk8s-metaflow.k8s.MetricSpecV2Beta1.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

type is the type of metric source.

It should be one of "ContainerResource", "External", "Object", "Pods" or "Resource", each mapping to a matching field in the object. Note: "ContainerResource" type is available on when the feature-gate HPAContainerMetrics is enabled

---

##### `containerResource`<sup>Optional</sup> <a name="containerResource" id="cdk8s-metaflow.k8s.MetricSpecV2Beta1.property.containerResource"></a>

```typescript
public readonly containerResource: ContainerResourceMetricSourceV2Beta1;
```

- *Type:* cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta1

container resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing a single container in each pod of the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. This is an alpha feature and can be enabled by the HPAContainerMetrics feature flag.

---

##### `external`<sup>Optional</sup> <a name="external" id="cdk8s-metaflow.k8s.MetricSpecV2Beta1.property.external"></a>

```typescript
public readonly external: ExternalMetricSourceV2Beta1;
```

- *Type:* cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta1

external refers to a global metric that is not associated with any Kubernetes object.

It allows autoscaling based on information coming from components running outside of cluster (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).

---

##### `object`<sup>Optional</sup> <a name="object" id="cdk8s-metaflow.k8s.MetricSpecV2Beta1.property.object"></a>

```typescript
public readonly object: ObjectMetricSourceV2Beta1;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta1

object refers to a metric describing a single kubernetes object (for example, hits-per-second on an Ingress object).

---

##### `pods`<sup>Optional</sup> <a name="pods" id="cdk8s-metaflow.k8s.MetricSpecV2Beta1.property.pods"></a>

```typescript
public readonly pods: PodsMetricSourceV2Beta1;
```

- *Type:* cdk8s-metaflow.k8s.PodsMetricSourceV2Beta1

pods refers to a metric describing each pod in the current scale target (for example, transactions-processed-per-second).

The values will be averaged together before being compared to the target value.

---

##### `resource`<sup>Optional</sup> <a name="resource" id="cdk8s-metaflow.k8s.MetricSpecV2Beta1.property.resource"></a>

```typescript
public readonly resource: ResourceMetricSourceV2Beta1;
```

- *Type:* cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta1

resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing each pod in the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.

---

### MetricSpecV2Beta2 <a name="MetricSpecV2Beta2" id="cdk8s-metaflow.k8s.MetricSpecV2Beta2"></a>

MetricSpec specifies how to scale based on a single metric (only `type` and one other matching field should be set at once).

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.MetricSpecV2Beta2.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const metricSpecV2Beta2: k8s.MetricSpecV2Beta2 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.MetricSpecV2Beta2.property.type">type</a></code> | <code>string</code> | type is the type of metric source. |
| <code><a href="#cdk8s-metaflow.k8s.MetricSpecV2Beta2.property.containerResource">containerResource</a></code> | <code>cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta2</code> | container resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing a single container in each pod of the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. This is an alpha feature and can be enabled by the HPAContainerMetrics feature flag. |
| <code><a href="#cdk8s-metaflow.k8s.MetricSpecV2Beta2.property.external">external</a></code> | <code>cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta2</code> | external refers to a global metric that is not associated with any Kubernetes object. |
| <code><a href="#cdk8s-metaflow.k8s.MetricSpecV2Beta2.property.object">object</a></code> | <code>cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta2</code> | object refers to a metric describing a single kubernetes object (for example, hits-per-second on an Ingress object). |
| <code><a href="#cdk8s-metaflow.k8s.MetricSpecV2Beta2.property.pods">pods</a></code> | <code>cdk8s-metaflow.k8s.PodsMetricSourceV2Beta2</code> | pods refers to a metric describing each pod in the current scale target (for example, transactions-processed-per-second). |
| <code><a href="#cdk8s-metaflow.k8s.MetricSpecV2Beta2.property.resource">resource</a></code> | <code>cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta2</code> | resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing each pod in the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. |

---

##### `type`<sup>Required</sup> <a name="type" id="cdk8s-metaflow.k8s.MetricSpecV2Beta2.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

type is the type of metric source.

It should be one of "ContainerResource", "External", "Object", "Pods" or "Resource", each mapping to a matching field in the object. Note: "ContainerResource" type is available on when the feature-gate HPAContainerMetrics is enabled

---

##### `containerResource`<sup>Optional</sup> <a name="containerResource" id="cdk8s-metaflow.k8s.MetricSpecV2Beta2.property.containerResource"></a>

```typescript
public readonly containerResource: ContainerResourceMetricSourceV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.ContainerResourceMetricSourceV2Beta2

container resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing a single container in each pod of the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. This is an alpha feature and can be enabled by the HPAContainerMetrics feature flag.

---

##### `external`<sup>Optional</sup> <a name="external" id="cdk8s-metaflow.k8s.MetricSpecV2Beta2.property.external"></a>

```typescript
public readonly external: ExternalMetricSourceV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.ExternalMetricSourceV2Beta2

external refers to a global metric that is not associated with any Kubernetes object.

It allows autoscaling based on information coming from components running outside of cluster (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster).

---

##### `object`<sup>Optional</sup> <a name="object" id="cdk8s-metaflow.k8s.MetricSpecV2Beta2.property.object"></a>

```typescript
public readonly object: ObjectMetricSourceV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta2

object refers to a metric describing a single kubernetes object (for example, hits-per-second on an Ingress object).

---

##### `pods`<sup>Optional</sup> <a name="pods" id="cdk8s-metaflow.k8s.MetricSpecV2Beta2.property.pods"></a>

```typescript
public readonly pods: PodsMetricSourceV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.PodsMetricSourceV2Beta2

pods refers to a metric describing each pod in the current scale target (for example, transactions-processed-per-second).

The values will be averaged together before being compared to the target value.

---

##### `resource`<sup>Optional</sup> <a name="resource" id="cdk8s-metaflow.k8s.MetricSpecV2Beta2.property.resource"></a>

```typescript
public readonly resource: ResourceMetricSourceV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta2

resource refers to a resource metric (such as those specified in requests and limits) known to Kubernetes describing each pod in the current scale target (e.g. CPU or memory). Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.

---

### MetricTargetV2Beta2 <a name="MetricTargetV2Beta2" id="cdk8s-metaflow.k8s.MetricTargetV2Beta2"></a>

MetricTarget defines the target value, average value, or average utilization of a specific metric.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.MetricTargetV2Beta2.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const metricTargetV2Beta2: k8s.MetricTargetV2Beta2 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.MetricTargetV2Beta2.property.type">type</a></code> | <code>string</code> | type represents whether the metric type is Utilization, Value, or AverageValue. |
| <code><a href="#cdk8s-metaflow.k8s.MetricTargetV2Beta2.property.averageUtilization">averageUtilization</a></code> | <code>number</code> | averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods. |
| <code><a href="#cdk8s-metaflow.k8s.MetricTargetV2Beta2.property.averageValue">averageValue</a></code> | <code>cdk8s-metaflow.k8s.Quantity</code> | averageValue is the target value of the average of the metric across all relevant pods (as a quantity). |
| <code><a href="#cdk8s-metaflow.k8s.MetricTargetV2Beta2.property.value">value</a></code> | <code>cdk8s-metaflow.k8s.Quantity</code> | value is the target value of the metric (as a quantity). |

---

##### `type`<sup>Required</sup> <a name="type" id="cdk8s-metaflow.k8s.MetricTargetV2Beta2.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

type represents whether the metric type is Utilization, Value, or AverageValue.

---

##### `averageUtilization`<sup>Optional</sup> <a name="averageUtilization" id="cdk8s-metaflow.k8s.MetricTargetV2Beta2.property.averageUtilization"></a>

```typescript
public readonly averageUtilization: number;
```

- *Type:* number

averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.

Currently only valid for Resource metric source type

---

##### `averageValue`<sup>Optional</sup> <a name="averageValue" id="cdk8s-metaflow.k8s.MetricTargetV2Beta2.property.averageValue"></a>

```typescript
public readonly averageValue: Quantity;
```

- *Type:* cdk8s-metaflow.k8s.Quantity

averageValue is the target value of the average of the metric across all relevant pods (as a quantity).

---

##### `value`<sup>Optional</sup> <a name="value" id="cdk8s-metaflow.k8s.MetricTargetV2Beta2.property.value"></a>

```typescript
public readonly value: Quantity;
```

- *Type:* cdk8s-metaflow.k8s.Quantity

value is the target value of the metric (as a quantity).

---

### MutatingWebhook <a name="MutatingWebhook" id="cdk8s-metaflow.k8s.MutatingWebhook"></a>

MutatingWebhook describes an admission webhook and the resources and operations it applies to.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.MutatingWebhook.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const mutatingWebhook: k8s.MutatingWebhook = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhook.property.admissionReviewVersions">admissionReviewVersions</a></code> | <code>string[]</code> | AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhook.property.clientConfig">clientConfig</a></code> | <code>cdk8s-metaflow.k8s.WebhookClientConfig</code> | ClientConfig defines how to communicate with the hook. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhook.property.name">name</a></code> | <code>string</code> | The name of the admission webhook. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhook.property.sideEffects">sideEffects</a></code> | <code>string</code> | SideEffects states whether this webhook has side effects. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhook.property.failurePolicy">failurePolicy</a></code> | <code>string</code> | FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhook.property.matchPolicy">matchPolicy</a></code> | <code>string</code> | matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent". |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhook.property.namespaceSelector">namespaceSelector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | NamespaceSelector decides whether to run the webhook on an object based on whether the namespace for that object matches the selector. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhook.property.objectSelector">objectSelector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | ObjectSelector decides whether to run the webhook based on if the object has matching labels. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhook.property.reinvocationPolicy">reinvocationPolicy</a></code> | <code>string</code> | reinvocationPolicy indicates whether this webhook should be called multiple times as part of a single admission evaluation. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhook.property.rules">rules</a></code> | <code>cdk8s-metaflow.k8s.RuleWithOperations[]</code> | Rules describes what operations on what resources/subresources the webhook cares about. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhook.property.timeoutSeconds">timeoutSeconds</a></code> | <code>number</code> | TimeoutSeconds specifies the timeout for this webhook. |

---

##### `admissionReviewVersions`<sup>Required</sup> <a name="admissionReviewVersions" id="cdk8s-metaflow.k8s.MutatingWebhook.property.admissionReviewVersions"></a>

```typescript
public readonly admissionReviewVersions: string[];
```

- *Type:* string[]

AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects.

API server will try to use first version in the list which it supports. If none of the versions specified in this list supported by API server, validation will fail for this object. If a persisted webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail and be subject to the failure policy.

---

##### `clientConfig`<sup>Required</sup> <a name="clientConfig" id="cdk8s-metaflow.k8s.MutatingWebhook.property.clientConfig"></a>

```typescript
public readonly clientConfig: WebhookClientConfig;
```

- *Type:* cdk8s-metaflow.k8s.WebhookClientConfig

ClientConfig defines how to communicate with the hook.

Required

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.MutatingWebhook.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the admission webhook.

Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where "imagepolicy" is the name of the webhook, and kubernetes.io is the name of the organization. Required.

---

##### `sideEffects`<sup>Required</sup> <a name="sideEffects" id="cdk8s-metaflow.k8s.MutatingWebhook.property.sideEffects"></a>

```typescript
public readonly sideEffects: string;
```

- *Type:* string

SideEffects states whether this webhook has side effects.

Acceptable values are: None, NoneOnDryRun (webhooks created via v1beta1 may also specify Some or Unknown). Webhooks with side effects MUST implement a reconciliation system, since a request may be rejected by a future step in the admission chain and the side effects therefore need to be undone. Requests with the dryRun attribute will be auto-rejected if they match a webhook with sideEffects == Unknown or Some.

---

##### `failurePolicy`<sup>Optional</sup> <a name="failurePolicy" id="cdk8s-metaflow.k8s.MutatingWebhook.property.failurePolicy"></a>

```typescript
public readonly failurePolicy: string;
```

- *Type:* string
- *Default:* Fail.

FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail.

Defaults to Fail.

---

##### `matchPolicy`<sup>Optional</sup> <a name="matchPolicy" id="cdk8s-metaflow.k8s.MutatingWebhook.property.matchPolicy"></a>

```typescript
public readonly matchPolicy: string;
```

- *Type:* string
- *Default:* Equivalent"

matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".

Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the webhook.

- Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the webhook.

Defaults to "Equivalent"

---

##### `namespaceSelector`<sup>Optional</sup> <a name="namespaceSelector" id="cdk8s-metaflow.k8s.MutatingWebhook.property.namespaceSelector"></a>

```typescript
public readonly namespaceSelector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector
- *Default:* the empty LabelSelector, which matches everything.

NamespaceSelector decides whether to run the webhook on an object based on whether the namespace for that object matches the selector.

If the object itself is a namespace, the matching is performed on object.metadata.labels. If the object is another cluster scoped resource, it never skips the webhook.

For example, to run the webhook on any objects whose namespace is not associated with "runlevel" of "0" or "1";  you will set the selector as follows: "namespaceSelector": {
"matchExpressions": [
{
"key": "runlevel",
"operator": "NotIn",
"values": [
"0",
"1"
]
}
]
}

If instead you want to only run the webhook on any objects whose namespace is associated with the "environment" of "prod" or "staging"; you will set the selector as follows: "namespaceSelector": {
"matchExpressions": [
{
"key": "environment",
"operator": "In",
"values": [
"prod",
"staging"
]
}
]
}

See https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/ for more examples of label selectors.

Default to the empty LabelSelector, which matches everything.

---

##### `objectSelector`<sup>Optional</sup> <a name="objectSelector" id="cdk8s-metaflow.k8s.MutatingWebhook.property.objectSelector"></a>

```typescript
public readonly objectSelector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector
- *Default:* the empty LabelSelector, which matches everything.

ObjectSelector decides whether to run the webhook based on if the object has matching labels.

objectSelector is evaluated against both the oldObject and newObject that would be sent to the webhook, and is considered to match if either object matches the selector. A null object (oldObject in the case of create, or newObject in the case of delete) or an object that cannot have labels (like a DeploymentRollback or a PodProxyOptions object) is not considered to match. Use the object selector only if the webhook is opt-in, because end users may skip the admission webhook by setting the labels. Default to the empty LabelSelector, which matches everything.

---

##### `reinvocationPolicy`<sup>Optional</sup> <a name="reinvocationPolicy" id="cdk8s-metaflow.k8s.MutatingWebhook.property.reinvocationPolicy"></a>

```typescript
public readonly reinvocationPolicy: string;
```

- *Type:* string
- *Default:* Never".

reinvocationPolicy indicates whether this webhook should be called multiple times as part of a single admission evaluation.

Allowed values are "Never" and "IfNeeded".

Never: the webhook will not be called more than once in a single admission evaluation.

IfNeeded: the webhook will be called at least one additional time as part of the admission evaluation if the object being admitted is modified by other admission plugins after the initial webhook call. Webhooks that specify this option *must* be idempotent, able to process objects they previously admitted. Note: * the number of additional invocations is not guaranteed to be exactly one. * if additional invocations result in further modifications to the object, webhooks are not guaranteed to be invoked again. * webhooks that use this option may be reordered to minimize the number of additional invocations. * to validate an object after all mutations are guaranteed complete, use a validating admission webhook instead.

Defaults to "Never".

---

##### `rules`<sup>Optional</sup> <a name="rules" id="cdk8s-metaflow.k8s.MutatingWebhook.property.rules"></a>

```typescript
public readonly rules: RuleWithOperations[];
```

- *Type:* cdk8s-metaflow.k8s.RuleWithOperations[]

Rules describes what operations on what resources/subresources the webhook cares about.

The webhook cares about an operation if it matches _any_ Rule. However, in order to prevent ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks from putting the cluster in a state which cannot be recovered from without completely disabling the plugin, ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks are never called on admission requests for ValidatingWebhookConfiguration and MutatingWebhookConfiguration objects.

---

##### `timeoutSeconds`<sup>Optional</sup> <a name="timeoutSeconds" id="cdk8s-metaflow.k8s.MutatingWebhook.property.timeoutSeconds"></a>

```typescript
public readonly timeoutSeconds: number;
```

- *Type:* number
- *Default:* 10 seconds.

TimeoutSeconds specifies the timeout for this webhook.

After the timeout passes, the webhook call will be ignored or the API call will fail based on the failure policy. The timeout value must be between 1 and 30 seconds. Default to 10 seconds.

---

### MutatingWebhookConfigurationListProps <a name="MutatingWebhookConfigurationListProps" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationListProps"></a>

MutatingWebhookConfigurationList is a list of MutatingWebhookConfiguration.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const mutatingWebhookConfigurationListProps: k8s.MutatingWebhookConfigurationListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.MutatingWebhookConfiguration[]</code> | List of MutatingWebhookConfiguration. |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationListProps.property.items"></a>

```typescript
public readonly items: MutatingWebhookConfiguration[];
```

- *Type:* cdk8s-metaflow.k8s.MutatingWebhookConfiguration[]

List of MutatingWebhookConfiguration.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

### MutatingWebhookConfigurationProps <a name="MutatingWebhookConfigurationProps" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationProps"></a>

MutatingWebhookConfiguration describes the configuration of and admission webhook that accept or reject and may change the object.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const mutatingWebhookConfigurationProps: k8s.MutatingWebhookConfigurationProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object metadata; |
| <code><a href="#cdk8s-metaflow.k8s.MutatingWebhookConfigurationProps.property.webhooks">webhooks</a></code> | <code>cdk8s-metaflow.k8s.MutatingWebhook[]</code> | Webhooks is a list of webhooks and the affected resources and operations. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object metadata;

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

##### `webhooks`<sup>Optional</sup> <a name="webhooks" id="cdk8s-metaflow.k8s.MutatingWebhookConfigurationProps.property.webhooks"></a>

```typescript
public readonly webhooks: MutatingWebhook[];
```

- *Type:* cdk8s-metaflow.k8s.MutatingWebhook[]

Webhooks is a list of webhooks and the affected resources and operations.

---

### NamespaceListProps <a name="NamespaceListProps" id="cdk8s-metaflow.k8s.NamespaceListProps"></a>

NamespaceList is a list of Namespaces.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NamespaceListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const namespaceListProps: k8s.NamespaceListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.Namespace[]</code> | Items is the list of Namespace objects in the list. |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.NamespaceListProps.property.items"></a>

```typescript
public readonly items: Namespace[];
```

- *Type:* cdk8s-metaflow.k8s.Namespace[]

Items is the list of Namespace objects in the list.

More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/namespaces/

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.NamespaceListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

### NamespaceProps <a name="NamespaceProps" id="cdk8s-metaflow.k8s.NamespaceProps"></a>

Namespace provides a scope for Names.

Use of multiple namespaces is optional.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NamespaceProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const namespaceProps: k8s.NamespaceProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.NamespaceSpec</code> | Spec defines the behavior of the Namespace. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.NamespaceProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.NamespaceProps.property.spec"></a>

```typescript
public readonly spec: NamespaceSpec;
```

- *Type:* cdk8s-metaflow.k8s.NamespaceSpec

Spec defines the behavior of the Namespace.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### NamespaceSpec <a name="NamespaceSpec" id="cdk8s-metaflow.k8s.NamespaceSpec"></a>

NamespaceSpec describes the attributes on a Namespace.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NamespaceSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const namespaceSpec: k8s.NamespaceSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NamespaceSpec.property.finalizers">finalizers</a></code> | <code>string[]</code> | Finalizers is an opaque list of values that must be empty to permanently remove object from storage. |

---

##### `finalizers`<sup>Optional</sup> <a name="finalizers" id="cdk8s-metaflow.k8s.NamespaceSpec.property.finalizers"></a>

```typescript
public readonly finalizers: string[];
```

- *Type:* string[]

Finalizers is an opaque list of values that must be empty to permanently remove object from storage.

More info: https://kubernetes.io/docs/tasks/administer-cluster/namespaces/

---

### NetworkPolicyEgressRule <a name="NetworkPolicyEgressRule" id="cdk8s-metaflow.k8s.NetworkPolicyEgressRule"></a>

NetworkPolicyEgressRule describes a particular set of traffic that is allowed out of pods matched by a NetworkPolicySpec's podSelector.

The traffic must match both ports and to. This type is beta-level in 1.8

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NetworkPolicyEgressRule.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const networkPolicyEgressRule: k8s.NetworkPolicyEgressRule = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyEgressRule.property.ports">ports</a></code> | <code>cdk8s-metaflow.k8s.NetworkPolicyPort[]</code> | List of destination ports for outgoing traffic. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyEgressRule.property.to">to</a></code> | <code>cdk8s-metaflow.k8s.NetworkPolicyPeer[]</code> | List of destinations for outgoing traffic of pods selected for this rule. |

---

##### `ports`<sup>Optional</sup> <a name="ports" id="cdk8s-metaflow.k8s.NetworkPolicyEgressRule.property.ports"></a>

```typescript
public readonly ports: NetworkPolicyPort[];
```

- *Type:* cdk8s-metaflow.k8s.NetworkPolicyPort[]

List of destination ports for outgoing traffic.

Each item in this list is combined using a logical OR. If this field is empty or missing, this rule matches all ports (traffic not restricted by port). If this field is present and contains at least one item, then this rule allows traffic only if the traffic matches at least one port in the list.

---

##### `to`<sup>Optional</sup> <a name="to" id="cdk8s-metaflow.k8s.NetworkPolicyEgressRule.property.to"></a>

```typescript
public readonly to: NetworkPolicyPeer[];
```

- *Type:* cdk8s-metaflow.k8s.NetworkPolicyPeer[]

List of destinations for outgoing traffic of pods selected for this rule.

Items in this list are combined using a logical OR operation. If this field is empty or missing, this rule matches all destinations (traffic not restricted by destination). If this field is present and contains at least one item, this rule allows traffic only if the traffic matches at least one item in the to list.

---

### NetworkPolicyIngressRule <a name="NetworkPolicyIngressRule" id="cdk8s-metaflow.k8s.NetworkPolicyIngressRule"></a>

NetworkPolicyIngressRule describes a particular set of traffic that is allowed to the pods matched by a NetworkPolicySpec's podSelector.

The traffic must match both ports and from.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NetworkPolicyIngressRule.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const networkPolicyIngressRule: k8s.NetworkPolicyIngressRule = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyIngressRule.property.from">from</a></code> | <code>cdk8s-metaflow.k8s.NetworkPolicyPeer[]</code> | List of sources which should be able to access the pods selected for this rule. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyIngressRule.property.ports">ports</a></code> | <code>cdk8s-metaflow.k8s.NetworkPolicyPort[]</code> | List of ports which should be made accessible on the pods selected for this rule. |

---

##### `from`<sup>Optional</sup> <a name="from" id="cdk8s-metaflow.k8s.NetworkPolicyIngressRule.property.from"></a>

```typescript
public readonly from: NetworkPolicyPeer[];
```

- *Type:* cdk8s-metaflow.k8s.NetworkPolicyPeer[]

List of sources which should be able to access the pods selected for this rule.

Items in this list are combined using a logical OR operation. If this field is empty or missing, this rule matches all sources (traffic not restricted by source). If this field is present and contains at least one item, this rule allows traffic only if the traffic matches at least one item in the from list.

---

##### `ports`<sup>Optional</sup> <a name="ports" id="cdk8s-metaflow.k8s.NetworkPolicyIngressRule.property.ports"></a>

```typescript
public readonly ports: NetworkPolicyPort[];
```

- *Type:* cdk8s-metaflow.k8s.NetworkPolicyPort[]

List of ports which should be made accessible on the pods selected for this rule.

Each item in this list is combined using a logical OR. If this field is empty or missing, this rule matches all ports (traffic not restricted by port). If this field is present and contains at least one item, then this rule allows traffic only if the traffic matches at least one port in the list.

---

### NetworkPolicyListProps <a name="NetworkPolicyListProps" id="cdk8s-metaflow.k8s.NetworkPolicyListProps"></a>

NetworkPolicyList is a list of NetworkPolicy objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NetworkPolicyListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const networkPolicyListProps: k8s.NetworkPolicyListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.NetworkPolicy[]</code> | Items is a list of schema objects. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.NetworkPolicyListProps.property.items"></a>

```typescript
public readonly items: NetworkPolicy[];
```

- *Type:* cdk8s-metaflow.k8s.NetworkPolicy[]

Items is a list of schema objects.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.NetworkPolicyListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### NetworkPolicyPeer <a name="NetworkPolicyPeer" id="cdk8s-metaflow.k8s.NetworkPolicyPeer"></a>

NetworkPolicyPeer describes a peer to allow traffic to/from.

Only certain combinations of fields are allowed

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NetworkPolicyPeer.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const networkPolicyPeer: k8s.NetworkPolicyPeer = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyPeer.property.ipBlock">ipBlock</a></code> | <code>cdk8s-metaflow.k8s.IpBlock</code> | IPBlock defines policy on a particular IPBlock. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyPeer.property.namespaceSelector">namespaceSelector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | Selects Namespaces using cluster-scoped labels. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyPeer.property.podSelector">podSelector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | This is a label selector which selects Pods. |

---

##### `ipBlock`<sup>Optional</sup> <a name="ipBlock" id="cdk8s-metaflow.k8s.NetworkPolicyPeer.property.ipBlock"></a>

```typescript
public readonly ipBlock: IpBlock;
```

- *Type:* cdk8s-metaflow.k8s.IpBlock

IPBlock defines policy on a particular IPBlock.

If this field is set then neither of the other fields can be.

---

##### `namespaceSelector`<sup>Optional</sup> <a name="namespaceSelector" id="cdk8s-metaflow.k8s.NetworkPolicyPeer.property.namespaceSelector"></a>

```typescript
public readonly namespaceSelector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

Selects Namespaces using cluster-scoped labels.

This field follows standard label selector semantics; if present but empty, it selects all namespaces.

If PodSelector is also set, then the NetworkPolicyPeer as a whole selects the Pods matching PodSelector in the Namespaces selected by NamespaceSelector. Otherwise it selects all Pods in the Namespaces selected by NamespaceSelector.

---

##### `podSelector`<sup>Optional</sup> <a name="podSelector" id="cdk8s-metaflow.k8s.NetworkPolicyPeer.property.podSelector"></a>

```typescript
public readonly podSelector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

This is a label selector which selects Pods.

This field follows standard label selector semantics; if present but empty, it selects all pods.

If NamespaceSelector is also set, then the NetworkPolicyPeer as a whole selects the Pods matching PodSelector in the Namespaces selected by NamespaceSelector. Otherwise it selects the Pods matching PodSelector in the policy's own Namespace.

---

### NetworkPolicyPort <a name="NetworkPolicyPort" id="cdk8s-metaflow.k8s.NetworkPolicyPort"></a>

NetworkPolicyPort describes a port to allow traffic on.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NetworkPolicyPort.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const networkPolicyPort: k8s.NetworkPolicyPort = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyPort.property.endPort">endPort</a></code> | <code>number</code> | If set, indicates that the range of ports from port to endPort, inclusive, should be allowed by the policy. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyPort.property.port">port</a></code> | <code>cdk8s-metaflow.k8s.IntOrString</code> | The port on the given protocol. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyPort.property.protocol">protocol</a></code> | <code>string</code> | The protocol (TCP, UDP, or SCTP) which traffic must match. |

---

##### `endPort`<sup>Optional</sup> <a name="endPort" id="cdk8s-metaflow.k8s.NetworkPolicyPort.property.endPort"></a>

```typescript
public readonly endPort: number;
```

- *Type:* number

If set, indicates that the range of ports from port to endPort, inclusive, should be allowed by the policy.

This field cannot be defined if the port field is not defined or if the port field is defined as a named (string) port. The endPort must be equal or greater than port. This feature is in Beta state and is enabled by default. It can be disabled using the Feature Gate "NetworkPolicyEndPort".

---

##### `port`<sup>Optional</sup> <a name="port" id="cdk8s-metaflow.k8s.NetworkPolicyPort.property.port"></a>

```typescript
public readonly port: IntOrString;
```

- *Type:* cdk8s-metaflow.k8s.IntOrString

The port on the given protocol.

This can either be a numerical or named port on a pod. If this field is not provided, this matches all port names and numbers. If present, only traffic on the specified protocol AND port will be matched.

---

##### `protocol`<sup>Optional</sup> <a name="protocol" id="cdk8s-metaflow.k8s.NetworkPolicyPort.property.protocol"></a>

```typescript
public readonly protocol: string;
```

- *Type:* string

The protocol (TCP, UDP, or SCTP) which traffic must match.

If not specified, this field defaults to TCP.

---

### NetworkPolicyProps <a name="NetworkPolicyProps" id="cdk8s-metaflow.k8s.NetworkPolicyProps"></a>

NetworkPolicy describes what network traffic is allowed for a set of Pods.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NetworkPolicyProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const networkPolicyProps: k8s.NetworkPolicyProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicyProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.NetworkPolicySpec</code> | Specification of the desired behavior for this NetworkPolicy. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.NetworkPolicyProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.NetworkPolicyProps.property.spec"></a>

```typescript
public readonly spec: NetworkPolicySpec;
```

- *Type:* cdk8s-metaflow.k8s.NetworkPolicySpec

Specification of the desired behavior for this NetworkPolicy.

---

### NetworkPolicySpec <a name="NetworkPolicySpec" id="cdk8s-metaflow.k8s.NetworkPolicySpec"></a>

NetworkPolicySpec provides the specification of a NetworkPolicy.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NetworkPolicySpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const networkPolicySpec: k8s.NetworkPolicySpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicySpec.property.podSelector">podSelector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | Selects the pods to which this NetworkPolicy object applies. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicySpec.property.egress">egress</a></code> | <code>cdk8s-metaflow.k8s.NetworkPolicyEgressRule[]</code> | List of egress rules to be applied to the selected pods. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicySpec.property.ingress">ingress</a></code> | <code>cdk8s-metaflow.k8s.NetworkPolicyIngressRule[]</code> | List of ingress rules to be applied to the selected pods. |
| <code><a href="#cdk8s-metaflow.k8s.NetworkPolicySpec.property.policyTypes">policyTypes</a></code> | <code>string[]</code> | List of rule types that the NetworkPolicy relates to. |

---

##### `podSelector`<sup>Required</sup> <a name="podSelector" id="cdk8s-metaflow.k8s.NetworkPolicySpec.property.podSelector"></a>

```typescript
public readonly podSelector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

Selects the pods to which this NetworkPolicy object applies.

The array of ingress rules is applied to any pods selected by this field. Multiple network policies can select the same set of pods. In this case, the ingress rules for each are combined additively. This field is NOT optional and follows standard label selector semantics. An empty podSelector matches all pods in this namespace.

---

##### `egress`<sup>Optional</sup> <a name="egress" id="cdk8s-metaflow.k8s.NetworkPolicySpec.property.egress"></a>

```typescript
public readonly egress: NetworkPolicyEgressRule[];
```

- *Type:* cdk8s-metaflow.k8s.NetworkPolicyEgressRule[]

List of egress rules to be applied to the selected pods.

Outgoing traffic is allowed if there are no NetworkPolicies selecting the pod (and cluster policy otherwise allows the traffic), OR if the traffic matches at least one egress rule across all of the NetworkPolicy objects whose podSelector matches the pod. If this field is empty then this NetworkPolicy limits all outgoing traffic (and serves solely to ensure that the pods it selects are isolated by default). This field is beta-level in 1.8

---

##### `ingress`<sup>Optional</sup> <a name="ingress" id="cdk8s-metaflow.k8s.NetworkPolicySpec.property.ingress"></a>

```typescript
public readonly ingress: NetworkPolicyIngressRule[];
```

- *Type:* cdk8s-metaflow.k8s.NetworkPolicyIngressRule[]

List of ingress rules to be applied to the selected pods.

Traffic is allowed to a pod if there are no NetworkPolicies selecting the pod (and cluster policy otherwise allows the traffic), OR if the traffic source is the pod's local node, OR if the traffic matches at least one ingress rule across all of the NetworkPolicy objects whose podSelector matches the pod. If this field is empty then this NetworkPolicy does not allow any traffic (and serves solely to ensure that the pods it selects are isolated by default)

---

##### `policyTypes`<sup>Optional</sup> <a name="policyTypes" id="cdk8s-metaflow.k8s.NetworkPolicySpec.property.policyTypes"></a>

```typescript
public readonly policyTypes: string[];
```

- *Type:* string[]

List of rule types that the NetworkPolicy relates to.

Valid options are ["Ingress"], ["Egress"], or ["Ingress", "Egress"]. If this field is not specified, it will default based on the existence of Ingress or Egress rules; policies that contain an Egress section are assumed to affect Egress, and all policies (whether or not they contain an Ingress section) are assumed to affect Ingress. If you want to write an egress-only policy, you must explicitly specify policyTypes [ "Egress" ]. Likewise, if you want to write a policy that specifies that no egress is allowed, you must specify a policyTypes value that include "Egress" (since such a policy would not include an Egress section and would otherwise default to just [ "Ingress" ]). This field is beta-level in 1.8

---

### NfsVolumeSource <a name="NfsVolumeSource" id="cdk8s-metaflow.k8s.NfsVolumeSource"></a>

Represents an NFS mount that lasts the lifetime of a pod.

NFS volumes do not support ownership management or SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NfsVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const nfsVolumeSource: k8s.NfsVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NfsVolumeSource.property.path">path</a></code> | <code>string</code> | Path that is exported by the NFS server. |
| <code><a href="#cdk8s-metaflow.k8s.NfsVolumeSource.property.server">server</a></code> | <code>string</code> | Server is the hostname or IP address of the NFS server. |
| <code><a href="#cdk8s-metaflow.k8s.NfsVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | ReadOnly here will force the NFS export to be mounted with read-only permissions. |

---

##### `path`<sup>Required</sup> <a name="path" id="cdk8s-metaflow.k8s.NfsVolumeSource.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* string

Path that is exported by the NFS server.

More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs

---

##### `server`<sup>Required</sup> <a name="server" id="cdk8s-metaflow.k8s.NfsVolumeSource.property.server"></a>

```typescript
public readonly server: string;
```

- *Type:* string

Server is the hostname or IP address of the NFS server.

More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.NfsVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs

ReadOnly here will force the NFS export to be mounted with read-only permissions.

Defaults to false. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs

---

### NodeAffinity <a name="NodeAffinity" id="cdk8s-metaflow.k8s.NodeAffinity"></a>

Node affinity is a group of node affinity scheduling rules.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NodeAffinity.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const nodeAffinity: k8s.NodeAffinity = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NodeAffinity.property.preferredDuringSchedulingIgnoredDuringExecution">preferredDuringSchedulingIgnoredDuringExecution</a></code> | <code>cdk8s-metaflow.k8s.PreferredSchedulingTerm[]</code> | The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. |
| <code><a href="#cdk8s-metaflow.k8s.NodeAffinity.property.requiredDuringSchedulingIgnoredDuringExecution">requiredDuringSchedulingIgnoredDuringExecution</a></code> | <code>cdk8s-metaflow.k8s.NodeSelector</code> | If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. |

---

##### `preferredDuringSchedulingIgnoredDuringExecution`<sup>Optional</sup> <a name="preferredDuringSchedulingIgnoredDuringExecution" id="cdk8s-metaflow.k8s.NodeAffinity.property.preferredDuringSchedulingIgnoredDuringExecution"></a>

```typescript
public readonly preferredDuringSchedulingIgnoredDuringExecution: PreferredSchedulingTerm[];
```

- *Type:* cdk8s-metaflow.k8s.PreferredSchedulingTerm[]

The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions.

The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node matches the corresponding matchExpressions; the node(s) with the highest sum are the most preferred.

---

##### `requiredDuringSchedulingIgnoredDuringExecution`<sup>Optional</sup> <a name="requiredDuringSchedulingIgnoredDuringExecution" id="cdk8s-metaflow.k8s.NodeAffinity.property.requiredDuringSchedulingIgnoredDuringExecution"></a>

```typescript
public readonly requiredDuringSchedulingIgnoredDuringExecution: NodeSelector;
```

- *Type:* cdk8s-metaflow.k8s.NodeSelector

If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node.

If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to an update), the system may or may not try to eventually evict the pod from its node.

---

### NodeConfigSource <a name="NodeConfigSource" id="cdk8s-metaflow.k8s.NodeConfigSource"></a>

NodeConfigSource specifies a source of node configuration.

Exactly one subfield (excluding metadata) must be non-nil. This API is deprecated since 1.22

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NodeConfigSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const nodeConfigSource: k8s.NodeConfigSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NodeConfigSource.property.configMap">configMap</a></code> | <code>cdk8s-metaflow.k8s.ConfigMapNodeConfigSource</code> | ConfigMap is a reference to a Node's ConfigMap. |

---

##### `configMap`<sup>Optional</sup> <a name="configMap" id="cdk8s-metaflow.k8s.NodeConfigSource.property.configMap"></a>

```typescript
public readonly configMap: ConfigMapNodeConfigSource;
```

- *Type:* cdk8s-metaflow.k8s.ConfigMapNodeConfigSource

ConfigMap is a reference to a Node's ConfigMap.

---

### NodeListProps <a name="NodeListProps" id="cdk8s-metaflow.k8s.NodeListProps"></a>

NodeList is the whole list of all Nodes which have been registered with master.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NodeListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const nodeListProps: k8s.NodeListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NodeListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.Node[]</code> | List of nodes. |
| <code><a href="#cdk8s-metaflow.k8s.NodeListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.NodeListProps.property.items"></a>

```typescript
public readonly items: Node[];
```

- *Type:* cdk8s-metaflow.k8s.Node[]

List of nodes.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.NodeListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

### NodeProps <a name="NodeProps" id="cdk8s-metaflow.k8s.NodeProps"></a>

Node is a worker node in Kubernetes.

Each node will have a unique identifier in the cache (i.e. in etcd).

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NodeProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const nodeProps: k8s.NodeProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NodeProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.NodeProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.NodeSpec</code> | Spec defines the behavior of a node. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.NodeProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.NodeProps.property.spec"></a>

```typescript
public readonly spec: NodeSpec;
```

- *Type:* cdk8s-metaflow.k8s.NodeSpec

Spec defines the behavior of a node.

https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### NodeSelector <a name="NodeSelector" id="cdk8s-metaflow.k8s.NodeSelector"></a>

A node selector represents the union of the results of one or more label queries over a set of nodes;

that is, it represents the OR of the selectors represented by the node selector terms.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NodeSelector.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const nodeSelector: k8s.NodeSelector = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NodeSelector.property.nodeSelectorTerms">nodeSelectorTerms</a></code> | <code>cdk8s-metaflow.k8s.NodeSelectorTerm[]</code> | Required. |

---

##### `nodeSelectorTerms`<sup>Required</sup> <a name="nodeSelectorTerms" id="cdk8s-metaflow.k8s.NodeSelector.property.nodeSelectorTerms"></a>

```typescript
public readonly nodeSelectorTerms: NodeSelectorTerm[];
```

- *Type:* cdk8s-metaflow.k8s.NodeSelectorTerm[]

Required.

A list of node selector terms. The terms are ORed.

---

### NodeSelectorRequirement <a name="NodeSelectorRequirement" id="cdk8s-metaflow.k8s.NodeSelectorRequirement"></a>

A node selector requirement is a selector that contains values, a key, and an operator that relates the key and values.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NodeSelectorRequirement.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const nodeSelectorRequirement: k8s.NodeSelectorRequirement = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NodeSelectorRequirement.property.key">key</a></code> | <code>string</code> | The label key that the selector applies to. |
| <code><a href="#cdk8s-metaflow.k8s.NodeSelectorRequirement.property.operator">operator</a></code> | <code>string</code> | Represents a key's relationship to a set of values. |
| <code><a href="#cdk8s-metaflow.k8s.NodeSelectorRequirement.property.values">values</a></code> | <code>string[]</code> | An array of string values. |

---

##### `key`<sup>Required</sup> <a name="key" id="cdk8s-metaflow.k8s.NodeSelectorRequirement.property.key"></a>

```typescript
public readonly key: string;
```

- *Type:* string

The label key that the selector applies to.

---

##### `operator`<sup>Required</sup> <a name="operator" id="cdk8s-metaflow.k8s.NodeSelectorRequirement.property.operator"></a>

```typescript
public readonly operator: string;
```

- *Type:* string

Represents a key's relationship to a set of values.

Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.

---

##### `values`<sup>Optional</sup> <a name="values" id="cdk8s-metaflow.k8s.NodeSelectorRequirement.property.values"></a>

```typescript
public readonly values: string[];
```

- *Type:* string[]

An array of string values.

If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.

---

### NodeSelectorTerm <a name="NodeSelectorTerm" id="cdk8s-metaflow.k8s.NodeSelectorTerm"></a>

A null or empty node selector term matches no objects.

The requirements of them are ANDed. The TopologySelectorTerm type implements a subset of the NodeSelectorTerm.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NodeSelectorTerm.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const nodeSelectorTerm: k8s.NodeSelectorTerm = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NodeSelectorTerm.property.matchExpressions">matchExpressions</a></code> | <code>cdk8s-metaflow.k8s.NodeSelectorRequirement[]</code> | A list of node selector requirements by node's labels. |
| <code><a href="#cdk8s-metaflow.k8s.NodeSelectorTerm.property.matchFields">matchFields</a></code> | <code>cdk8s-metaflow.k8s.NodeSelectorRequirement[]</code> | A list of node selector requirements by node's fields. |

---

##### `matchExpressions`<sup>Optional</sup> <a name="matchExpressions" id="cdk8s-metaflow.k8s.NodeSelectorTerm.property.matchExpressions"></a>

```typescript
public readonly matchExpressions: NodeSelectorRequirement[];
```

- *Type:* cdk8s-metaflow.k8s.NodeSelectorRequirement[]

A list of node selector requirements by node's labels.

---

##### `matchFields`<sup>Optional</sup> <a name="matchFields" id="cdk8s-metaflow.k8s.NodeSelectorTerm.property.matchFields"></a>

```typescript
public readonly matchFields: NodeSelectorRequirement[];
```

- *Type:* cdk8s-metaflow.k8s.NodeSelectorRequirement[]

A list of node selector requirements by node's fields.

---

### NodeSpec <a name="NodeSpec" id="cdk8s-metaflow.k8s.NodeSpec"></a>

NodeSpec describes the attributes that a node is created with.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NodeSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const nodeSpec: k8s.NodeSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NodeSpec.property.configSource">configSource</a></code> | <code>cdk8s-metaflow.k8s.NodeConfigSource</code> | Deprecated. |
| <code><a href="#cdk8s-metaflow.k8s.NodeSpec.property.externalId">externalId</a></code> | <code>string</code> | Deprecated. |
| <code><a href="#cdk8s-metaflow.k8s.NodeSpec.property.podCidr">podCidr</a></code> | <code>string</code> | PodCIDR represents the pod IP range assigned to the node. |
| <code><a href="#cdk8s-metaflow.k8s.NodeSpec.property.podCidRs">podCidRs</a></code> | <code>string[]</code> | podCIDRs represents the IP ranges assigned to the node for usage by Pods on that node. |
| <code><a href="#cdk8s-metaflow.k8s.NodeSpec.property.providerId">providerId</a></code> | <code>string</code> | ID of the node assigned by the cloud provider in the format: <ProviderName>://<ProviderSpecificNodeID>. |
| <code><a href="#cdk8s-metaflow.k8s.NodeSpec.property.taints">taints</a></code> | <code>cdk8s-metaflow.k8s.Taint[]</code> | If specified, the node's taints. |
| <code><a href="#cdk8s-metaflow.k8s.NodeSpec.property.unschedulable">unschedulable</a></code> | <code>boolean</code> | Unschedulable controls node schedulability of new pods. |

---

##### `configSource`<sup>Optional</sup> <a name="configSource" id="cdk8s-metaflow.k8s.NodeSpec.property.configSource"></a>

```typescript
public readonly configSource: NodeConfigSource;
```

- *Type:* cdk8s-metaflow.k8s.NodeConfigSource

Deprecated.

If specified, the source of the node's configuration. The DynamicKubeletConfig feature gate must be enabled for the Kubelet to use this field. This field is deprecated as of 1.22: https://git.k8s.io/enhancements/keps/sig-node/281-dynamic-kubelet-configuration

---

##### `externalId`<sup>Optional</sup> <a name="externalId" id="cdk8s-metaflow.k8s.NodeSpec.property.externalId"></a>

```typescript
public readonly externalId: string;
```

- *Type:* string

Deprecated.

Not all kubelets will set this field. Remove field after 1.13. see: https://issues.k8s.io/61966

---

##### `podCidr`<sup>Optional</sup> <a name="podCidr" id="cdk8s-metaflow.k8s.NodeSpec.property.podCidr"></a>

```typescript
public readonly podCidr: string;
```

- *Type:* string

PodCIDR represents the pod IP range assigned to the node.

---

##### `podCidRs`<sup>Optional</sup> <a name="podCidRs" id="cdk8s-metaflow.k8s.NodeSpec.property.podCidRs"></a>

```typescript
public readonly podCidRs: string[];
```

- *Type:* string[]

podCIDRs represents the IP ranges assigned to the node for usage by Pods on that node.

If this field is specified, the 0th entry must match the podCIDR field. It may contain at most 1 value for each of IPv4 and IPv6.

---

##### `providerId`<sup>Optional</sup> <a name="providerId" id="cdk8s-metaflow.k8s.NodeSpec.property.providerId"></a>

```typescript
public readonly providerId: string;
```

- *Type:* string

ID of the node assigned by the cloud provider in the format: <ProviderName>://<ProviderSpecificNodeID>.

---

##### `taints`<sup>Optional</sup> <a name="taints" id="cdk8s-metaflow.k8s.NodeSpec.property.taints"></a>

```typescript
public readonly taints: Taint[];
```

- *Type:* cdk8s-metaflow.k8s.Taint[]

If specified, the node's taints.

---

##### `unschedulable`<sup>Optional</sup> <a name="unschedulable" id="cdk8s-metaflow.k8s.NodeSpec.property.unschedulable"></a>

```typescript
public readonly unschedulable: boolean;
```

- *Type:* boolean

Unschedulable controls node schedulability of new pods.

By default, node is schedulable. More info: https://kubernetes.io/docs/concepts/nodes/node/#manual-node-administration

---

### NonResourceAttributes <a name="NonResourceAttributes" id="cdk8s-metaflow.k8s.NonResourceAttributes"></a>

NonResourceAttributes includes the authorization attributes available for non-resource requests to the Authorizer interface.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NonResourceAttributes.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const nonResourceAttributes: k8s.NonResourceAttributes = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NonResourceAttributes.property.path">path</a></code> | <code>string</code> | Path is the URL path of the request. |
| <code><a href="#cdk8s-metaflow.k8s.NonResourceAttributes.property.verb">verb</a></code> | <code>string</code> | Verb is the standard HTTP verb. |

---

##### `path`<sup>Optional</sup> <a name="path" id="cdk8s-metaflow.k8s.NonResourceAttributes.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* string

Path is the URL path of the request.

---

##### `verb`<sup>Optional</sup> <a name="verb" id="cdk8s-metaflow.k8s.NonResourceAttributes.property.verb"></a>

```typescript
public readonly verb: string;
```

- *Type:* string

Verb is the standard HTTP verb.

---

### NonResourcePolicyRuleV1Beta1 <a name="NonResourcePolicyRuleV1Beta1" id="cdk8s-metaflow.k8s.NonResourcePolicyRuleV1Beta1"></a>

NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL.

A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.NonResourcePolicyRuleV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const nonResourcePolicyRuleV1Beta1: k8s.NonResourcePolicyRuleV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.NonResourcePolicyRuleV1Beta1.property.nonResourceUrLs">nonResourceUrLs</a></code> | <code>string[]</code> | `nonResourceURLs` is a set of url prefixes that a user should have access to and may not be empty. |
| <code><a href="#cdk8s-metaflow.k8s.NonResourcePolicyRuleV1Beta1.property.verbs">verbs</a></code> | <code>string[]</code> | `verbs` is a list of matching verbs and may not be empty. |

---

##### `nonResourceUrLs`<sup>Required</sup> <a name="nonResourceUrLs" id="cdk8s-metaflow.k8s.NonResourcePolicyRuleV1Beta1.property.nonResourceUrLs"></a>

```typescript
public readonly nonResourceUrLs: string[];
```

- *Type:* string[]

`nonResourceURLs` is a set of url prefixes that a user should have access to and may not be empty.

For example:
- "/healthz" is legal
- "/hea*" is illegal
- "/hea" is legal but matches nothing
- "/hea/*" also matches nothing
- "/healthz/*" matches all per-component health checks.
"*" matches all non-resource urls. if it is present, it must be the only entry. Required.

---

##### `verbs`<sup>Required</sup> <a name="verbs" id="cdk8s-metaflow.k8s.NonResourcePolicyRuleV1Beta1.property.verbs"></a>

```typescript
public readonly verbs: string[];
```

- *Type:* string[]

`verbs` is a list of matching verbs and may not be empty.

"*" matches all verbs. If it is present, it must be the only entry. Required.

---

### ObjectFieldSelector <a name="ObjectFieldSelector" id="cdk8s-metaflow.k8s.ObjectFieldSelector"></a>

ObjectFieldSelector selects an APIVersioned field of an object.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ObjectFieldSelector.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const objectFieldSelector: k8s.ObjectFieldSelector = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ObjectFieldSelector.property.fieldPath">fieldPath</a></code> | <code>string</code> | Path of the field to select in the specified API version. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectFieldSelector.property.apiVersion">apiVersion</a></code> | <code>string</code> | Version of the schema the FieldPath is written in terms of, defaults to "v1". |

---

##### `fieldPath`<sup>Required</sup> <a name="fieldPath" id="cdk8s-metaflow.k8s.ObjectFieldSelector.property.fieldPath"></a>

```typescript
public readonly fieldPath: string;
```

- *Type:* string

Path of the field to select in the specified API version.

---

##### `apiVersion`<sup>Optional</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ObjectFieldSelector.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

Version of the schema the FieldPath is written in terms of, defaults to "v1".

---

### ObjectMeta <a name="ObjectMeta" id="cdk8s-metaflow.k8s.ObjectMeta"></a>

ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ObjectMeta.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const objectMeta: k8s.ObjectMeta = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMeta.property.annotations">annotations</a></code> | <code>{[ key: string ]: string}</code> | Annotations is an unstructured key value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMeta.property.clusterName">clusterName</a></code> | <code>string</code> | The name of the cluster which the object belongs to. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMeta.property.creationTimestamp">creationTimestamp</a></code> | <code>Date</code> | CreationTimestamp is a timestamp representing the server time when this object was created. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMeta.property.deletionGracePeriodSeconds">deletionGracePeriodSeconds</a></code> | <code>number</code> | Number of seconds allowed for this object to gracefully terminate before it will be removed from the system. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMeta.property.deletionTimestamp">deletionTimestamp</a></code> | <code>Date</code> | DeletionTimestamp is RFC 3339 date and time at which this resource will be deleted. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMeta.property.finalizers">finalizers</a></code> | <code>string[]</code> | Must be empty before the object is deleted from the registry. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMeta.property.generateName">generateName</a></code> | <code>string</code> | GenerateName is an optional prefix, used by the server, to generate a unique name ONLY IF the Name field has not been provided. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMeta.property.generation">generation</a></code> | <code>number</code> | A sequence number representing a specific generation of the desired state. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMeta.property.labels">labels</a></code> | <code>{[ key: string ]: string}</code> | Map of string keys and values that can be used to organize and categorize (scope and select) objects. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMeta.property.managedFields">managedFields</a></code> | <code>cdk8s-metaflow.k8s.ManagedFieldsEntry[]</code> | ManagedFields maps workflow-id and version to the set of fields that are managed by that workflow. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMeta.property.name">name</a></code> | <code>string</code> | Name must be unique within a namespace. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMeta.property.namespace">namespace</a></code> | <code>string</code> | Namespace defines the space within which each name must be unique. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMeta.property.ownerReferences">ownerReferences</a></code> | <code>cdk8s-metaflow.k8s.OwnerReference[]</code> | List of objects depended by this object. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMeta.property.resourceVersion">resourceVersion</a></code> | <code>string</code> | An opaque value that represents the internal version of this object that can be used by clients to determine when objects have changed. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMeta.property.selfLink">selfLink</a></code> | <code>string</code> | SelfLink is a URL representing this object. Populated by the system. Read-only. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMeta.property.uid">uid</a></code> | <code>string</code> | UID is the unique in time and space value for this object. |

---

##### `annotations`<sup>Optional</sup> <a name="annotations" id="cdk8s-metaflow.k8s.ObjectMeta.property.annotations"></a>

```typescript
public readonly annotations: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

Annotations is an unstructured key value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata.

They are not queryable and should be preserved when modifying objects. More info: http://kubernetes.io/docs/user-guide/annotations

---

##### `clusterName`<sup>Optional</sup> <a name="clusterName" id="cdk8s-metaflow.k8s.ObjectMeta.property.clusterName"></a>

```typescript
public readonly clusterName: string;
```

- *Type:* string

The name of the cluster which the object belongs to.

This is used to distinguish resources with same name and namespace in different clusters. This field is not set anywhere right now and apiserver is going to ignore it if set in create or update request.

---

##### `creationTimestamp`<sup>Optional</sup> <a name="creationTimestamp" id="cdk8s-metaflow.k8s.ObjectMeta.property.creationTimestamp"></a>

```typescript
public readonly creationTimestamp: Date;
```

- *Type:* Date

CreationTimestamp is a timestamp representing the server time when this object was created.

It is not guaranteed to be set in happens-before order across separate operations. Clients may not set this value. It is represented in RFC3339 form and is in UTC.

Populated by the system. Read-only. Null for lists. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `deletionGracePeriodSeconds`<sup>Optional</sup> <a name="deletionGracePeriodSeconds" id="cdk8s-metaflow.k8s.ObjectMeta.property.deletionGracePeriodSeconds"></a>

```typescript
public readonly deletionGracePeriodSeconds: number;
```

- *Type:* number

Number of seconds allowed for this object to gracefully terminate before it will be removed from the system.

Only set when deletionTimestamp is also set. May only be shortened. Read-only.

---

##### `deletionTimestamp`<sup>Optional</sup> <a name="deletionTimestamp" id="cdk8s-metaflow.k8s.ObjectMeta.property.deletionTimestamp"></a>

```typescript
public readonly deletionTimestamp: Date;
```

- *Type:* Date

DeletionTimestamp is RFC 3339 date and time at which this resource will be deleted.

This field is set by the server when a graceful deletion is requested by the user, and is not directly settable by a client. The resource is expected to be deleted (no longer visible from resource lists, and not reachable by name) after the time in this field, once the finalizers list is empty. As long as the finalizers list contains items, deletion is blocked. Once the deletionTimestamp is set, this value may not be unset or be set further into the future, although it may be shortened or the resource may be deleted prior to this time. For example, a user may request that a pod is deleted in 30 seconds. The Kubelet will react by sending a graceful termination signal to the containers in the pod. After that 30 seconds, the Kubelet will send a hard termination signal (SIGKILL) to the container and after cleanup, remove the pod from the API. In the presence of network partitions, this object may still exist after this timestamp, until an administrator or automated process can determine the resource is fully terminated. If not set, graceful deletion of the object has not been requested.

Populated by the system when a graceful deletion is requested. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `finalizers`<sup>Optional</sup> <a name="finalizers" id="cdk8s-metaflow.k8s.ObjectMeta.property.finalizers"></a>

```typescript
public readonly finalizers: string[];
```

- *Type:* string[]

Must be empty before the object is deleted from the registry.

Each entry is an identifier for the responsible component that will remove the entry from the list. If the deletionTimestamp of the object is non-nil, entries in this list can only be removed. Finalizers may be processed and removed in any order.  Order is NOT enforced because it introduces significant risk of stuck finalizers. finalizers is a shared field, any actor with permission can reorder it. If the finalizer list is processed in order, then this can lead to a situation in which the component responsible for the first finalizer in the list is waiting for a signal (field value, external system, or other) produced by a component responsible for a finalizer later in the list, resulting in a deadlock. Without enforced ordering finalizers are free to order amongst themselves and are not vulnerable to ordering changes in the list.

---

##### `generateName`<sup>Optional</sup> <a name="generateName" id="cdk8s-metaflow.k8s.ObjectMeta.property.generateName"></a>

```typescript
public readonly generateName: string;
```

- *Type:* string

GenerateName is an optional prefix, used by the server, to generate a unique name ONLY IF the Name field has not been provided.

If this field is used, the name returned to the client will be different than the name passed. This value will also be combined with a unique suffix. The provided value has the same validation rules as the Name field, and may be truncated by the length of the suffix required to make the value unique on the server.

If this field is specified and the generated name exists, the server will NOT return a 409 - instead, it will either return 201 Created or 500 with Reason ServerTimeout indicating a unique name could not be found in the time allotted, and the client should retry (optionally after the time indicated in the Retry-After header).

Applied only if Name is not specified. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#idempotency

---

##### `generation`<sup>Optional</sup> <a name="generation" id="cdk8s-metaflow.k8s.ObjectMeta.property.generation"></a>

```typescript
public readonly generation: number;
```

- *Type:* number

A sequence number representing a specific generation of the desired state.

Populated by the system. Read-only.

---

##### `labels`<sup>Optional</sup> <a name="labels" id="cdk8s-metaflow.k8s.ObjectMeta.property.labels"></a>

```typescript
public readonly labels: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

Map of string keys and values that can be used to organize and categorize (scope and select) objects.

May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels

---

##### `managedFields`<sup>Optional</sup> <a name="managedFields" id="cdk8s-metaflow.k8s.ObjectMeta.property.managedFields"></a>

```typescript
public readonly managedFields: ManagedFieldsEntry[];
```

- *Type:* cdk8s-metaflow.k8s.ManagedFieldsEntry[]

ManagedFields maps workflow-id and version to the set of fields that are managed by that workflow.

This is mostly for internal housekeeping, and users typically shouldn't need to set or understand this field. A workflow can be the user's name, a controller's name, or the name of a specific apply path like "ci-cd". The set of fields is always in the version that the workflow used when modifying the object.

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.ObjectMeta.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name must be unique within a namespace.

Is required when creating resources, although some resources may allow a client to request the generation of an appropriate name automatically. Name is primarily intended for creation idempotence and configuration definition. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names

---

##### `namespace`<sup>Optional</sup> <a name="namespace" id="cdk8s-metaflow.k8s.ObjectMeta.property.namespace"></a>

```typescript
public readonly namespace: string;
```

- *Type:* string

Namespace defines the space within which each name must be unique.

An empty namespace is equivalent to the "default" namespace, but "default" is the canonical representation. Not all objects are required to be scoped to a namespace - the value of this field for those objects will be empty.

Must be a DNS_LABEL. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/namespaces

---

##### `ownerReferences`<sup>Optional</sup> <a name="ownerReferences" id="cdk8s-metaflow.k8s.ObjectMeta.property.ownerReferences"></a>

```typescript
public readonly ownerReferences: OwnerReference[];
```

- *Type:* cdk8s-metaflow.k8s.OwnerReference[]

List of objects depended by this object.

If ALL objects in the list have been deleted, this object will be garbage collected. If this object is managed by a controller, then an entry in this list will point to this controller, with the controller field set to true. There cannot be more than one managing controller.

---

##### `resourceVersion`<sup>Optional</sup> <a name="resourceVersion" id="cdk8s-metaflow.k8s.ObjectMeta.property.resourceVersion"></a>

```typescript
public readonly resourceVersion: string;
```

- *Type:* string

An opaque value that represents the internal version of this object that can be used by clients to determine when objects have changed.

May be used for optimistic concurrency, change detection, and the watch operation on a resource or set of resources. Clients must treat these values as opaque and passed unmodified back to the server. They may only be valid for a particular resource or set of resources.

Populated by the system. Read-only. Value must be treated as opaque by clients and . More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#concurrency-control-and-consistency

---

##### `selfLink`<sup>Optional</sup> <a name="selfLink" id="cdk8s-metaflow.k8s.ObjectMeta.property.selfLink"></a>

```typescript
public readonly selfLink: string;
```

- *Type:* string

SelfLink is a URL representing this object. Populated by the system. Read-only.

DEPRECATED Kubernetes will stop propagating this field in 1.20 release and the field is planned to be removed in 1.21 release.

---

##### `uid`<sup>Optional</sup> <a name="uid" id="cdk8s-metaflow.k8s.ObjectMeta.property.uid"></a>

```typescript
public readonly uid: string;
```

- *Type:* string

UID is the unique in time and space value for this object.

It is typically generated by the server on successful creation of a resource and is not allowed to change on PUT operations.

Populated by the system. Read-only. More info: http://kubernetes.io/docs/user-guide/identifiers#uids

---

### ObjectMetricSourceV2Beta1 <a name="ObjectMetricSourceV2Beta1" id="cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta1"></a>

ObjectMetricSource indicates how to scale on a metric describing a kubernetes object (for example, hits-per-second on an Ingress object).

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const objectMetricSourceV2Beta1: k8s.ObjectMetricSourceV2Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta1.property.metricName">metricName</a></code> | <code>string</code> | metricName is the name of the metric in question. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta1.property.target">target</a></code> | <code>cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta1</code> | target is the described Kubernetes object. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta1.property.targetValue">targetValue</a></code> | <code>cdk8s-metaflow.k8s.Quantity</code> | targetValue is the target value of the metric (as a quantity). |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta1.property.averageValue">averageValue</a></code> | <code>cdk8s-metaflow.k8s.Quantity</code> | averageValue is the target value of the average of the metric across all relevant pods (as a quantity). |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta1.property.selector">selector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | selector is the string-encoded form of a standard kubernetes label selector for the given metric When set, it is passed as an additional parameter to the metrics server for more specific metrics scoping When unset, just the metricName will be used to gather metrics. |

---

##### `metricName`<sup>Required</sup> <a name="metricName" id="cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta1.property.metricName"></a>

```typescript
public readonly metricName: string;
```

- *Type:* string

metricName is the name of the metric in question.

---

##### `target`<sup>Required</sup> <a name="target" id="cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta1.property.target"></a>

```typescript
public readonly target: CrossVersionObjectReferenceV2Beta1;
```

- *Type:* cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta1

target is the described Kubernetes object.

---

##### `targetValue`<sup>Required</sup> <a name="targetValue" id="cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta1.property.targetValue"></a>

```typescript
public readonly targetValue: Quantity;
```

- *Type:* cdk8s-metaflow.k8s.Quantity

targetValue is the target value of the metric (as a quantity).

---

##### `averageValue`<sup>Optional</sup> <a name="averageValue" id="cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta1.property.averageValue"></a>

```typescript
public readonly averageValue: Quantity;
```

- *Type:* cdk8s-metaflow.k8s.Quantity

averageValue is the target value of the average of the metric across all relevant pods (as a quantity).

---

##### `selector`<sup>Optional</sup> <a name="selector" id="cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta1.property.selector"></a>

```typescript
public readonly selector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

selector is the string-encoded form of a standard kubernetes label selector for the given metric When set, it is passed as an additional parameter to the metrics server for more specific metrics scoping When unset, just the metricName will be used to gather metrics.

---

### ObjectMetricSourceV2Beta2 <a name="ObjectMetricSourceV2Beta2" id="cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta2"></a>

ObjectMetricSource indicates how to scale on a metric describing a kubernetes object (for example, hits-per-second on an Ingress object).

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta2.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const objectMetricSourceV2Beta2: k8s.ObjectMetricSourceV2Beta2 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta2.property.describedObject">describedObject</a></code> | <code>cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta2</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta2.property.metric">metric</a></code> | <code>cdk8s-metaflow.k8s.MetricIdentifierV2Beta2</code> | metric identifies the target metric by name and selector. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta2.property.target">target</a></code> | <code>cdk8s-metaflow.k8s.MetricTargetV2Beta2</code> | target specifies the target value for the given metric. |

---

##### `describedObject`<sup>Required</sup> <a name="describedObject" id="cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta2.property.describedObject"></a>

```typescript
public readonly describedObject: CrossVersionObjectReferenceV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.CrossVersionObjectReferenceV2Beta2

---

##### `metric`<sup>Required</sup> <a name="metric" id="cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta2.property.metric"></a>

```typescript
public readonly metric: MetricIdentifierV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.MetricIdentifierV2Beta2

metric identifies the target metric by name and selector.

---

##### `target`<sup>Required</sup> <a name="target" id="cdk8s-metaflow.k8s.ObjectMetricSourceV2Beta2.property.target"></a>

```typescript
public readonly target: MetricTargetV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.MetricTargetV2Beta2

target specifies the target value for the given metric.

---

### ObjectReference <a name="ObjectReference" id="cdk8s-metaflow.k8s.ObjectReference"></a>

ObjectReference contains enough information to let you inspect or modify the referred object.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ObjectReference.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const objectReference: k8s.ObjectReference = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ObjectReference.property.apiVersion">apiVersion</a></code> | <code>string</code> | API version of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectReference.property.fieldPath">fieldPath</a></code> | <code>string</code> | If referring to a piece of an object instead of an entire object, this string should contain a valid JSON/Go field access statement, such as desiredState.manifest.containers[2]. For example, if the object reference is to a container within a pod, this would take on a value like: "spec.containers{name}" (where "name" refers to the name of the container that triggered the event) or if no container name is specified "spec.containers[2]" (container with index 2 in this pod). This syntax is chosen only to have some well-defined way of referencing a part of an object. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectReference.property.kind">kind</a></code> | <code>string</code> | Kind of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectReference.property.name">name</a></code> | <code>string</code> | Name of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectReference.property.namespace">namespace</a></code> | <code>string</code> | Namespace of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectReference.property.resourceVersion">resourceVersion</a></code> | <code>string</code> | Specific resourceVersion to which this reference is made, if any. |
| <code><a href="#cdk8s-metaflow.k8s.ObjectReference.property.uid">uid</a></code> | <code>string</code> | UID of the referent. |

---

##### `apiVersion`<sup>Optional</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.ObjectReference.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

API version of the referent.

---

##### `fieldPath`<sup>Optional</sup> <a name="fieldPath" id="cdk8s-metaflow.k8s.ObjectReference.property.fieldPath"></a>

```typescript
public readonly fieldPath: string;
```

- *Type:* string

If referring to a piece of an object instead of an entire object, this string should contain a valid JSON/Go field access statement, such as desiredState.manifest.containers[2]. For example, if the object reference is to a container within a pod, this would take on a value like: "spec.containers{name}" (where "name" refers to the name of the container that triggered the event) or if no container name is specified "spec.containers[2]" (container with index 2 in this pod). This syntax is chosen only to have some well-defined way of referencing a part of an object.

---

##### `kind`<sup>Optional</sup> <a name="kind" id="cdk8s-metaflow.k8s.ObjectReference.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

Kind of the referent.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.ObjectReference.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the referent.

More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names

---

##### `namespace`<sup>Optional</sup> <a name="namespace" id="cdk8s-metaflow.k8s.ObjectReference.property.namespace"></a>

```typescript
public readonly namespace: string;
```

- *Type:* string

Namespace of the referent.

More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/namespaces/

---

##### `resourceVersion`<sup>Optional</sup> <a name="resourceVersion" id="cdk8s-metaflow.k8s.ObjectReference.property.resourceVersion"></a>

```typescript
public readonly resourceVersion: string;
```

- *Type:* string

Specific resourceVersion to which this reference is made, if any.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#concurrency-control-and-consistency

---

##### `uid`<sup>Optional</sup> <a name="uid" id="cdk8s-metaflow.k8s.ObjectReference.property.uid"></a>

```typescript
public readonly uid: string;
```

- *Type:* string

UID of the referent.

More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#uids

---

### Overhead <a name="Overhead" id="cdk8s-metaflow.k8s.Overhead"></a>

Overhead structure represents the resource overhead associated with running a pod.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.Overhead.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const overhead: k8s.Overhead = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Overhead.property.podFixed">podFixed</a></code> | <code>{[ key: string ]: cdk8s-metaflow.k8s.Quantity}</code> | PodFixed represents the fixed resource overhead associated with running a pod. |

---

##### `podFixed`<sup>Optional</sup> <a name="podFixed" id="cdk8s-metaflow.k8s.Overhead.property.podFixed"></a>

```typescript
public readonly podFixed: {[ key: string ]: Quantity};
```

- *Type:* {[ key: string ]: cdk8s-metaflow.k8s.Quantity}

PodFixed represents the fixed resource overhead associated with running a pod.

---

### OverheadV1Alpha1 <a name="OverheadV1Alpha1" id="cdk8s-metaflow.k8s.OverheadV1Alpha1"></a>

Overhead structure represents the resource overhead associated with running a pod.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.OverheadV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const overheadV1Alpha1: k8s.OverheadV1Alpha1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.OverheadV1Alpha1.property.podFixed">podFixed</a></code> | <code>{[ key: string ]: cdk8s-metaflow.k8s.Quantity}</code> | PodFixed represents the fixed resource overhead associated with running a pod. |

---

##### `podFixed`<sup>Optional</sup> <a name="podFixed" id="cdk8s-metaflow.k8s.OverheadV1Alpha1.property.podFixed"></a>

```typescript
public readonly podFixed: {[ key: string ]: Quantity};
```

- *Type:* {[ key: string ]: cdk8s-metaflow.k8s.Quantity}

PodFixed represents the fixed resource overhead associated with running a pod.

---

### OverheadV1Beta1 <a name="OverheadV1Beta1" id="cdk8s-metaflow.k8s.OverheadV1Beta1"></a>

Overhead structure represents the resource overhead associated with running a pod.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.OverheadV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const overheadV1Beta1: k8s.OverheadV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.OverheadV1Beta1.property.podFixed">podFixed</a></code> | <code>{[ key: string ]: cdk8s-metaflow.k8s.Quantity}</code> | PodFixed represents the fixed resource overhead associated with running a pod. |

---

##### `podFixed`<sup>Optional</sup> <a name="podFixed" id="cdk8s-metaflow.k8s.OverheadV1Beta1.property.podFixed"></a>

```typescript
public readonly podFixed: {[ key: string ]: Quantity};
```

- *Type:* {[ key: string ]: cdk8s-metaflow.k8s.Quantity}

PodFixed represents the fixed resource overhead associated with running a pod.

---

### OwnerReference <a name="OwnerReference" id="cdk8s-metaflow.k8s.OwnerReference"></a>

OwnerReference contains enough information to let you identify an owning object.

An owning object must be in the same namespace as the dependent, or be cluster-scoped, so there is no namespace field.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.OwnerReference.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const ownerReference: k8s.OwnerReference = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.OwnerReference.property.apiVersion">apiVersion</a></code> | <code>string</code> | API version of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.OwnerReference.property.kind">kind</a></code> | <code>string</code> | Kind of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.OwnerReference.property.name">name</a></code> | <code>string</code> | Name of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.OwnerReference.property.uid">uid</a></code> | <code>string</code> | UID of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.OwnerReference.property.blockOwnerDeletion">blockOwnerDeletion</a></code> | <code>boolean</code> | If true, AND if the owner has the "foregroundDeletion" finalizer, then the owner cannot be deleted from the key-value store until this reference is removed. |
| <code><a href="#cdk8s-metaflow.k8s.OwnerReference.property.controller">controller</a></code> | <code>boolean</code> | If true, this reference points to the managing controller. |

---

##### `apiVersion`<sup>Required</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.OwnerReference.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string

API version of the referent.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.OwnerReference.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

Kind of the referent.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.OwnerReference.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the referent.

More info: http://kubernetes.io/docs/user-guide/identifiers#names

---

##### `uid`<sup>Required</sup> <a name="uid" id="cdk8s-metaflow.k8s.OwnerReference.property.uid"></a>

```typescript
public readonly uid: string;
```

- *Type:* string

UID of the referent.

More info: http://kubernetes.io/docs/user-guide/identifiers#uids

---

##### `blockOwnerDeletion`<sup>Optional</sup> <a name="blockOwnerDeletion" id="cdk8s-metaflow.k8s.OwnerReference.property.blockOwnerDeletion"></a>

```typescript
public readonly blockOwnerDeletion: boolean;
```

- *Type:* boolean
- *Default:* false. To set this field, a user needs "delete" permission of the owner, otherwise 422 (Unprocessable Entity) will be returned.

If true, AND if the owner has the "foregroundDeletion" finalizer, then the owner cannot be deleted from the key-value store until this reference is removed.

Defaults to false. To set this field, a user needs "delete" permission of the owner, otherwise 422 (Unprocessable Entity) will be returned.

---

##### `controller`<sup>Optional</sup> <a name="controller" id="cdk8s-metaflow.k8s.OwnerReference.property.controller"></a>

```typescript
public readonly controller: boolean;
```

- *Type:* boolean

If true, this reference points to the managing controller.

---

### PersistentVolumeClaimListProps <a name="PersistentVolumeClaimListProps" id="cdk8s-metaflow.k8s.PersistentVolumeClaimListProps"></a>

PersistentVolumeClaimList is a list of PersistentVolumeClaim items.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PersistentVolumeClaimListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const persistentVolumeClaimListProps: k8s.PersistentVolumeClaimListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.PersistentVolumeClaim[]</code> | A list of persistent volume claims. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.PersistentVolumeClaimListProps.property.items"></a>

```typescript
public readonly items: PersistentVolumeClaim[];
```

- *Type:* cdk8s-metaflow.k8s.PersistentVolumeClaim[]

A list of persistent volume claims.

More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PersistentVolumeClaimListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

### PersistentVolumeClaimProps <a name="PersistentVolumeClaimProps" id="cdk8s-metaflow.k8s.PersistentVolumeClaimProps"></a>

PersistentVolumeClaim is a user's request for and claim to a persistent volume.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PersistentVolumeClaimProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const persistentVolumeClaimProps: k8s.PersistentVolumeClaimProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.PersistentVolumeClaimSpec</code> | Spec defines the desired characteristics of a volume requested by a pod author. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PersistentVolumeClaimProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.PersistentVolumeClaimProps.property.spec"></a>

```typescript
public readonly spec: PersistentVolumeClaimSpec;
```

- *Type:* cdk8s-metaflow.k8s.PersistentVolumeClaimSpec

Spec defines the desired characteristics of a volume requested by a pod author.

More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims

---

### PersistentVolumeClaimSpec <a name="PersistentVolumeClaimSpec" id="cdk8s-metaflow.k8s.PersistentVolumeClaimSpec"></a>

PersistentVolumeClaimSpec describes the common attributes of storage devices and allows a Source for provider-specific attributes.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PersistentVolumeClaimSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const persistentVolumeClaimSpec: k8s.PersistentVolumeClaimSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimSpec.property.accessModes">accessModes</a></code> | <code>string[]</code> | AccessModes contains the desired access modes the volume should have. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimSpec.property.dataSource">dataSource</a></code> | <code>cdk8s-metaflow.k8s.TypedLocalObjectReference</code> | This field can be used to specify either: * An existing VolumeSnapshot object (snapshot.storage.k8s.io/VolumeSnapshot) * An existing PVC (PersistentVolumeClaim) If the provisioner or an external controller can support the specified data source, it will create a new volume based on the contents of the specified data source. If the AnyVolumeDataSource feature gate is enabled, this field will always have the same contents as the DataSourceRef field. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimSpec.property.dataSourceRef">dataSourceRef</a></code> | <code>cdk8s-metaflow.k8s.TypedLocalObjectReference</code> | Specifies the object from which to populate the volume with data, if a non-empty volume is desired. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimSpec.property.resources">resources</a></code> | <code>cdk8s-metaflow.k8s.ResourceRequirements</code> | Resources represents the minimum resources the volume should have. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimSpec.property.selector">selector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | A label query over volumes to consider for binding. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimSpec.property.storageClassName">storageClassName</a></code> | <code>string</code> | Name of the StorageClass required by the claim. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimSpec.property.volumeMode">volumeMode</a></code> | <code>string</code> | volumeMode defines what type of volume is required by the claim. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimSpec.property.volumeName">volumeName</a></code> | <code>string</code> | VolumeName is the binding reference to the PersistentVolume backing this claim. |

---

##### `accessModes`<sup>Optional</sup> <a name="accessModes" id="cdk8s-metaflow.k8s.PersistentVolumeClaimSpec.property.accessModes"></a>

```typescript
public readonly accessModes: string[];
```

- *Type:* string[]

AccessModes contains the desired access modes the volume should have.

More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1

---

##### `dataSource`<sup>Optional</sup> <a name="dataSource" id="cdk8s-metaflow.k8s.PersistentVolumeClaimSpec.property.dataSource"></a>

```typescript
public readonly dataSource: TypedLocalObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.TypedLocalObjectReference

This field can be used to specify either: * An existing VolumeSnapshot object (snapshot.storage.k8s.io/VolumeSnapshot) * An existing PVC (PersistentVolumeClaim) If the provisioner or an external controller can support the specified data source, it will create a new volume based on the contents of the specified data source. If the AnyVolumeDataSource feature gate is enabled, this field will always have the same contents as the DataSourceRef field.

---

##### `dataSourceRef`<sup>Optional</sup> <a name="dataSourceRef" id="cdk8s-metaflow.k8s.PersistentVolumeClaimSpec.property.dataSourceRef"></a>

```typescript
public readonly dataSourceRef: TypedLocalObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.TypedLocalObjectReference

Specifies the object from which to populate the volume with data, if a non-empty volume is desired.

This may be any local object from a non-empty API group (non core object) or a PersistentVolumeClaim object. When this field is specified, volume binding will only succeed if the type of the specified object matches some installed volume populator or dynamic provisioner. This field will replace the functionality of the DataSource field and as such if both fields are non-empty, they must have the same value. For backwards compatibility, both fields (DataSource and DataSourceRef) will be set to the same value automatically if one of them is empty and the other is non-empty. There are two important differences between DataSource and DataSourceRef: * While DataSource only allows two specific types of objects, DataSourceRef
allows any non-core object, as well as PersistentVolumeClaim objects.
* While DataSource ignores disallowed values (dropping them), DataSourceRef
preserves all values, and generates an error if a disallowed value is
specified.
(Alpha) Using this field requires the AnyVolumeDataSource feature gate to be enabled.

---

##### `resources`<sup>Optional</sup> <a name="resources" id="cdk8s-metaflow.k8s.PersistentVolumeClaimSpec.property.resources"></a>

```typescript
public readonly resources: ResourceRequirements;
```

- *Type:* cdk8s-metaflow.k8s.ResourceRequirements

Resources represents the minimum resources the volume should have.

More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#resources

---

##### `selector`<sup>Optional</sup> <a name="selector" id="cdk8s-metaflow.k8s.PersistentVolumeClaimSpec.property.selector"></a>

```typescript
public readonly selector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

A label query over volumes to consider for binding.

---

##### `storageClassName`<sup>Optional</sup> <a name="storageClassName" id="cdk8s-metaflow.k8s.PersistentVolumeClaimSpec.property.storageClassName"></a>

```typescript
public readonly storageClassName: string;
```

- *Type:* string

Name of the StorageClass required by the claim.

More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#class-1

---

##### `volumeMode`<sup>Optional</sup> <a name="volumeMode" id="cdk8s-metaflow.k8s.PersistentVolumeClaimSpec.property.volumeMode"></a>

```typescript
public readonly volumeMode: string;
```

- *Type:* string

volumeMode defines what type of volume is required by the claim.

Value of Filesystem is implied when not included in claim spec.

---

##### `volumeName`<sup>Optional</sup> <a name="volumeName" id="cdk8s-metaflow.k8s.PersistentVolumeClaimSpec.property.volumeName"></a>

```typescript
public readonly volumeName: string;
```

- *Type:* string

VolumeName is the binding reference to the PersistentVolume backing this claim.

---

### PersistentVolumeClaimTemplate <a name="PersistentVolumeClaimTemplate" id="cdk8s-metaflow.k8s.PersistentVolumeClaimTemplate"></a>

PersistentVolumeClaimTemplate is used to produce PersistentVolumeClaim objects as part of an EphemeralVolumeSource.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PersistentVolumeClaimTemplate.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const persistentVolumeClaimTemplate: k8s.PersistentVolumeClaimTemplate = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimTemplate.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.PersistentVolumeClaimSpec</code> | The specification for the PersistentVolumeClaim. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimTemplate.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | May contain labels and annotations that will be copied into the PVC when creating it. |

---

##### `spec`<sup>Required</sup> <a name="spec" id="cdk8s-metaflow.k8s.PersistentVolumeClaimTemplate.property.spec"></a>

```typescript
public readonly spec: PersistentVolumeClaimSpec;
```

- *Type:* cdk8s-metaflow.k8s.PersistentVolumeClaimSpec

The specification for the PersistentVolumeClaim.

The entire content is copied unchanged into the PVC that gets created from this template. The same fields as in a PersistentVolumeClaim are also valid here.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PersistentVolumeClaimTemplate.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

May contain labels and annotations that will be copied into the PVC when creating it.

No other fields are allowed and will be rejected during validation.

---

### PersistentVolumeClaimVolumeSource <a name="PersistentVolumeClaimVolumeSource" id="cdk8s-metaflow.k8s.PersistentVolumeClaimVolumeSource"></a>

PersistentVolumeClaimVolumeSource references the user's PVC in the same namespace.

This volume finds the bound PV and mounts that volume for the pod. A PersistentVolumeClaimVolumeSource is, essentially, a wrapper around another type of volume that is owned by someone else (the system).

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PersistentVolumeClaimVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const persistentVolumeClaimVolumeSource: k8s.PersistentVolumeClaimVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimVolumeSource.property.claimName">claimName</a></code> | <code>string</code> | ClaimName is the name of a PersistentVolumeClaim in the same namespace as the pod using this volume. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeClaimVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Will force the ReadOnly setting in VolumeMounts. |

---

##### `claimName`<sup>Required</sup> <a name="claimName" id="cdk8s-metaflow.k8s.PersistentVolumeClaimVolumeSource.property.claimName"></a>

```typescript
public readonly claimName: string;
```

- *Type:* string

ClaimName is the name of a PersistentVolumeClaim in the same namespace as the pod using this volume.

More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.PersistentVolumeClaimVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean

Will force the ReadOnly setting in VolumeMounts.

Default false.

---

### PersistentVolumeListProps <a name="PersistentVolumeListProps" id="cdk8s-metaflow.k8s.PersistentVolumeListProps"></a>

PersistentVolumeList is a list of PersistentVolume items.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PersistentVolumeListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const persistentVolumeListProps: k8s.PersistentVolumeListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.PersistentVolume[]</code> | List of persistent volumes. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.PersistentVolumeListProps.property.items"></a>

```typescript
public readonly items: PersistentVolume[];
```

- *Type:* cdk8s-metaflow.k8s.PersistentVolume[]

List of persistent volumes.

More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PersistentVolumeListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

### PersistentVolumeProps <a name="PersistentVolumeProps" id="cdk8s-metaflow.k8s.PersistentVolumeProps"></a>

PersistentVolume (PV) is a storage resource provisioned by an administrator.

It is analogous to a node. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PersistentVolumeProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const persistentVolumeProps: k8s.PersistentVolumeProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.PersistentVolumeSpec</code> | Spec defines a specification of a persistent volume owned by the cluster. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PersistentVolumeProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.PersistentVolumeProps.property.spec"></a>

```typescript
public readonly spec: PersistentVolumeSpec;
```

- *Type:* cdk8s-metaflow.k8s.PersistentVolumeSpec

Spec defines a specification of a persistent volume owned by the cluster.

Provisioned by an administrator. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistent-volumes

---

### PersistentVolumeSpec <a name="PersistentVolumeSpec" id="cdk8s-metaflow.k8s.PersistentVolumeSpec"></a>

PersistentVolumeSpec is the specification of a persistent volume.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const persistentVolumeSpec: k8s.PersistentVolumeSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.accessModes">accessModes</a></code> | <code>string[]</code> | AccessModes contains all ways the volume can be mounted. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.awsElasticBlockStore">awsElasticBlockStore</a></code> | <code>cdk8s-metaflow.k8s.AwsElasticBlockStoreVolumeSource</code> | AWSElasticBlockStore represents an AWS Disk resource that is attached to a kubelet's host machine and then exposed to the pod. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.azureDisk">azureDisk</a></code> | <code>cdk8s-metaflow.k8s.AzureDiskVolumeSource</code> | AzureDisk represents an Azure Data Disk mount on the host and bind mount to the pod. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.azureFile">azureFile</a></code> | <code>cdk8s-metaflow.k8s.AzureFilePersistentVolumeSource</code> | AzureFile represents an Azure File Service mount on the host and bind mount to the pod. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.capacity">capacity</a></code> | <code>{[ key: string ]: cdk8s-metaflow.k8s.Quantity}</code> | A description of the persistent volume's resources and capacity. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.cephfs">cephfs</a></code> | <code>cdk8s-metaflow.k8s.CephFsPersistentVolumeSource</code> | CephFS represents a Ceph FS mount on the host that shares a pod's lifetime. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.cinder">cinder</a></code> | <code>cdk8s-metaflow.k8s.CinderPersistentVolumeSource</code> | Cinder represents a cinder volume attached and mounted on kubelets host machine. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.claimRef">claimRef</a></code> | <code>cdk8s-metaflow.k8s.ObjectReference</code> | ClaimRef is part of a bi-directional binding between PersistentVolume and PersistentVolumeClaim. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.csi">csi</a></code> | <code>cdk8s-metaflow.k8s.CsiPersistentVolumeSource</code> | CSI represents storage that is handled by an external CSI driver (Beta feature). |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.fc">fc</a></code> | <code>cdk8s-metaflow.k8s.FcVolumeSource</code> | FC represents a Fibre Channel resource that is attached to a kubelet's host machine and then exposed to the pod. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.flexVolume">flexVolume</a></code> | <code>cdk8s-metaflow.k8s.FlexPersistentVolumeSource</code> | FlexVolume represents a generic volume resource that is provisioned/attached using an exec based plugin. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.flocker">flocker</a></code> | <code>cdk8s-metaflow.k8s.FlockerVolumeSource</code> | Flocker represents a Flocker volume attached to a kubelet's host machine and exposed to the pod for its usage. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.gcePersistentDisk">gcePersistentDisk</a></code> | <code>cdk8s-metaflow.k8s.GcePersistentDiskVolumeSource</code> | GCEPersistentDisk represents a GCE Disk resource that is attached to a kubelet's host machine and then exposed to the pod. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.glusterfs">glusterfs</a></code> | <code>cdk8s-metaflow.k8s.GlusterfsPersistentVolumeSource</code> | Glusterfs represents a Glusterfs volume that is attached to a host and exposed to the pod. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.hostPath">hostPath</a></code> | <code>cdk8s-metaflow.k8s.HostPathVolumeSource</code> | HostPath represents a directory on the host. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.iscsi">iscsi</a></code> | <code>cdk8s-metaflow.k8s.IscsiPersistentVolumeSource</code> | ISCSI represents an ISCSI Disk resource that is attached to a kubelet's host machine and then exposed to the pod. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.local">local</a></code> | <code>cdk8s-metaflow.k8s.LocalVolumeSource</code> | Local represents directly-attached storage with node affinity. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.mountOptions">mountOptions</a></code> | <code>string[]</code> | A list of mount options, e.g. ["ro", "soft"]. Not validated - mount will simply fail if one is invalid. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes/#mount-options. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.nfs">nfs</a></code> | <code>cdk8s-metaflow.k8s.NfsVolumeSource</code> | NFS represents an NFS mount on the host. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.nodeAffinity">nodeAffinity</a></code> | <code>cdk8s-metaflow.k8s.VolumeNodeAffinity</code> | NodeAffinity defines constraints that limit what nodes this volume can be accessed from. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.persistentVolumeReclaimPolicy">persistentVolumeReclaimPolicy</a></code> | <code>string</code> | What happens to a persistent volume when released from its claim. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.photonPersistentDisk">photonPersistentDisk</a></code> | <code>cdk8s-metaflow.k8s.PhotonPersistentDiskVolumeSource</code> | PhotonPersistentDisk represents a PhotonController persistent disk attached and mounted on kubelets host machine. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.portworxVolume">portworxVolume</a></code> | <code>cdk8s-metaflow.k8s.PortworxVolumeSource</code> | PortworxVolume represents a portworx volume attached and mounted on kubelets host machine. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.quobyte">quobyte</a></code> | <code>cdk8s-metaflow.k8s.QuobyteVolumeSource</code> | Quobyte represents a Quobyte mount on the host that shares a pod's lifetime. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.rbd">rbd</a></code> | <code>cdk8s-metaflow.k8s.RbdPersistentVolumeSource</code> | RBD represents a Rados Block Device mount on the host that shares a pod's lifetime. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.scaleIo">scaleIo</a></code> | <code>cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource</code> | ScaleIO represents a ScaleIO persistent volume attached and mounted on Kubernetes nodes. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.storageClassName">storageClassName</a></code> | <code>string</code> | Name of StorageClass to which this persistent volume belongs. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.storageos">storageos</a></code> | <code>cdk8s-metaflow.k8s.StorageOsPersistentVolumeSource</code> | StorageOS represents a StorageOS volume that is attached to the kubelet's host machine and mounted into the pod More info: https://examples.k8s.io/volumes/storageos/README.md. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.volumeMode">volumeMode</a></code> | <code>string</code> | volumeMode defines if a volume is intended to be used with a formatted filesystem or to remain in raw block state. |
| <code><a href="#cdk8s-metaflow.k8s.PersistentVolumeSpec.property.vsphereVolume">vsphereVolume</a></code> | <code>cdk8s-metaflow.k8s.VsphereVirtualDiskVolumeSource</code> | VsphereVolume represents a vSphere volume attached and mounted on kubelets host machine. |

---

##### `accessModes`<sup>Optional</sup> <a name="accessModes" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.accessModes"></a>

```typescript
public readonly accessModes: string[];
```

- *Type:* string[]

AccessModes contains all ways the volume can be mounted.

More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes

---

##### `awsElasticBlockStore`<sup>Optional</sup> <a name="awsElasticBlockStore" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.awsElasticBlockStore"></a>

```typescript
public readonly awsElasticBlockStore: AwsElasticBlockStoreVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.AwsElasticBlockStoreVolumeSource

AWSElasticBlockStore represents an AWS Disk resource that is attached to a kubelet's host machine and then exposed to the pod.

More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore

---

##### `azureDisk`<sup>Optional</sup> <a name="azureDisk" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.azureDisk"></a>

```typescript
public readonly azureDisk: AzureDiskVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.AzureDiskVolumeSource

AzureDisk represents an Azure Data Disk mount on the host and bind mount to the pod.

---

##### `azureFile`<sup>Optional</sup> <a name="azureFile" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.azureFile"></a>

```typescript
public readonly azureFile: AzureFilePersistentVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.AzureFilePersistentVolumeSource

AzureFile represents an Azure File Service mount on the host and bind mount to the pod.

---

##### `capacity`<sup>Optional</sup> <a name="capacity" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.capacity"></a>

```typescript
public readonly capacity: {[ key: string ]: Quantity};
```

- *Type:* {[ key: string ]: cdk8s-metaflow.k8s.Quantity}

A description of the persistent volume's resources and capacity.

More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#capacity

---

##### `cephfs`<sup>Optional</sup> <a name="cephfs" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.cephfs"></a>

```typescript
public readonly cephfs: CephFsPersistentVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.CephFsPersistentVolumeSource

CephFS represents a Ceph FS mount on the host that shares a pod's lifetime.

---

##### `cinder`<sup>Optional</sup> <a name="cinder" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.cinder"></a>

```typescript
public readonly cinder: CinderPersistentVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.CinderPersistentVolumeSource

Cinder represents a cinder volume attached and mounted on kubelets host machine.

More info: https://examples.k8s.io/mysql-cinder-pd/README.md

---

##### `claimRef`<sup>Optional</sup> <a name="claimRef" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.claimRef"></a>

```typescript
public readonly claimRef: ObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.ObjectReference

ClaimRef is part of a bi-directional binding between PersistentVolume and PersistentVolumeClaim.

Expected to be non-nil when bound. claim.VolumeName is the authoritative bind between PV and PVC. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#binding

---

##### `csi`<sup>Optional</sup> <a name="csi" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.csi"></a>

```typescript
public readonly csi: CsiPersistentVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.CsiPersistentVolumeSource

CSI represents storage that is handled by an external CSI driver (Beta feature).

---

##### `fc`<sup>Optional</sup> <a name="fc" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.fc"></a>

```typescript
public readonly fc: FcVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.FcVolumeSource

FC represents a Fibre Channel resource that is attached to a kubelet's host machine and then exposed to the pod.

---

##### `flexVolume`<sup>Optional</sup> <a name="flexVolume" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.flexVolume"></a>

```typescript
public readonly flexVolume: FlexPersistentVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.FlexPersistentVolumeSource

FlexVolume represents a generic volume resource that is provisioned/attached using an exec based plugin.

---

##### `flocker`<sup>Optional</sup> <a name="flocker" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.flocker"></a>

```typescript
public readonly flocker: FlockerVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.FlockerVolumeSource

Flocker represents a Flocker volume attached to a kubelet's host machine and exposed to the pod for its usage.

This depends on the Flocker control service being running

---

##### `gcePersistentDisk`<sup>Optional</sup> <a name="gcePersistentDisk" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.gcePersistentDisk"></a>

```typescript
public readonly gcePersistentDisk: GcePersistentDiskVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.GcePersistentDiskVolumeSource

GCEPersistentDisk represents a GCE Disk resource that is attached to a kubelet's host machine and then exposed to the pod.

Provisioned by an admin. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk

---

##### `glusterfs`<sup>Optional</sup> <a name="glusterfs" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.glusterfs"></a>

```typescript
public readonly glusterfs: GlusterfsPersistentVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.GlusterfsPersistentVolumeSource

Glusterfs represents a Glusterfs volume that is attached to a host and exposed to the pod.

Provisioned by an admin. More info: https://examples.k8s.io/volumes/glusterfs/README.md

---

##### `hostPath`<sup>Optional</sup> <a name="hostPath" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.hostPath"></a>

```typescript
public readonly hostPath: HostPathVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.HostPathVolumeSource

HostPath represents a directory on the host.

Provisioned by a developer or tester. This is useful for single-node development and testing only! On-host storage is not supported in any way and WILL NOT WORK in a multi-node cluster. More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath

---

##### `iscsi`<sup>Optional</sup> <a name="iscsi" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.iscsi"></a>

```typescript
public readonly iscsi: IscsiPersistentVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.IscsiPersistentVolumeSource

ISCSI represents an ISCSI Disk resource that is attached to a kubelet's host machine and then exposed to the pod.

Provisioned by an admin.

---

##### `local`<sup>Optional</sup> <a name="local" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.local"></a>

```typescript
public readonly local: LocalVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.LocalVolumeSource

Local represents directly-attached storage with node affinity.

---

##### `mountOptions`<sup>Optional</sup> <a name="mountOptions" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.mountOptions"></a>

```typescript
public readonly mountOptions: string[];
```

- *Type:* string[]

A list of mount options, e.g. ["ro", "soft"]. Not validated - mount will simply fail if one is invalid. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes/#mount-options.

---

##### `nfs`<sup>Optional</sup> <a name="nfs" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.nfs"></a>

```typescript
public readonly nfs: NfsVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.NfsVolumeSource

NFS represents an NFS mount on the host.

Provisioned by an admin. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs

---

##### `nodeAffinity`<sup>Optional</sup> <a name="nodeAffinity" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.nodeAffinity"></a>

```typescript
public readonly nodeAffinity: VolumeNodeAffinity;
```

- *Type:* cdk8s-metaflow.k8s.VolumeNodeAffinity

NodeAffinity defines constraints that limit what nodes this volume can be accessed from.

This field influences the scheduling of pods that use this volume.

---

##### `persistentVolumeReclaimPolicy`<sup>Optional</sup> <a name="persistentVolumeReclaimPolicy" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.persistentVolumeReclaimPolicy"></a>

```typescript
public readonly persistentVolumeReclaimPolicy: string;
```

- *Type:* string

What happens to a persistent volume when released from its claim.

Valid options are Retain (default for manually created PersistentVolumes), Delete (default for dynamically provisioned PersistentVolumes), and Recycle (deprecated). Recycle must be supported by the volume plugin underlying this PersistentVolume. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#reclaiming

---

##### `photonPersistentDisk`<sup>Optional</sup> <a name="photonPersistentDisk" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.photonPersistentDisk"></a>

```typescript
public readonly photonPersistentDisk: PhotonPersistentDiskVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.PhotonPersistentDiskVolumeSource

PhotonPersistentDisk represents a PhotonController persistent disk attached and mounted on kubelets host machine.

---

##### `portworxVolume`<sup>Optional</sup> <a name="portworxVolume" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.portworxVolume"></a>

```typescript
public readonly portworxVolume: PortworxVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.PortworxVolumeSource

PortworxVolume represents a portworx volume attached and mounted on kubelets host machine.

---

##### `quobyte`<sup>Optional</sup> <a name="quobyte" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.quobyte"></a>

```typescript
public readonly quobyte: QuobyteVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.QuobyteVolumeSource

Quobyte represents a Quobyte mount on the host that shares a pod's lifetime.

---

##### `rbd`<sup>Optional</sup> <a name="rbd" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.rbd"></a>

```typescript
public readonly rbd: RbdPersistentVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.RbdPersistentVolumeSource

RBD represents a Rados Block Device mount on the host that shares a pod's lifetime.

More info: https://examples.k8s.io/volumes/rbd/README.md

---

##### `scaleIo`<sup>Optional</sup> <a name="scaleIo" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.scaleIo"></a>

```typescript
public readonly scaleIo: ScaleIoPersistentVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource

ScaleIO represents a ScaleIO persistent volume attached and mounted on Kubernetes nodes.

---

##### `storageClassName`<sup>Optional</sup> <a name="storageClassName" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.storageClassName"></a>

```typescript
public readonly storageClassName: string;
```

- *Type:* string

Name of StorageClass to which this persistent volume belongs.

Empty value means that this volume does not belong to any StorageClass.

---

##### `storageos`<sup>Optional</sup> <a name="storageos" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.storageos"></a>

```typescript
public readonly storageos: StorageOsPersistentVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.StorageOsPersistentVolumeSource

StorageOS represents a StorageOS volume that is attached to the kubelet's host machine and mounted into the pod More info: https://examples.k8s.io/volumes/storageos/README.md.

---

##### `volumeMode`<sup>Optional</sup> <a name="volumeMode" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.volumeMode"></a>

```typescript
public readonly volumeMode: string;
```

- *Type:* string

volumeMode defines if a volume is intended to be used with a formatted filesystem or to remain in raw block state.

Value of Filesystem is implied when not included in spec.

---

##### `vsphereVolume`<sup>Optional</sup> <a name="vsphereVolume" id="cdk8s-metaflow.k8s.PersistentVolumeSpec.property.vsphereVolume"></a>

```typescript
public readonly vsphereVolume: VsphereVirtualDiskVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.VsphereVirtualDiskVolumeSource

VsphereVolume represents a vSphere volume attached and mounted on kubelets host machine.

---

### PhotonPersistentDiskVolumeSource <a name="PhotonPersistentDiskVolumeSource" id="cdk8s-metaflow.k8s.PhotonPersistentDiskVolumeSource"></a>

Represents a Photon Controller persistent disk resource.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PhotonPersistentDiskVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const photonPersistentDiskVolumeSource: k8s.PhotonPersistentDiskVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PhotonPersistentDiskVolumeSource.property.pdId">pdId</a></code> | <code>string</code> | ID that identifies Photon Controller persistent disk. |
| <code><a href="#cdk8s-metaflow.k8s.PhotonPersistentDiskVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type to mount. |

---

##### `pdId`<sup>Required</sup> <a name="pdId" id="cdk8s-metaflow.k8s.PhotonPersistentDiskVolumeSource.property.pdId"></a>

```typescript
public readonly pdId: string;
```

- *Type:* string

ID that identifies Photon Controller persistent disk.

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.PhotonPersistentDiskVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type to mount.

Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.

---

### PodAffinity <a name="PodAffinity" id="cdk8s-metaflow.k8s.PodAffinity"></a>

Pod affinity is a group of inter pod affinity scheduling rules.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodAffinity.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podAffinity: k8s.PodAffinity = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodAffinity.property.preferredDuringSchedulingIgnoredDuringExecution">preferredDuringSchedulingIgnoredDuringExecution</a></code> | <code>cdk8s-metaflow.k8s.WeightedPodAffinityTerm[]</code> | The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. |
| <code><a href="#cdk8s-metaflow.k8s.PodAffinity.property.requiredDuringSchedulingIgnoredDuringExecution">requiredDuringSchedulingIgnoredDuringExecution</a></code> | <code>cdk8s-metaflow.k8s.PodAffinityTerm[]</code> | If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. |

---

##### `preferredDuringSchedulingIgnoredDuringExecution`<sup>Optional</sup> <a name="preferredDuringSchedulingIgnoredDuringExecution" id="cdk8s-metaflow.k8s.PodAffinity.property.preferredDuringSchedulingIgnoredDuringExecution"></a>

```typescript
public readonly preferredDuringSchedulingIgnoredDuringExecution: WeightedPodAffinityTerm[];
```

- *Type:* cdk8s-metaflow.k8s.WeightedPodAffinityTerm[]

The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions.

The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.

---

##### `requiredDuringSchedulingIgnoredDuringExecution`<sup>Optional</sup> <a name="requiredDuringSchedulingIgnoredDuringExecution" id="cdk8s-metaflow.k8s.PodAffinity.property.requiredDuringSchedulingIgnoredDuringExecution"></a>

```typescript
public readonly requiredDuringSchedulingIgnoredDuringExecution: PodAffinityTerm[];
```

- *Type:* cdk8s-metaflow.k8s.PodAffinityTerm[]

If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node.

If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.

---

### PodAffinityTerm <a name="PodAffinityTerm" id="cdk8s-metaflow.k8s.PodAffinityTerm"></a>

Defines a set of pods (namely those matching the labelSelector relative to the given namespace(s)) that this pod should be co-located (affinity) or not co-located (anti-affinity) with, where co-located is defined as running on a node whose value of the label with key <topologyKey> matches that of any node on which a pod of the set of pods is running.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodAffinityTerm.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podAffinityTerm: k8s.PodAffinityTerm = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodAffinityTerm.property.topologyKey">topologyKey</a></code> | <code>string</code> | This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. |
| <code><a href="#cdk8s-metaflow.k8s.PodAffinityTerm.property.labelSelector">labelSelector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | A label query over a set of resources, in this case pods. |
| <code><a href="#cdk8s-metaflow.k8s.PodAffinityTerm.property.namespaces">namespaces</a></code> | <code>string[]</code> | namespaces specifies a static list of namespace names that the term applies to. |
| <code><a href="#cdk8s-metaflow.k8s.PodAffinityTerm.property.namespaceSelector">namespaceSelector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | A label query over the set of namespaces that the term applies to. |

---

##### `topologyKey`<sup>Required</sup> <a name="topologyKey" id="cdk8s-metaflow.k8s.PodAffinityTerm.property.topologyKey"></a>

```typescript
public readonly topologyKey: string;
```

- *Type:* string

This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running.

Empty topologyKey is not allowed.

---

##### `labelSelector`<sup>Optional</sup> <a name="labelSelector" id="cdk8s-metaflow.k8s.PodAffinityTerm.property.labelSelector"></a>

```typescript
public readonly labelSelector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

A label query over a set of resources, in this case pods.

---

##### `namespaces`<sup>Optional</sup> <a name="namespaces" id="cdk8s-metaflow.k8s.PodAffinityTerm.property.namespaces"></a>

```typescript
public readonly namespaces: string[];
```

- *Type:* string[]

namespaces specifies a static list of namespace names that the term applies to.

The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace"

---

##### `namespaceSelector`<sup>Optional</sup> <a name="namespaceSelector" id="cdk8s-metaflow.k8s.PodAffinityTerm.property.namespaceSelector"></a>

```typescript
public readonly namespaceSelector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

A label query over the set of namespaces that the term applies to.

The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces. This field is beta-level and is only honored when PodAffinityNamespaceSelector feature is enabled.

---

### PodAntiAffinity <a name="PodAntiAffinity" id="cdk8s-metaflow.k8s.PodAntiAffinity"></a>

Pod anti affinity is a group of inter pod anti affinity scheduling rules.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodAntiAffinity.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podAntiAffinity: k8s.PodAntiAffinity = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodAntiAffinity.property.preferredDuringSchedulingIgnoredDuringExecution">preferredDuringSchedulingIgnoredDuringExecution</a></code> | <code>cdk8s-metaflow.k8s.WeightedPodAffinityTerm[]</code> | The scheduler will prefer to schedule pods to nodes that satisfy the anti-affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. |
| <code><a href="#cdk8s-metaflow.k8s.PodAntiAffinity.property.requiredDuringSchedulingIgnoredDuringExecution">requiredDuringSchedulingIgnoredDuringExecution</a></code> | <code>cdk8s-metaflow.k8s.PodAffinityTerm[]</code> | If the anti-affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. |

---

##### `preferredDuringSchedulingIgnoredDuringExecution`<sup>Optional</sup> <a name="preferredDuringSchedulingIgnoredDuringExecution" id="cdk8s-metaflow.k8s.PodAntiAffinity.property.preferredDuringSchedulingIgnoredDuringExecution"></a>

```typescript
public readonly preferredDuringSchedulingIgnoredDuringExecution: WeightedPodAffinityTerm[];
```

- *Type:* cdk8s-metaflow.k8s.WeightedPodAffinityTerm[]

The scheduler will prefer to schedule pods to nodes that satisfy the anti-affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions.

The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling anti-affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.

---

##### `requiredDuringSchedulingIgnoredDuringExecution`<sup>Optional</sup> <a name="requiredDuringSchedulingIgnoredDuringExecution" id="cdk8s-metaflow.k8s.PodAntiAffinity.property.requiredDuringSchedulingIgnoredDuringExecution"></a>

```typescript
public readonly requiredDuringSchedulingIgnoredDuringExecution: PodAffinityTerm[];
```

- *Type:* cdk8s-metaflow.k8s.PodAffinityTerm[]

If the anti-affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node.

If the anti-affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.

---

### PodDisruptionBudgetListProps <a name="PodDisruptionBudgetListProps" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListProps"></a>

PodDisruptionBudgetList is a collection of PodDisruptionBudgets.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podDisruptionBudgetListProps: k8s.PodDisruptionBudgetListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.PodDisruptionBudget[]</code> | Items is a list of PodDisruptionBudgets. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard object's metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListProps.property.items"></a>

```typescript
public readonly items: PodDisruptionBudget[];
```

- *Type:* cdk8s-metaflow.k8s.PodDisruptionBudget[]

Items is a list of PodDisruptionBudgets.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### PodDisruptionBudgetListV1Beta1Props <a name="PodDisruptionBudgetListV1Beta1Props" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1Props"></a>

PodDisruptionBudgetList is a collection of PodDisruptionBudgets.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podDisruptionBudgetListV1Beta1Props: k8s.PodDisruptionBudgetListV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1[]</code> | items list individual PodDisruptionBudget objects. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard object's metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1Props.property.items"></a>

```typescript
public readonly items: PodDisruptionBudgetV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1[]

items list individual PodDisruptionBudget objects.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodDisruptionBudgetListV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### PodDisruptionBudgetProps <a name="PodDisruptionBudgetProps" id="cdk8s-metaflow.k8s.PodDisruptionBudgetProps"></a>

PodDisruptionBudget is an object to define the max disruption that can be caused to a collection of pods.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodDisruptionBudgetProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podDisruptionBudgetProps: k8s.PodDisruptionBudgetProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.PodDisruptionBudgetSpec</code> | Specification of the desired behavior of the PodDisruptionBudget. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodDisruptionBudgetProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.PodDisruptionBudgetProps.property.spec"></a>

```typescript
public readonly spec: PodDisruptionBudgetSpec;
```

- *Type:* cdk8s-metaflow.k8s.PodDisruptionBudgetSpec

Specification of the desired behavior of the PodDisruptionBudget.

---

### PodDisruptionBudgetSpec <a name="PodDisruptionBudgetSpec" id="cdk8s-metaflow.k8s.PodDisruptionBudgetSpec"></a>

PodDisruptionBudgetSpec is a description of a PodDisruptionBudget.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodDisruptionBudgetSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podDisruptionBudgetSpec: k8s.PodDisruptionBudgetSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetSpec.property.maxUnavailable">maxUnavailable</a></code> | <code>cdk8s-metaflow.k8s.IntOrString</code> | An eviction is allowed if at most "maxUnavailable" pods selected by "selector" are unavailable after the eviction, i.e. even in absence of the evicted pod. For example, one can prevent all voluntary evictions by specifying 0. This is a mutually exclusive setting with "minAvailable". |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetSpec.property.minAvailable">minAvailable</a></code> | <code>cdk8s-metaflow.k8s.IntOrString</code> | An eviction is allowed if at least "minAvailable" pods selected by "selector" will still be available after the eviction, i.e. even in the absence of the evicted pod.  So for example you can prevent all voluntary evictions by specifying "100%". |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetSpec.property.selector">selector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | Label query over pods whose evictions are managed by the disruption budget. |

---

##### `maxUnavailable`<sup>Optional</sup> <a name="maxUnavailable" id="cdk8s-metaflow.k8s.PodDisruptionBudgetSpec.property.maxUnavailable"></a>

```typescript
public readonly maxUnavailable: IntOrString;
```

- *Type:* cdk8s-metaflow.k8s.IntOrString

An eviction is allowed if at most "maxUnavailable" pods selected by "selector" are unavailable after the eviction, i.e. even in absence of the evicted pod. For example, one can prevent all voluntary evictions by specifying 0. This is a mutually exclusive setting with "minAvailable".

---

##### `minAvailable`<sup>Optional</sup> <a name="minAvailable" id="cdk8s-metaflow.k8s.PodDisruptionBudgetSpec.property.minAvailable"></a>

```typescript
public readonly minAvailable: IntOrString;
```

- *Type:* cdk8s-metaflow.k8s.IntOrString

An eviction is allowed if at least "minAvailable" pods selected by "selector" will still be available after the eviction, i.e. even in the absence of the evicted pod.  So for example you can prevent all voluntary evictions by specifying "100%".

---

##### `selector`<sup>Optional</sup> <a name="selector" id="cdk8s-metaflow.k8s.PodDisruptionBudgetSpec.property.selector"></a>

```typescript
public readonly selector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

Label query over pods whose evictions are managed by the disruption budget.

A null selector will match no pods, while an empty ({}) selector will select all pods within the namespace.

---

### PodDisruptionBudgetSpecV1Beta1 <a name="PodDisruptionBudgetSpecV1Beta1" id="cdk8s-metaflow.k8s.PodDisruptionBudgetSpecV1Beta1"></a>

PodDisruptionBudgetSpec is a description of a PodDisruptionBudget.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodDisruptionBudgetSpecV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podDisruptionBudgetSpecV1Beta1: k8s.PodDisruptionBudgetSpecV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetSpecV1Beta1.property.maxUnavailable">maxUnavailable</a></code> | <code>cdk8s-metaflow.k8s.IntOrString</code> | An eviction is allowed if at most "maxUnavailable" pods selected by "selector" are unavailable after the eviction, i.e. even in absence of the evicted pod. For example, one can prevent all voluntary evictions by specifying 0. This is a mutually exclusive setting with "minAvailable". |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetSpecV1Beta1.property.minAvailable">minAvailable</a></code> | <code>cdk8s-metaflow.k8s.IntOrString</code> | An eviction is allowed if at least "minAvailable" pods selected by "selector" will still be available after the eviction, i.e. even in the absence of the evicted pod.  So for example you can prevent all voluntary evictions by specifying "100%". |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetSpecV1Beta1.property.selector">selector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | Label query over pods whose evictions are managed by the disruption budget. |

---

##### `maxUnavailable`<sup>Optional</sup> <a name="maxUnavailable" id="cdk8s-metaflow.k8s.PodDisruptionBudgetSpecV1Beta1.property.maxUnavailable"></a>

```typescript
public readonly maxUnavailable: IntOrString;
```

- *Type:* cdk8s-metaflow.k8s.IntOrString

An eviction is allowed if at most "maxUnavailable" pods selected by "selector" are unavailable after the eviction, i.e. even in absence of the evicted pod. For example, one can prevent all voluntary evictions by specifying 0. This is a mutually exclusive setting with "minAvailable".

---

##### `minAvailable`<sup>Optional</sup> <a name="minAvailable" id="cdk8s-metaflow.k8s.PodDisruptionBudgetSpecV1Beta1.property.minAvailable"></a>

```typescript
public readonly minAvailable: IntOrString;
```

- *Type:* cdk8s-metaflow.k8s.IntOrString

An eviction is allowed if at least "minAvailable" pods selected by "selector" will still be available after the eviction, i.e. even in the absence of the evicted pod.  So for example you can prevent all voluntary evictions by specifying "100%".

---

##### `selector`<sup>Optional</sup> <a name="selector" id="cdk8s-metaflow.k8s.PodDisruptionBudgetSpecV1Beta1.property.selector"></a>

```typescript
public readonly selector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

Label query over pods whose evictions are managed by the disruption budget.

A null selector selects no pods. An empty selector ({}) also selects no pods, which differs from standard behavior of selecting all pods. In policy/v1, an empty selector will select all pods in the namespace.

---

### PodDisruptionBudgetV1Beta1Props <a name="PodDisruptionBudgetV1Beta1Props" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1Props"></a>

PodDisruptionBudget is an object to define the max disruption that can be caused to a collection of pods.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podDisruptionBudgetV1Beta1Props: k8s.PodDisruptionBudgetV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1Props.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.PodDisruptionBudgetSpecV1Beta1</code> | Specification of the desired behavior of the PodDisruptionBudget. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.PodDisruptionBudgetV1Beta1Props.property.spec"></a>

```typescript
public readonly spec: PodDisruptionBudgetSpecV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.PodDisruptionBudgetSpecV1Beta1

Specification of the desired behavior of the PodDisruptionBudget.

---

### PodDnsConfig <a name="PodDnsConfig" id="cdk8s-metaflow.k8s.PodDnsConfig"></a>

PodDNSConfig defines the DNS parameters of a pod in addition to those generated from DNSPolicy.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodDnsConfig.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podDnsConfig: k8s.PodDnsConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDnsConfig.property.nameservers">nameservers</a></code> | <code>string[]</code> | A list of DNS name server IP addresses. |
| <code><a href="#cdk8s-metaflow.k8s.PodDnsConfig.property.options">options</a></code> | <code>cdk8s-metaflow.k8s.PodDnsConfigOption[]</code> | A list of DNS resolver options. |
| <code><a href="#cdk8s-metaflow.k8s.PodDnsConfig.property.searches">searches</a></code> | <code>string[]</code> | A list of DNS search domains for host-name lookup. |

---

##### `nameservers`<sup>Optional</sup> <a name="nameservers" id="cdk8s-metaflow.k8s.PodDnsConfig.property.nameservers"></a>

```typescript
public readonly nameservers: string[];
```

- *Type:* string[]

A list of DNS name server IP addresses.

This will be appended to the base nameservers generated from DNSPolicy. Duplicated nameservers will be removed.

---

##### `options`<sup>Optional</sup> <a name="options" id="cdk8s-metaflow.k8s.PodDnsConfig.property.options"></a>

```typescript
public readonly options: PodDnsConfigOption[];
```

- *Type:* cdk8s-metaflow.k8s.PodDnsConfigOption[]

A list of DNS resolver options.

This will be merged with the base options generated from DNSPolicy. Duplicated entries will be removed. Resolution options given in Options will override those that appear in the base DNSPolicy.

---

##### `searches`<sup>Optional</sup> <a name="searches" id="cdk8s-metaflow.k8s.PodDnsConfig.property.searches"></a>

```typescript
public readonly searches: string[];
```

- *Type:* string[]

A list of DNS search domains for host-name lookup.

This will be appended to the base search paths generated from DNSPolicy. Duplicated search paths will be removed.

---

### PodDnsConfigOption <a name="PodDnsConfigOption" id="cdk8s-metaflow.k8s.PodDnsConfigOption"></a>

PodDNSConfigOption defines DNS resolver options of a pod.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodDnsConfigOption.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podDnsConfigOption: k8s.PodDnsConfigOption = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodDnsConfigOption.property.name">name</a></code> | <code>string</code> | Required. |
| <code><a href="#cdk8s-metaflow.k8s.PodDnsConfigOption.property.value">value</a></code> | <code>string</code> | *No description.* |

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.PodDnsConfigOption.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Required.

---

##### `value`<sup>Optional</sup> <a name="value" id="cdk8s-metaflow.k8s.PodDnsConfigOption.property.value"></a>

```typescript
public readonly value: string;
```

- *Type:* string

---

### PodListProps <a name="PodListProps" id="cdk8s-metaflow.k8s.PodListProps"></a>

PodList is a list of Pods.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podListProps: k8s.PodListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.Pod[]</code> | List of pods. |
| <code><a href="#cdk8s-metaflow.k8s.PodListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.PodListProps.property.items"></a>

```typescript
public readonly items: Pod[];
```

- *Type:* cdk8s-metaflow.k8s.Pod[]

List of pods.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

### PodProps <a name="PodProps" id="cdk8s-metaflow.k8s.PodProps"></a>

Pod is a collection of containers that can run on a host.

This resource is created by clients and scheduled onto hosts.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podProps: k8s.PodProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.PodProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.PodSpec</code> | Specification of the desired behavior of the pod. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.PodProps.property.spec"></a>

```typescript
public readonly spec: PodSpec;
```

- *Type:* cdk8s-metaflow.k8s.PodSpec

Specification of the desired behavior of the pod.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### PodReadinessGate <a name="PodReadinessGate" id="cdk8s-metaflow.k8s.PodReadinessGate"></a>

PodReadinessGate contains the reference to a pod condition.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodReadinessGate.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podReadinessGate: k8s.PodReadinessGate = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodReadinessGate.property.conditionType">conditionType</a></code> | <code>string</code> | ConditionType refers to a condition in the pod's condition list with matching type. |

---

##### `conditionType`<sup>Required</sup> <a name="conditionType" id="cdk8s-metaflow.k8s.PodReadinessGate.property.conditionType"></a>

```typescript
public readonly conditionType: string;
```

- *Type:* string

ConditionType refers to a condition in the pod's condition list with matching type.

---

### PodSecurityContext <a name="PodSecurityContext" id="cdk8s-metaflow.k8s.PodSecurityContext"></a>

PodSecurityContext holds pod-level security attributes and common container settings.

Some fields are also present in container.securityContext.  Field values of container.securityContext take precedence over field values of PodSecurityContext.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodSecurityContext.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podSecurityContext: k8s.PodSecurityContext = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityContext.property.fsGroup">fsGroup</a></code> | <code>number</code> | A special supplemental group that applies to all containers in a pod. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityContext.property.fsGroupChangePolicy">fsGroupChangePolicy</a></code> | <code>string</code> | fsGroupChangePolicy defines behavior of changing ownership and permission of the volume before being exposed inside Pod. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityContext.property.runAsGroup">runAsGroup</a></code> | <code>number</code> | The GID to run the entrypoint of the container process. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityContext.property.runAsNonRoot">runAsNonRoot</a></code> | <code>boolean</code> | Indicates that the container must run as a non-root user. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityContext.property.runAsUser">runAsUser</a></code> | <code>number</code> | The UID to run the entrypoint of the container process. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityContext.property.seccompProfile">seccompProfile</a></code> | <code>cdk8s-metaflow.k8s.SeccompProfile</code> | The seccomp options to use by the containers in this pod. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityContext.property.seLinuxOptions">seLinuxOptions</a></code> | <code>cdk8s-metaflow.k8s.SeLinuxOptions</code> | The SELinux context to be applied to all containers. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityContext.property.supplementalGroups">supplementalGroups</a></code> | <code>number[]</code> | A list of groups applied to the first process run in each container, in addition to the container's primary GID. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityContext.property.sysctls">sysctls</a></code> | <code>cdk8s-metaflow.k8s.Sysctl[]</code> | Sysctls hold a list of namespaced sysctls used for the pod. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityContext.property.windowsOptions">windowsOptions</a></code> | <code>cdk8s-metaflow.k8s.WindowsSecurityContextOptions</code> | The Windows specific settings applied to all containers. |

---

##### `fsGroup`<sup>Optional</sup> <a name="fsGroup" id="cdk8s-metaflow.k8s.PodSecurityContext.property.fsGroup"></a>

```typescript
public readonly fsGroup: number;
```

- *Type:* number

A special supplemental group that applies to all containers in a pod.

Some volume types allow the Kubelet to change the ownership of that volume to be owned by the pod:

1. The owning GID will be the FSGroup 2. The setgid bit is set (new files created in the volume will be owned by FSGroup) 3. The permission bits are OR'd with rw-rw----

If unset, the Kubelet will not modify the ownership and permissions of any volume.

---

##### `fsGroupChangePolicy`<sup>Optional</sup> <a name="fsGroupChangePolicy" id="cdk8s-metaflow.k8s.PodSecurityContext.property.fsGroupChangePolicy"></a>

```typescript
public readonly fsGroupChangePolicy: string;
```

- *Type:* string

fsGroupChangePolicy defines behavior of changing ownership and permission of the volume before being exposed inside Pod.

This field will only apply to volume types which support fsGroup based ownership(and permissions). It will have no effect on ephemeral volume types such as: secret, configmaps and emptydir. Valid values are "OnRootMismatch" and "Always". If not specified, "Always" is used.

---

##### `runAsGroup`<sup>Optional</sup> <a name="runAsGroup" id="cdk8s-metaflow.k8s.PodSecurityContext.property.runAsGroup"></a>

```typescript
public readonly runAsGroup: number;
```

- *Type:* number

The GID to run the entrypoint of the container process.

Uses runtime default if unset. May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.

---

##### `runAsNonRoot`<sup>Optional</sup> <a name="runAsNonRoot" id="cdk8s-metaflow.k8s.PodSecurityContext.property.runAsNonRoot"></a>

```typescript
public readonly runAsNonRoot: boolean;
```

- *Type:* boolean

Indicates that the container must run as a non-root user.

If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.

---

##### `runAsUser`<sup>Optional</sup> <a name="runAsUser" id="cdk8s-metaflow.k8s.PodSecurityContext.property.runAsUser"></a>

```typescript
public readonly runAsUser: number;
```

- *Type:* number
- *Default:* user specified in image metadata if unspecified. May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.

The UID to run the entrypoint of the container process.

Defaults to user specified in image metadata if unspecified. May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.

---

##### `seccompProfile`<sup>Optional</sup> <a name="seccompProfile" id="cdk8s-metaflow.k8s.PodSecurityContext.property.seccompProfile"></a>

```typescript
public readonly seccompProfile: SeccompProfile;
```

- *Type:* cdk8s-metaflow.k8s.SeccompProfile

The seccomp options to use by the containers in this pod.

---

##### `seLinuxOptions`<sup>Optional</sup> <a name="seLinuxOptions" id="cdk8s-metaflow.k8s.PodSecurityContext.property.seLinuxOptions"></a>

```typescript
public readonly seLinuxOptions: SeLinuxOptions;
```

- *Type:* cdk8s-metaflow.k8s.SeLinuxOptions

The SELinux context to be applied to all containers.

If unspecified, the container runtime will allocate a random SELinux context for each container.  May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container.

---

##### `supplementalGroups`<sup>Optional</sup> <a name="supplementalGroups" id="cdk8s-metaflow.k8s.PodSecurityContext.property.supplementalGroups"></a>

```typescript
public readonly supplementalGroups: number[];
```

- *Type:* number[]

A list of groups applied to the first process run in each container, in addition to the container's primary GID.

If unspecified, no groups will be added to any container.

---

##### `sysctls`<sup>Optional</sup> <a name="sysctls" id="cdk8s-metaflow.k8s.PodSecurityContext.property.sysctls"></a>

```typescript
public readonly sysctls: Sysctl[];
```

- *Type:* cdk8s-metaflow.k8s.Sysctl[]

Sysctls hold a list of namespaced sysctls used for the pod.

Pods with unsupported sysctls (by the container runtime) might fail to launch.

---

##### `windowsOptions`<sup>Optional</sup> <a name="windowsOptions" id="cdk8s-metaflow.k8s.PodSecurityContext.property.windowsOptions"></a>

```typescript
public readonly windowsOptions: WindowsSecurityContextOptions;
```

- *Type:* cdk8s-metaflow.k8s.WindowsSecurityContextOptions

The Windows specific settings applied to all containers.

If unspecified, the options within a container's SecurityContext will be used. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.

---

### PodSecurityPolicyListV1Beta1Props <a name="PodSecurityPolicyListV1Beta1Props" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1Props"></a>

PodSecurityPolicyList is a list of PodSecurityPolicy objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podSecurityPolicyListV1Beta1Props: k8s.PodSecurityPolicyListV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1[]</code> | items is a list of schema objects. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1Props.property.items"></a>

```typescript
public readonly items: PodSecurityPolicyV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1[]

items is a list of schema objects.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodSecurityPolicyListV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### PodSecurityPolicySpecV1Beta1 <a name="PodSecurityPolicySpecV1Beta1" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1"></a>

PodSecurityPolicySpec defines the policy enforced.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podSecurityPolicySpecV1Beta1: k8s.PodSecurityPolicySpecV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.fsGroup">fsGroup</a></code> | <code>cdk8s-metaflow.k8s.FsGroupStrategyOptionsV1Beta1</code> | fsGroup is the strategy that will dictate what fs group is used by the SecurityContext. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.runAsUser">runAsUser</a></code> | <code>cdk8s-metaflow.k8s.RunAsUserStrategyOptionsV1Beta1</code> | runAsUser is the strategy that will dictate the allowable RunAsUser values that may be set. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.seLinux">seLinux</a></code> | <code>cdk8s-metaflow.k8s.SeLinuxStrategyOptionsV1Beta1</code> | seLinux is the strategy that will dictate the allowable labels that may be set. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.supplementalGroups">supplementalGroups</a></code> | <code>cdk8s-metaflow.k8s.SupplementalGroupsStrategyOptionsV1Beta1</code> | supplementalGroups is the strategy that will dictate what supplemental groups are used by the SecurityContext. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.allowedCapabilities">allowedCapabilities</a></code> | <code>string[]</code> | allowedCapabilities is a list of capabilities that can be requested to add to the container. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.allowedCsiDrivers">allowedCsiDrivers</a></code> | <code>cdk8s-metaflow.k8s.AllowedCsiDriverV1Beta1[]</code> | AllowedCSIDrivers is an allowlist of inline CSI drivers that must be explicitly set to be embedded within a pod spec. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.allowedFlexVolumes">allowedFlexVolumes</a></code> | <code>cdk8s-metaflow.k8s.AllowedFlexVolumeV1Beta1[]</code> | allowedFlexVolumes is an allowlist of Flexvolumes. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.allowedHostPaths">allowedHostPaths</a></code> | <code>cdk8s-metaflow.k8s.AllowedHostPathV1Beta1[]</code> | allowedHostPaths is an allowlist of host paths. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.allowedProcMountTypes">allowedProcMountTypes</a></code> | <code>string[]</code> | AllowedProcMountTypes is an allowlist of allowed ProcMountTypes. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.allowedUnsafeSysctls">allowedUnsafeSysctls</a></code> | <code>string[]</code> | allowedUnsafeSysctls is a list of explicitly allowed unsafe sysctls, defaults to none. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.allowPrivilegeEscalation">allowPrivilegeEscalation</a></code> | <code>boolean</code> | allowPrivilegeEscalation determines if a pod can request to allow privilege escalation. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.defaultAddCapabilities">defaultAddCapabilities</a></code> | <code>string[]</code> | defaultAddCapabilities is the default set of capabilities that will be added to the container unless the pod spec specifically drops the capability. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.defaultAllowPrivilegeEscalation">defaultAllowPrivilegeEscalation</a></code> | <code>boolean</code> | defaultAllowPrivilegeEscalation controls the default setting for whether a process can gain more privileges than its parent process. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.forbiddenSysctls">forbiddenSysctls</a></code> | <code>string[]</code> | forbiddenSysctls is a list of explicitly forbidden sysctls, defaults to none. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.hostIpc">hostIpc</a></code> | <code>boolean</code> | hostIPC determines if the policy allows the use of HostIPC in the pod spec. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.hostNetwork">hostNetwork</a></code> | <code>boolean</code> | hostNetwork determines if the policy allows the use of HostNetwork in the pod spec. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.hostPid">hostPid</a></code> | <code>boolean</code> | hostPID determines if the policy allows the use of HostPID in the pod spec. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.hostPorts">hostPorts</a></code> | <code>cdk8s-metaflow.k8s.HostPortRangeV1Beta1[]</code> | hostPorts determines which host port ranges are allowed to be exposed. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.privileged">privileged</a></code> | <code>boolean</code> | privileged determines if a pod can request to be run as privileged. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.readOnlyRootFilesystem">readOnlyRootFilesystem</a></code> | <code>boolean</code> | readOnlyRootFilesystem when set to true will force containers to run with a read only root file system. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.requiredDropCapabilities">requiredDropCapabilities</a></code> | <code>string[]</code> | requiredDropCapabilities are the capabilities that will be dropped from the container. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.runAsGroup">runAsGroup</a></code> | <code>cdk8s-metaflow.k8s.RunAsGroupStrategyOptionsV1Beta1</code> | RunAsGroup is the strategy that will dictate the allowable RunAsGroup values that may be set. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.runtimeClass">runtimeClass</a></code> | <code>cdk8s-metaflow.k8s.RuntimeClassStrategyOptionsV1Beta1</code> | runtimeClass is the strategy that will dictate the allowable RuntimeClasses for a pod. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.volumes">volumes</a></code> | <code>string[]</code> | volumes is an allowlist of volume plugins. |

---

##### `fsGroup`<sup>Required</sup> <a name="fsGroup" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.fsGroup"></a>

```typescript
public readonly fsGroup: FsGroupStrategyOptionsV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.FsGroupStrategyOptionsV1Beta1

fsGroup is the strategy that will dictate what fs group is used by the SecurityContext.

---

##### `runAsUser`<sup>Required</sup> <a name="runAsUser" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.runAsUser"></a>

```typescript
public readonly runAsUser: RunAsUserStrategyOptionsV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.RunAsUserStrategyOptionsV1Beta1

runAsUser is the strategy that will dictate the allowable RunAsUser values that may be set.

---

##### `seLinux`<sup>Required</sup> <a name="seLinux" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.seLinux"></a>

```typescript
public readonly seLinux: SeLinuxStrategyOptionsV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.SeLinuxStrategyOptionsV1Beta1

seLinux is the strategy that will dictate the allowable labels that may be set.

---

##### `supplementalGroups`<sup>Required</sup> <a name="supplementalGroups" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.supplementalGroups"></a>

```typescript
public readonly supplementalGroups: SupplementalGroupsStrategyOptionsV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.SupplementalGroupsStrategyOptionsV1Beta1

supplementalGroups is the strategy that will dictate what supplemental groups are used by the SecurityContext.

---

##### `allowedCapabilities`<sup>Optional</sup> <a name="allowedCapabilities" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.allowedCapabilities"></a>

```typescript
public readonly allowedCapabilities: string[];
```

- *Type:* string[]

allowedCapabilities is a list of capabilities that can be requested to add to the container.

Capabilities in this field may be added at the pod author's discretion. You must not list a capability in both allowedCapabilities and requiredDropCapabilities.

---

##### `allowedCsiDrivers`<sup>Optional</sup> <a name="allowedCsiDrivers" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.allowedCsiDrivers"></a>

```typescript
public readonly allowedCsiDrivers: AllowedCsiDriverV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.AllowedCsiDriverV1Beta1[]

AllowedCSIDrivers is an allowlist of inline CSI drivers that must be explicitly set to be embedded within a pod spec.

An empty value indicates that any CSI driver can be used for inline ephemeral volumes. This is a beta field, and is only honored if the API server enables the CSIInlineVolume feature gate.

---

##### `allowedFlexVolumes`<sup>Optional</sup> <a name="allowedFlexVolumes" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.allowedFlexVolumes"></a>

```typescript
public readonly allowedFlexVolumes: AllowedFlexVolumeV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.AllowedFlexVolumeV1Beta1[]

allowedFlexVolumes is an allowlist of Flexvolumes.

Empty or nil indicates that all Flexvolumes may be used.  This parameter is effective only when the usage of the Flexvolumes is allowed in the "volumes" field.

---

##### `allowedHostPaths`<sup>Optional</sup> <a name="allowedHostPaths" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.allowedHostPaths"></a>

```typescript
public readonly allowedHostPaths: AllowedHostPathV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.AllowedHostPathV1Beta1[]

allowedHostPaths is an allowlist of host paths.

Empty indicates that all host paths may be used.

---

##### `allowedProcMountTypes`<sup>Optional</sup> <a name="allowedProcMountTypes" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.allowedProcMountTypes"></a>

```typescript
public readonly allowedProcMountTypes: string[];
```

- *Type:* string[]

AllowedProcMountTypes is an allowlist of allowed ProcMountTypes.

Empty or nil indicates that only the DefaultProcMountType may be used. This requires the ProcMountType feature flag to be enabled.

---

##### `allowedUnsafeSysctls`<sup>Optional</sup> <a name="allowedUnsafeSysctls" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.allowedUnsafeSysctls"></a>

```typescript
public readonly allowedUnsafeSysctls: string[];
```

- *Type:* string[]

allowedUnsafeSysctls is a list of explicitly allowed unsafe sysctls, defaults to none.

Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of allowed sysctls. Single * means all unsafe sysctls are allowed. Kubelet has to allowlist all allowed unsafe sysctls explicitly to avoid rejection.

Examples: e.g. "foo/*" allows "foo/bar", "foo/baz", etc. e.g. "foo.*" allows "foo.bar", "foo.baz", etc.

---

##### `allowPrivilegeEscalation`<sup>Optional</sup> <a name="allowPrivilegeEscalation" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.allowPrivilegeEscalation"></a>

```typescript
public readonly allowPrivilegeEscalation: boolean;
```

- *Type:* boolean

allowPrivilegeEscalation determines if a pod can request to allow privilege escalation.

If unspecified, defaults to true.

---

##### `defaultAddCapabilities`<sup>Optional</sup> <a name="defaultAddCapabilities" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.defaultAddCapabilities"></a>

```typescript
public readonly defaultAddCapabilities: string[];
```

- *Type:* string[]

defaultAddCapabilities is the default set of capabilities that will be added to the container unless the pod spec specifically drops the capability.

You may not list a capability in both defaultAddCapabilities and requiredDropCapabilities. Capabilities added here are implicitly allowed, and need not be included in the allowedCapabilities list.

---

##### `defaultAllowPrivilegeEscalation`<sup>Optional</sup> <a name="defaultAllowPrivilegeEscalation" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.defaultAllowPrivilegeEscalation"></a>

```typescript
public readonly defaultAllowPrivilegeEscalation: boolean;
```

- *Type:* boolean

defaultAllowPrivilegeEscalation controls the default setting for whether a process can gain more privileges than its parent process.

---

##### `forbiddenSysctls`<sup>Optional</sup> <a name="forbiddenSysctls" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.forbiddenSysctls"></a>

```typescript
public readonly forbiddenSysctls: string[];
```

- *Type:* string[]

forbiddenSysctls is a list of explicitly forbidden sysctls, defaults to none.

Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of forbidden sysctls. Single * means all sysctls are forbidden.

Examples: e.g. "foo/*" forbids "foo/bar", "foo/baz", etc. e.g. "foo.*" forbids "foo.bar", "foo.baz", etc.

---

##### `hostIpc`<sup>Optional</sup> <a name="hostIpc" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.hostIpc"></a>

```typescript
public readonly hostIpc: boolean;
```

- *Type:* boolean

hostIPC determines if the policy allows the use of HostIPC in the pod spec.

---

##### `hostNetwork`<sup>Optional</sup> <a name="hostNetwork" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.hostNetwork"></a>

```typescript
public readonly hostNetwork: boolean;
```

- *Type:* boolean

hostNetwork determines if the policy allows the use of HostNetwork in the pod spec.

---

##### `hostPid`<sup>Optional</sup> <a name="hostPid" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.hostPid"></a>

```typescript
public readonly hostPid: boolean;
```

- *Type:* boolean

hostPID determines if the policy allows the use of HostPID in the pod spec.

---

##### `hostPorts`<sup>Optional</sup> <a name="hostPorts" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.hostPorts"></a>

```typescript
public readonly hostPorts: HostPortRangeV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.HostPortRangeV1Beta1[]

hostPorts determines which host port ranges are allowed to be exposed.

---

##### `privileged`<sup>Optional</sup> <a name="privileged" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.privileged"></a>

```typescript
public readonly privileged: boolean;
```

- *Type:* boolean

privileged determines if a pod can request to be run as privileged.

---

##### `readOnlyRootFilesystem`<sup>Optional</sup> <a name="readOnlyRootFilesystem" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.readOnlyRootFilesystem"></a>

```typescript
public readonly readOnlyRootFilesystem: boolean;
```

- *Type:* boolean

readOnlyRootFilesystem when set to true will force containers to run with a read only root file system.

If the container specifically requests to run with a non-read only root file system the PSP should deny the pod. If set to false the container may run with a read only root file system if it wishes but it will not be forced to.

---

##### `requiredDropCapabilities`<sup>Optional</sup> <a name="requiredDropCapabilities" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.requiredDropCapabilities"></a>

```typescript
public readonly requiredDropCapabilities: string[];
```

- *Type:* string[]

requiredDropCapabilities are the capabilities that will be dropped from the container.

These are required to be dropped and cannot be added.

---

##### `runAsGroup`<sup>Optional</sup> <a name="runAsGroup" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.runAsGroup"></a>

```typescript
public readonly runAsGroup: RunAsGroupStrategyOptionsV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.RunAsGroupStrategyOptionsV1Beta1

RunAsGroup is the strategy that will dictate the allowable RunAsGroup values that may be set.

If this field is omitted, the pod's RunAsGroup can take any value. This field requires the RunAsGroup feature gate to be enabled.

---

##### `runtimeClass`<sup>Optional</sup> <a name="runtimeClass" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.runtimeClass"></a>

```typescript
public readonly runtimeClass: RuntimeClassStrategyOptionsV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.RuntimeClassStrategyOptionsV1Beta1

runtimeClass is the strategy that will dictate the allowable RuntimeClasses for a pod.

If this field is omitted, the pod's runtimeClassName field is unrestricted. Enforcement of this field depends on the RuntimeClass feature gate being enabled.

---

##### `volumes`<sup>Optional</sup> <a name="volumes" id="cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1.property.volumes"></a>

```typescript
public readonly volumes: string[];
```

- *Type:* string[]

volumes is an allowlist of volume plugins.

Empty indicates that no volumes may be used. To allow all volumes you may use '*'.

---

### PodSecurityPolicyV1Beta1Props <a name="PodSecurityPolicyV1Beta1Props" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1Props"></a>

PodSecurityPolicy governs the ability to make requests that affect the Security Context that will be applied to a pod and container.

Deprecated in 1.21.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podSecurityPolicyV1Beta1Props: k8s.PodSecurityPolicyV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1Props.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1</code> | spec defines the policy enforced. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.PodSecurityPolicyV1Beta1Props.property.spec"></a>

```typescript
public readonly spec: PodSecurityPolicySpecV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.PodSecurityPolicySpecV1Beta1

spec defines the policy enforced.

---

### PodsMetricSourceV2Beta1 <a name="PodsMetricSourceV2Beta1" id="cdk8s-metaflow.k8s.PodsMetricSourceV2Beta1"></a>

PodsMetricSource indicates how to scale on a metric describing each pod in the current scale target (for example, transactions-processed-per-second).

The values will be averaged together before being compared to the target value.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodsMetricSourceV2Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podsMetricSourceV2Beta1: k8s.PodsMetricSourceV2Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodsMetricSourceV2Beta1.property.metricName">metricName</a></code> | <code>string</code> | metricName is the name of the metric in question. |
| <code><a href="#cdk8s-metaflow.k8s.PodsMetricSourceV2Beta1.property.targetAverageValue">targetAverageValue</a></code> | <code>cdk8s-metaflow.k8s.Quantity</code> | targetAverageValue is the target value of the average of the metric across all relevant pods (as a quantity). |
| <code><a href="#cdk8s-metaflow.k8s.PodsMetricSourceV2Beta1.property.selector">selector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | selector is the string-encoded form of a standard kubernetes label selector for the given metric When set, it is passed as an additional parameter to the metrics server for more specific metrics scoping When unset, just the metricName will be used to gather metrics. |

---

##### `metricName`<sup>Required</sup> <a name="metricName" id="cdk8s-metaflow.k8s.PodsMetricSourceV2Beta1.property.metricName"></a>

```typescript
public readonly metricName: string;
```

- *Type:* string

metricName is the name of the metric in question.

---

##### `targetAverageValue`<sup>Required</sup> <a name="targetAverageValue" id="cdk8s-metaflow.k8s.PodsMetricSourceV2Beta1.property.targetAverageValue"></a>

```typescript
public readonly targetAverageValue: Quantity;
```

- *Type:* cdk8s-metaflow.k8s.Quantity

targetAverageValue is the target value of the average of the metric across all relevant pods (as a quantity).

---

##### `selector`<sup>Optional</sup> <a name="selector" id="cdk8s-metaflow.k8s.PodsMetricSourceV2Beta1.property.selector"></a>

```typescript
public readonly selector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

selector is the string-encoded form of a standard kubernetes label selector for the given metric When set, it is passed as an additional parameter to the metrics server for more specific metrics scoping When unset, just the metricName will be used to gather metrics.

---

### PodsMetricSourceV2Beta2 <a name="PodsMetricSourceV2Beta2" id="cdk8s-metaflow.k8s.PodsMetricSourceV2Beta2"></a>

PodsMetricSource indicates how to scale on a metric describing each pod in the current scale target (for example, transactions-processed-per-second).

The values will be averaged together before being compared to the target value.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodsMetricSourceV2Beta2.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podsMetricSourceV2Beta2: k8s.PodsMetricSourceV2Beta2 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodsMetricSourceV2Beta2.property.metric">metric</a></code> | <code>cdk8s-metaflow.k8s.MetricIdentifierV2Beta2</code> | metric identifies the target metric by name and selector. |
| <code><a href="#cdk8s-metaflow.k8s.PodsMetricSourceV2Beta2.property.target">target</a></code> | <code>cdk8s-metaflow.k8s.MetricTargetV2Beta2</code> | target specifies the target value for the given metric. |

---

##### `metric`<sup>Required</sup> <a name="metric" id="cdk8s-metaflow.k8s.PodsMetricSourceV2Beta2.property.metric"></a>

```typescript
public readonly metric: MetricIdentifierV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.MetricIdentifierV2Beta2

metric identifies the target metric by name and selector.

---

##### `target`<sup>Required</sup> <a name="target" id="cdk8s-metaflow.k8s.PodsMetricSourceV2Beta2.property.target"></a>

```typescript
public readonly target: MetricTargetV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.MetricTargetV2Beta2

target specifies the target value for the given metric.

---

### PodSpec <a name="PodSpec" id="cdk8s-metaflow.k8s.PodSpec"></a>

PodSpec is a description of a pod.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podSpec: k8s.PodSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.containers">containers</a></code> | <code>cdk8s-metaflow.k8s.Container[]</code> | List of containers belonging to the pod. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.activeDeadlineSeconds">activeDeadlineSeconds</a></code> | <code>number</code> | Optional duration in seconds the pod may be active on the node relative to StartTime before the system will actively try to mark it failed and kill associated containers. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.affinity">affinity</a></code> | <code>cdk8s-metaflow.k8s.Affinity</code> | If specified, the pod's scheduling constraints. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.automountServiceAccountToken">automountServiceAccountToken</a></code> | <code>boolean</code> | AutomountServiceAccountToken indicates whether a service account token should be automatically mounted. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.dnsConfig">dnsConfig</a></code> | <code>cdk8s-metaflow.k8s.PodDnsConfig</code> | Specifies the DNS parameters of a pod. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.dnsPolicy">dnsPolicy</a></code> | <code>string</code> | Set DNS policy for the pod. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.enableServiceLinks">enableServiceLinks</a></code> | <code>boolean</code> | EnableServiceLinks indicates whether information about services should be injected into pod's environment variables, matching the syntax of Docker links. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.ephemeralContainers">ephemeralContainers</a></code> | <code>cdk8s-metaflow.k8s.EphemeralContainer[]</code> | List of ephemeral containers run in this pod. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.hostAliases">hostAliases</a></code> | <code>cdk8s-metaflow.k8s.HostAlias[]</code> | HostAliases is an optional list of hosts and IPs that will be injected into the pod's hosts file if specified. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.hostIpc">hostIpc</a></code> | <code>boolean</code> | Use the host's ipc namespace. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.hostname">hostname</a></code> | <code>string</code> | Specifies the hostname of the Pod If not specified, the pod's hostname will be set to a system-defined value. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.hostNetwork">hostNetwork</a></code> | <code>boolean</code> | Host networking requested for this pod. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.hostPid">hostPid</a></code> | <code>boolean</code> | Use the host's pid namespace. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.imagePullSecrets">imagePullSecrets</a></code> | <code>cdk8s-metaflow.k8s.LocalObjectReference[]</code> | ImagePullSecrets is an optional list of references to secrets in the same namespace to use for pulling any of the images used by this PodSpec. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.initContainers">initContainers</a></code> | <code>cdk8s-metaflow.k8s.Container[]</code> | List of initialization containers belonging to the pod. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.nodeName">nodeName</a></code> | <code>string</code> | NodeName is a request to schedule this pod onto a specific node. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.nodeSelector">nodeSelector</a></code> | <code>{[ key: string ]: string}</code> | NodeSelector is a selector which must be true for the pod to fit on a node. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.overhead">overhead</a></code> | <code>{[ key: string ]: cdk8s-metaflow.k8s.Quantity}</code> | Overhead represents the resource overhead associated with running a pod for a given RuntimeClass. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.preemptionPolicy">preemptionPolicy</a></code> | <code>string</code> | PreemptionPolicy is the Policy for preempting pods with lower priority. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.priority">priority</a></code> | <code>number</code> | The priority value. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.priorityClassName">priorityClassName</a></code> | <code>string</code> | If specified, indicates the pod's priority. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.readinessGates">readinessGates</a></code> | <code>cdk8s-metaflow.k8s.PodReadinessGate[]</code> | If specified, all readiness gates will be evaluated for pod readiness. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.restartPolicy">restartPolicy</a></code> | <code>string</code> | Restart policy for all containers within the pod. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.runtimeClassName">runtimeClassName</a></code> | <code>string</code> | RuntimeClassName refers to a RuntimeClass object in the node.k8s.io group, which should be used to run this pod.  If no RuntimeClass resource matches the named class, the pod will not be run. If unset or empty, the "legacy" RuntimeClass will be used, which is an implicit class with an empty definition that uses the default runtime handler. More info: https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class This is a beta feature as of Kubernetes v1.14. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.schedulerName">schedulerName</a></code> | <code>string</code> | If specified, the pod will be dispatched by specified scheduler. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.securityContext">securityContext</a></code> | <code>cdk8s-metaflow.k8s.PodSecurityContext</code> | SecurityContext holds pod-level security attributes and common container settings. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.serviceAccount">serviceAccount</a></code> | <code>string</code> | DeprecatedServiceAccount is a depreciated alias for ServiceAccountName. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.serviceAccountName">serviceAccountName</a></code> | <code>string</code> | ServiceAccountName is the name of the ServiceAccount to use to run this pod. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.setHostnameAsFqdn">setHostnameAsFqdn</a></code> | <code>boolean</code> | If true the pod's hostname will be configured as the pod's FQDN, rather than the leaf name (the default). |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.shareProcessNamespace">shareProcessNamespace</a></code> | <code>boolean</code> | Share a single process namespace between all of the containers in a pod. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.subdomain">subdomain</a></code> | <code>string</code> | If specified, the fully qualified Pod hostname will be "<hostname>.<subdomain>.<pod namespace>.svc.<cluster domain>". If not specified, the pod will not have a domainname at all. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.terminationGracePeriodSeconds">terminationGracePeriodSeconds</a></code> | <code>number</code> | Optional duration in seconds the pod needs to terminate gracefully. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.tolerations">tolerations</a></code> | <code>cdk8s-metaflow.k8s.Toleration[]</code> | If specified, the pod's tolerations. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.topologySpreadConstraints">topologySpreadConstraints</a></code> | <code>cdk8s-metaflow.k8s.TopologySpreadConstraint[]</code> | TopologySpreadConstraints describes how a group of pods ought to spread across topology domains. |
| <code><a href="#cdk8s-metaflow.k8s.PodSpec.property.volumes">volumes</a></code> | <code>cdk8s-metaflow.k8s.Volume[]</code> | List of volumes that can be mounted by containers belonging to the pod. |

---

##### `containers`<sup>Required</sup> <a name="containers" id="cdk8s-metaflow.k8s.PodSpec.property.containers"></a>

```typescript
public readonly containers: Container[];
```

- *Type:* cdk8s-metaflow.k8s.Container[]

List of containers belonging to the pod.

Containers cannot currently be added or removed. There must be at least one container in a Pod. Cannot be updated.

---

##### `activeDeadlineSeconds`<sup>Optional</sup> <a name="activeDeadlineSeconds" id="cdk8s-metaflow.k8s.PodSpec.property.activeDeadlineSeconds"></a>

```typescript
public readonly activeDeadlineSeconds: number;
```

- *Type:* number

Optional duration in seconds the pod may be active on the node relative to StartTime before the system will actively try to mark it failed and kill associated containers.

Value must be a positive integer.

---

##### `affinity`<sup>Optional</sup> <a name="affinity" id="cdk8s-metaflow.k8s.PodSpec.property.affinity"></a>

```typescript
public readonly affinity: Affinity;
```

- *Type:* cdk8s-metaflow.k8s.Affinity

If specified, the pod's scheduling constraints.

---

##### `automountServiceAccountToken`<sup>Optional</sup> <a name="automountServiceAccountToken" id="cdk8s-metaflow.k8s.PodSpec.property.automountServiceAccountToken"></a>

```typescript
public readonly automountServiceAccountToken: boolean;
```

- *Type:* boolean

AutomountServiceAccountToken indicates whether a service account token should be automatically mounted.

---

##### `dnsConfig`<sup>Optional</sup> <a name="dnsConfig" id="cdk8s-metaflow.k8s.PodSpec.property.dnsConfig"></a>

```typescript
public readonly dnsConfig: PodDnsConfig;
```

- *Type:* cdk8s-metaflow.k8s.PodDnsConfig

Specifies the DNS parameters of a pod.

Parameters specified here will be merged to the generated DNS configuration based on DNSPolicy.

---

##### `dnsPolicy`<sup>Optional</sup> <a name="dnsPolicy" id="cdk8s-metaflow.k8s.PodSpec.property.dnsPolicy"></a>

```typescript
public readonly dnsPolicy: string;
```

- *Type:* string
- *Default:* ClusterFirst". Valid values are 'ClusterFirstWithHostNet', 'ClusterFirst', 'Default' or 'None'. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy. To have DNS options set along with hostNetwork, you have to specify DNS policy explicitly to 'ClusterFirstWithHostNet'.

Set DNS policy for the pod.

Defaults to "ClusterFirst". Valid values are 'ClusterFirstWithHostNet', 'ClusterFirst', 'Default' or 'None'. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy. To have DNS options set along with hostNetwork, you have to specify DNS policy explicitly to 'ClusterFirstWithHostNet'.

---

##### `enableServiceLinks`<sup>Optional</sup> <a name="enableServiceLinks" id="cdk8s-metaflow.k8s.PodSpec.property.enableServiceLinks"></a>

```typescript
public readonly enableServiceLinks: boolean;
```

- *Type:* boolean
- *Default:* true.

EnableServiceLinks indicates whether information about services should be injected into pod's environment variables, matching the syntax of Docker links.

Optional: Defaults to true.

---

##### `ephemeralContainers`<sup>Optional</sup> <a name="ephemeralContainers" id="cdk8s-metaflow.k8s.PodSpec.property.ephemeralContainers"></a>

```typescript
public readonly ephemeralContainers: EphemeralContainer[];
```

- *Type:* cdk8s-metaflow.k8s.EphemeralContainer[]

List of ephemeral containers run in this pod.

Ephemeral containers may be run in an existing pod to perform user-initiated actions such as debugging. This list cannot be specified when creating a pod, and it cannot be modified by updating the pod spec. In order to add an ephemeral container to an existing pod, use the pod's ephemeralcontainers subresource. This field is alpha-level and is only honored by servers that enable the EphemeralContainers feature.

---

##### `hostAliases`<sup>Optional</sup> <a name="hostAliases" id="cdk8s-metaflow.k8s.PodSpec.property.hostAliases"></a>

```typescript
public readonly hostAliases: HostAlias[];
```

- *Type:* cdk8s-metaflow.k8s.HostAlias[]

HostAliases is an optional list of hosts and IPs that will be injected into the pod's hosts file if specified.

This is only valid for non-hostNetwork pods.

---

##### `hostIpc`<sup>Optional</sup> <a name="hostIpc" id="cdk8s-metaflow.k8s.PodSpec.property.hostIpc"></a>

```typescript
public readonly hostIpc: boolean;
```

- *Type:* boolean
- *Default:* false.

Use the host's ipc namespace.

Optional: Default to false.

---

##### `hostname`<sup>Optional</sup> <a name="hostname" id="cdk8s-metaflow.k8s.PodSpec.property.hostname"></a>

```typescript
public readonly hostname: string;
```

- *Type:* string

Specifies the hostname of the Pod If not specified, the pod's hostname will be set to a system-defined value.

---

##### `hostNetwork`<sup>Optional</sup> <a name="hostNetwork" id="cdk8s-metaflow.k8s.PodSpec.property.hostNetwork"></a>

```typescript
public readonly hostNetwork: boolean;
```

- *Type:* boolean
- *Default:* false.

Host networking requested for this pod.

Use the host's network namespace. If this option is set, the ports that will be used must be specified. Default to false.

---

##### `hostPid`<sup>Optional</sup> <a name="hostPid" id="cdk8s-metaflow.k8s.PodSpec.property.hostPid"></a>

```typescript
public readonly hostPid: boolean;
```

- *Type:* boolean
- *Default:* false.

Use the host's pid namespace.

Optional: Default to false.

---

##### `imagePullSecrets`<sup>Optional</sup> <a name="imagePullSecrets" id="cdk8s-metaflow.k8s.PodSpec.property.imagePullSecrets"></a>

```typescript
public readonly imagePullSecrets: LocalObjectReference[];
```

- *Type:* cdk8s-metaflow.k8s.LocalObjectReference[]

ImagePullSecrets is an optional list of references to secrets in the same namespace to use for pulling any of the images used by this PodSpec.

If specified, these secrets will be passed to individual puller implementations for them to use. For example, in the case of docker, only DockerConfig type secrets are honored. More info: https://kubernetes.io/docs/concepts/containers/images#specifying-imagepullsecrets-on-a-pod

---

##### `initContainers`<sup>Optional</sup> <a name="initContainers" id="cdk8s-metaflow.k8s.PodSpec.property.initContainers"></a>

```typescript
public readonly initContainers: Container[];
```

- *Type:* cdk8s-metaflow.k8s.Container[]

List of initialization containers belonging to the pod.

Init containers are executed in order prior to containers being started. If any init container fails, the pod is considered to have failed and is handled according to its restartPolicy. The name for an init container or normal container must be unique among all containers. Init containers may not have Lifecycle actions, Readiness probes, Liveness probes, or Startup probes. The resourceRequirements of an init container are taken into account during scheduling by finding the highest request/limit for each resource type, and then using the max of of that value or the sum of the normal containers. Limits are applied to init containers in a similar fashion. Init containers cannot currently be added or removed. Cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/init-containers/

---

##### `nodeName`<sup>Optional</sup> <a name="nodeName" id="cdk8s-metaflow.k8s.PodSpec.property.nodeName"></a>

```typescript
public readonly nodeName: string;
```

- *Type:* string

NodeName is a request to schedule this pod onto a specific node.

If it is non-empty, the scheduler simply schedules this pod onto that node, assuming that it fits resource requirements.

---

##### `nodeSelector`<sup>Optional</sup> <a name="nodeSelector" id="cdk8s-metaflow.k8s.PodSpec.property.nodeSelector"></a>

```typescript
public readonly nodeSelector: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

NodeSelector is a selector which must be true for the pod to fit on a node.

Selector which must match a node's labels for the pod to be scheduled on that node. More info: https://kubernetes.io/docs/concepts/configuration/assign-pod-node/

---

##### `overhead`<sup>Optional</sup> <a name="overhead" id="cdk8s-metaflow.k8s.PodSpec.property.overhead"></a>

```typescript
public readonly overhead: {[ key: string ]: Quantity};
```

- *Type:* {[ key: string ]: cdk8s-metaflow.k8s.Quantity}

Overhead represents the resource overhead associated with running a pod for a given RuntimeClass.

This field will be autopopulated at admission time by the RuntimeClass admission controller. If the RuntimeClass admission controller is enabled, overhead must not be set in Pod create requests. The RuntimeClass admission controller will reject Pod create requests which have the overhead already set. If RuntimeClass is configured and selected in the PodSpec, Overhead will be set to the value defined in the corresponding RuntimeClass, otherwise it will remain unset and treated as zero. More info: https://git.k8s.io/enhancements/keps/sig-node/688-pod-overhead/README.md This field is beta-level as of Kubernetes v1.18, and is only honored by servers that enable the PodOverhead feature.

---

##### `preemptionPolicy`<sup>Optional</sup> <a name="preemptionPolicy" id="cdk8s-metaflow.k8s.PodSpec.property.preemptionPolicy"></a>

```typescript
public readonly preemptionPolicy: string;
```

- *Type:* string
- *Default:* PreemptLowerPriority if unset. This field is beta-level, gated by the NonPreemptingPriority feature-gate.

PreemptionPolicy is the Policy for preempting pods with lower priority.

One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset. This field is beta-level, gated by the NonPreemptingPriority feature-gate.

---

##### `priority`<sup>Optional</sup> <a name="priority" id="cdk8s-metaflow.k8s.PodSpec.property.priority"></a>

```typescript
public readonly priority: number;
```

- *Type:* number

The priority value.

Various system components use this field to find the priority of the pod. When Priority Admission Controller is enabled, it prevents users from setting this field. The admission controller populates this field from PriorityClassName. The higher the value, the higher the priority.

---

##### `priorityClassName`<sup>Optional</sup> <a name="priorityClassName" id="cdk8s-metaflow.k8s.PodSpec.property.priorityClassName"></a>

```typescript
public readonly priorityClassName: string;
```

- *Type:* string

If specified, indicates the pod's priority.

"system-node-critical" and "system-cluster-critical" are two special keywords which indicate the highest priorities with the former being the highest priority. Any other name must be defined by creating a PriorityClass object with that name. If not specified, the pod priority will be default or zero if there is no default.

---

##### `readinessGates`<sup>Optional</sup> <a name="readinessGates" id="cdk8s-metaflow.k8s.PodSpec.property.readinessGates"></a>

```typescript
public readonly readinessGates: PodReadinessGate[];
```

- *Type:* cdk8s-metaflow.k8s.PodReadinessGate[]

If specified, all readiness gates will be evaluated for pod readiness.

A pod is ready when all its containers are ready AND all conditions specified in the readiness gates have status equal to "True" More info: https://git.k8s.io/enhancements/keps/sig-network/580-pod-readiness-gates

---

##### `restartPolicy`<sup>Optional</sup> <a name="restartPolicy" id="cdk8s-metaflow.k8s.PodSpec.property.restartPolicy"></a>

```typescript
public readonly restartPolicy: string;
```

- *Type:* string
- *Default:* Always. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#restart-policy

Restart policy for all containers within the pod.

One of Always, OnFailure, Never. Default to Always. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#restart-policy

---

##### `runtimeClassName`<sup>Optional</sup> <a name="runtimeClassName" id="cdk8s-metaflow.k8s.PodSpec.property.runtimeClassName"></a>

```typescript
public readonly runtimeClassName: string;
```

- *Type:* string

RuntimeClassName refers to a RuntimeClass object in the node.k8s.io group, which should be used to run this pod.  If no RuntimeClass resource matches the named class, the pod will not be run. If unset or empty, the "legacy" RuntimeClass will be used, which is an implicit class with an empty definition that uses the default runtime handler. More info: https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class This is a beta feature as of Kubernetes v1.14.

---

##### `schedulerName`<sup>Optional</sup> <a name="schedulerName" id="cdk8s-metaflow.k8s.PodSpec.property.schedulerName"></a>

```typescript
public readonly schedulerName: string;
```

- *Type:* string

If specified, the pod will be dispatched by specified scheduler.

If not specified, the pod will be dispatched by default scheduler.

---

##### `securityContext`<sup>Optional</sup> <a name="securityContext" id="cdk8s-metaflow.k8s.PodSpec.property.securityContext"></a>

```typescript
public readonly securityContext: PodSecurityContext;
```

- *Type:* cdk8s-metaflow.k8s.PodSecurityContext
- *Default:* empty.  See type description for default values of each field.

SecurityContext holds pod-level security attributes and common container settings.

Optional: Defaults to empty.  See type description for default values of each field.

---

##### `serviceAccount`<sup>Optional</sup> <a name="serviceAccount" id="cdk8s-metaflow.k8s.PodSpec.property.serviceAccount"></a>

```typescript
public readonly serviceAccount: string;
```

- *Type:* string

DeprecatedServiceAccount is a depreciated alias for ServiceAccountName.

Deprecated: Use serviceAccountName instead.

---

##### `serviceAccountName`<sup>Optional</sup> <a name="serviceAccountName" id="cdk8s-metaflow.k8s.PodSpec.property.serviceAccountName"></a>

```typescript
public readonly serviceAccountName: string;
```

- *Type:* string

ServiceAccountName is the name of the ServiceAccount to use to run this pod.

More info: https://kubernetes.io/docs/tasks/configure-pod-container/configure-service-account/

---

##### `setHostnameAsFqdn`<sup>Optional</sup> <a name="setHostnameAsFqdn" id="cdk8s-metaflow.k8s.PodSpec.property.setHostnameAsFqdn"></a>

```typescript
public readonly setHostnameAsFqdn: boolean;
```

- *Type:* boolean
- *Default:* false.

If true the pod's hostname will be configured as the pod's FQDN, rather than the leaf name (the default).

In Linux containers, this means setting the FQDN in the hostname field of the kernel (the nodename field of struct utsname). In Windows containers, this means setting the registry value of hostname for the registry key HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\Tcpip\Parameters to FQDN. If a pod does not have FQDN, this has no effect. Default to false.

---

##### `shareProcessNamespace`<sup>Optional</sup> <a name="shareProcessNamespace" id="cdk8s-metaflow.k8s.PodSpec.property.shareProcessNamespace"></a>

```typescript
public readonly shareProcessNamespace: boolean;
```

- *Type:* boolean
- *Default:* false.

Share a single process namespace between all of the containers in a pod.

When this is set containers will be able to view and signal processes from other containers in the same pod, and the first process in each container will not be assigned PID 1. HostPID and ShareProcessNamespace cannot both be set. Optional: Default to false.

---

##### `subdomain`<sup>Optional</sup> <a name="subdomain" id="cdk8s-metaflow.k8s.PodSpec.property.subdomain"></a>

```typescript
public readonly subdomain: string;
```

- *Type:* string

If specified, the fully qualified Pod hostname will be "<hostname>.<subdomain>.<pod namespace>.svc.<cluster domain>". If not specified, the pod will not have a domainname at all.

---

##### `terminationGracePeriodSeconds`<sup>Optional</sup> <a name="terminationGracePeriodSeconds" id="cdk8s-metaflow.k8s.PodSpec.property.terminationGracePeriodSeconds"></a>

```typescript
public readonly terminationGracePeriodSeconds: number;
```

- *Type:* number
- *Default:* 30 seconds.

Optional duration in seconds the pod needs to terminate gracefully.

May be decreased in delete request. Value must be non-negative integer. The value zero indicates stop immediately via the kill signal (no opportunity to shut down). If this value is nil, the default grace period will be used instead. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process. Defaults to 30 seconds.

---

##### `tolerations`<sup>Optional</sup> <a name="tolerations" id="cdk8s-metaflow.k8s.PodSpec.property.tolerations"></a>

```typescript
public readonly tolerations: Toleration[];
```

- *Type:* cdk8s-metaflow.k8s.Toleration[]

If specified, the pod's tolerations.

---

##### `topologySpreadConstraints`<sup>Optional</sup> <a name="topologySpreadConstraints" id="cdk8s-metaflow.k8s.PodSpec.property.topologySpreadConstraints"></a>

```typescript
public readonly topologySpreadConstraints: TopologySpreadConstraint[];
```

- *Type:* cdk8s-metaflow.k8s.TopologySpreadConstraint[]

TopologySpreadConstraints describes how a group of pods ought to spread across topology domains.

Scheduler will schedule pods in a way which abides by the constraints. All topologySpreadConstraints are ANDed.

---

##### `volumes`<sup>Optional</sup> <a name="volumes" id="cdk8s-metaflow.k8s.PodSpec.property.volumes"></a>

```typescript
public readonly volumes: Volume[];
```

- *Type:* cdk8s-metaflow.k8s.Volume[]

List of volumes that can be mounted by containers belonging to the pod.

More info: https://kubernetes.io/docs/concepts/storage/volumes

---

### PodTemplateListProps <a name="PodTemplateListProps" id="cdk8s-metaflow.k8s.PodTemplateListProps"></a>

PodTemplateList is a list of PodTemplates.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodTemplateListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podTemplateListProps: k8s.PodTemplateListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.PodTemplate[]</code> | List of pod templates. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.PodTemplateListProps.property.items"></a>

```typescript
public readonly items: PodTemplate[];
```

- *Type:* cdk8s-metaflow.k8s.PodTemplate[]

List of pod templates.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodTemplateListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

### PodTemplateProps <a name="PodTemplateProps" id="cdk8s-metaflow.k8s.PodTemplateProps"></a>

PodTemplate describes a template for creating copies of a predefined pod.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodTemplateProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podTemplateProps: k8s.PodTemplateProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateProps.property.template">template</a></code> | <code>cdk8s-metaflow.k8s.PodTemplateSpec</code> | Template defines the pods that will be created from this pod template. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodTemplateProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `template`<sup>Optional</sup> <a name="template" id="cdk8s-metaflow.k8s.PodTemplateProps.property.template"></a>

```typescript
public readonly template: PodTemplateSpec;
```

- *Type:* cdk8s-metaflow.k8s.PodTemplateSpec

Template defines the pods that will be created from this pod template.

https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### PodTemplateSpec <a name="PodTemplateSpec" id="cdk8s-metaflow.k8s.PodTemplateSpec"></a>

PodTemplateSpec describes the data a pod should have when created from a template.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PodTemplateSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const podTemplateSpec: k8s.PodTemplateSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateSpec.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.PodTemplateSpec.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.PodSpec</code> | Specification of the desired behavior of the pod. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PodTemplateSpec.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.PodTemplateSpec.property.spec"></a>

```typescript
public readonly spec: PodSpec;
```

- *Type:* cdk8s-metaflow.k8s.PodSpec

Specification of the desired behavior of the pod.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### PolicyRule <a name="PolicyRule" id="cdk8s-metaflow.k8s.PolicyRule"></a>

PolicyRule holds information that describes a policy rule, but does not contain information about who the rule applies to or which namespace the rule applies to.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PolicyRule.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const policyRule: k8s.PolicyRule = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PolicyRule.property.verbs">verbs</a></code> | <code>string[]</code> | Verbs is a list of Verbs that apply to ALL the ResourceKinds and AttributeRestrictions contained in this rule. |
| <code><a href="#cdk8s-metaflow.k8s.PolicyRule.property.apiGroups">apiGroups</a></code> | <code>string[]</code> | APIGroups is the name of the APIGroup that contains the resources. |
| <code><a href="#cdk8s-metaflow.k8s.PolicyRule.property.nonResourceUrLs">nonResourceUrLs</a></code> | <code>string[]</code> | NonResourceURLs is a set of partial urls that a user should have access to. |
| <code><a href="#cdk8s-metaflow.k8s.PolicyRule.property.resourceNames">resourceNames</a></code> | <code>string[]</code> | ResourceNames is an optional white list of names that the rule applies to. |
| <code><a href="#cdk8s-metaflow.k8s.PolicyRule.property.resources">resources</a></code> | <code>string[]</code> | Resources is a list of resources this rule applies to. |

---

##### `verbs`<sup>Required</sup> <a name="verbs" id="cdk8s-metaflow.k8s.PolicyRule.property.verbs"></a>

```typescript
public readonly verbs: string[];
```

- *Type:* string[]

Verbs is a list of Verbs that apply to ALL the ResourceKinds and AttributeRestrictions contained in this rule.

'*' represents all verbs.

---

##### `apiGroups`<sup>Optional</sup> <a name="apiGroups" id="cdk8s-metaflow.k8s.PolicyRule.property.apiGroups"></a>

```typescript
public readonly apiGroups: string[];
```

- *Type:* string[]

APIGroups is the name of the APIGroup that contains the resources.

If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed.

---

##### `nonResourceUrLs`<sup>Optional</sup> <a name="nonResourceUrLs" id="cdk8s-metaflow.k8s.PolicyRule.property.nonResourceUrLs"></a>

```typescript
public readonly nonResourceUrLs: string[];
```

- *Type:* string[]

NonResourceURLs is a set of partial urls that a user should have access to.

*s are allowed, but only as the full, final step in the path Since non-resource URLs are not namespaced, this field is only applicable for ClusterRoles referenced from a ClusterRoleBinding. Rules can either apply to API resources (such as "pods" or "secrets") or non-resource URL paths (such as "/api"),  but not both.

---

##### `resourceNames`<sup>Optional</sup> <a name="resourceNames" id="cdk8s-metaflow.k8s.PolicyRule.property.resourceNames"></a>

```typescript
public readonly resourceNames: string[];
```

- *Type:* string[]

ResourceNames is an optional white list of names that the rule applies to.

An empty set means that everything is allowed.

---

##### `resources`<sup>Optional</sup> <a name="resources" id="cdk8s-metaflow.k8s.PolicyRule.property.resources"></a>

```typescript
public readonly resources: string[];
```

- *Type:* string[]

Resources is a list of resources this rule applies to.

'*' represents all resources.

---

### PolicyRulesWithSubjectsV1Beta1 <a name="PolicyRulesWithSubjectsV1Beta1" id="cdk8s-metaflow.k8s.PolicyRulesWithSubjectsV1Beta1"></a>

PolicyRulesWithSubjects prescribes a test that applies to a request to an apiserver.

The test considers the subject making the request, the verb being requested, and the resource to be acted upon. This PolicyRulesWithSubjects matches a request if and only if both (a) at least one member of subjects matches the request and (b) at least one member of resourceRules or nonResourceRules matches the request.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PolicyRulesWithSubjectsV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const policyRulesWithSubjectsV1Beta1: k8s.PolicyRulesWithSubjectsV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PolicyRulesWithSubjectsV1Beta1.property.subjects">subjects</a></code> | <code>cdk8s-metaflow.k8s.SubjectV1Beta1[]</code> | subjects is the list of normal user, serviceaccount, or group that this rule cares about. |
| <code><a href="#cdk8s-metaflow.k8s.PolicyRulesWithSubjectsV1Beta1.property.nonResourceRules">nonResourceRules</a></code> | <code>cdk8s-metaflow.k8s.NonResourcePolicyRuleV1Beta1[]</code> | `nonResourceRules` is a list of NonResourcePolicyRules that identify matching requests according to their verb and the target non-resource URL. |
| <code><a href="#cdk8s-metaflow.k8s.PolicyRulesWithSubjectsV1Beta1.property.resourceRules">resourceRules</a></code> | <code>cdk8s-metaflow.k8s.ResourcePolicyRuleV1Beta1[]</code> | `resourceRules` is a slice of ResourcePolicyRules that identify matching requests according to their verb and the target resource. |

---

##### `subjects`<sup>Required</sup> <a name="subjects" id="cdk8s-metaflow.k8s.PolicyRulesWithSubjectsV1Beta1.property.subjects"></a>

```typescript
public readonly subjects: SubjectV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.SubjectV1Beta1[]

subjects is the list of normal user, serviceaccount, or group that this rule cares about.

There must be at least one member in this slice. A slice that includes both the system:authenticated and system:unauthenticated user groups matches every request. Required.

---

##### `nonResourceRules`<sup>Optional</sup> <a name="nonResourceRules" id="cdk8s-metaflow.k8s.PolicyRulesWithSubjectsV1Beta1.property.nonResourceRules"></a>

```typescript
public readonly nonResourceRules: NonResourcePolicyRuleV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.NonResourcePolicyRuleV1Beta1[]

`nonResourceRules` is a list of NonResourcePolicyRules that identify matching requests according to their verb and the target non-resource URL.

---

##### `resourceRules`<sup>Optional</sup> <a name="resourceRules" id="cdk8s-metaflow.k8s.PolicyRulesWithSubjectsV1Beta1.property.resourceRules"></a>

```typescript
public readonly resourceRules: ResourcePolicyRuleV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.ResourcePolicyRuleV1Beta1[]

`resourceRules` is a slice of ResourcePolicyRules that identify matching requests according to their verb and the target resource.

At least one of `resourceRules` and `nonResourceRules` has to be non-empty.

---

### PolicyRuleV1Alpha1 <a name="PolicyRuleV1Alpha1" id="cdk8s-metaflow.k8s.PolicyRuleV1Alpha1"></a>

PolicyRule holds information that describes a policy rule, but does not contain information about who the rule applies to or which namespace the rule applies to.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PolicyRuleV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const policyRuleV1Alpha1: k8s.PolicyRuleV1Alpha1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PolicyRuleV1Alpha1.property.verbs">verbs</a></code> | <code>string[]</code> | Verbs is a list of Verbs that apply to ALL the ResourceKinds and AttributeRestrictions contained in this rule. |
| <code><a href="#cdk8s-metaflow.k8s.PolicyRuleV1Alpha1.property.apiGroups">apiGroups</a></code> | <code>string[]</code> | APIGroups is the name of the APIGroup that contains the resources. |
| <code><a href="#cdk8s-metaflow.k8s.PolicyRuleV1Alpha1.property.nonResourceUrLs">nonResourceUrLs</a></code> | <code>string[]</code> | NonResourceURLs is a set of partial urls that a user should have access to. |
| <code><a href="#cdk8s-metaflow.k8s.PolicyRuleV1Alpha1.property.resourceNames">resourceNames</a></code> | <code>string[]</code> | ResourceNames is an optional white list of names that the rule applies to. |
| <code><a href="#cdk8s-metaflow.k8s.PolicyRuleV1Alpha1.property.resources">resources</a></code> | <code>string[]</code> | Resources is a list of resources this rule applies to. |

---

##### `verbs`<sup>Required</sup> <a name="verbs" id="cdk8s-metaflow.k8s.PolicyRuleV1Alpha1.property.verbs"></a>

```typescript
public readonly verbs: string[];
```

- *Type:* string[]

Verbs is a list of Verbs that apply to ALL the ResourceKinds and AttributeRestrictions contained in this rule.

'*' represents all verbs.

---

##### `apiGroups`<sup>Optional</sup> <a name="apiGroups" id="cdk8s-metaflow.k8s.PolicyRuleV1Alpha1.property.apiGroups"></a>

```typescript
public readonly apiGroups: string[];
```

- *Type:* string[]

APIGroups is the name of the APIGroup that contains the resources.

If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed.

---

##### `nonResourceUrLs`<sup>Optional</sup> <a name="nonResourceUrLs" id="cdk8s-metaflow.k8s.PolicyRuleV1Alpha1.property.nonResourceUrLs"></a>

```typescript
public readonly nonResourceUrLs: string[];
```

- *Type:* string[]

NonResourceURLs is a set of partial urls that a user should have access to.

*s are allowed, but only as the full, final step in the path Since non-resource URLs are not namespaced, this field is only applicable for ClusterRoles referenced from a ClusterRoleBinding. Rules can either apply to API resources (such as "pods" or "secrets") or non-resource URL paths (such as "/api"),  but not both.

---

##### `resourceNames`<sup>Optional</sup> <a name="resourceNames" id="cdk8s-metaflow.k8s.PolicyRuleV1Alpha1.property.resourceNames"></a>

```typescript
public readonly resourceNames: string[];
```

- *Type:* string[]

ResourceNames is an optional white list of names that the rule applies to.

An empty set means that everything is allowed.

---

##### `resources`<sup>Optional</sup> <a name="resources" id="cdk8s-metaflow.k8s.PolicyRuleV1Alpha1.property.resources"></a>

```typescript
public readonly resources: string[];
```

- *Type:* string[]

Resources is a list of resources this rule applies to.

'*' represents all resources.

---

### PortworxVolumeSource <a name="PortworxVolumeSource" id="cdk8s-metaflow.k8s.PortworxVolumeSource"></a>

PortworxVolumeSource represents a Portworx volume resource.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PortworxVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const portworxVolumeSource: k8s.PortworxVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PortworxVolumeSource.property.volumeId">volumeId</a></code> | <code>string</code> | VolumeID uniquely identifies a Portworx volume. |
| <code><a href="#cdk8s-metaflow.k8s.PortworxVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | FSType represents the filesystem type to mount Must be a filesystem type supported by the host operating system. |
| <code><a href="#cdk8s-metaflow.k8s.PortworxVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Defaults to false (read/write). |

---

##### `volumeId`<sup>Required</sup> <a name="volumeId" id="cdk8s-metaflow.k8s.PortworxVolumeSource.property.volumeId"></a>

```typescript
public readonly volumeId: string;
```

- *Type:* string

VolumeID uniquely identifies a Portworx volume.

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.PortworxVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

FSType represents the filesystem type to mount Must be a filesystem type supported by the host operating system.

Ex. "ext4", "xfs". Implicitly inferred to be "ext4" if unspecified.

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.PortworxVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.

Defaults to false (read/write).

ReadOnly here will force the ReadOnly setting in VolumeMounts.

---

### Preconditions <a name="Preconditions" id="cdk8s-metaflow.k8s.Preconditions"></a>

Preconditions must be fulfilled before an operation (update, delete, etc.) is carried out.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.Preconditions.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const preconditions: k8s.Preconditions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Preconditions.property.resourceVersion">resourceVersion</a></code> | <code>string</code> | Specifies the target ResourceVersion. |
| <code><a href="#cdk8s-metaflow.k8s.Preconditions.property.uid">uid</a></code> | <code>string</code> | Specifies the target UID. |

---

##### `resourceVersion`<sup>Optional</sup> <a name="resourceVersion" id="cdk8s-metaflow.k8s.Preconditions.property.resourceVersion"></a>

```typescript
public readonly resourceVersion: string;
```

- *Type:* string

Specifies the target ResourceVersion.

---

##### `uid`<sup>Optional</sup> <a name="uid" id="cdk8s-metaflow.k8s.Preconditions.property.uid"></a>

```typescript
public readonly uid: string;
```

- *Type:* string

Specifies the target UID.

---

### PreferredSchedulingTerm <a name="PreferredSchedulingTerm" id="cdk8s-metaflow.k8s.PreferredSchedulingTerm"></a>

An empty preferred scheduling term matches all objects with implicit weight 0 (i.e. it's a no-op). A null preferred scheduling term matches no objects (i.e. is also a no-op).

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PreferredSchedulingTerm.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const preferredSchedulingTerm: k8s.PreferredSchedulingTerm = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PreferredSchedulingTerm.property.preference">preference</a></code> | <code>cdk8s-metaflow.k8s.NodeSelectorTerm</code> | A node selector term, associated with the corresponding weight. |
| <code><a href="#cdk8s-metaflow.k8s.PreferredSchedulingTerm.property.weight">weight</a></code> | <code>number</code> | Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100. |

---

##### `preference`<sup>Required</sup> <a name="preference" id="cdk8s-metaflow.k8s.PreferredSchedulingTerm.property.preference"></a>

```typescript
public readonly preference: NodeSelectorTerm;
```

- *Type:* cdk8s-metaflow.k8s.NodeSelectorTerm

A node selector term, associated with the corresponding weight.

---

##### `weight`<sup>Required</sup> <a name="weight" id="cdk8s-metaflow.k8s.PreferredSchedulingTerm.property.weight"></a>

```typescript
public readonly weight: number;
```

- *Type:* number

Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100.

---

### PriorityClassListProps <a name="PriorityClassListProps" id="cdk8s-metaflow.k8s.PriorityClassListProps"></a>

PriorityClassList is a collection of priority classes.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PriorityClassListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const priorityClassListProps: k8s.PriorityClassListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.PriorityClass[]</code> | items is the list of PriorityClasses. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.PriorityClassListProps.property.items"></a>

```typescript
public readonly items: PriorityClass[];
```

- *Type:* cdk8s-metaflow.k8s.PriorityClass[]

items is the list of PriorityClasses.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PriorityClassListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

### PriorityClassListV1Alpha1Props <a name="PriorityClassListV1Alpha1Props" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1Props"></a>

PriorityClassList is a collection of priority classes.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const priorityClassListV1Alpha1Props: k8s.PriorityClassListV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.PriorityClassV1Alpha1[]</code> | items is the list of PriorityClasses. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassListV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1Props.property.items"></a>

```typescript
public readonly items: PriorityClassV1Alpha1[];
```

- *Type:* cdk8s-metaflow.k8s.PriorityClassV1Alpha1[]

items is the list of PriorityClasses.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PriorityClassListV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

### PriorityClassProps <a name="PriorityClassProps" id="cdk8s-metaflow.k8s.PriorityClassProps"></a>

PriorityClass defines mapping from a priority class name to the priority integer value.

The value can be any valid integer.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PriorityClassProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const priorityClassProps: k8s.PriorityClassProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassProps.property.value">value</a></code> | <code>number</code> | The value of this priority class. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassProps.property.description">description</a></code> | <code>string</code> | description is an arbitrary string that usually provides guidelines on when this priority class should be used. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassProps.property.globalDefault">globalDefault</a></code> | <code>boolean</code> | globalDefault specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassProps.property.preemptionPolicy">preemptionPolicy</a></code> | <code>string</code> | PreemptionPolicy is the Policy for preempting pods with lower priority. |

---

##### `value`<sup>Required</sup> <a name="value" id="cdk8s-metaflow.k8s.PriorityClassProps.property.value"></a>

```typescript
public readonly value: number;
```

- *Type:* number

The value of this priority class.

This is the actual priority that pods receive when they have the name of this class in their pod spec.

---

##### `description`<sup>Optional</sup> <a name="description" id="cdk8s-metaflow.k8s.PriorityClassProps.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* string

description is an arbitrary string that usually provides guidelines on when this priority class should be used.

---

##### `globalDefault`<sup>Optional</sup> <a name="globalDefault" id="cdk8s-metaflow.k8s.PriorityClassProps.property.globalDefault"></a>

```typescript
public readonly globalDefault: boolean;
```

- *Type:* boolean

globalDefault specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class.

Only one PriorityClass can be marked as `globalDefault`. However, if more than one PriorityClasses exists with their `globalDefault` field set to true, the smallest value of such global default PriorityClasses will be used as the default priority.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PriorityClassProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `preemptionPolicy`<sup>Optional</sup> <a name="preemptionPolicy" id="cdk8s-metaflow.k8s.PriorityClassProps.property.preemptionPolicy"></a>

```typescript
public readonly preemptionPolicy: string;
```

- *Type:* string
- *Default:* PreemptLowerPriority if unset. This field is beta-level, gated by the NonPreemptingPriority feature-gate.

PreemptionPolicy is the Policy for preempting pods with lower priority.

One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset. This field is beta-level, gated by the NonPreemptingPriority feature-gate.

---

### PriorityClassV1Alpha1Props <a name="PriorityClassV1Alpha1Props" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1Props"></a>

DEPRECATED - This group version of PriorityClass is deprecated by scheduling.k8s.io/v1/PriorityClass. PriorityClass defines mapping from a priority class name to the priority integer value. The value can be any valid integer.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const priorityClassV1Alpha1Props: k8s.PriorityClassV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1Props.property.value">value</a></code> | <code>number</code> | The value of this priority class. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1Props.property.description">description</a></code> | <code>string</code> | description is an arbitrary string that usually provides guidelines on when this priority class should be used. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1Props.property.globalDefault">globalDefault</a></code> | <code>boolean</code> | globalDefault specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityClassV1Alpha1Props.property.preemptionPolicy">preemptionPolicy</a></code> | <code>string</code> | PreemptionPolicy is the Policy for preempting pods with lower priority. |

---

##### `value`<sup>Required</sup> <a name="value" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1Props.property.value"></a>

```typescript
public readonly value: number;
```

- *Type:* number

The value of this priority class.

This is the actual priority that pods receive when they have the name of this class in their pod spec.

---

##### `description`<sup>Optional</sup> <a name="description" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1Props.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* string

description is an arbitrary string that usually provides guidelines on when this priority class should be used.

---

##### `globalDefault`<sup>Optional</sup> <a name="globalDefault" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1Props.property.globalDefault"></a>

```typescript
public readonly globalDefault: boolean;
```

- *Type:* boolean

globalDefault specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class.

Only one PriorityClass can be marked as `globalDefault`. However, if more than one PriorityClasses exists with their `globalDefault` field set to true, the smallest value of such global default PriorityClasses will be used as the default priority.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `preemptionPolicy`<sup>Optional</sup> <a name="preemptionPolicy" id="cdk8s-metaflow.k8s.PriorityClassV1Alpha1Props.property.preemptionPolicy"></a>

```typescript
public readonly preemptionPolicy: string;
```

- *Type:* string
- *Default:* PreemptLowerPriority if unset. This field is beta-level, gated by the NonPreemptingPriority feature-gate.

PreemptionPolicy is the Policy for preempting pods with lower priority.

One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset. This field is beta-level, gated by the NonPreemptingPriority feature-gate.

---

### PriorityLevelConfigurationListV1Beta1Props <a name="PriorityLevelConfigurationListV1Beta1Props" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1Props"></a>

PriorityLevelConfigurationList is a list of PriorityLevelConfiguration objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const priorityLevelConfigurationListV1Beta1Props: k8s.PriorityLevelConfigurationListV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1[]</code> | `items` is a list of request-priorities. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | `metadata` is the standard object's metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1Props.property.items"></a>

```typescript
public readonly items: PriorityLevelConfigurationV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1[]

`items` is a list of request-priorities.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationListV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

`metadata` is the standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### PriorityLevelConfigurationReferenceV1Beta1 <a name="PriorityLevelConfigurationReferenceV1Beta1" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationReferenceV1Beta1"></a>

PriorityLevelConfigurationReference contains information that points to the "request-priority" being used.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationReferenceV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const priorityLevelConfigurationReferenceV1Beta1: k8s.PriorityLevelConfigurationReferenceV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationReferenceV1Beta1.property.name">name</a></code> | <code>string</code> | `name` is the name of the priority level configuration being referenced Required. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationReferenceV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

`name` is the name of the priority level configuration being referenced Required.

---

### PriorityLevelConfigurationSpecV1Beta1 <a name="PriorityLevelConfigurationSpecV1Beta1" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationSpecV1Beta1"></a>

PriorityLevelConfigurationSpec specifies the configuration of a priority level.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationSpecV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const priorityLevelConfigurationSpecV1Beta1: k8s.PriorityLevelConfigurationSpecV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationSpecV1Beta1.property.type">type</a></code> | <code>string</code> | `type` indicates whether this priority level is subject to limitation on request execution. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationSpecV1Beta1.property.limited">limited</a></code> | <code>cdk8s-metaflow.k8s.LimitedPriorityLevelConfigurationV1Beta1</code> | `limited` specifies how requests are handled for a Limited priority level. |

---

##### `type`<sup>Required</sup> <a name="type" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationSpecV1Beta1.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

`type` indicates whether this priority level is subject to limitation on request execution.

A value of `"Exempt"` means that requests of this priority level are not subject to a limit (and thus are never queued) and do not detract from the capacity made available to other priority levels.  A value of `"Limited"` means that (a) requests of this priority level _are_ subject to limits and (b) some of the server's limited capacity is made available exclusively to this priority level. Required.

---

##### `limited`<sup>Optional</sup> <a name="limited" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationSpecV1Beta1.property.limited"></a>

```typescript
public readonly limited: LimitedPriorityLevelConfigurationV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.LimitedPriorityLevelConfigurationV1Beta1

`limited` specifies how requests are handled for a Limited priority level.

This field must be non-empty if and only if `type` is `"Limited"`.

---

### PriorityLevelConfigurationV1Beta1Props <a name="PriorityLevelConfigurationV1Beta1Props" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1Props"></a>

PriorityLevelConfiguration represents the configuration of a priority level.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const priorityLevelConfigurationV1Beta1Props: k8s.PriorityLevelConfigurationV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | `metadata` is the standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1Props.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.PriorityLevelConfigurationSpecV1Beta1</code> | `spec` is the specification of the desired behavior of a "request-priority". |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

`metadata` is the standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.PriorityLevelConfigurationV1Beta1Props.property.spec"></a>

```typescript
public readonly spec: PriorityLevelConfigurationSpecV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.PriorityLevelConfigurationSpecV1Beta1

`spec` is the specification of the desired behavior of a "request-priority".

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### Probe <a name="Probe" id="cdk8s-metaflow.k8s.Probe"></a>

Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.Probe.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const probe: k8s.Probe = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Probe.property.exec">exec</a></code> | <code>cdk8s-metaflow.k8s.ExecAction</code> | One and only one of the following should be specified. |
| <code><a href="#cdk8s-metaflow.k8s.Probe.property.failureThreshold">failureThreshold</a></code> | <code>number</code> | Minimum consecutive failures for the probe to be considered failed after having succeeded. |
| <code><a href="#cdk8s-metaflow.k8s.Probe.property.httpGet">httpGet</a></code> | <code>cdk8s-metaflow.k8s.HttpGetAction</code> | HTTPGet specifies the http request to perform. |
| <code><a href="#cdk8s-metaflow.k8s.Probe.property.initialDelaySeconds">initialDelaySeconds</a></code> | <code>number</code> | Number of seconds after the container has started before liveness probes are initiated. |
| <code><a href="#cdk8s-metaflow.k8s.Probe.property.periodSeconds">periodSeconds</a></code> | <code>number</code> | How often (in seconds) to perform the probe. |
| <code><a href="#cdk8s-metaflow.k8s.Probe.property.successThreshold">successThreshold</a></code> | <code>number</code> | Minimum consecutive successes for the probe to be considered successful after having failed. |
| <code><a href="#cdk8s-metaflow.k8s.Probe.property.tcpSocket">tcpSocket</a></code> | <code>cdk8s-metaflow.k8s.TcpSocketAction</code> | TCPSocket specifies an action involving a TCP port. |
| <code><a href="#cdk8s-metaflow.k8s.Probe.property.terminationGracePeriodSeconds">terminationGracePeriodSeconds</a></code> | <code>number</code> | Optional duration in seconds the pod needs to terminate gracefully upon probe failure. |
| <code><a href="#cdk8s-metaflow.k8s.Probe.property.timeoutSeconds">timeoutSeconds</a></code> | <code>number</code> | Number of seconds after which the probe times out. |

---

##### `exec`<sup>Optional</sup> <a name="exec" id="cdk8s-metaflow.k8s.Probe.property.exec"></a>

```typescript
public readonly exec: ExecAction;
```

- *Type:* cdk8s-metaflow.k8s.ExecAction

One and only one of the following should be specified.

Exec specifies the action to take.

---

##### `failureThreshold`<sup>Optional</sup> <a name="failureThreshold" id="cdk8s-metaflow.k8s.Probe.property.failureThreshold"></a>

```typescript
public readonly failureThreshold: number;
```

- *Type:* number
- *Default:* 3. Minimum value is 1.

Minimum consecutive failures for the probe to be considered failed after having succeeded.

Defaults to 3. Minimum value is 1.

---

##### `httpGet`<sup>Optional</sup> <a name="httpGet" id="cdk8s-metaflow.k8s.Probe.property.httpGet"></a>

```typescript
public readonly httpGet: HttpGetAction;
```

- *Type:* cdk8s-metaflow.k8s.HttpGetAction

HTTPGet specifies the http request to perform.

---

##### `initialDelaySeconds`<sup>Optional</sup> <a name="initialDelaySeconds" id="cdk8s-metaflow.k8s.Probe.property.initialDelaySeconds"></a>

```typescript
public readonly initialDelaySeconds: number;
```

- *Type:* number

Number of seconds after the container has started before liveness probes are initiated.

More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes

---

##### `periodSeconds`<sup>Optional</sup> <a name="periodSeconds" id="cdk8s-metaflow.k8s.Probe.property.periodSeconds"></a>

```typescript
public readonly periodSeconds: number;
```

- *Type:* number
- *Default:* 10 seconds. Minimum value is 1.

How often (in seconds) to perform the probe.

Default to 10 seconds. Minimum value is 1.

---

##### `successThreshold`<sup>Optional</sup> <a name="successThreshold" id="cdk8s-metaflow.k8s.Probe.property.successThreshold"></a>

```typescript
public readonly successThreshold: number;
```

- *Type:* number
- *Default:* 1. Must be 1 for liveness and startup. Minimum value is 1.

Minimum consecutive successes for the probe to be considered successful after having failed.

Defaults to 1. Must be 1 for liveness and startup. Minimum value is 1.

---

##### `tcpSocket`<sup>Optional</sup> <a name="tcpSocket" id="cdk8s-metaflow.k8s.Probe.property.tcpSocket"></a>

```typescript
public readonly tcpSocket: TcpSocketAction;
```

- *Type:* cdk8s-metaflow.k8s.TcpSocketAction

TCPSocket specifies an action involving a TCP port.

TCP hooks not yet supported

---

##### `terminationGracePeriodSeconds`<sup>Optional</sup> <a name="terminationGracePeriodSeconds" id="cdk8s-metaflow.k8s.Probe.property.terminationGracePeriodSeconds"></a>

```typescript
public readonly terminationGracePeriodSeconds: number;
```

- *Type:* number

Optional duration in seconds the pod needs to terminate gracefully upon probe failure.

The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process. If this value is nil, the pod's terminationGracePeriodSeconds will be used. Otherwise, this value overrides the value provided by the pod spec. Value must be non-negative integer. The value zero indicates stop immediately via the kill signal (no opportunity to shut down). This is a beta field and requires enabling ProbeTerminationGracePeriod feature gate. Minimum value is 1. spec.terminationGracePeriodSeconds is used if unset.

---

##### `timeoutSeconds`<sup>Optional</sup> <a name="timeoutSeconds" id="cdk8s-metaflow.k8s.Probe.property.timeoutSeconds"></a>

```typescript
public readonly timeoutSeconds: number;
```

- *Type:* number
- *Default:* 1 second. Minimum value is 1. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes

Number of seconds after which the probe times out.

Defaults to 1 second. Minimum value is 1. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes

---

### ProjectedVolumeSource <a name="ProjectedVolumeSource" id="cdk8s-metaflow.k8s.ProjectedVolumeSource"></a>

Represents a projected volume source.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ProjectedVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const projectedVolumeSource: k8s.ProjectedVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ProjectedVolumeSource.property.defaultMode">defaultMode</a></code> | <code>number</code> | Mode bits used to set permissions on created files by default. |
| <code><a href="#cdk8s-metaflow.k8s.ProjectedVolumeSource.property.sources">sources</a></code> | <code>cdk8s-metaflow.k8s.VolumeProjection[]</code> | list of volume projections. |

---

##### `defaultMode`<sup>Optional</sup> <a name="defaultMode" id="cdk8s-metaflow.k8s.ProjectedVolumeSource.property.defaultMode"></a>

```typescript
public readonly defaultMode: number;
```

- *Type:* number

Mode bits used to set permissions on created files by default.

Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.

---

##### `sources`<sup>Optional</sup> <a name="sources" id="cdk8s-metaflow.k8s.ProjectedVolumeSource.property.sources"></a>

```typescript
public readonly sources: VolumeProjection[];
```

- *Type:* cdk8s-metaflow.k8s.VolumeProjection[]

list of volume projections.

---

### QueuingConfigurationV1Beta1 <a name="QueuingConfigurationV1Beta1" id="cdk8s-metaflow.k8s.QueuingConfigurationV1Beta1"></a>

QueuingConfiguration holds the configuration parameters for queuing.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.QueuingConfigurationV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const queuingConfigurationV1Beta1: k8s.QueuingConfigurationV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.QueuingConfigurationV1Beta1.property.handSize">handSize</a></code> | <code>number</code> | `handSize` is a small positive number that configures the shuffle sharding of requests into queues. |
| <code><a href="#cdk8s-metaflow.k8s.QueuingConfigurationV1Beta1.property.queueLengthLimit">queueLengthLimit</a></code> | <code>number</code> | `queueLengthLimit` is the maximum number of requests allowed to be waiting in a given queue of this priority level at a time; |
| <code><a href="#cdk8s-metaflow.k8s.QueuingConfigurationV1Beta1.property.queues">queues</a></code> | <code>number</code> | `queues` is the number of queues for this priority level. |

---

##### `handSize`<sup>Optional</sup> <a name="handSize" id="cdk8s-metaflow.k8s.QueuingConfigurationV1Beta1.property.handSize"></a>

```typescript
public readonly handSize: number;
```

- *Type:* number

`handSize` is a small positive number that configures the shuffle sharding of requests into queues.

When enqueuing a request at this priority level the request's flow identifier (a string pair) is hashed and the hash value is used to shuffle the list of queues and deal a hand of the size specified here.  The request is put into one of the shortest queues in that hand. `handSize` must be no larger than `queues`, and should be significantly smaller (so that a few heavy flows do not saturate most of the queues).  See the user-facing documentation for more extensive guidance on setting this field.  This field has a default value of 8.

---

##### `queueLengthLimit`<sup>Optional</sup> <a name="queueLengthLimit" id="cdk8s-metaflow.k8s.QueuingConfigurationV1Beta1.property.queueLengthLimit"></a>

```typescript
public readonly queueLengthLimit: number;
```

- *Type:* number

`queueLengthLimit` is the maximum number of requests allowed to be waiting in a given queue of this priority level at a time;

excess requests are rejected.  This value must be positive.  If not specified, it will be defaulted to 50.

---

##### `queues`<sup>Optional</sup> <a name="queues" id="cdk8s-metaflow.k8s.QueuingConfigurationV1Beta1.property.queues"></a>

```typescript
public readonly queues: number;
```

- *Type:* number

`queues` is the number of queues for this priority level.

The queues exist independently at each apiserver. The value must be positive.  Setting it to 1 effectively precludes shufflesharding and thus makes the distinguisher method of associated flow schemas irrelevant.  This field has a default value of 64.

---

### QuobyteVolumeSource <a name="QuobyteVolumeSource" id="cdk8s-metaflow.k8s.QuobyteVolumeSource"></a>

Represents a Quobyte mount that lasts the lifetime of a pod.

Quobyte volumes do not support ownership management or SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.QuobyteVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const quobyteVolumeSource: k8s.QuobyteVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.QuobyteVolumeSource.property.registry">registry</a></code> | <code>string</code> | Registry represents a single or multiple Quobyte Registry services specified as a string as host:port pair (multiple entries are separated with commas) which acts as the central registry for volumes. |
| <code><a href="#cdk8s-metaflow.k8s.QuobyteVolumeSource.property.volume">volume</a></code> | <code>string</code> | Volume is a string that references an already created Quobyte volume by name. |
| <code><a href="#cdk8s-metaflow.k8s.QuobyteVolumeSource.property.group">group</a></code> | <code>string</code> | Group to map volume access to Default is no group. |
| <code><a href="#cdk8s-metaflow.k8s.QuobyteVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | ReadOnly here will force the Quobyte volume to be mounted with read-only permissions. |
| <code><a href="#cdk8s-metaflow.k8s.QuobyteVolumeSource.property.tenant">tenant</a></code> | <code>string</code> | Tenant owning the given Quobyte volume in the Backend Used with dynamically provisioned Quobyte volumes, value is set by the plugin. |
| <code><a href="#cdk8s-metaflow.k8s.QuobyteVolumeSource.property.user">user</a></code> | <code>string</code> | User to map volume access to Defaults to serivceaccount user. |

---

##### `registry`<sup>Required</sup> <a name="registry" id="cdk8s-metaflow.k8s.QuobyteVolumeSource.property.registry"></a>

```typescript
public readonly registry: string;
```

- *Type:* string

Registry represents a single or multiple Quobyte Registry services specified as a string as host:port pair (multiple entries are separated with commas) which acts as the central registry for volumes.

---

##### `volume`<sup>Required</sup> <a name="volume" id="cdk8s-metaflow.k8s.QuobyteVolumeSource.property.volume"></a>

```typescript
public readonly volume: string;
```

- *Type:* string

Volume is a string that references an already created Quobyte volume by name.

---

##### `group`<sup>Optional</sup> <a name="group" id="cdk8s-metaflow.k8s.QuobyteVolumeSource.property.group"></a>

```typescript
public readonly group: string;
```

- *Type:* string
- *Default:* no group

Group to map volume access to Default is no group.

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.QuobyteVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false.

ReadOnly here will force the Quobyte volume to be mounted with read-only permissions.

Defaults to false.

---

##### `tenant`<sup>Optional</sup> <a name="tenant" id="cdk8s-metaflow.k8s.QuobyteVolumeSource.property.tenant"></a>

```typescript
public readonly tenant: string;
```

- *Type:* string

Tenant owning the given Quobyte volume in the Backend Used with dynamically provisioned Quobyte volumes, value is set by the plugin.

---

##### `user`<sup>Optional</sup> <a name="user" id="cdk8s-metaflow.k8s.QuobyteVolumeSource.property.user"></a>

```typescript
public readonly user: string;
```

- *Type:* string
- *Default:* serivceaccount user

User to map volume access to Defaults to serivceaccount user.

---

### RbdPersistentVolumeSource <a name="RbdPersistentVolumeSource" id="cdk8s-metaflow.k8s.RbdPersistentVolumeSource"></a>

Represents a Rados Block Device mount that lasts the lifetime of a pod.

RBD volumes support ownership management and SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RbdPersistentVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const rbdPersistentVolumeSource: k8s.RbdPersistentVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RbdPersistentVolumeSource.property.image">image</a></code> | <code>string</code> | The rados image name. |
| <code><a href="#cdk8s-metaflow.k8s.RbdPersistentVolumeSource.property.monitors">monitors</a></code> | <code>string[]</code> | A collection of Ceph monitors. |
| <code><a href="#cdk8s-metaflow.k8s.RbdPersistentVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type of the volume that you want to mount. |
| <code><a href="#cdk8s-metaflow.k8s.RbdPersistentVolumeSource.property.keyring">keyring</a></code> | <code>string</code> | Keyring is the path to key ring for RBDUser. |
| <code><a href="#cdk8s-metaflow.k8s.RbdPersistentVolumeSource.property.pool">pool</a></code> | <code>string</code> | The rados pool name. |
| <code><a href="#cdk8s-metaflow.k8s.RbdPersistentVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | ReadOnly here will force the ReadOnly setting in VolumeMounts. |
| <code><a href="#cdk8s-metaflow.k8s.RbdPersistentVolumeSource.property.secretRef">secretRef</a></code> | <code>cdk8s-metaflow.k8s.SecretReference</code> | SecretRef is name of the authentication secret for RBDUser. |
| <code><a href="#cdk8s-metaflow.k8s.RbdPersistentVolumeSource.property.user">user</a></code> | <code>string</code> | The rados user name. |

---

##### `image`<sup>Required</sup> <a name="image" id="cdk8s-metaflow.k8s.RbdPersistentVolumeSource.property.image"></a>

```typescript
public readonly image: string;
```

- *Type:* string

The rados image name.

More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

---

##### `monitors`<sup>Required</sup> <a name="monitors" id="cdk8s-metaflow.k8s.RbdPersistentVolumeSource.property.monitors"></a>

```typescript
public readonly monitors: string[];
```

- *Type:* string[]

A collection of Ceph monitors.

More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.RbdPersistentVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type of the volume that you want to mount.

Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#rbd

---

##### `keyring`<sup>Optional</sup> <a name="keyring" id="cdk8s-metaflow.k8s.RbdPersistentVolumeSource.property.keyring"></a>

```typescript
public readonly keyring: string;
```

- *Type:* string
- *Default:* etc/ceph/keyring. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

Keyring is the path to key ring for RBDUser.

Default is /etc/ceph/keyring. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

---

##### `pool`<sup>Optional</sup> <a name="pool" id="cdk8s-metaflow.k8s.RbdPersistentVolumeSource.property.pool"></a>

```typescript
public readonly pool: string;
```

- *Type:* string
- *Default:* rbd. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

The rados pool name.

Default is rbd. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.RbdPersistentVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

ReadOnly here will force the ReadOnly setting in VolumeMounts.

Defaults to false. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

---

##### `secretRef`<sup>Optional</sup> <a name="secretRef" id="cdk8s-metaflow.k8s.RbdPersistentVolumeSource.property.secretRef"></a>

```typescript
public readonly secretRef: SecretReference;
```

- *Type:* cdk8s-metaflow.k8s.SecretReference
- *Default:* nil. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

SecretRef is name of the authentication secret for RBDUser.

If provided overrides keyring. Default is nil. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

---

##### `user`<sup>Optional</sup> <a name="user" id="cdk8s-metaflow.k8s.RbdPersistentVolumeSource.property.user"></a>

```typescript
public readonly user: string;
```

- *Type:* string
- *Default:* admin. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

The rados user name.

Default is admin. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

---

### RbdVolumeSource <a name="RbdVolumeSource" id="cdk8s-metaflow.k8s.RbdVolumeSource"></a>

Represents a Rados Block Device mount that lasts the lifetime of a pod.

RBD volumes support ownership management and SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RbdVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const rbdVolumeSource: k8s.RbdVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RbdVolumeSource.property.image">image</a></code> | <code>string</code> | The rados image name. |
| <code><a href="#cdk8s-metaflow.k8s.RbdVolumeSource.property.monitors">monitors</a></code> | <code>string[]</code> | A collection of Ceph monitors. |
| <code><a href="#cdk8s-metaflow.k8s.RbdVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type of the volume that you want to mount. |
| <code><a href="#cdk8s-metaflow.k8s.RbdVolumeSource.property.keyring">keyring</a></code> | <code>string</code> | Keyring is the path to key ring for RBDUser. |
| <code><a href="#cdk8s-metaflow.k8s.RbdVolumeSource.property.pool">pool</a></code> | <code>string</code> | The rados pool name. |
| <code><a href="#cdk8s-metaflow.k8s.RbdVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | ReadOnly here will force the ReadOnly setting in VolumeMounts. |
| <code><a href="#cdk8s-metaflow.k8s.RbdVolumeSource.property.secretRef">secretRef</a></code> | <code>cdk8s-metaflow.k8s.LocalObjectReference</code> | SecretRef is name of the authentication secret for RBDUser. |
| <code><a href="#cdk8s-metaflow.k8s.RbdVolumeSource.property.user">user</a></code> | <code>string</code> | The rados user name. |

---

##### `image`<sup>Required</sup> <a name="image" id="cdk8s-metaflow.k8s.RbdVolumeSource.property.image"></a>

```typescript
public readonly image: string;
```

- *Type:* string

The rados image name.

More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

---

##### `monitors`<sup>Required</sup> <a name="monitors" id="cdk8s-metaflow.k8s.RbdVolumeSource.property.monitors"></a>

```typescript
public readonly monitors: string[];
```

- *Type:* string[]

A collection of Ceph monitors.

More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.RbdVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type of the volume that you want to mount.

Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#rbd

---

##### `keyring`<sup>Optional</sup> <a name="keyring" id="cdk8s-metaflow.k8s.RbdVolumeSource.property.keyring"></a>

```typescript
public readonly keyring: string;
```

- *Type:* string
- *Default:* etc/ceph/keyring. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

Keyring is the path to key ring for RBDUser.

Default is /etc/ceph/keyring. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

---

##### `pool`<sup>Optional</sup> <a name="pool" id="cdk8s-metaflow.k8s.RbdVolumeSource.property.pool"></a>

```typescript
public readonly pool: string;
```

- *Type:* string
- *Default:* rbd. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

The rados pool name.

Default is rbd. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.RbdVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

ReadOnly here will force the ReadOnly setting in VolumeMounts.

Defaults to false. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

---

##### `secretRef`<sup>Optional</sup> <a name="secretRef" id="cdk8s-metaflow.k8s.RbdVolumeSource.property.secretRef"></a>

```typescript
public readonly secretRef: LocalObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.LocalObjectReference
- *Default:* nil. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

SecretRef is name of the authentication secret for RBDUser.

If provided overrides keyring. Default is nil. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

---

##### `user`<sup>Optional</sup> <a name="user" id="cdk8s-metaflow.k8s.RbdVolumeSource.property.user"></a>

```typescript
public readonly user: string;
```

- *Type:* string
- *Default:* admin. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

The rados user name.

Default is admin. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

---

### ReplicaSetListProps <a name="ReplicaSetListProps" id="cdk8s-metaflow.k8s.ReplicaSetListProps"></a>

ReplicaSetList is a collection of ReplicaSets.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ReplicaSetListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const replicaSetListProps: k8s.ReplicaSetListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.ReplicaSet[]</code> | List of ReplicaSets. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.ReplicaSetListProps.property.items"></a>

```typescript
public readonly items: ReplicaSet[];
```

- *Type:* cdk8s-metaflow.k8s.ReplicaSet[]

List of ReplicaSets.

More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ReplicaSetListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

### ReplicaSetProps <a name="ReplicaSetProps" id="cdk8s-metaflow.k8s.ReplicaSetProps"></a>

ReplicaSet ensures that a specified number of pod replicas are running at any given time.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ReplicaSetProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const replicaSetProps: k8s.ReplicaSetProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | If the Labels of a ReplicaSet are empty, they are defaulted to be the same as the Pod(s) that the ReplicaSet manages. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.ReplicaSetSpec</code> | Spec defines the specification of the desired behavior of the ReplicaSet. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ReplicaSetProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

If the Labels of a ReplicaSet are empty, they are defaulted to be the same as the Pod(s) that the ReplicaSet manages.

Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.ReplicaSetProps.property.spec"></a>

```typescript
public readonly spec: ReplicaSetSpec;
```

- *Type:* cdk8s-metaflow.k8s.ReplicaSetSpec

Spec defines the specification of the desired behavior of the ReplicaSet.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### ReplicaSetSpec <a name="ReplicaSetSpec" id="cdk8s-metaflow.k8s.ReplicaSetSpec"></a>

ReplicaSetSpec is the specification of a ReplicaSet.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ReplicaSetSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const replicaSetSpec: k8s.ReplicaSetSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetSpec.property.selector">selector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | Selector is a label query over pods that should match the replica count. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetSpec.property.minReadySeconds">minReadySeconds</a></code> | <code>number</code> | Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetSpec.property.replicas">replicas</a></code> | <code>number</code> | Replicas is the number of desired replicas. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicaSetSpec.property.template">template</a></code> | <code>cdk8s-metaflow.k8s.PodTemplateSpec</code> | Template is the object that describes the pod that will be created if insufficient replicas are detected. |

---

##### `selector`<sup>Required</sup> <a name="selector" id="cdk8s-metaflow.k8s.ReplicaSetSpec.property.selector"></a>

```typescript
public readonly selector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

Selector is a label query over pods that should match the replica count.

Label keys and values that must match in order to be controlled by this replica set. It must match the pod template's labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors

---

##### `minReadySeconds`<sup>Optional</sup> <a name="minReadySeconds" id="cdk8s-metaflow.k8s.ReplicaSetSpec.property.minReadySeconds"></a>

```typescript
public readonly minReadySeconds: number;
```

- *Type:* number
- *Default:* 0 (pod will be considered available as soon as it is ready)

Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available.

Defaults to 0 (pod will be considered available as soon as it is ready)

---

##### `replicas`<sup>Optional</sup> <a name="replicas" id="cdk8s-metaflow.k8s.ReplicaSetSpec.property.replicas"></a>

```typescript
public readonly replicas: number;
```

- *Type:* number
- *Default:* 1. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller/#what-is-a-replicationcontroller

Replicas is the number of desired replicas.

This is a pointer to distinguish between explicit zero and unspecified. Defaults to 1. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller/#what-is-a-replicationcontroller

---

##### `template`<sup>Optional</sup> <a name="template" id="cdk8s-metaflow.k8s.ReplicaSetSpec.property.template"></a>

```typescript
public readonly template: PodTemplateSpec;
```

- *Type:* cdk8s-metaflow.k8s.PodTemplateSpec

Template is the object that describes the pod that will be created if insufficient replicas are detected.

More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template

---

### ReplicationControllerListProps <a name="ReplicationControllerListProps" id="cdk8s-metaflow.k8s.ReplicationControllerListProps"></a>

ReplicationControllerList is a collection of replication controllers.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ReplicationControllerListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const replicationControllerListProps: k8s.ReplicationControllerListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.ReplicationController[]</code> | List of replication controllers. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.ReplicationControllerListProps.property.items"></a>

```typescript
public readonly items: ReplicationController[];
```

- *Type:* cdk8s-metaflow.k8s.ReplicationController[]

List of replication controllers.

More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ReplicationControllerListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

### ReplicationControllerProps <a name="ReplicationControllerProps" id="cdk8s-metaflow.k8s.ReplicationControllerProps"></a>

ReplicationController represents the configuration of a replication controller.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ReplicationControllerProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const replicationControllerProps: k8s.ReplicationControllerProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | If the Labels of a ReplicationController are empty, they are defaulted to be the same as the Pod(s) that the replication controller manages. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.ReplicationControllerSpec</code> | Spec defines the specification of the desired behavior of the replication controller. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ReplicationControllerProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

If the Labels of a ReplicationController are empty, they are defaulted to be the same as the Pod(s) that the replication controller manages.

Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.ReplicationControllerProps.property.spec"></a>

```typescript
public readonly spec: ReplicationControllerSpec;
```

- *Type:* cdk8s-metaflow.k8s.ReplicationControllerSpec

Spec defines the specification of the desired behavior of the replication controller.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### ReplicationControllerSpec <a name="ReplicationControllerSpec" id="cdk8s-metaflow.k8s.ReplicationControllerSpec"></a>

ReplicationControllerSpec is the specification of a replication controller.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ReplicationControllerSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const replicationControllerSpec: k8s.ReplicationControllerSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerSpec.property.minReadySeconds">minReadySeconds</a></code> | <code>number</code> | Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerSpec.property.replicas">replicas</a></code> | <code>number</code> | Replicas is the number of desired replicas. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerSpec.property.selector">selector</a></code> | <code>{[ key: string ]: string}</code> | Selector is a label query over pods that should match the Replicas count. |
| <code><a href="#cdk8s-metaflow.k8s.ReplicationControllerSpec.property.template">template</a></code> | <code>cdk8s-metaflow.k8s.PodTemplateSpec</code> | Template is the object that describes the pod that will be created if insufficient replicas are detected. |

---

##### `minReadySeconds`<sup>Optional</sup> <a name="minReadySeconds" id="cdk8s-metaflow.k8s.ReplicationControllerSpec.property.minReadySeconds"></a>

```typescript
public readonly minReadySeconds: number;
```

- *Type:* number
- *Default:* 0 (pod will be considered available as soon as it is ready)

Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available.

Defaults to 0 (pod will be considered available as soon as it is ready)

---

##### `replicas`<sup>Optional</sup> <a name="replicas" id="cdk8s-metaflow.k8s.ReplicationControllerSpec.property.replicas"></a>

```typescript
public readonly replicas: number;
```

- *Type:* number
- *Default:* 1. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#what-is-a-replicationcontroller

Replicas is the number of desired replicas.

This is a pointer to distinguish between explicit zero and unspecified. Defaults to 1. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#what-is-a-replicationcontroller

---

##### `selector`<sup>Optional</sup> <a name="selector" id="cdk8s-metaflow.k8s.ReplicationControllerSpec.property.selector"></a>

```typescript
public readonly selector: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

Selector is a label query over pods that should match the Replicas count.

If Selector is empty, it is defaulted to the labels present on the Pod template. Label keys and values that must match in order to be controlled by this replication controller, if empty defaulted to labels on Pod template. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors

---

##### `template`<sup>Optional</sup> <a name="template" id="cdk8s-metaflow.k8s.ReplicationControllerSpec.property.template"></a>

```typescript
public readonly template: PodTemplateSpec;
```

- *Type:* cdk8s-metaflow.k8s.PodTemplateSpec

Template is the object that describes the pod that will be created if insufficient replicas are detected.

This takes precedence over a TemplateRef. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template

---

### ResourceAttributes <a name="ResourceAttributes" id="cdk8s-metaflow.k8s.ResourceAttributes"></a>

ResourceAttributes includes the authorization attributes available for resource requests to the Authorizer interface.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ResourceAttributes.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const resourceAttributes: k8s.ResourceAttributes = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceAttributes.property.group">group</a></code> | <code>string</code> | Group is the API Group of the Resource. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceAttributes.property.name">name</a></code> | <code>string</code> | Name is the name of the resource being requested for a "get" or deleted for a "delete". |
| <code><a href="#cdk8s-metaflow.k8s.ResourceAttributes.property.namespace">namespace</a></code> | <code>string</code> | Namespace is the namespace of the action being requested. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceAttributes.property.resource">resource</a></code> | <code>string</code> | Resource is one of the existing resource types. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceAttributes.property.subresource">subresource</a></code> | <code>string</code> | Subresource is one of the existing resource types. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceAttributes.property.verb">verb</a></code> | <code>string</code> | Verb is a kubernetes resource API verb, like: get, list, watch, create, update, delete, proxy. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceAttributes.property.version">version</a></code> | <code>string</code> | Version is the API Version of the Resource. |

---

##### `group`<sup>Optional</sup> <a name="group" id="cdk8s-metaflow.k8s.ResourceAttributes.property.group"></a>

```typescript
public readonly group: string;
```

- *Type:* string

Group is the API Group of the Resource.

"*" means all.

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.ResourceAttributes.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name is the name of the resource being requested for a "get" or deleted for a "delete".

"" (empty) means all.

---

##### `namespace`<sup>Optional</sup> <a name="namespace" id="cdk8s-metaflow.k8s.ResourceAttributes.property.namespace"></a>

```typescript
public readonly namespace: string;
```

- *Type:* string

Namespace is the namespace of the action being requested.

Currently, there is no distinction between no namespace and all namespaces "" (empty) is defaulted for LocalSubjectAccessReviews "" (empty) is empty for cluster-scoped resources "" (empty) means "all" for namespace scoped resources from a SubjectAccessReview or SelfSubjectAccessReview

---

##### `resource`<sup>Optional</sup> <a name="resource" id="cdk8s-metaflow.k8s.ResourceAttributes.property.resource"></a>

```typescript
public readonly resource: string;
```

- *Type:* string

Resource is one of the existing resource types.

"*" means all.

---

##### `subresource`<sup>Optional</sup> <a name="subresource" id="cdk8s-metaflow.k8s.ResourceAttributes.property.subresource"></a>

```typescript
public readonly subresource: string;
```

- *Type:* string

Subresource is one of the existing resource types.

"" means none.

---

##### `verb`<sup>Optional</sup> <a name="verb" id="cdk8s-metaflow.k8s.ResourceAttributes.property.verb"></a>

```typescript
public readonly verb: string;
```

- *Type:* string

Verb is a kubernetes resource API verb, like: get, list, watch, create, update, delete, proxy.

"*" means all.

---

##### `version`<sup>Optional</sup> <a name="version" id="cdk8s-metaflow.k8s.ResourceAttributes.property.version"></a>

```typescript
public readonly version: string;
```

- *Type:* string

Version is the API Version of the Resource.

"*" means all.

---

### ResourceFieldSelector <a name="ResourceFieldSelector" id="cdk8s-metaflow.k8s.ResourceFieldSelector"></a>

ResourceFieldSelector represents container resources (cpu, memory) and their output format.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ResourceFieldSelector.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const resourceFieldSelector: k8s.ResourceFieldSelector = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceFieldSelector.property.resource">resource</a></code> | <code>string</code> | Required: resource to select. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceFieldSelector.property.containerName">containerName</a></code> | <code>string</code> | Container name: required for volumes, optional for env vars. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceFieldSelector.property.divisor">divisor</a></code> | <code>cdk8s-metaflow.k8s.Quantity</code> | Specifies the output format of the exposed resources, defaults to "1". |

---

##### `resource`<sup>Required</sup> <a name="resource" id="cdk8s-metaflow.k8s.ResourceFieldSelector.property.resource"></a>

```typescript
public readonly resource: string;
```

- *Type:* string

Required: resource to select.

---

##### `containerName`<sup>Optional</sup> <a name="containerName" id="cdk8s-metaflow.k8s.ResourceFieldSelector.property.containerName"></a>

```typescript
public readonly containerName: string;
```

- *Type:* string

Container name: required for volumes, optional for env vars.

---

##### `divisor`<sup>Optional</sup> <a name="divisor" id="cdk8s-metaflow.k8s.ResourceFieldSelector.property.divisor"></a>

```typescript
public readonly divisor: Quantity;
```

- *Type:* cdk8s-metaflow.k8s.Quantity

Specifies the output format of the exposed resources, defaults to "1".

---

### ResourceMetricSourceV2Beta1 <a name="ResourceMetricSourceV2Beta1" id="cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta1"></a>

ResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const resourceMetricSourceV2Beta1: k8s.ResourceMetricSourceV2Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta1.property.name">name</a></code> | <code>string</code> | name is the name of the resource in question. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta1.property.targetAverageUtilization">targetAverageUtilization</a></code> | <code>number</code> | targetAverageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta1.property.targetAverageValue">targetAverageValue</a></code> | <code>cdk8s-metaflow.k8s.Quantity</code> | targetAverageValue is the target value of the average of the resource metric across all relevant pods, as a raw value (instead of as a percentage of the request), similar to the "pods" metric source type. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

name is the name of the resource in question.

---

##### `targetAverageUtilization`<sup>Optional</sup> <a name="targetAverageUtilization" id="cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta1.property.targetAverageUtilization"></a>

```typescript
public readonly targetAverageUtilization: number;
```

- *Type:* number

targetAverageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.

---

##### `targetAverageValue`<sup>Optional</sup> <a name="targetAverageValue" id="cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta1.property.targetAverageValue"></a>

```typescript
public readonly targetAverageValue: Quantity;
```

- *Type:* cdk8s-metaflow.k8s.Quantity

targetAverageValue is the target value of the average of the resource metric across all relevant pods, as a raw value (instead of as a percentage of the request), similar to the "pods" metric source type.

---

### ResourceMetricSourceV2Beta2 <a name="ResourceMetricSourceV2Beta2" id="cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta2"></a>

ResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta2.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const resourceMetricSourceV2Beta2: k8s.ResourceMetricSourceV2Beta2 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta2.property.name">name</a></code> | <code>string</code> | name is the name of the resource in question. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta2.property.target">target</a></code> | <code>cdk8s-metaflow.k8s.MetricTargetV2Beta2</code> | target specifies the target value for the given metric. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta2.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

name is the name of the resource in question.

---

##### `target`<sup>Required</sup> <a name="target" id="cdk8s-metaflow.k8s.ResourceMetricSourceV2Beta2.property.target"></a>

```typescript
public readonly target: MetricTargetV2Beta2;
```

- *Type:* cdk8s-metaflow.k8s.MetricTargetV2Beta2

target specifies the target value for the given metric.

---

### ResourcePolicyRuleV1Beta1 <a name="ResourcePolicyRuleV1Beta1" id="cdk8s-metaflow.k8s.ResourcePolicyRuleV1Beta1"></a>

ResourcePolicyRule is a predicate that matches some resource requests, testing the request's verb and the target resource.

A ResourcePolicyRule matches a resource request if and only if: (a) at least one member of verbs matches the request, (b) at least one member of apiGroups matches the request, (c) at least one member of resources matches the request, and (d) least one member of namespaces matches the request.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ResourcePolicyRuleV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const resourcePolicyRuleV1Beta1: k8s.ResourcePolicyRuleV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourcePolicyRuleV1Beta1.property.apiGroups">apiGroups</a></code> | <code>string[]</code> | `apiGroups` is a list of matching API groups and may not be empty. |
| <code><a href="#cdk8s-metaflow.k8s.ResourcePolicyRuleV1Beta1.property.resources">resources</a></code> | <code>string[]</code> | `resources` is a list of matching resources (i.e., lowercase and plural) with, if desired, subresource.  For example, [ "services", "nodes/status" ].  This list may not be empty. "*" matches all resources and, if present, must be the only entry. Required. |
| <code><a href="#cdk8s-metaflow.k8s.ResourcePolicyRuleV1Beta1.property.verbs">verbs</a></code> | <code>string[]</code> | `verbs` is a list of matching verbs and may not be empty. |
| <code><a href="#cdk8s-metaflow.k8s.ResourcePolicyRuleV1Beta1.property.clusterScope">clusterScope</a></code> | <code>boolean</code> | `clusterScope` indicates whether to match requests that do not specify a namespace (which happens either because the resource is not namespaced or the request targets all namespaces). |
| <code><a href="#cdk8s-metaflow.k8s.ResourcePolicyRuleV1Beta1.property.namespaces">namespaces</a></code> | <code>string[]</code> | `namespaces` is a list of target namespaces that restricts matches. |

---

##### `apiGroups`<sup>Required</sup> <a name="apiGroups" id="cdk8s-metaflow.k8s.ResourcePolicyRuleV1Beta1.property.apiGroups"></a>

```typescript
public readonly apiGroups: string[];
```

- *Type:* string[]

`apiGroups` is a list of matching API groups and may not be empty.

"*" matches all API groups and, if present, must be the only entry. Required.

---

##### `resources`<sup>Required</sup> <a name="resources" id="cdk8s-metaflow.k8s.ResourcePolicyRuleV1Beta1.property.resources"></a>

```typescript
public readonly resources: string[];
```

- *Type:* string[]

`resources` is a list of matching resources (i.e., lowercase and plural) with, if desired, subresource.  For example, [ "services", "nodes/status" ].  This list may not be empty. "*" matches all resources and, if present, must be the only entry. Required.

---

##### `verbs`<sup>Required</sup> <a name="verbs" id="cdk8s-metaflow.k8s.ResourcePolicyRuleV1Beta1.property.verbs"></a>

```typescript
public readonly verbs: string[];
```

- *Type:* string[]

`verbs` is a list of matching verbs and may not be empty.

"*" matches all verbs and, if present, must be the only entry. Required.

---

##### `clusterScope`<sup>Optional</sup> <a name="clusterScope" id="cdk8s-metaflow.k8s.ResourcePolicyRuleV1Beta1.property.clusterScope"></a>

```typescript
public readonly clusterScope: boolean;
```

- *Type:* boolean

`clusterScope` indicates whether to match requests that do not specify a namespace (which happens either because the resource is not namespaced or the request targets all namespaces).

If this field is omitted or false then the `namespaces` field must contain a non-empty list.

---

##### `namespaces`<sup>Optional</sup> <a name="namespaces" id="cdk8s-metaflow.k8s.ResourcePolicyRuleV1Beta1.property.namespaces"></a>

```typescript
public readonly namespaces: string[];
```

- *Type:* string[]

`namespaces` is a list of target namespaces that restricts matches.

A request that specifies a target namespace matches only if either (a) this list contains that target namespace or (b) this list contains "*".  Note that "*" matches any specified namespace but does not match a request that _does not specify_ a namespace (see the `clusterScope` field for that). This list may be empty, but only if `clusterScope` is true.

---

### ResourceQuotaListProps <a name="ResourceQuotaListProps" id="cdk8s-metaflow.k8s.ResourceQuotaListProps"></a>

ResourceQuotaList is a list of ResourceQuota items.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ResourceQuotaListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const resourceQuotaListProps: k8s.ResourceQuotaListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.ResourceQuota[]</code> | Items is a list of ResourceQuota objects. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.ResourceQuotaListProps.property.items"></a>

```typescript
public readonly items: ResourceQuota[];
```

- *Type:* cdk8s-metaflow.k8s.ResourceQuota[]

Items is a list of ResourceQuota objects.

More info: https://kubernetes.io/docs/concepts/policy/resource-quotas/

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ResourceQuotaListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

### ResourceQuotaProps <a name="ResourceQuotaProps" id="cdk8s-metaflow.k8s.ResourceQuotaProps"></a>

ResourceQuota sets aggregate quota restrictions enforced per namespace.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ResourceQuotaProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const resourceQuotaProps: k8s.ResourceQuotaProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.ResourceQuotaSpec</code> | Spec defines the desired quota. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ResourceQuotaProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.ResourceQuotaProps.property.spec"></a>

```typescript
public readonly spec: ResourceQuotaSpec;
```

- *Type:* cdk8s-metaflow.k8s.ResourceQuotaSpec

Spec defines the desired quota.

https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### ResourceQuotaSpec <a name="ResourceQuotaSpec" id="cdk8s-metaflow.k8s.ResourceQuotaSpec"></a>

ResourceQuotaSpec defines the desired hard limits to enforce for Quota.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ResourceQuotaSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const resourceQuotaSpec: k8s.ResourceQuotaSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaSpec.property.hard">hard</a></code> | <code>{[ key: string ]: cdk8s-metaflow.k8s.Quantity}</code> | hard is the set of desired hard limits for each named resource. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaSpec.property.scopes">scopes</a></code> | <code>string[]</code> | A collection of filters that must match each object tracked by a quota. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceQuotaSpec.property.scopeSelector">scopeSelector</a></code> | <code>cdk8s-metaflow.k8s.ScopeSelector</code> | scopeSelector is also a collection of filters like scopes that must match each object tracked by a quota but expressed using ScopeSelectorOperator in combination with possible values. |

---

##### `hard`<sup>Optional</sup> <a name="hard" id="cdk8s-metaflow.k8s.ResourceQuotaSpec.property.hard"></a>

```typescript
public readonly hard: {[ key: string ]: Quantity};
```

- *Type:* {[ key: string ]: cdk8s-metaflow.k8s.Quantity}

hard is the set of desired hard limits for each named resource.

More info: https://kubernetes.io/docs/concepts/policy/resource-quotas/

---

##### `scopes`<sup>Optional</sup> <a name="scopes" id="cdk8s-metaflow.k8s.ResourceQuotaSpec.property.scopes"></a>

```typescript
public readonly scopes: string[];
```

- *Type:* string[]

A collection of filters that must match each object tracked by a quota.

If not specified, the quota matches all objects.

---

##### `scopeSelector`<sup>Optional</sup> <a name="scopeSelector" id="cdk8s-metaflow.k8s.ResourceQuotaSpec.property.scopeSelector"></a>

```typescript
public readonly scopeSelector: ScopeSelector;
```

- *Type:* cdk8s-metaflow.k8s.ScopeSelector

scopeSelector is also a collection of filters like scopes that must match each object tracked by a quota but expressed using ScopeSelectorOperator in combination with possible values.

For a resource to match, both scopes AND scopeSelector (if specified in spec), must be matched.

---

### ResourceRequirements <a name="ResourceRequirements" id="cdk8s-metaflow.k8s.ResourceRequirements"></a>

ResourceRequirements describes the compute resource requirements.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ResourceRequirements.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const resourceRequirements: k8s.ResourceRequirements = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ResourceRequirements.property.limits">limits</a></code> | <code>{[ key: string ]: cdk8s-metaflow.k8s.Quantity}</code> | Limits describes the maximum amount of compute resources allowed. |
| <code><a href="#cdk8s-metaflow.k8s.ResourceRequirements.property.requests">requests</a></code> | <code>{[ key: string ]: cdk8s-metaflow.k8s.Quantity}</code> | Requests describes the minimum amount of compute resources required. |

---

##### `limits`<sup>Optional</sup> <a name="limits" id="cdk8s-metaflow.k8s.ResourceRequirements.property.limits"></a>

```typescript
public readonly limits: {[ key: string ]: Quantity};
```

- *Type:* {[ key: string ]: cdk8s-metaflow.k8s.Quantity}

Limits describes the maximum amount of compute resources allowed.

More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/

---

##### `requests`<sup>Optional</sup> <a name="requests" id="cdk8s-metaflow.k8s.ResourceRequirements.property.requests"></a>

```typescript
public readonly requests: {[ key: string ]: Quantity};
```

- *Type:* {[ key: string ]: cdk8s-metaflow.k8s.Quantity}

Requests describes the minimum amount of compute resources required.

If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/

---

### RoleBindingListProps <a name="RoleBindingListProps" id="cdk8s-metaflow.k8s.RoleBindingListProps"></a>

RoleBindingList is a collection of RoleBindings.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RoleBindingListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const roleBindingListProps: k8s.RoleBindingListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.RoleBinding[]</code> | Items is a list of RoleBindings. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard object's metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.RoleBindingListProps.property.items"></a>

```typescript
public readonly items: RoleBinding[];
```

- *Type:* cdk8s-metaflow.k8s.RoleBinding[]

Items is a list of RoleBindings.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RoleBindingListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard object's metadata.

---

### RoleBindingListV1Alpha1Props <a name="RoleBindingListV1Alpha1Props" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1Props"></a>

RoleBindingList is a collection of RoleBindings Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 RoleBindingList, and will no longer be served in v1.22.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const roleBindingListV1Alpha1Props: k8s.RoleBindingListV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.RoleBindingV1Alpha1[]</code> | Items is a list of RoleBindings. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingListV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard object's metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1Props.property.items"></a>

```typescript
public readonly items: RoleBindingV1Alpha1[];
```

- *Type:* cdk8s-metaflow.k8s.RoleBindingV1Alpha1[]

Items is a list of RoleBindings.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RoleBindingListV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard object's metadata.

---

### RoleBindingProps <a name="RoleBindingProps" id="cdk8s-metaflow.k8s.RoleBindingProps"></a>

RoleBinding references a role, but does not contain it.

It can reference a Role in the same namespace or a ClusterRole in the global namespace. It adds who information via Subjects and namespace information by which namespace it exists in.  RoleBindings in a given namespace only have effect in that namespace.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RoleBindingProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const roleBindingProps: k8s.RoleBindingProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingProps.property.roleRef">roleRef</a></code> | <code>cdk8s-metaflow.k8s.RoleRef</code> | RoleRef can reference a Role in the current namespace or a ClusterRole in the global namespace. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingProps.property.subjects">subjects</a></code> | <code>cdk8s-metaflow.k8s.Subject[]</code> | Subjects holds references to the objects the role applies to. |

---

##### `roleRef`<sup>Required</sup> <a name="roleRef" id="cdk8s-metaflow.k8s.RoleBindingProps.property.roleRef"></a>

```typescript
public readonly roleRef: RoleRef;
```

- *Type:* cdk8s-metaflow.k8s.RoleRef

RoleRef can reference a Role in the current namespace or a ClusterRole in the global namespace.

If the RoleRef cannot be resolved, the Authorizer must return an error.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RoleBindingProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

---

##### `subjects`<sup>Optional</sup> <a name="subjects" id="cdk8s-metaflow.k8s.RoleBindingProps.property.subjects"></a>

```typescript
public readonly subjects: Subject[];
```

- *Type:* cdk8s-metaflow.k8s.Subject[]

Subjects holds references to the objects the role applies to.

---

### RoleBindingV1Alpha1Props <a name="RoleBindingV1Alpha1Props" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1Props"></a>

RoleBinding references a role, but does not contain it.

It can reference a Role in the same namespace or a ClusterRole in the global namespace. It adds who information via Subjects and namespace information by which namespace it exists in.  RoleBindings in a given namespace only have effect in that namespace. Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 RoleBinding, and will no longer be served in v1.22.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const roleBindingV1Alpha1Props: k8s.RoleBindingV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1Props.property.roleRef">roleRef</a></code> | <code>cdk8s-metaflow.k8s.RoleRefV1Alpha1</code> | RoleRef can reference a Role in the current namespace or a ClusterRole in the global namespace. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.RoleBindingV1Alpha1Props.property.subjects">subjects</a></code> | <code>cdk8s-metaflow.k8s.SubjectV1Alpha1[]</code> | Subjects holds references to the objects the role applies to. |

---

##### `roleRef`<sup>Required</sup> <a name="roleRef" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1Props.property.roleRef"></a>

```typescript
public readonly roleRef: RoleRefV1Alpha1;
```

- *Type:* cdk8s-metaflow.k8s.RoleRefV1Alpha1

RoleRef can reference a Role in the current namespace or a ClusterRole in the global namespace.

If the RoleRef cannot be resolved, the Authorizer must return an error.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

---

##### `subjects`<sup>Optional</sup> <a name="subjects" id="cdk8s-metaflow.k8s.RoleBindingV1Alpha1Props.property.subjects"></a>

```typescript
public readonly subjects: SubjectV1Alpha1[];
```

- *Type:* cdk8s-metaflow.k8s.SubjectV1Alpha1[]

Subjects holds references to the objects the role applies to.

---

### RoleListProps <a name="RoleListProps" id="cdk8s-metaflow.k8s.RoleListProps"></a>

RoleList is a collection of Roles.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RoleListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const roleListProps: k8s.RoleListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.Role[]</code> | Items is a list of Roles. |
| <code><a href="#cdk8s-metaflow.k8s.RoleListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard object's metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.RoleListProps.property.items"></a>

```typescript
public readonly items: Role[];
```

- *Type:* cdk8s-metaflow.k8s.Role[]

Items is a list of Roles.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RoleListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard object's metadata.

---

### RoleListV1Alpha1Props <a name="RoleListV1Alpha1Props" id="cdk8s-metaflow.k8s.RoleListV1Alpha1Props"></a>

RoleList is a collection of Roles.

Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 RoleList, and will no longer be served in v1.22.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RoleListV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const roleListV1Alpha1Props: k8s.RoleListV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.RoleV1Alpha1[]</code> | Items is a list of Roles. |
| <code><a href="#cdk8s-metaflow.k8s.RoleListV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard object's metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.RoleListV1Alpha1Props.property.items"></a>

```typescript
public readonly items: RoleV1Alpha1[];
```

- *Type:* cdk8s-metaflow.k8s.RoleV1Alpha1[]

Items is a list of Roles.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RoleListV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard object's metadata.

---

### RoleProps <a name="RoleProps" id="cdk8s-metaflow.k8s.RoleProps"></a>

Role is a namespaced, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RoleProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const roleProps: k8s.RoleProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.RoleProps.property.rules">rules</a></code> | <code>cdk8s-metaflow.k8s.PolicyRule[]</code> | Rules holds all the PolicyRules for this Role. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RoleProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

---

##### `rules`<sup>Optional</sup> <a name="rules" id="cdk8s-metaflow.k8s.RoleProps.property.rules"></a>

```typescript
public readonly rules: PolicyRule[];
```

- *Type:* cdk8s-metaflow.k8s.PolicyRule[]

Rules holds all the PolicyRules for this Role.

---

### RoleRef <a name="RoleRef" id="cdk8s-metaflow.k8s.RoleRef"></a>

RoleRef contains information that points to the role being used.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RoleRef.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const roleRef: k8s.RoleRef = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleRef.property.apiGroup">apiGroup</a></code> | <code>string</code> | APIGroup is the group for the resource being referenced. |
| <code><a href="#cdk8s-metaflow.k8s.RoleRef.property.kind">kind</a></code> | <code>string</code> | Kind is the type of resource being referenced. |
| <code><a href="#cdk8s-metaflow.k8s.RoleRef.property.name">name</a></code> | <code>string</code> | Name is the name of resource being referenced. |

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.RoleRef.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

APIGroup is the group for the resource being referenced.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.RoleRef.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

Kind is the type of resource being referenced.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.RoleRef.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name is the name of resource being referenced.

---

### RoleRefV1Alpha1 <a name="RoleRefV1Alpha1" id="cdk8s-metaflow.k8s.RoleRefV1Alpha1"></a>

RoleRef contains information that points to the role being used.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RoleRefV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const roleRefV1Alpha1: k8s.RoleRefV1Alpha1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleRefV1Alpha1.property.apiGroup">apiGroup</a></code> | <code>string</code> | APIGroup is the group for the resource being referenced. |
| <code><a href="#cdk8s-metaflow.k8s.RoleRefV1Alpha1.property.kind">kind</a></code> | <code>string</code> | Kind is the type of resource being referenced. |
| <code><a href="#cdk8s-metaflow.k8s.RoleRefV1Alpha1.property.name">name</a></code> | <code>string</code> | Name is the name of resource being referenced. |

---

##### `apiGroup`<sup>Required</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.RoleRefV1Alpha1.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

APIGroup is the group for the resource being referenced.

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.RoleRefV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

Kind is the type of resource being referenced.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.RoleRefV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name is the name of resource being referenced.

---

### RoleV1Alpha1Props <a name="RoleV1Alpha1Props" id="cdk8s-metaflow.k8s.RoleV1Alpha1Props"></a>

Role is a namespaced, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding.

Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 Role, and will no longer be served in v1.22.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RoleV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const roleV1Alpha1Props: k8s.RoleV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.RoleV1Alpha1Props.property.rules">rules</a></code> | <code>cdk8s-metaflow.k8s.PolicyRuleV1Alpha1[]</code> | Rules holds all the PolicyRules for this Role. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RoleV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

---

##### `rules`<sup>Optional</sup> <a name="rules" id="cdk8s-metaflow.k8s.RoleV1Alpha1Props.property.rules"></a>

```typescript
public readonly rules: PolicyRuleV1Alpha1[];
```

- *Type:* cdk8s-metaflow.k8s.PolicyRuleV1Alpha1[]

Rules holds all the PolicyRules for this Role.

---

### RollingUpdateDaemonSet <a name="RollingUpdateDaemonSet" id="cdk8s-metaflow.k8s.RollingUpdateDaemonSet"></a>

Spec to control the desired behavior of daemon set rolling update.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RollingUpdateDaemonSet.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const rollingUpdateDaemonSet: k8s.RollingUpdateDaemonSet = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RollingUpdateDaemonSet.property.maxSurge">maxSurge</a></code> | <code>cdk8s-metaflow.k8s.IntOrString</code> | The maximum number of nodes with an existing available DaemonSet pod that can have an updated DaemonSet pod during during an update. |
| <code><a href="#cdk8s-metaflow.k8s.RollingUpdateDaemonSet.property.maxUnavailable">maxUnavailable</a></code> | <code>cdk8s-metaflow.k8s.IntOrString</code> | The maximum number of DaemonSet pods that can be unavailable during the update. |

---

##### `maxSurge`<sup>Optional</sup> <a name="maxSurge" id="cdk8s-metaflow.k8s.RollingUpdateDaemonSet.property.maxSurge"></a>

```typescript
public readonly maxSurge: IntOrString;
```

- *Type:* cdk8s-metaflow.k8s.IntOrString

The maximum number of nodes with an existing available DaemonSet pod that can have an updated DaemonSet pod during during an update.

Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). This can not be 0 if MaxUnavailable is 0. Absolute number is calculated from percentage by rounding up to a minimum of 1. Default value is 0. Example: when this is set to 30%, at most 30% of the total number of nodes that should be running the daemon pod (i.e. status.desiredNumberScheduled) can have their a new pod created before the old pod is marked as deleted. The update starts by launching new pods on 30% of nodes. Once an updated pod is available (Ready for at least minReadySeconds) the old DaemonSet pod on that node is marked deleted. If the old pod becomes unavailable for any reason (Ready transitions to false, is evicted, or is drained) an updated pod is immediatedly created on that node without considering surge limits. Allowing surge implies the possibility that the resources consumed by the daemonset on any given node can double if the readiness check fails, and so resource intensive daemonsets should take into account that they may cause evictions during disruption. This is beta field and enabled/disabled by DaemonSetUpdateSurge feature gate.

---

##### `maxUnavailable`<sup>Optional</sup> <a name="maxUnavailable" id="cdk8s-metaflow.k8s.RollingUpdateDaemonSet.property.maxUnavailable"></a>

```typescript
public readonly maxUnavailable: IntOrString;
```

- *Type:* cdk8s-metaflow.k8s.IntOrString

The maximum number of DaemonSet pods that can be unavailable during the update.

Value can be an absolute number (ex: 5) or a percentage of total number of DaemonSet pods at the start of the update (ex: 10%). Absolute number is calculated from percentage by rounding up. This cannot be 0 if MaxSurge is 0 Default value is 1. Example: when this is set to 30%, at most 30% of the total number of nodes that should be running the daemon pod (i.e. status.desiredNumberScheduled) can have their pods stopped for an update at any given time. The update starts by stopping at most 30% of those DaemonSet pods and then brings up new DaemonSet pods in their place. Once the new pods are available, it then proceeds onto other DaemonSet pods, thus ensuring that at least 70% of original number of DaemonSet pods are available at all times during the update.

---

### RollingUpdateDeployment <a name="RollingUpdateDeployment" id="cdk8s-metaflow.k8s.RollingUpdateDeployment"></a>

Spec to control the desired behavior of rolling update.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RollingUpdateDeployment.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const rollingUpdateDeployment: k8s.RollingUpdateDeployment = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RollingUpdateDeployment.property.maxSurge">maxSurge</a></code> | <code>cdk8s-metaflow.k8s.IntOrString</code> | The maximum number of pods that can be scheduled above the desired number of pods. |
| <code><a href="#cdk8s-metaflow.k8s.RollingUpdateDeployment.property.maxUnavailable">maxUnavailable</a></code> | <code>cdk8s-metaflow.k8s.IntOrString</code> | The maximum number of pods that can be unavailable during the update. |

---

##### `maxSurge`<sup>Optional</sup> <a name="maxSurge" id="cdk8s-metaflow.k8s.RollingUpdateDeployment.property.maxSurge"></a>

```typescript
public readonly maxSurge: IntOrString;
```

- *Type:* cdk8s-metaflow.k8s.IntOrString
- *Default:* 25%. Example: when this is set to 30%, the new ReplicaSet can be scaled up immediately when the rolling update starts, such that the total number of old and new pods do not exceed 130% of desired pods. Once old pods have been killed, new ReplicaSet can be scaled up further, ensuring that total number of pods running at any time during the update is at most 130% of desired pods.

The maximum number of pods that can be scheduled above the desired number of pods.

Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). This can not be 0 if MaxUnavailable is 0. Absolute number is calculated from percentage by rounding up. Defaults to 25%. Example: when this is set to 30%, the new ReplicaSet can be scaled up immediately when the rolling update starts, such that the total number of old and new pods do not exceed 130% of desired pods. Once old pods have been killed, new ReplicaSet can be scaled up further, ensuring that total number of pods running at any time during the update is at most 130% of desired pods.

---

##### `maxUnavailable`<sup>Optional</sup> <a name="maxUnavailable" id="cdk8s-metaflow.k8s.RollingUpdateDeployment.property.maxUnavailable"></a>

```typescript
public readonly maxUnavailable: IntOrString;
```

- *Type:* cdk8s-metaflow.k8s.IntOrString
- *Default:* 25%. Example: when this is set to 30%, the old ReplicaSet can be scaled down to 70% of desired pods immediately when the rolling update starts. Once new pods are ready, old ReplicaSet can be scaled down further, followed by scaling up the new ReplicaSet, ensuring that the total number of pods available at all times during the update is at least 70% of desired pods.

The maximum number of pods that can be unavailable during the update.

Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). Absolute number is calculated from percentage by rounding down. This can not be 0 if MaxSurge is 0. Defaults to 25%. Example: when this is set to 30%, the old ReplicaSet can be scaled down to 70% of desired pods immediately when the rolling update starts. Once new pods are ready, old ReplicaSet can be scaled down further, followed by scaling up the new ReplicaSet, ensuring that the total number of pods available at all times during the update is at least 70% of desired pods.

---

### RollingUpdateStatefulSetStrategy <a name="RollingUpdateStatefulSetStrategy" id="cdk8s-metaflow.k8s.RollingUpdateStatefulSetStrategy"></a>

RollingUpdateStatefulSetStrategy is used to communicate parameter for RollingUpdateStatefulSetStrategyType.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RollingUpdateStatefulSetStrategy.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const rollingUpdateStatefulSetStrategy: k8s.RollingUpdateStatefulSetStrategy = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RollingUpdateStatefulSetStrategy.property.partition">partition</a></code> | <code>number</code> | Partition indicates the ordinal at which the StatefulSet should be partitioned. |

---

##### `partition`<sup>Optional</sup> <a name="partition" id="cdk8s-metaflow.k8s.RollingUpdateStatefulSetStrategy.property.partition"></a>

```typescript
public readonly partition: number;
```

- *Type:* number

Partition indicates the ordinal at which the StatefulSet should be partitioned.

Default value is 0.

---

### RuleWithOperations <a name="RuleWithOperations" id="cdk8s-metaflow.k8s.RuleWithOperations"></a>

RuleWithOperations is a tuple of Operations and Resources.

It is recommended to make sure that all the tuple expansions are valid.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RuleWithOperations.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const ruleWithOperations: k8s.RuleWithOperations = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuleWithOperations.property.apiGroups">apiGroups</a></code> | <code>string[]</code> | APIGroups is the API groups the resources belong to. |
| <code><a href="#cdk8s-metaflow.k8s.RuleWithOperations.property.apiVersions">apiVersions</a></code> | <code>string[]</code> | APIVersions is the API versions the resources belong to. |
| <code><a href="#cdk8s-metaflow.k8s.RuleWithOperations.property.operations">operations</a></code> | <code>string[]</code> | Operations is the operations the admission hook cares about - CREATE, UPDATE, DELETE, CONNECT or * for all of those operations and any future admission operations that are added. |
| <code><a href="#cdk8s-metaflow.k8s.RuleWithOperations.property.resources">resources</a></code> | <code>string[]</code> | Resources is a list of resources this rule applies to. |
| <code><a href="#cdk8s-metaflow.k8s.RuleWithOperations.property.scope">scope</a></code> | <code>string</code> | scope specifies the scope of this rule. |

---

##### `apiGroups`<sup>Optional</sup> <a name="apiGroups" id="cdk8s-metaflow.k8s.RuleWithOperations.property.apiGroups"></a>

```typescript
public readonly apiGroups: string[];
```

- *Type:* string[]

APIGroups is the API groups the resources belong to.

'*' is all groups. If '*' is present, the length of the slice must be one. Required.

---

##### `apiVersions`<sup>Optional</sup> <a name="apiVersions" id="cdk8s-metaflow.k8s.RuleWithOperations.property.apiVersions"></a>

```typescript
public readonly apiVersions: string[];
```

- *Type:* string[]

APIVersions is the API versions the resources belong to.

'*' is all versions. If '*' is present, the length of the slice must be one. Required.

---

##### `operations`<sup>Optional</sup> <a name="operations" id="cdk8s-metaflow.k8s.RuleWithOperations.property.operations"></a>

```typescript
public readonly operations: string[];
```

- *Type:* string[]

Operations is the operations the admission hook cares about - CREATE, UPDATE, DELETE, CONNECT or * for all of those operations and any future admission operations that are added.

If '*' is present, the length of the slice must be one. Required.

---

##### `resources`<sup>Optional</sup> <a name="resources" id="cdk8s-metaflow.k8s.RuleWithOperations.property.resources"></a>

```typescript
public readonly resources: string[];
```

- *Type:* string[]

Resources is a list of resources this rule applies to.

For example: 'pods' means pods. 'pods/log' means the log subresource of pods. '*' means all resources, but not subresources. 'pods/*' means all subresources of pods. '_/scale' means all scale subresources. '_/*' means all resources and their subresources.

If wildcard is present, the validation rule will ensure resources do not overlap with each other.

Depending on the enclosing object, subresources might not be allowed. Required.

---

##### `scope`<sup>Optional</sup> <a name="scope" id="cdk8s-metaflow.k8s.RuleWithOperations.property.scope"></a>

```typescript
public readonly scope: string;
```

- *Type:* string
- *Default:* .

scope specifies the scope of this rule.

Valid values are "Cluster", "Namespaced", and "*" "Cluster" means that only cluster-scoped resources will match this rule. Namespace API objects are cluster-scoped. "Namespaced" means that only namespaced resources will match this rule. "*" means that there are no scope restrictions. Subresources match the scope of their parent resource. Default is "*".

---

### RunAsGroupStrategyOptionsV1Beta1 <a name="RunAsGroupStrategyOptionsV1Beta1" id="cdk8s-metaflow.k8s.RunAsGroupStrategyOptionsV1Beta1"></a>

RunAsGroupStrategyOptions defines the strategy type and any options used to create the strategy.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RunAsGroupStrategyOptionsV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const runAsGroupStrategyOptionsV1Beta1: k8s.RunAsGroupStrategyOptionsV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RunAsGroupStrategyOptionsV1Beta1.property.rule">rule</a></code> | <code>string</code> | rule is the strategy that will dictate the allowable RunAsGroup values that may be set. |
| <code><a href="#cdk8s-metaflow.k8s.RunAsGroupStrategyOptionsV1Beta1.property.ranges">ranges</a></code> | <code>cdk8s-metaflow.k8s.IdRangeV1Beta1[]</code> | ranges are the allowed ranges of gids that may be used. |

---

##### `rule`<sup>Required</sup> <a name="rule" id="cdk8s-metaflow.k8s.RunAsGroupStrategyOptionsV1Beta1.property.rule"></a>

```typescript
public readonly rule: string;
```

- *Type:* string

rule is the strategy that will dictate the allowable RunAsGroup values that may be set.

---

##### `ranges`<sup>Optional</sup> <a name="ranges" id="cdk8s-metaflow.k8s.RunAsGroupStrategyOptionsV1Beta1.property.ranges"></a>

```typescript
public readonly ranges: IdRangeV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.IdRangeV1Beta1[]

ranges are the allowed ranges of gids that may be used.

If you would like to force a single gid then supply a single range with the same start and end. Required for MustRunAs.

---

### RunAsUserStrategyOptionsV1Beta1 <a name="RunAsUserStrategyOptionsV1Beta1" id="cdk8s-metaflow.k8s.RunAsUserStrategyOptionsV1Beta1"></a>

RunAsUserStrategyOptions defines the strategy type and any options used to create the strategy.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RunAsUserStrategyOptionsV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const runAsUserStrategyOptionsV1Beta1: k8s.RunAsUserStrategyOptionsV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RunAsUserStrategyOptionsV1Beta1.property.rule">rule</a></code> | <code>string</code> | rule is the strategy that will dictate the allowable RunAsUser values that may be set. |
| <code><a href="#cdk8s-metaflow.k8s.RunAsUserStrategyOptionsV1Beta1.property.ranges">ranges</a></code> | <code>cdk8s-metaflow.k8s.IdRangeV1Beta1[]</code> | ranges are the allowed ranges of uids that may be used. |

---

##### `rule`<sup>Required</sup> <a name="rule" id="cdk8s-metaflow.k8s.RunAsUserStrategyOptionsV1Beta1.property.rule"></a>

```typescript
public readonly rule: string;
```

- *Type:* string

rule is the strategy that will dictate the allowable RunAsUser values that may be set.

---

##### `ranges`<sup>Optional</sup> <a name="ranges" id="cdk8s-metaflow.k8s.RunAsUserStrategyOptionsV1Beta1.property.ranges"></a>

```typescript
public readonly ranges: IdRangeV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.IdRangeV1Beta1[]

ranges are the allowed ranges of uids that may be used.

If you would like to force a single uid then supply a single range with the same start and end. Required for MustRunAs.

---

### RuntimeClassListProps <a name="RuntimeClassListProps" id="cdk8s-metaflow.k8s.RuntimeClassListProps"></a>

RuntimeClassList is a list of RuntimeClass objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RuntimeClassListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const runtimeClassListProps: k8s.RuntimeClassListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.RuntimeClass[]</code> | Items is a list of schema objects. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.RuntimeClassListProps.property.items"></a>

```typescript
public readonly items: RuntimeClass[];
```

- *Type:* cdk8s-metaflow.k8s.RuntimeClass[]

Items is a list of schema objects.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RuntimeClassListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### RuntimeClassListV1Alpha1Props <a name="RuntimeClassListV1Alpha1Props" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1Props"></a>

RuntimeClassList is a list of RuntimeClass objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const runtimeClassListV1Alpha1Props: k8s.RuntimeClassListV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.RuntimeClassV1Alpha1[]</code> | Items is a list of schema objects. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1Props.property.items"></a>

```typescript
public readonly items: RuntimeClassV1Alpha1[];
```

- *Type:* cdk8s-metaflow.k8s.RuntimeClassV1Alpha1[]

Items is a list of schema objects.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RuntimeClassListV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### RuntimeClassListV1Beta1Props <a name="RuntimeClassListV1Beta1Props" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1Props"></a>

RuntimeClassList is a list of RuntimeClass objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const runtimeClassListV1Beta1Props: k8s.RuntimeClassListV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.RuntimeClassV1Beta1[]</code> | Items is a list of schema objects. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassListV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1Props.property.items"></a>

```typescript
public readonly items: RuntimeClassV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.RuntimeClassV1Beta1[]

Items is a list of schema objects.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RuntimeClassListV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### RuntimeClassProps <a name="RuntimeClassProps" id="cdk8s-metaflow.k8s.RuntimeClassProps"></a>

RuntimeClass defines a class of container runtime supported in the cluster.

The RuntimeClass is used to determine which container runtime is used to run all containers in a pod. RuntimeClasses are manually defined by a user or cluster provisioner, and referenced in the PodSpec. The Kubelet is responsible for resolving the RuntimeClassName reference before running the pod.  For more details, see https://kubernetes.io/docs/concepts/containers/runtime-class/

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RuntimeClassProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const runtimeClassProps: k8s.RuntimeClassProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassProps.property.handler">handler</a></code> | <code>string</code> | Handler specifies the underlying runtime and configuration that the CRI implementation will use to handle pods of this class. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassProps.property.overhead">overhead</a></code> | <code>cdk8s-metaflow.k8s.Overhead</code> | Overhead represents the resource overhead associated with running a pod for a given RuntimeClass. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassProps.property.scheduling">scheduling</a></code> | <code>cdk8s-metaflow.k8s.Scheduling</code> | Scheduling holds the scheduling constraints to ensure that pods running with this RuntimeClass are scheduled to nodes that support it. |

---

##### `handler`<sup>Required</sup> <a name="handler" id="cdk8s-metaflow.k8s.RuntimeClassProps.property.handler"></a>

```typescript
public readonly handler: string;
```

- *Type:* string

Handler specifies the underlying runtime and configuration that the CRI implementation will use to handle pods of this class.

The possible values are specific to the node & CRI configuration.  It is assumed that all handlers are available on every node, and handlers of the same name are equivalent on every node. For example, a handler called "runc" might specify that the runc OCI runtime (using native Linux containers) will be used to run the containers in a pod. The Handler must be lowercase, conform to the DNS Label (RFC 1123) requirements, and is immutable.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RuntimeClassProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

##### `overhead`<sup>Optional</sup> <a name="overhead" id="cdk8s-metaflow.k8s.RuntimeClassProps.property.overhead"></a>

```typescript
public readonly overhead: Overhead;
```

- *Type:* cdk8s-metaflow.k8s.Overhead

Overhead represents the resource overhead associated with running a pod for a given RuntimeClass.

For more details, see
https://kubernetes.io/docs/concepts/scheduling-eviction/pod-overhead/
This field is in beta starting v1.18 and is only honored by servers that enable the PodOverhead feature.

---

##### `scheduling`<sup>Optional</sup> <a name="scheduling" id="cdk8s-metaflow.k8s.RuntimeClassProps.property.scheduling"></a>

```typescript
public readonly scheduling: Scheduling;
```

- *Type:* cdk8s-metaflow.k8s.Scheduling

Scheduling holds the scheduling constraints to ensure that pods running with this RuntimeClass are scheduled to nodes that support it.

If scheduling is nil, this RuntimeClass is assumed to be supported by all nodes.

---

### RuntimeClassSpecV1Alpha1 <a name="RuntimeClassSpecV1Alpha1" id="cdk8s-metaflow.k8s.RuntimeClassSpecV1Alpha1"></a>

RuntimeClassSpec is a specification of a RuntimeClass.

It contains parameters that are required to describe the RuntimeClass to the Container Runtime Interface (CRI) implementation, as well as any other components that need to understand how the pod will be run. The RuntimeClassSpec is immutable.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RuntimeClassSpecV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const runtimeClassSpecV1Alpha1: k8s.RuntimeClassSpecV1Alpha1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassSpecV1Alpha1.property.runtimeHandler">runtimeHandler</a></code> | <code>string</code> | RuntimeHandler specifies the underlying runtime and configuration that the CRI implementation will use to handle pods of this class. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassSpecV1Alpha1.property.overhead">overhead</a></code> | <code>cdk8s-metaflow.k8s.OverheadV1Alpha1</code> | Overhead represents the resource overhead associated with running a pod for a given RuntimeClass. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassSpecV1Alpha1.property.scheduling">scheduling</a></code> | <code>cdk8s-metaflow.k8s.SchedulingV1Alpha1</code> | Scheduling holds the scheduling constraints to ensure that pods running with this RuntimeClass are scheduled to nodes that support it. |

---

##### `runtimeHandler`<sup>Required</sup> <a name="runtimeHandler" id="cdk8s-metaflow.k8s.RuntimeClassSpecV1Alpha1.property.runtimeHandler"></a>

```typescript
public readonly runtimeHandler: string;
```

- *Type:* string

RuntimeHandler specifies the underlying runtime and configuration that the CRI implementation will use to handle pods of this class.

The possible values are specific to the node & CRI configuration.  It is assumed that all handlers are available on every node, and handlers of the same name are equivalent on every node. For example, a handler called "runc" might specify that the runc OCI runtime (using native Linux containers) will be used to run the containers in a pod. The RuntimeHandler must be lowercase, conform to the DNS Label (RFC 1123) requirements, and is immutable.

---

##### `overhead`<sup>Optional</sup> <a name="overhead" id="cdk8s-metaflow.k8s.RuntimeClassSpecV1Alpha1.property.overhead"></a>

```typescript
public readonly overhead: OverheadV1Alpha1;
```

- *Type:* cdk8s-metaflow.k8s.OverheadV1Alpha1

Overhead represents the resource overhead associated with running a pod for a given RuntimeClass.

For more details, see https://git.k8s.io/enhancements/keps/sig-node/688-pod-overhead/README.md This field is beta-level as of Kubernetes v1.18, and is only honored by servers that enable the PodOverhead feature.

---

##### `scheduling`<sup>Optional</sup> <a name="scheduling" id="cdk8s-metaflow.k8s.RuntimeClassSpecV1Alpha1.property.scheduling"></a>

```typescript
public readonly scheduling: SchedulingV1Alpha1;
```

- *Type:* cdk8s-metaflow.k8s.SchedulingV1Alpha1

Scheduling holds the scheduling constraints to ensure that pods running with this RuntimeClass are scheduled to nodes that support it.

If scheduling is nil, this RuntimeClass is assumed to be supported by all nodes.

---

### RuntimeClassStrategyOptionsV1Beta1 <a name="RuntimeClassStrategyOptionsV1Beta1" id="cdk8s-metaflow.k8s.RuntimeClassStrategyOptionsV1Beta1"></a>

RuntimeClassStrategyOptions define the strategy that will dictate the allowable RuntimeClasses for a pod.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RuntimeClassStrategyOptionsV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const runtimeClassStrategyOptionsV1Beta1: k8s.RuntimeClassStrategyOptionsV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassStrategyOptionsV1Beta1.property.allowedRuntimeClassNames">allowedRuntimeClassNames</a></code> | <code>string[]</code> | allowedRuntimeClassNames is an allowlist of RuntimeClass names that may be specified on a pod. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassStrategyOptionsV1Beta1.property.defaultRuntimeClassName">defaultRuntimeClassName</a></code> | <code>string</code> | defaultRuntimeClassName is the default RuntimeClassName to set on the pod. |

---

##### `allowedRuntimeClassNames`<sup>Required</sup> <a name="allowedRuntimeClassNames" id="cdk8s-metaflow.k8s.RuntimeClassStrategyOptionsV1Beta1.property.allowedRuntimeClassNames"></a>

```typescript
public readonly allowedRuntimeClassNames: string[];
```

- *Type:* string[]

allowedRuntimeClassNames is an allowlist of RuntimeClass names that may be specified on a pod.

A value of "*" means that any RuntimeClass name is allowed, and must be the only item in the list. An empty list requires the RuntimeClassName field to be unset.

---

##### `defaultRuntimeClassName`<sup>Optional</sup> <a name="defaultRuntimeClassName" id="cdk8s-metaflow.k8s.RuntimeClassStrategyOptionsV1Beta1.property.defaultRuntimeClassName"></a>

```typescript
public readonly defaultRuntimeClassName: string;
```

- *Type:* string

defaultRuntimeClassName is the default RuntimeClassName to set on the pod.

The default MUST be allowed by the allowedRuntimeClassNames list. A value of nil does not mutate the Pod.

---

### RuntimeClassV1Alpha1Props <a name="RuntimeClassV1Alpha1Props" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1Props"></a>

RuntimeClass defines a class of container runtime supported in the cluster.

The RuntimeClass is used to determine which container runtime is used to run all containers in a pod. RuntimeClasses are (currently) manually defined by a user or cluster provisioner, and referenced in the PodSpec. The Kubelet is responsible for resolving the RuntimeClassName reference before running the pod.  For more details, see https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const runtimeClassV1Alpha1Props: k8s.RuntimeClassV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1Props.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.RuntimeClassSpecV1Alpha1</code> | Specification of the RuntimeClass More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |

---

##### `spec`<sup>Required</sup> <a name="spec" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1Props.property.spec"></a>

```typescript
public readonly spec: RuntimeClassSpecV1Alpha1;
```

- *Type:* cdk8s-metaflow.k8s.RuntimeClassSpecV1Alpha1

Specification of the RuntimeClass More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RuntimeClassV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

### RuntimeClassV1Beta1Props <a name="RuntimeClassV1Beta1Props" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1Props"></a>

RuntimeClass defines a class of container runtime supported in the cluster.

The RuntimeClass is used to determine which container runtime is used to run all containers in a pod. RuntimeClasses are (currently) manually defined by a user or cluster provisioner, and referenced in the PodSpec. The Kubelet is responsible for resolving the RuntimeClassName reference before running the pod.  For more details, see https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const runtimeClassV1Beta1Props: k8s.RuntimeClassV1Beta1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1Props.property.handler">handler</a></code> | <code>string</code> | Handler specifies the underlying runtime and configuration that the CRI implementation will use to handle pods of this class. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1Props.property.overhead">overhead</a></code> | <code>cdk8s-metaflow.k8s.OverheadV1Beta1</code> | Overhead represents the resource overhead associated with running a pod for a given RuntimeClass. |
| <code><a href="#cdk8s-metaflow.k8s.RuntimeClassV1Beta1Props.property.scheduling">scheduling</a></code> | <code>cdk8s-metaflow.k8s.SchedulingV1Beta1</code> | Scheduling holds the scheduling constraints to ensure that pods running with this RuntimeClass are scheduled to nodes that support it. |

---

##### `handler`<sup>Required</sup> <a name="handler" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1Props.property.handler"></a>

```typescript
public readonly handler: string;
```

- *Type:* string

Handler specifies the underlying runtime and configuration that the CRI implementation will use to handle pods of this class.

The possible values are specific to the node & CRI configuration.  It is assumed that all handlers are available on every node, and handlers of the same name are equivalent on every node. For example, a handler called "runc" might specify that the runc OCI runtime (using native Linux containers) will be used to run the containers in a pod. The Handler must be lowercase, conform to the DNS Label (RFC 1123) requirements, and is immutable.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

##### `overhead`<sup>Optional</sup> <a name="overhead" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1Props.property.overhead"></a>

```typescript
public readonly overhead: OverheadV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.OverheadV1Beta1

Overhead represents the resource overhead associated with running a pod for a given RuntimeClass.

For more details, see https://git.k8s.io/enhancements/keps/sig-node/688-pod-overhead/README.md This field is beta-level as of Kubernetes v1.18, and is only honored by servers that enable the PodOverhead feature.

---

##### `scheduling`<sup>Optional</sup> <a name="scheduling" id="cdk8s-metaflow.k8s.RuntimeClassV1Beta1Props.property.scheduling"></a>

```typescript
public readonly scheduling: SchedulingV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.SchedulingV1Beta1

Scheduling holds the scheduling constraints to ensure that pods running with this RuntimeClass are scheduled to nodes that support it.

If scheduling is nil, this RuntimeClass is assumed to be supported by all nodes.

---

### ScaleIoPersistentVolumeSource <a name="ScaleIoPersistentVolumeSource" id="cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource"></a>

ScaleIOPersistentVolumeSource represents a persistent ScaleIO volume.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const scaleIoPersistentVolumeSource: k8s.ScaleIoPersistentVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.gateway">gateway</a></code> | <code>string</code> | The host address of the ScaleIO API Gateway. |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.secretRef">secretRef</a></code> | <code>cdk8s-metaflow.k8s.SecretReference</code> | SecretRef references to the secret for ScaleIO user and other sensitive information. |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.system">system</a></code> | <code>string</code> | The name of the storage system as configured in ScaleIO. |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type to mount. |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.protectionDomain">protectionDomain</a></code> | <code>string</code> | The name of the ScaleIO Protection Domain for the configured storage. |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Defaults to false (read/write). |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.sslEnabled">sslEnabled</a></code> | <code>boolean</code> | Flag to enable/disable SSL communication with Gateway, default false. |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.storageMode">storageMode</a></code> | <code>string</code> | Indicates whether the storage for a volume should be ThickProvisioned or ThinProvisioned. |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.storagePool">storagePool</a></code> | <code>string</code> | The ScaleIO Storage Pool associated with the protection domain. |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.volumeName">volumeName</a></code> | <code>string</code> | The name of a volume already created in the ScaleIO system that is associated with this volume source. |

---

##### `gateway`<sup>Required</sup> <a name="gateway" id="cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.gateway"></a>

```typescript
public readonly gateway: string;
```

- *Type:* string

The host address of the ScaleIO API Gateway.

---

##### `secretRef`<sup>Required</sup> <a name="secretRef" id="cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.secretRef"></a>

```typescript
public readonly secretRef: SecretReference;
```

- *Type:* cdk8s-metaflow.k8s.SecretReference

SecretRef references to the secret for ScaleIO user and other sensitive information.

If this is not provided, Login operation will fail.

---

##### `system`<sup>Required</sup> <a name="system" id="cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.system"></a>

```typescript
public readonly system: string;
```

- *Type:* string

The name of the storage system as configured in ScaleIO.

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string
- *Default:* xfs"

Filesystem type to mount.

Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Default is "xfs"

---

##### `protectionDomain`<sup>Optional</sup> <a name="protectionDomain" id="cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.protectionDomain"></a>

```typescript
public readonly protectionDomain: string;
```

- *Type:* string

The name of the ScaleIO Protection Domain for the configured storage.

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.

Defaults to false (read/write).

ReadOnly here will force the ReadOnly setting in VolumeMounts.

---

##### `sslEnabled`<sup>Optional</sup> <a name="sslEnabled" id="cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.sslEnabled"></a>

```typescript
public readonly sslEnabled: boolean;
```

- *Type:* boolean

Flag to enable/disable SSL communication with Gateway, default false.

---

##### `storageMode`<sup>Optional</sup> <a name="storageMode" id="cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.storageMode"></a>

```typescript
public readonly storageMode: string;
```

- *Type:* string
- *Default:* ThinProvisioned.

Indicates whether the storage for a volume should be ThickProvisioned or ThinProvisioned.

Default is ThinProvisioned.

---

##### `storagePool`<sup>Optional</sup> <a name="storagePool" id="cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.storagePool"></a>

```typescript
public readonly storagePool: string;
```

- *Type:* string

The ScaleIO Storage Pool associated with the protection domain.

---

##### `volumeName`<sup>Optional</sup> <a name="volumeName" id="cdk8s-metaflow.k8s.ScaleIoPersistentVolumeSource.property.volumeName"></a>

```typescript
public readonly volumeName: string;
```

- *Type:* string

The name of a volume already created in the ScaleIO system that is associated with this volume source.

---

### ScaleIoVolumeSource <a name="ScaleIoVolumeSource" id="cdk8s-metaflow.k8s.ScaleIoVolumeSource"></a>

ScaleIOVolumeSource represents a persistent ScaleIO volume.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ScaleIoVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const scaleIoVolumeSource: k8s.ScaleIoVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.gateway">gateway</a></code> | <code>string</code> | The host address of the ScaleIO API Gateway. |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.secretRef">secretRef</a></code> | <code>cdk8s-metaflow.k8s.LocalObjectReference</code> | SecretRef references to the secret for ScaleIO user and other sensitive information. |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.system">system</a></code> | <code>string</code> | The name of the storage system as configured in ScaleIO. |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type to mount. |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.protectionDomain">protectionDomain</a></code> | <code>string</code> | The name of the ScaleIO Protection Domain for the configured storage. |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Defaults to false (read/write). |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.sslEnabled">sslEnabled</a></code> | <code>boolean</code> | Flag to enable/disable SSL communication with Gateway, default false. |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.storageMode">storageMode</a></code> | <code>string</code> | Indicates whether the storage for a volume should be ThickProvisioned or ThinProvisioned. |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.storagePool">storagePool</a></code> | <code>string</code> | The ScaleIO Storage Pool associated with the protection domain. |
| <code><a href="#cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.volumeName">volumeName</a></code> | <code>string</code> | The name of a volume already created in the ScaleIO system that is associated with this volume source. |

---

##### `gateway`<sup>Required</sup> <a name="gateway" id="cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.gateway"></a>

```typescript
public readonly gateway: string;
```

- *Type:* string

The host address of the ScaleIO API Gateway.

---

##### `secretRef`<sup>Required</sup> <a name="secretRef" id="cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.secretRef"></a>

```typescript
public readonly secretRef: LocalObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.LocalObjectReference

SecretRef references to the secret for ScaleIO user and other sensitive information.

If this is not provided, Login operation will fail.

---

##### `system`<sup>Required</sup> <a name="system" id="cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.system"></a>

```typescript
public readonly system: string;
```

- *Type:* string

The name of the storage system as configured in ScaleIO.

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string
- *Default:* xfs".

Filesystem type to mount.

Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Default is "xfs".

---

##### `protectionDomain`<sup>Optional</sup> <a name="protectionDomain" id="cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.protectionDomain"></a>

```typescript
public readonly protectionDomain: string;
```

- *Type:* string

The name of the ScaleIO Protection Domain for the configured storage.

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.

Defaults to false (read/write).

ReadOnly here will force the ReadOnly setting in VolumeMounts.

---

##### `sslEnabled`<sup>Optional</sup> <a name="sslEnabled" id="cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.sslEnabled"></a>

```typescript
public readonly sslEnabled: boolean;
```

- *Type:* boolean

Flag to enable/disable SSL communication with Gateway, default false.

---

##### `storageMode`<sup>Optional</sup> <a name="storageMode" id="cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.storageMode"></a>

```typescript
public readonly storageMode: string;
```

- *Type:* string
- *Default:* ThinProvisioned.

Indicates whether the storage for a volume should be ThickProvisioned or ThinProvisioned.

Default is ThinProvisioned.

---

##### `storagePool`<sup>Optional</sup> <a name="storagePool" id="cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.storagePool"></a>

```typescript
public readonly storagePool: string;
```

- *Type:* string

The ScaleIO Storage Pool associated with the protection domain.

---

##### `volumeName`<sup>Optional</sup> <a name="volumeName" id="cdk8s-metaflow.k8s.ScaleIoVolumeSource.property.volumeName"></a>

```typescript
public readonly volumeName: string;
```

- *Type:* string

The name of a volume already created in the ScaleIO system that is associated with this volume source.

---

### ScaleProps <a name="ScaleProps" id="cdk8s-metaflow.k8s.ScaleProps"></a>

Scale represents a scaling request for a resource.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ScaleProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const scaleProps: k8s.ScaleProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ScaleProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object metadata; |
| <code><a href="#cdk8s-metaflow.k8s.ScaleProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.ScaleSpec</code> | defines the behavior of the scale. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ScaleProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object metadata;

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.ScaleProps.property.spec"></a>

```typescript
public readonly spec: ScaleSpec;
```

- *Type:* cdk8s-metaflow.k8s.ScaleSpec

defines the behavior of the scale.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status.

---

### ScaleSpec <a name="ScaleSpec" id="cdk8s-metaflow.k8s.ScaleSpec"></a>

ScaleSpec describes the attributes of a scale subresource.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ScaleSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const scaleSpec: k8s.ScaleSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ScaleSpec.property.replicas">replicas</a></code> | <code>number</code> | desired number of instances for the scaled object. |

---

##### `replicas`<sup>Optional</sup> <a name="replicas" id="cdk8s-metaflow.k8s.ScaleSpec.property.replicas"></a>

```typescript
public readonly replicas: number;
```

- *Type:* number

desired number of instances for the scaled object.

---

### Scheduling <a name="Scheduling" id="cdk8s-metaflow.k8s.Scheduling"></a>

Scheduling specifies the scheduling constraints for nodes supporting a RuntimeClass.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.Scheduling.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const scheduling: k8s.Scheduling = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Scheduling.property.nodeSelector">nodeSelector</a></code> | <code>{[ key: string ]: string}</code> | nodeSelector lists labels that must be present on nodes that support this RuntimeClass. |
| <code><a href="#cdk8s-metaflow.k8s.Scheduling.property.tolerations">tolerations</a></code> | <code>cdk8s-metaflow.k8s.Toleration[]</code> | tolerations are appended (excluding duplicates) to pods running with this RuntimeClass during admission, effectively unioning the set of nodes tolerated by the pod and the RuntimeClass. |

---

##### `nodeSelector`<sup>Optional</sup> <a name="nodeSelector" id="cdk8s-metaflow.k8s.Scheduling.property.nodeSelector"></a>

```typescript
public readonly nodeSelector: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

nodeSelector lists labels that must be present on nodes that support this RuntimeClass.

Pods using this RuntimeClass can only be scheduled to a node matched by this selector. The RuntimeClass nodeSelector is merged with a pod's existing nodeSelector. Any conflicts will cause the pod to be rejected in admission.

---

##### `tolerations`<sup>Optional</sup> <a name="tolerations" id="cdk8s-metaflow.k8s.Scheduling.property.tolerations"></a>

```typescript
public readonly tolerations: Toleration[];
```

- *Type:* cdk8s-metaflow.k8s.Toleration[]

tolerations are appended (excluding duplicates) to pods running with this RuntimeClass during admission, effectively unioning the set of nodes tolerated by the pod and the RuntimeClass.

---

### SchedulingV1Alpha1 <a name="SchedulingV1Alpha1" id="cdk8s-metaflow.k8s.SchedulingV1Alpha1"></a>

Scheduling specifies the scheduling constraints for nodes supporting a RuntimeClass.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SchedulingV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const schedulingV1Alpha1: k8s.SchedulingV1Alpha1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SchedulingV1Alpha1.property.nodeSelector">nodeSelector</a></code> | <code>{[ key: string ]: string}</code> | nodeSelector lists labels that must be present on nodes that support this RuntimeClass. |
| <code><a href="#cdk8s-metaflow.k8s.SchedulingV1Alpha1.property.tolerations">tolerations</a></code> | <code>cdk8s-metaflow.k8s.Toleration[]</code> | tolerations are appended (excluding duplicates) to pods running with this RuntimeClass during admission, effectively unioning the set of nodes tolerated by the pod and the RuntimeClass. |

---

##### `nodeSelector`<sup>Optional</sup> <a name="nodeSelector" id="cdk8s-metaflow.k8s.SchedulingV1Alpha1.property.nodeSelector"></a>

```typescript
public readonly nodeSelector: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

nodeSelector lists labels that must be present on nodes that support this RuntimeClass.

Pods using this RuntimeClass can only be scheduled to a node matched by this selector. The RuntimeClass nodeSelector is merged with a pod's existing nodeSelector. Any conflicts will cause the pod to be rejected in admission.

---

##### `tolerations`<sup>Optional</sup> <a name="tolerations" id="cdk8s-metaflow.k8s.SchedulingV1Alpha1.property.tolerations"></a>

```typescript
public readonly tolerations: Toleration[];
```

- *Type:* cdk8s-metaflow.k8s.Toleration[]

tolerations are appended (excluding duplicates) to pods running with this RuntimeClass during admission, effectively unioning the set of nodes tolerated by the pod and the RuntimeClass.

---

### SchedulingV1Beta1 <a name="SchedulingV1Beta1" id="cdk8s-metaflow.k8s.SchedulingV1Beta1"></a>

Scheduling specifies the scheduling constraints for nodes supporting a RuntimeClass.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SchedulingV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const schedulingV1Beta1: k8s.SchedulingV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SchedulingV1Beta1.property.nodeSelector">nodeSelector</a></code> | <code>{[ key: string ]: string}</code> | nodeSelector lists labels that must be present on nodes that support this RuntimeClass. |
| <code><a href="#cdk8s-metaflow.k8s.SchedulingV1Beta1.property.tolerations">tolerations</a></code> | <code>cdk8s-metaflow.k8s.Toleration[]</code> | tolerations are appended (excluding duplicates) to pods running with this RuntimeClass during admission, effectively unioning the set of nodes tolerated by the pod and the RuntimeClass. |

---

##### `nodeSelector`<sup>Optional</sup> <a name="nodeSelector" id="cdk8s-metaflow.k8s.SchedulingV1Beta1.property.nodeSelector"></a>

```typescript
public readonly nodeSelector: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

nodeSelector lists labels that must be present on nodes that support this RuntimeClass.

Pods using this RuntimeClass can only be scheduled to a node matched by this selector. The RuntimeClass nodeSelector is merged with a pod's existing nodeSelector. Any conflicts will cause the pod to be rejected in admission.

---

##### `tolerations`<sup>Optional</sup> <a name="tolerations" id="cdk8s-metaflow.k8s.SchedulingV1Beta1.property.tolerations"></a>

```typescript
public readonly tolerations: Toleration[];
```

- *Type:* cdk8s-metaflow.k8s.Toleration[]

tolerations are appended (excluding duplicates) to pods running with this RuntimeClass during admission, effectively unioning the set of nodes tolerated by the pod and the RuntimeClass.

---

### ScopedResourceSelectorRequirement <a name="ScopedResourceSelectorRequirement" id="cdk8s-metaflow.k8s.ScopedResourceSelectorRequirement"></a>

A scoped-resource selector requirement is a selector that contains values, a scope name, and an operator that relates the scope name and values.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ScopedResourceSelectorRequirement.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const scopedResourceSelectorRequirement: k8s.ScopedResourceSelectorRequirement = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ScopedResourceSelectorRequirement.property.operator">operator</a></code> | <code>string</code> | Represents a scope's relationship to a set of values. |
| <code><a href="#cdk8s-metaflow.k8s.ScopedResourceSelectorRequirement.property.scopeName">scopeName</a></code> | <code>string</code> | The name of the scope that the selector applies to. |
| <code><a href="#cdk8s-metaflow.k8s.ScopedResourceSelectorRequirement.property.values">values</a></code> | <code>string[]</code> | An array of string values. |

---

##### `operator`<sup>Required</sup> <a name="operator" id="cdk8s-metaflow.k8s.ScopedResourceSelectorRequirement.property.operator"></a>

```typescript
public readonly operator: string;
```

- *Type:* string

Represents a scope's relationship to a set of values.

Valid operators are In, NotIn, Exists, DoesNotExist.

---

##### `scopeName`<sup>Required</sup> <a name="scopeName" id="cdk8s-metaflow.k8s.ScopedResourceSelectorRequirement.property.scopeName"></a>

```typescript
public readonly scopeName: string;
```

- *Type:* string

The name of the scope that the selector applies to.

---

##### `values`<sup>Optional</sup> <a name="values" id="cdk8s-metaflow.k8s.ScopedResourceSelectorRequirement.property.values"></a>

```typescript
public readonly values: string[];
```

- *Type:* string[]

An array of string values.

If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.

---

### ScopeSelector <a name="ScopeSelector" id="cdk8s-metaflow.k8s.ScopeSelector"></a>

A scope selector represents the AND of the selectors represented by the scoped-resource selector requirements.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ScopeSelector.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const scopeSelector: k8s.ScopeSelector = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ScopeSelector.property.matchExpressions">matchExpressions</a></code> | <code>cdk8s-metaflow.k8s.ScopedResourceSelectorRequirement[]</code> | A list of scope selector requirements by scope of the resources. |

---

##### `matchExpressions`<sup>Optional</sup> <a name="matchExpressions" id="cdk8s-metaflow.k8s.ScopeSelector.property.matchExpressions"></a>

```typescript
public readonly matchExpressions: ScopedResourceSelectorRequirement[];
```

- *Type:* cdk8s-metaflow.k8s.ScopedResourceSelectorRequirement[]

A list of scope selector requirements by scope of the resources.

---

### SeccompProfile <a name="SeccompProfile" id="cdk8s-metaflow.k8s.SeccompProfile"></a>

SeccompProfile defines a pod/container's seccomp profile settings.

Only one profile source may be set.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SeccompProfile.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const seccompProfile: k8s.SeccompProfile = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SeccompProfile.property.type">type</a></code> | <code>string</code> | type indicates which kind of seccomp profile will be applied. Valid options are:. |
| <code><a href="#cdk8s-metaflow.k8s.SeccompProfile.property.localhostProfile">localhostProfile</a></code> | <code>string</code> | localhostProfile indicates a profile defined in a file on the node should be used. |

---

##### `type`<sup>Required</sup> <a name="type" id="cdk8s-metaflow.k8s.SeccompProfile.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

type indicates which kind of seccomp profile will be applied. Valid options are:.

Localhost - a profile defined in a file on the node should be used. RuntimeDefault - the container runtime default profile should be used. Unconfined - no profile should be applied.

---

##### `localhostProfile`<sup>Optional</sup> <a name="localhostProfile" id="cdk8s-metaflow.k8s.SeccompProfile.property.localhostProfile"></a>

```typescript
public readonly localhostProfile: string;
```

- *Type:* string

localhostProfile indicates a profile defined in a file on the node should be used.

The profile must be preconfigured on the node to work. Must be a descending path, relative to the kubelet's configured seccomp profile location. Must only be set if type is "Localhost".

---

### SecretEnvSource <a name="SecretEnvSource" id="cdk8s-metaflow.k8s.SecretEnvSource"></a>

SecretEnvSource selects a Secret to populate the environment variables with.

The contents of the target Secret's Data field will represent the key-value pairs as environment variables.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SecretEnvSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const secretEnvSource: k8s.SecretEnvSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SecretEnvSource.property.name">name</a></code> | <code>string</code> | Name of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.SecretEnvSource.property.optional">optional</a></code> | <code>boolean</code> | Specify whether the Secret must be defined. |

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.SecretEnvSource.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the referent.

More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names

---

##### `optional`<sup>Optional</sup> <a name="optional" id="cdk8s-metaflow.k8s.SecretEnvSource.property.optional"></a>

```typescript
public readonly optional: boolean;
```

- *Type:* boolean

Specify whether the Secret must be defined.

---

### SecretKeySelector <a name="SecretKeySelector" id="cdk8s-metaflow.k8s.SecretKeySelector"></a>

SecretKeySelector selects a key of a Secret.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SecretKeySelector.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const secretKeySelector: k8s.SecretKeySelector = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SecretKeySelector.property.key">key</a></code> | <code>string</code> | The key of the secret to select from. |
| <code><a href="#cdk8s-metaflow.k8s.SecretKeySelector.property.name">name</a></code> | <code>string</code> | Name of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.SecretKeySelector.property.optional">optional</a></code> | <code>boolean</code> | Specify whether the Secret or its key must be defined. |

---

##### `key`<sup>Required</sup> <a name="key" id="cdk8s-metaflow.k8s.SecretKeySelector.property.key"></a>

```typescript
public readonly key: string;
```

- *Type:* string

The key of the secret to select from.

Must be a valid secret key.

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.SecretKeySelector.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the referent.

More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names

---

##### `optional`<sup>Optional</sup> <a name="optional" id="cdk8s-metaflow.k8s.SecretKeySelector.property.optional"></a>

```typescript
public readonly optional: boolean;
```

- *Type:* boolean

Specify whether the Secret or its key must be defined.

---

### SecretListProps <a name="SecretListProps" id="cdk8s-metaflow.k8s.SecretListProps"></a>

SecretList is a list of Secret.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SecretListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const secretListProps: k8s.SecretListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SecretListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.Secret[]</code> | Items is a list of secret objects. |
| <code><a href="#cdk8s-metaflow.k8s.SecretListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.SecretListProps.property.items"></a>

```typescript
public readonly items: Secret[];
```

- *Type:* cdk8s-metaflow.k8s.Secret[]

Items is a list of secret objects.

More info: https://kubernetes.io/docs/concepts/configuration/secret

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.SecretListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

### SecretProjection <a name="SecretProjection" id="cdk8s-metaflow.k8s.SecretProjection"></a>

Adapts a secret into a projected volume.

The contents of the target Secret's Data field will be presented in a projected volume as files using the keys in the Data field as the file names. Note that this is identical to a secret volume source without the default mode.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SecretProjection.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const secretProjection: k8s.SecretProjection = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SecretProjection.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.KeyToPath[]</code> | If unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. |
| <code><a href="#cdk8s-metaflow.k8s.SecretProjection.property.name">name</a></code> | <code>string</code> | Name of the referent. |
| <code><a href="#cdk8s-metaflow.k8s.SecretProjection.property.optional">optional</a></code> | <code>boolean</code> | Specify whether the Secret or its key must be defined. |

---

##### `items`<sup>Optional</sup> <a name="items" id="cdk8s-metaflow.k8s.SecretProjection.property.items"></a>

```typescript
public readonly items: KeyToPath[];
```

- *Type:* cdk8s-metaflow.k8s.KeyToPath[]

If unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value.

If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.SecretProjection.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the referent.

More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names

---

##### `optional`<sup>Optional</sup> <a name="optional" id="cdk8s-metaflow.k8s.SecretProjection.property.optional"></a>

```typescript
public readonly optional: boolean;
```

- *Type:* boolean

Specify whether the Secret or its key must be defined.

---

### SecretProps <a name="SecretProps" id="cdk8s-metaflow.k8s.SecretProps"></a>

Secret holds secret data of a certain type.

The total bytes of the values in the Data field must be less than MaxSecretSize bytes.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SecretProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const secretProps: k8s.SecretProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SecretProps.property.data">data</a></code> | <code>{[ key: string ]: string}</code> | Data contains the secret data. |
| <code><a href="#cdk8s-metaflow.k8s.SecretProps.property.immutable">immutable</a></code> | <code>boolean</code> | Immutable, if set to true, ensures that data stored in the Secret cannot be updated (only object metadata can be modified). |
| <code><a href="#cdk8s-metaflow.k8s.SecretProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.SecretProps.property.stringData">stringData</a></code> | <code>{[ key: string ]: string}</code> | stringData allows specifying non-binary secret data in string form. |
| <code><a href="#cdk8s-metaflow.k8s.SecretProps.property.type">type</a></code> | <code>string</code> | Used to facilitate programmatic handling of secret data. |

---

##### `data`<sup>Optional</sup> <a name="data" id="cdk8s-metaflow.k8s.SecretProps.property.data"></a>

```typescript
public readonly data: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

Data contains the secret data.

Each key must consist of alphanumeric characters, '-', '_' or '.'. The serialized form of the secret data is a base64 encoded string, representing the arbitrary (possibly non-string) data value here. Described in https://tools.ietf.org/html/rfc4648#section-4

---

##### `immutable`<sup>Optional</sup> <a name="immutable" id="cdk8s-metaflow.k8s.SecretProps.property.immutable"></a>

```typescript
public readonly immutable: boolean;
```

- *Type:* boolean

Immutable, if set to true, ensures that data stored in the Secret cannot be updated (only object metadata can be modified).

If not set to true, the field can be modified at any time. Defaulted to nil.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.SecretProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `stringData`<sup>Optional</sup> <a name="stringData" id="cdk8s-metaflow.k8s.SecretProps.property.stringData"></a>

```typescript
public readonly stringData: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

stringData allows specifying non-binary secret data in string form.

It is provided as a write-only input field for convenience. All keys and values are merged into the data field on write, overwriting any existing values. The stringData field is never output when reading from the API.

---

##### `type`<sup>Optional</sup> <a name="type" id="cdk8s-metaflow.k8s.SecretProps.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

Used to facilitate programmatic handling of secret data.

---

### SecretReference <a name="SecretReference" id="cdk8s-metaflow.k8s.SecretReference"></a>

SecretReference represents a Secret Reference.

It has enough information to retrieve secret in any namespace

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SecretReference.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const secretReference: k8s.SecretReference = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SecretReference.property.name">name</a></code> | <code>string</code> | Name is unique within a namespace to reference a secret resource. |
| <code><a href="#cdk8s-metaflow.k8s.SecretReference.property.namespace">namespace</a></code> | <code>string</code> | Namespace defines the space within which the secret name must be unique. |

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.SecretReference.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name is unique within a namespace to reference a secret resource.

---

##### `namespace`<sup>Optional</sup> <a name="namespace" id="cdk8s-metaflow.k8s.SecretReference.property.namespace"></a>

```typescript
public readonly namespace: string;
```

- *Type:* string

Namespace defines the space within which the secret name must be unique.

---

### SecretVolumeSource <a name="SecretVolumeSource" id="cdk8s-metaflow.k8s.SecretVolumeSource"></a>

Adapts a Secret into a volume.

The contents of the target Secret's Data field will be presented in a volume as files using the keys in the Data field as the file names. Secret volumes support ownership management and SELinux relabeling.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SecretVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const secretVolumeSource: k8s.SecretVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SecretVolumeSource.property.defaultMode">defaultMode</a></code> | <code>number</code> | Optional: mode bits used to set permissions on created files by default. |
| <code><a href="#cdk8s-metaflow.k8s.SecretVolumeSource.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.KeyToPath[]</code> | If unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. |
| <code><a href="#cdk8s-metaflow.k8s.SecretVolumeSource.property.optional">optional</a></code> | <code>boolean</code> | Specify whether the Secret or its keys must be defined. |
| <code><a href="#cdk8s-metaflow.k8s.SecretVolumeSource.property.secretName">secretName</a></code> | <code>string</code> | Name of the secret in the pod's namespace to use. |

---

##### `defaultMode`<sup>Optional</sup> <a name="defaultMode" id="cdk8s-metaflow.k8s.SecretVolumeSource.property.defaultMode"></a>

```typescript
public readonly defaultMode: number;
```

- *Type:* number
- *Default:* 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.

Optional: mode bits used to set permissions on created files by default.

Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.

---

##### `items`<sup>Optional</sup> <a name="items" id="cdk8s-metaflow.k8s.SecretVolumeSource.property.items"></a>

```typescript
public readonly items: KeyToPath[];
```

- *Type:* cdk8s-metaflow.k8s.KeyToPath[]

If unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value.

If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.

---

##### `optional`<sup>Optional</sup> <a name="optional" id="cdk8s-metaflow.k8s.SecretVolumeSource.property.optional"></a>

```typescript
public readonly optional: boolean;
```

- *Type:* boolean

Specify whether the Secret or its keys must be defined.

---

##### `secretName`<sup>Optional</sup> <a name="secretName" id="cdk8s-metaflow.k8s.SecretVolumeSource.property.secretName"></a>

```typescript
public readonly secretName: string;
```

- *Type:* string

Name of the secret in the pod's namespace to use.

More info: https://kubernetes.io/docs/concepts/storage/volumes#secret

---

### SecurityContext <a name="SecurityContext" id="cdk8s-metaflow.k8s.SecurityContext"></a>

SecurityContext holds security configuration that will be applied to a container.

Some fields are present in both SecurityContext and PodSecurityContext.  When both are set, the values in SecurityContext take precedence.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SecurityContext.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const securityContext: k8s.SecurityContext = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SecurityContext.property.allowPrivilegeEscalation">allowPrivilegeEscalation</a></code> | <code>boolean</code> | AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process. |
| <code><a href="#cdk8s-metaflow.k8s.SecurityContext.property.capabilities">capabilities</a></code> | <code>cdk8s-metaflow.k8s.Capabilities</code> | The capabilities to add/drop when running containers. |
| <code><a href="#cdk8s-metaflow.k8s.SecurityContext.property.privileged">privileged</a></code> | <code>boolean</code> | Run container in privileged mode. |
| <code><a href="#cdk8s-metaflow.k8s.SecurityContext.property.procMount">procMount</a></code> | <code>string</code> | procMount denotes the type of proc mount to use for the containers. |
| <code><a href="#cdk8s-metaflow.k8s.SecurityContext.property.readOnlyRootFilesystem">readOnlyRootFilesystem</a></code> | <code>boolean</code> | Whether this container has a read-only root filesystem. |
| <code><a href="#cdk8s-metaflow.k8s.SecurityContext.property.runAsGroup">runAsGroup</a></code> | <code>number</code> | The GID to run the entrypoint of the container process. |
| <code><a href="#cdk8s-metaflow.k8s.SecurityContext.property.runAsNonRoot">runAsNonRoot</a></code> | <code>boolean</code> | Indicates that the container must run as a non-root user. |
| <code><a href="#cdk8s-metaflow.k8s.SecurityContext.property.runAsUser">runAsUser</a></code> | <code>number</code> | The UID to run the entrypoint of the container process. |
| <code><a href="#cdk8s-metaflow.k8s.SecurityContext.property.seccompProfile">seccompProfile</a></code> | <code>cdk8s-metaflow.k8s.SeccompProfile</code> | The seccomp options to use by this container. |
| <code><a href="#cdk8s-metaflow.k8s.SecurityContext.property.seLinuxOptions">seLinuxOptions</a></code> | <code>cdk8s-metaflow.k8s.SeLinuxOptions</code> | The SELinux context to be applied to the container. |
| <code><a href="#cdk8s-metaflow.k8s.SecurityContext.property.windowsOptions">windowsOptions</a></code> | <code>cdk8s-metaflow.k8s.WindowsSecurityContextOptions</code> | The Windows specific settings applied to all containers. |

---

##### `allowPrivilegeEscalation`<sup>Optional</sup> <a name="allowPrivilegeEscalation" id="cdk8s-metaflow.k8s.SecurityContext.property.allowPrivilegeEscalation"></a>

```typescript
public readonly allowPrivilegeEscalation: boolean;
```

- *Type:* boolean

AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process.

This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN

---

##### `capabilities`<sup>Optional</sup> <a name="capabilities" id="cdk8s-metaflow.k8s.SecurityContext.property.capabilities"></a>

```typescript
public readonly capabilities: Capabilities;
```

- *Type:* cdk8s-metaflow.k8s.Capabilities
- *Default:* the default set of capabilities granted by the container runtime.

The capabilities to add/drop when running containers.

Defaults to the default set of capabilities granted by the container runtime.

---

##### `privileged`<sup>Optional</sup> <a name="privileged" id="cdk8s-metaflow.k8s.SecurityContext.property.privileged"></a>

```typescript
public readonly privileged: boolean;
```

- *Type:* boolean
- *Default:* false.

Run container in privileged mode.

Processes in privileged containers are essentially equivalent to root on the host. Defaults to false.

---

##### `procMount`<sup>Optional</sup> <a name="procMount" id="cdk8s-metaflow.k8s.SecurityContext.property.procMount"></a>

```typescript
public readonly procMount: string;
```

- *Type:* string

procMount denotes the type of proc mount to use for the containers.

The default is DefaultProcMount which uses the container runtime defaults for readonly paths and masked paths. This requires the ProcMountType feature flag to be enabled.

---

##### `readOnlyRootFilesystem`<sup>Optional</sup> <a name="readOnlyRootFilesystem" id="cdk8s-metaflow.k8s.SecurityContext.property.readOnlyRootFilesystem"></a>

```typescript
public readonly readOnlyRootFilesystem: boolean;
```

- *Type:* boolean
- *Default:* false.

Whether this container has a read-only root filesystem.

Default is false.

---

##### `runAsGroup`<sup>Optional</sup> <a name="runAsGroup" id="cdk8s-metaflow.k8s.SecurityContext.property.runAsGroup"></a>

```typescript
public readonly runAsGroup: number;
```

- *Type:* number

The GID to run the entrypoint of the container process.

Uses runtime default if unset. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.

---

##### `runAsNonRoot`<sup>Optional</sup> <a name="runAsNonRoot" id="cdk8s-metaflow.k8s.SecurityContext.property.runAsNonRoot"></a>

```typescript
public readonly runAsNonRoot: boolean;
```

- *Type:* boolean

Indicates that the container must run as a non-root user.

If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.

---

##### `runAsUser`<sup>Optional</sup> <a name="runAsUser" id="cdk8s-metaflow.k8s.SecurityContext.property.runAsUser"></a>

```typescript
public readonly runAsUser: number;
```

- *Type:* number
- *Default:* user specified in image metadata if unspecified. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.

The UID to run the entrypoint of the container process.

Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.

---

##### `seccompProfile`<sup>Optional</sup> <a name="seccompProfile" id="cdk8s-metaflow.k8s.SecurityContext.property.seccompProfile"></a>

```typescript
public readonly seccompProfile: SeccompProfile;
```

- *Type:* cdk8s-metaflow.k8s.SeccompProfile

The seccomp options to use by this container.

If seccomp options are provided at both the pod & container level, the container options override the pod options.

---

##### `seLinuxOptions`<sup>Optional</sup> <a name="seLinuxOptions" id="cdk8s-metaflow.k8s.SecurityContext.property.seLinuxOptions"></a>

```typescript
public readonly seLinuxOptions: SeLinuxOptions;
```

- *Type:* cdk8s-metaflow.k8s.SeLinuxOptions

The SELinux context to be applied to the container.

If unspecified, the container runtime will allocate a random SELinux context for each container.  May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.

---

##### `windowsOptions`<sup>Optional</sup> <a name="windowsOptions" id="cdk8s-metaflow.k8s.SecurityContext.property.windowsOptions"></a>

```typescript
public readonly windowsOptions: WindowsSecurityContextOptions;
```

- *Type:* cdk8s-metaflow.k8s.WindowsSecurityContextOptions

The Windows specific settings applied to all containers.

If unspecified, the options from the PodSecurityContext will be used. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.

---

### SelfSubjectAccessReviewProps <a name="SelfSubjectAccessReviewProps" id="cdk8s-metaflow.k8s.SelfSubjectAccessReviewProps"></a>

SelfSubjectAccessReview checks whether or the current user can perform an action.

Not filling in a spec.namespace means "in all namespaces".  Self is a special case, because users should always be able to check whether they can perform an action

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SelfSubjectAccessReviewProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const selfSubjectAccessReviewProps: k8s.SelfSubjectAccessReviewProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReviewProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.SelfSubjectAccessReviewSpec</code> | Spec holds information about the request being evaluated. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReviewProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard list metadata. |

---

##### `spec`<sup>Required</sup> <a name="spec" id="cdk8s-metaflow.k8s.SelfSubjectAccessReviewProps.property.spec"></a>

```typescript
public readonly spec: SelfSubjectAccessReviewSpec;
```

- *Type:* cdk8s-metaflow.k8s.SelfSubjectAccessReviewSpec

Spec holds information about the request being evaluated.

user and groups must be empty

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.SelfSubjectAccessReviewProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### SelfSubjectAccessReviewSpec <a name="SelfSubjectAccessReviewSpec" id="cdk8s-metaflow.k8s.SelfSubjectAccessReviewSpec"></a>

SelfSubjectAccessReviewSpec is a description of the access request.

Exactly one of ResourceAuthorizationAttributes and NonResourceAuthorizationAttributes must be set

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SelfSubjectAccessReviewSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const selfSubjectAccessReviewSpec: k8s.SelfSubjectAccessReviewSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReviewSpec.property.nonResourceAttributes">nonResourceAttributes</a></code> | <code>cdk8s-metaflow.k8s.NonResourceAttributes</code> | NonResourceAttributes describes information for a non-resource access request. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectAccessReviewSpec.property.resourceAttributes">resourceAttributes</a></code> | <code>cdk8s-metaflow.k8s.ResourceAttributes</code> | ResourceAuthorizationAttributes describes information for a resource access request. |

---

##### `nonResourceAttributes`<sup>Optional</sup> <a name="nonResourceAttributes" id="cdk8s-metaflow.k8s.SelfSubjectAccessReviewSpec.property.nonResourceAttributes"></a>

```typescript
public readonly nonResourceAttributes: NonResourceAttributes;
```

- *Type:* cdk8s-metaflow.k8s.NonResourceAttributes

NonResourceAttributes describes information for a non-resource access request.

---

##### `resourceAttributes`<sup>Optional</sup> <a name="resourceAttributes" id="cdk8s-metaflow.k8s.SelfSubjectAccessReviewSpec.property.resourceAttributes"></a>

```typescript
public readonly resourceAttributes: ResourceAttributes;
```

- *Type:* cdk8s-metaflow.k8s.ResourceAttributes

ResourceAuthorizationAttributes describes information for a resource access request.

---

### SelfSubjectRulesReviewProps <a name="SelfSubjectRulesReviewProps" id="cdk8s-metaflow.k8s.SelfSubjectRulesReviewProps"></a>

SelfSubjectRulesReview enumerates the set of actions the current user can perform within a namespace.

The returned list of actions may be incomplete depending on the server's authorization mode, and any errors experienced during the evaluation. SelfSubjectRulesReview should be used by UIs to show/hide actions, or to quickly let an end user reason about their permissions. It should NOT Be used by external systems to drive authorization decisions as this raises confused deputy, cache lifetime/revocation, and correctness concerns. SubjectAccessReview, and LocalAccessReview are the correct way to defer authorization decisions to the API server.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SelfSubjectRulesReviewProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const selfSubjectRulesReviewProps: k8s.SelfSubjectRulesReviewProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReviewProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.SelfSubjectRulesReviewSpec</code> | Spec holds information about the request being evaluated. |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReviewProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard list metadata. |

---

##### `spec`<sup>Required</sup> <a name="spec" id="cdk8s-metaflow.k8s.SelfSubjectRulesReviewProps.property.spec"></a>

```typescript
public readonly spec: SelfSubjectRulesReviewSpec;
```

- *Type:* cdk8s-metaflow.k8s.SelfSubjectRulesReviewSpec

Spec holds information about the request being evaluated.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.SelfSubjectRulesReviewProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### SelfSubjectRulesReviewSpec <a name="SelfSubjectRulesReviewSpec" id="cdk8s-metaflow.k8s.SelfSubjectRulesReviewSpec"></a>

SelfSubjectRulesReviewSpec defines the specification for SelfSubjectRulesReview.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SelfSubjectRulesReviewSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const selfSubjectRulesReviewSpec: k8s.SelfSubjectRulesReviewSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SelfSubjectRulesReviewSpec.property.namespace">namespace</a></code> | <code>string</code> | Namespace to evaluate rules for. |

---

##### `namespace`<sup>Optional</sup> <a name="namespace" id="cdk8s-metaflow.k8s.SelfSubjectRulesReviewSpec.property.namespace"></a>

```typescript
public readonly namespace: string;
```

- *Type:* string

Namespace to evaluate rules for.

Required.

---

### SeLinuxOptions <a name="SeLinuxOptions" id="cdk8s-metaflow.k8s.SeLinuxOptions"></a>

SELinuxOptions are the labels to be applied to the container.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SeLinuxOptions.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const seLinuxOptions: k8s.SeLinuxOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SeLinuxOptions.property.level">level</a></code> | <code>string</code> | Level is SELinux level label that applies to the container. |
| <code><a href="#cdk8s-metaflow.k8s.SeLinuxOptions.property.role">role</a></code> | <code>string</code> | Role is a SELinux role label that applies to the container. |
| <code><a href="#cdk8s-metaflow.k8s.SeLinuxOptions.property.type">type</a></code> | <code>string</code> | Type is a SELinux type label that applies to the container. |
| <code><a href="#cdk8s-metaflow.k8s.SeLinuxOptions.property.user">user</a></code> | <code>string</code> | User is a SELinux user label that applies to the container. |

---

##### `level`<sup>Optional</sup> <a name="level" id="cdk8s-metaflow.k8s.SeLinuxOptions.property.level"></a>

```typescript
public readonly level: string;
```

- *Type:* string

Level is SELinux level label that applies to the container.

---

##### `role`<sup>Optional</sup> <a name="role" id="cdk8s-metaflow.k8s.SeLinuxOptions.property.role"></a>

```typescript
public readonly role: string;
```

- *Type:* string

Role is a SELinux role label that applies to the container.

---

##### `type`<sup>Optional</sup> <a name="type" id="cdk8s-metaflow.k8s.SeLinuxOptions.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

Type is a SELinux type label that applies to the container.

---

##### `user`<sup>Optional</sup> <a name="user" id="cdk8s-metaflow.k8s.SeLinuxOptions.property.user"></a>

```typescript
public readonly user: string;
```

- *Type:* string

User is a SELinux user label that applies to the container.

---

### SeLinuxStrategyOptionsV1Beta1 <a name="SeLinuxStrategyOptionsV1Beta1" id="cdk8s-metaflow.k8s.SeLinuxStrategyOptionsV1Beta1"></a>

SELinuxStrategyOptions defines the strategy type and any options used to create the strategy.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SeLinuxStrategyOptionsV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const seLinuxStrategyOptionsV1Beta1: k8s.SeLinuxStrategyOptionsV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SeLinuxStrategyOptionsV1Beta1.property.rule">rule</a></code> | <code>string</code> | rule is the strategy that will dictate the allowable labels that may be set. |
| <code><a href="#cdk8s-metaflow.k8s.SeLinuxStrategyOptionsV1Beta1.property.seLinuxOptions">seLinuxOptions</a></code> | <code>cdk8s-metaflow.k8s.SeLinuxOptions</code> | seLinuxOptions required to run as; |

---

##### `rule`<sup>Required</sup> <a name="rule" id="cdk8s-metaflow.k8s.SeLinuxStrategyOptionsV1Beta1.property.rule"></a>

```typescript
public readonly rule: string;
```

- *Type:* string

rule is the strategy that will dictate the allowable labels that may be set.

---

##### `seLinuxOptions`<sup>Optional</sup> <a name="seLinuxOptions" id="cdk8s-metaflow.k8s.SeLinuxStrategyOptionsV1Beta1.property.seLinuxOptions"></a>

```typescript
public readonly seLinuxOptions: SeLinuxOptions;
```

- *Type:* cdk8s-metaflow.k8s.SeLinuxOptions

seLinuxOptions required to run as;

required for MustRunAs More info: https://kubernetes.io/docs/tasks/configure-pod-container/security-context/

---

### ServiceAccountListProps <a name="ServiceAccountListProps" id="cdk8s-metaflow.k8s.ServiceAccountListProps"></a>

ServiceAccountList is a list of ServiceAccount objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ServiceAccountListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const serviceAccountListProps: k8s.ServiceAccountListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.ServiceAccount[]</code> | List of ServiceAccounts. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.ServiceAccountListProps.property.items"></a>

```typescript
public readonly items: ServiceAccount[];
```

- *Type:* cdk8s-metaflow.k8s.ServiceAccount[]

List of ServiceAccounts.

More info: https://kubernetes.io/docs/tasks/configure-pod-container/configure-service-account/

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ServiceAccountListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

### ServiceAccountOptions <a name="ServiceAccountOptions" id="cdk8s-metaflow.ServiceAccountOptions"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.ServiceAccountOptions.Initializer"></a>

```typescript
import { ServiceAccountOptions } from 'cdk8s-metaflow'

const serviceAccountOptions: ServiceAccountOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.ServiceAccountOptions.property.annotations">annotations</a></code> | <code>{[ key: string ]: string}</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.ServiceAccountOptions.property.create">create</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.ServiceAccountOptions.property.name">name</a></code> | <code>string</code> | *No description.* |

---

##### `annotations`<sup>Optional</sup> <a name="annotations" id="cdk8s-metaflow.ServiceAccountOptions.property.annotations"></a>

```typescript
public readonly annotations: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

---

##### `create`<sup>Optional</sup> <a name="create" id="cdk8s-metaflow.ServiceAccountOptions.property.create"></a>

```typescript
public readonly create: boolean;
```

- *Type:* boolean

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.ServiceAccountOptions.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

---

### ServiceAccountProps <a name="ServiceAccountProps" id="cdk8s-metaflow.k8s.ServiceAccountProps"></a>

ServiceAccount binds together: * a name, understood by users, and perhaps by peripheral systems, for an identity * a principal that can be authenticated and authorized * a set of secrets.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ServiceAccountProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const serviceAccountProps: k8s.ServiceAccountProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountProps.property.automountServiceAccountToken">automountServiceAccountToken</a></code> | <code>boolean</code> | AutomountServiceAccountToken indicates whether pods running as this service account should have an API token automatically mounted. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountProps.property.imagePullSecrets">imagePullSecrets</a></code> | <code>cdk8s-metaflow.k8s.LocalObjectReference[]</code> | ImagePullSecrets is a list of references to secrets in the same namespace to use for pulling any images in pods that reference this ServiceAccount. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountProps.property.secrets">secrets</a></code> | <code>cdk8s-metaflow.k8s.ObjectReference[]</code> | Secrets is the list of secrets allowed to be used by pods running using this ServiceAccount. |

---

##### `automountServiceAccountToken`<sup>Optional</sup> <a name="automountServiceAccountToken" id="cdk8s-metaflow.k8s.ServiceAccountProps.property.automountServiceAccountToken"></a>

```typescript
public readonly automountServiceAccountToken: boolean;
```

- *Type:* boolean

AutomountServiceAccountToken indicates whether pods running as this service account should have an API token automatically mounted.

Can be overridden at the pod level.

---

##### `imagePullSecrets`<sup>Optional</sup> <a name="imagePullSecrets" id="cdk8s-metaflow.k8s.ServiceAccountProps.property.imagePullSecrets"></a>

```typescript
public readonly imagePullSecrets: LocalObjectReference[];
```

- *Type:* cdk8s-metaflow.k8s.LocalObjectReference[]

ImagePullSecrets is a list of references to secrets in the same namespace to use for pulling any images in pods that reference this ServiceAccount.

ImagePullSecrets are distinct from Secrets because Secrets can be mounted in the pod, but ImagePullSecrets are only accessed by the kubelet. More info: https://kubernetes.io/docs/concepts/containers/images/#specifying-imagepullsecrets-on-a-pod

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ServiceAccountProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `secrets`<sup>Optional</sup> <a name="secrets" id="cdk8s-metaflow.k8s.ServiceAccountProps.property.secrets"></a>

```typescript
public readonly secrets: ObjectReference[];
```

- *Type:* cdk8s-metaflow.k8s.ObjectReference[]

Secrets is the list of secrets allowed to be used by pods running using this ServiceAccount.

More info: https://kubernetes.io/docs/concepts/configuration/secret

---

### ServiceAccountSubjectV1Beta1 <a name="ServiceAccountSubjectV1Beta1" id="cdk8s-metaflow.k8s.ServiceAccountSubjectV1Beta1"></a>

ServiceAccountSubject holds detailed information for service-account-kind subject.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ServiceAccountSubjectV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const serviceAccountSubjectV1Beta1: k8s.ServiceAccountSubjectV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountSubjectV1Beta1.property.name">name</a></code> | <code>string</code> | `name` is the name of matching ServiceAccount objects, or "*" to match regardless of name. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountSubjectV1Beta1.property.namespace">namespace</a></code> | <code>string</code> | `namespace` is the namespace of matching ServiceAccount objects. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ServiceAccountSubjectV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

`name` is the name of matching ServiceAccount objects, or "*" to match regardless of name.

Required.

---

##### `namespace`<sup>Required</sup> <a name="namespace" id="cdk8s-metaflow.k8s.ServiceAccountSubjectV1Beta1.property.namespace"></a>

```typescript
public readonly namespace: string;
```

- *Type:* string

`namespace` is the namespace of matching ServiceAccount objects.

Required.

---

### ServiceAccountTokenProjection <a name="ServiceAccountTokenProjection" id="cdk8s-metaflow.k8s.ServiceAccountTokenProjection"></a>

ServiceAccountTokenProjection represents a projected service account token volume.

This projection can be used to insert a service account token into the pods runtime filesystem for use against APIs (Kubernetes API Server or otherwise).

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ServiceAccountTokenProjection.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const serviceAccountTokenProjection: k8s.ServiceAccountTokenProjection = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountTokenProjection.property.path">path</a></code> | <code>string</code> | Path is the path relative to the mount point of the file to project the token into. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountTokenProjection.property.audience">audience</a></code> | <code>string</code> | Audience is the intended audience of the token. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceAccountTokenProjection.property.expirationSeconds">expirationSeconds</a></code> | <code>number</code> | ExpirationSeconds is the requested duration of validity of the service account token. |

---

##### `path`<sup>Required</sup> <a name="path" id="cdk8s-metaflow.k8s.ServiceAccountTokenProjection.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* string

Path is the path relative to the mount point of the file to project the token into.

---

##### `audience`<sup>Optional</sup> <a name="audience" id="cdk8s-metaflow.k8s.ServiceAccountTokenProjection.property.audience"></a>

```typescript
public readonly audience: string;
```

- *Type:* string

Audience is the intended audience of the token.

A recipient of a token must identify itself with an identifier specified in the audience of the token, and otherwise should reject the token. The audience defaults to the identifier of the apiserver.

---

##### `expirationSeconds`<sup>Optional</sup> <a name="expirationSeconds" id="cdk8s-metaflow.k8s.ServiceAccountTokenProjection.property.expirationSeconds"></a>

```typescript
public readonly expirationSeconds: number;
```

- *Type:* number
- *Default:* 1 hour and must be at least 10 minutes.

ExpirationSeconds is the requested duration of validity of the service account token.

As the token approaches expiration, the kubelet volume plugin will proactively rotate the service account token. The kubelet will start trying to rotate the token if the token is older than 80 percent of its time to live or if the token is older than 24 hours.Defaults to 1 hour and must be at least 10 minutes.

---

### ServiceBackendPort <a name="ServiceBackendPort" id="cdk8s-metaflow.k8s.ServiceBackendPort"></a>

ServiceBackendPort is the service port being referenced.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ServiceBackendPort.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const serviceBackendPort: k8s.ServiceBackendPort = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceBackendPort.property.name">name</a></code> | <code>string</code> | Name is the name of the port on the Service. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceBackendPort.property.number">number</a></code> | <code>number</code> | Number is the numerical port number (e.g. 80) on the Service. This is a mutually exclusive setting with "Name". |

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.ServiceBackendPort.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name is the name of the port on the Service.

This is a mutually exclusive setting with "Number".

---

##### `number`<sup>Optional</sup> <a name="number" id="cdk8s-metaflow.k8s.ServiceBackendPort.property.number"></a>

```typescript
public readonly number: number;
```

- *Type:* number

Number is the numerical port number (e.g. 80) on the Service. This is a mutually exclusive setting with "Name".

---

### ServiceListProps <a name="ServiceListProps" id="cdk8s-metaflow.k8s.ServiceListProps"></a>

ServiceList holds a list of services.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ServiceListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const serviceListProps: k8s.ServiceListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.Service[]</code> | List of services. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.ServiceListProps.property.items"></a>

```typescript
public readonly items: Service[];
```

- *Type:* cdk8s-metaflow.k8s.Service[]

List of services.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ServiceListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

### ServiceOptions <a name="ServiceOptions" id="cdk8s-metaflow.ServiceOptions"></a>

#### Initializer <a name="Initializer" id="cdk8s-metaflow.ServiceOptions.Initializer"></a>

```typescript
import { ServiceOptions } from 'cdk8s-metaflow'

const serviceOptions: ServiceOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.ServiceOptions.property.annotations">annotations</a></code> | <code>{[ key: string ]: string}</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.ServiceOptions.property.port">port</a></code> | <code>number</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.ServiceOptions.property.type">type</a></code> | <code><a href="#cdk8s-metaflow.ServiceType">ServiceType</a></code> | *No description.* |

---

##### `annotations`<sup>Optional</sup> <a name="annotations" id="cdk8s-metaflow.ServiceOptions.property.annotations"></a>

```typescript
public readonly annotations: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

---

##### `port`<sup>Optional</sup> <a name="port" id="cdk8s-metaflow.ServiceOptions.property.port"></a>

```typescript
public readonly port: number;
```

- *Type:* number

---

##### `type`<sup>Optional</sup> <a name="type" id="cdk8s-metaflow.ServiceOptions.property.type"></a>

```typescript
public readonly type: ServiceType;
```

- *Type:* <a href="#cdk8s-metaflow.ServiceType">ServiceType</a>

---

### ServicePort <a name="ServicePort" id="cdk8s-metaflow.k8s.ServicePort"></a>

ServicePort contains information on service's port.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ServicePort.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const servicePort: k8s.ServicePort = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServicePort.property.port">port</a></code> | <code>number</code> | The port that will be exposed by this service. |
| <code><a href="#cdk8s-metaflow.k8s.ServicePort.property.appProtocol">appProtocol</a></code> | <code>string</code> | The application protocol for this port. |
| <code><a href="#cdk8s-metaflow.k8s.ServicePort.property.name">name</a></code> | <code>string</code> | The name of this port within the service. |
| <code><a href="#cdk8s-metaflow.k8s.ServicePort.property.nodePort">nodePort</a></code> | <code>number</code> | The port on each node on which this service is exposed when type is NodePort or LoadBalancer. |
| <code><a href="#cdk8s-metaflow.k8s.ServicePort.property.protocol">protocol</a></code> | <code>string</code> | The IP protocol for this port. |
| <code><a href="#cdk8s-metaflow.k8s.ServicePort.property.targetPort">targetPort</a></code> | <code>cdk8s-metaflow.k8s.IntOrString</code> | Number or name of the port to access on the pods targeted by the service. |

---

##### `port`<sup>Required</sup> <a name="port" id="cdk8s-metaflow.k8s.ServicePort.property.port"></a>

```typescript
public readonly port: number;
```

- *Type:* number

The port that will be exposed by this service.

---

##### `appProtocol`<sup>Optional</sup> <a name="appProtocol" id="cdk8s-metaflow.k8s.ServicePort.property.appProtocol"></a>

```typescript
public readonly appProtocol: string;
```

- *Type:* string

The application protocol for this port.

This field follows standard Kubernetes label syntax. Un-prefixed names are reserved for IANA standard service names (as per RFC-6335 and http://www.iana.org/assignments/service-names). Non-standard protocols should use prefixed names such as mycompany.com/my-custom-protocol.

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.ServicePort.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of this port within the service.

This must be a DNS_LABEL. All ports within a ServiceSpec must have unique names. When considering the endpoints for a Service, this must match the 'name' field in the EndpointPort. Optional if only one ServicePort is defined on this service.

---

##### `nodePort`<sup>Optional</sup> <a name="nodePort" id="cdk8s-metaflow.k8s.ServicePort.property.nodePort"></a>

```typescript
public readonly nodePort: number;
```

- *Type:* number

The port on each node on which this service is exposed when type is NodePort or LoadBalancer.

Usually assigned by the system. If a value is specified, in-range, and not in use it will be used, otherwise the operation will fail.  If not specified, a port will be allocated if this Service requires one.  If this field is specified when creating a Service which does not need it, creation will fail. This field will be wiped when updating a Service to no longer need it (e.g. changing type from NodePort to ClusterIP). More info: https://kubernetes.io/docs/concepts/services-networking/service/#type-nodeport

---

##### `protocol`<sup>Optional</sup> <a name="protocol" id="cdk8s-metaflow.k8s.ServicePort.property.protocol"></a>

```typescript
public readonly protocol: string;
```

- *Type:* string
- *Default:* TCP.

The IP protocol for this port.

Supports "TCP", "UDP", and "SCTP". Default is TCP.

---

##### `targetPort`<sup>Optional</sup> <a name="targetPort" id="cdk8s-metaflow.k8s.ServicePort.property.targetPort"></a>

```typescript
public readonly targetPort: IntOrString;
```

- *Type:* cdk8s-metaflow.k8s.IntOrString

Number or name of the port to access on the pods targeted by the service.

Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME. If this is a string, it will be looked up as a named port in the target Pod's container ports. If this is not specified, the value of the 'port' field is used (an identity map). This field is ignored for services with clusterIP=None, and should be omitted or set equal to the 'port' field. More info: https://kubernetes.io/docs/concepts/services-networking/service/#defining-a-service

---

### ServiceProps <a name="ServiceProps" id="cdk8s-metaflow.k8s.ServiceProps"></a>

Service is a named abstraction of software service (for example, mysql) consisting of local port (for example 3306) that the proxy listens on, and the selector that determines which pods will answer requests sent through the proxy.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ServiceProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const serviceProps: k8s.ServiceProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.ServiceSpec</code> | Spec defines the behavior of a service. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ServiceProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.ServiceProps.property.spec"></a>

```typescript
public readonly spec: ServiceSpec;
```

- *Type:* cdk8s-metaflow.k8s.ServiceSpec

Spec defines the behavior of a service.

https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status

---

### ServiceReference <a name="ServiceReference" id="cdk8s-metaflow.k8s.ServiceReference"></a>

ServiceReference holds a reference to Service.legacy.k8s.io.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ServiceReference.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const serviceReference: k8s.ServiceReference = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceReference.property.name">name</a></code> | <code>string</code> | `name` is the name of the service. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceReference.property.namespace">namespace</a></code> | <code>string</code> | `namespace` is the namespace of the service. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceReference.property.path">path</a></code> | <code>string</code> | `path` is an optional URL path which will be sent in any request to this service. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceReference.property.port">port</a></code> | <code>number</code> | If specified, the port on the service that hosting webhook. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ServiceReference.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

`name` is the name of the service.

Required

---

##### `namespace`<sup>Required</sup> <a name="namespace" id="cdk8s-metaflow.k8s.ServiceReference.property.namespace"></a>

```typescript
public readonly namespace: string;
```

- *Type:* string

`namespace` is the namespace of the service.

Required

---

##### `path`<sup>Optional</sup> <a name="path" id="cdk8s-metaflow.k8s.ServiceReference.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* string

`path` is an optional URL path which will be sent in any request to this service.

---

##### `port`<sup>Optional</sup> <a name="port" id="cdk8s-metaflow.k8s.ServiceReference.property.port"></a>

```typescript
public readonly port: number;
```

- *Type:* number
- *Default:* 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive).

If specified, the port on the service that hosting webhook.

Default to 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive).

---

### ServiceSpec <a name="ServiceSpec" id="cdk8s-metaflow.k8s.ServiceSpec"></a>

ServiceSpec describes the attributes that a user creates on a service.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ServiceSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const serviceSpec: k8s.ServiceSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.allocateLoadBalancerNodePorts">allocateLoadBalancerNodePorts</a></code> | <code>boolean</code> | allocateLoadBalancerNodePorts defines if NodePorts will be automatically allocated for services with type LoadBalancer. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.clusterIp">clusterIp</a></code> | <code>string</code> | clusterIP is the IP address of the service and is usually assigned randomly. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.clusterIPs">clusterIPs</a></code> | <code>string[]</code> | ClusterIPs is a list of IP addresses assigned to this service, and are usually assigned randomly. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.externalIPs">externalIPs</a></code> | <code>string[]</code> | externalIPs is a list of IP addresses for which nodes in the cluster will also accept traffic for this service. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.externalName">externalName</a></code> | <code>string</code> | externalName is the external reference that discovery mechanisms will return as an alias for this service (e.g. a DNS CNAME record). No proxying will be involved.  Must be a lowercase RFC-1123 hostname (https://tools.ietf.org/html/rfc1123) and requires `type` to be "ExternalName". |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.externalTrafficPolicy">externalTrafficPolicy</a></code> | <code>string</code> | externalTrafficPolicy denotes if this Service desires to route external traffic to node-local or cluster-wide endpoints. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.healthCheckNodePort">healthCheckNodePort</a></code> | <code>number</code> | healthCheckNodePort specifies the healthcheck nodePort for the service. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.internalTrafficPolicy">internalTrafficPolicy</a></code> | <code>string</code> | InternalTrafficPolicy specifies if the cluster internal traffic should be routed to all endpoints or node-local endpoints only. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.ipFamilies">ipFamilies</a></code> | <code>string[]</code> | IPFamilies is a list of IP families (e.g. IPv4, IPv6) assigned to this service, and is gated by the "IPv6DualStack" feature gate.  This field is usually assigned automatically based on cluster configuration and the ipFamilyPolicy field. If this field is specified manually, the requested family is available in the cluster, and ipFamilyPolicy allows it, it will be used; otherwise creation of the service will fail.  This field is conditionally mutable: it allows for adding or removing a secondary IP family, but it does not allow changing the primary IP family of the Service.  Valid values are "IPv4" and "IPv6".  This field only applies to Services of types ClusterIP, NodePort, and LoadBalancer, and does apply to "headless" services.  This field will be wiped when updating a Service to type ExternalName. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.ipFamilyPolicy">ipFamilyPolicy</a></code> | <code>string</code> | IPFamilyPolicy represents the dual-stack-ness requested or required by this Service, and is gated by the "IPv6DualStack" feature gate. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.loadBalancerClass">loadBalancerClass</a></code> | <code>string</code> | loadBalancerClass is the class of the load balancer implementation this Service belongs to. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.loadBalancerIp">loadBalancerIp</a></code> | <code>string</code> | Only applies to Service Type: LoadBalancer LoadBalancer will get created with the IP specified in this field. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.loadBalancerSourceRanges">loadBalancerSourceRanges</a></code> | <code>string[]</code> | If specified and supported by the platform, this will restrict traffic through the cloud-provider load-balancer will be restricted to the specified client IPs. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.ports">ports</a></code> | <code>cdk8s-metaflow.k8s.ServicePort[]</code> | The list of ports that are exposed by this service. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.publishNotReadyAddresses">publishNotReadyAddresses</a></code> | <code>boolean</code> | publishNotReadyAddresses indicates that any agent which deals with endpoints for this Service should disregard any indications of ready/not-ready. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.selector">selector</a></code> | <code>{[ key: string ]: string}</code> | Route service traffic to pods with label keys and values matching this selector. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.sessionAffinity">sessionAffinity</a></code> | <code>string</code> | Supports "ClientIP" and "None". |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.sessionAffinityConfig">sessionAffinityConfig</a></code> | <code>cdk8s-metaflow.k8s.SessionAffinityConfig</code> | sessionAffinityConfig contains the configurations of session affinity. |
| <code><a href="#cdk8s-metaflow.k8s.ServiceSpec.property.type">type</a></code> | <code>string</code> | type determines how the Service is exposed. |

---

##### `allocateLoadBalancerNodePorts`<sup>Optional</sup> <a name="allocateLoadBalancerNodePorts" id="cdk8s-metaflow.k8s.ServiceSpec.property.allocateLoadBalancerNodePorts"></a>

```typescript
public readonly allocateLoadBalancerNodePorts: boolean;
```

- *Type:* boolean
- *Default:* true". It may be set to "false" if the cluster load-balancer does not rely on NodePorts.  If the caller requests specific NodePorts (by specifying a value), those requests will be respected, regardless of this field. This field may only be set for services with type LoadBalancer and will be cleared if the type is changed to any other type. This field is beta-level and is only honored by servers that enable the ServiceLBNodePortControl feature.

allocateLoadBalancerNodePorts defines if NodePorts will be automatically allocated for services with type LoadBalancer.

Default is "true". It may be set to "false" if the cluster load-balancer does not rely on NodePorts.  If the caller requests specific NodePorts (by specifying a value), those requests will be respected, regardless of this field. This field may only be set for services with type LoadBalancer and will be cleared if the type is changed to any other type. This field is beta-level and is only honored by servers that enable the ServiceLBNodePortControl feature.

---

##### `clusterIp`<sup>Optional</sup> <a name="clusterIp" id="cdk8s-metaflow.k8s.ServiceSpec.property.clusterIp"></a>

```typescript
public readonly clusterIp: string;
```

- *Type:* string

clusterIP is the IP address of the service and is usually assigned randomly.

If an address is specified manually, is in-range (as per system configuration), and is not in use, it will be allocated to the service; otherwise creation of the service will fail. This field may not be changed through updates unless the type field is also being changed to ExternalName (which requires this field to be blank) or the type field is being changed from ExternalName (in which case this field may optionally be specified, as describe above).  Valid values are "None", empty string (""), or a valid IP address. Setting this to "None" makes a "headless service" (no virtual IP), which is useful when direct endpoint connections are preferred and proxying is not required.  Only applies to types ClusterIP, NodePort, and LoadBalancer. If this field is specified when creating a Service of type ExternalName, creation will fail. This field will be wiped when updating a Service to type ExternalName. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies

---

##### `clusterIPs`<sup>Optional</sup> <a name="clusterIPs" id="cdk8s-metaflow.k8s.ServiceSpec.property.clusterIPs"></a>

```typescript
public readonly clusterIPs: string[];
```

- *Type:* string[]

ClusterIPs is a list of IP addresses assigned to this service, and are usually assigned randomly.

If an address is specified manually, is in-range (as per system configuration), and is not in use, it will be allocated to the service; otherwise creation of the service will fail. This field may not be changed through updates unless the type field is also being changed to ExternalName (which requires this field to be empty) or the type field is being changed from ExternalName (in which case this field may optionally be specified, as describe above).  Valid values are "None", empty string (""), or a valid IP address.  Setting this to "None" makes a "headless service" (no virtual IP), which is useful when direct endpoint connections are preferred and proxying is not required.  Only applies to types ClusterIP, NodePort, and LoadBalancer. If this field is specified when creating a Service of type ExternalName, creation will fail. This field will be wiped when updating a Service to type ExternalName.  If this field is not specified, it will be initialized from the clusterIP field.  If this field is specified, clients must ensure that clusterIPs[0] and clusterIP have the same value.

Unless the "IPv6DualStack" feature gate is enabled, this field is limited to one value, which must be the same as the clusterIP field.  If the feature gate is enabled, this field may hold a maximum of two entries (dual-stack IPs, in either order).  These IPs must correspond to the values of the ipFamilies field. Both clusterIPs and ipFamilies are governed by the ipFamilyPolicy field. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies

---

##### `externalIPs`<sup>Optional</sup> <a name="externalIPs" id="cdk8s-metaflow.k8s.ServiceSpec.property.externalIPs"></a>

```typescript
public readonly externalIPs: string[];
```

- *Type:* string[]

externalIPs is a list of IP addresses for which nodes in the cluster will also accept traffic for this service.

These IPs are not managed by Kubernetes.  The user is responsible for ensuring that traffic arrives at a node with this IP.  A common example is external load-balancers that are not part of the Kubernetes system.

---

##### `externalName`<sup>Optional</sup> <a name="externalName" id="cdk8s-metaflow.k8s.ServiceSpec.property.externalName"></a>

```typescript
public readonly externalName: string;
```

- *Type:* string

externalName is the external reference that discovery mechanisms will return as an alias for this service (e.g. a DNS CNAME record). No proxying will be involved.  Must be a lowercase RFC-1123 hostname (https://tools.ietf.org/html/rfc1123) and requires `type` to be "ExternalName".

---

##### `externalTrafficPolicy`<sup>Optional</sup> <a name="externalTrafficPolicy" id="cdk8s-metaflow.k8s.ServiceSpec.property.externalTrafficPolicy"></a>

```typescript
public readonly externalTrafficPolicy: string;
```

- *Type:* string

externalTrafficPolicy denotes if this Service desires to route external traffic to node-local or cluster-wide endpoints.

"Local" preserves the client source IP and avoids a second hop for LoadBalancer and Nodeport type services, but risks potentially imbalanced traffic spreading. "Cluster" obscures the client source IP and may cause a second hop to another node, but should have good overall load-spreading.

---

##### `healthCheckNodePort`<sup>Optional</sup> <a name="healthCheckNodePort" id="cdk8s-metaflow.k8s.ServiceSpec.property.healthCheckNodePort"></a>

```typescript
public readonly healthCheckNodePort: number;
```

- *Type:* number

healthCheckNodePort specifies the healthcheck nodePort for the service.

This only applies when type is set to LoadBalancer and externalTrafficPolicy is set to Local. If a value is specified, is in-range, and is not in use, it will be used.  If not specified, a value will be automatically allocated.  External systems (e.g. load-balancers) can use this port to determine if a given node holds endpoints for this service or not.  If this field is specified when creating a Service which does not need it, creation will fail. This field will be wiped when updating a Service to no longer need it (e.g. changing type).

---

##### `internalTrafficPolicy`<sup>Optional</sup> <a name="internalTrafficPolicy" id="cdk8s-metaflow.k8s.ServiceSpec.property.internalTrafficPolicy"></a>

```typescript
public readonly internalTrafficPolicy: string;
```

- *Type:* string

InternalTrafficPolicy specifies if the cluster internal traffic should be routed to all endpoints or node-local endpoints only.

"Cluster" routes internal traffic to a Service to all endpoints. "Local" routes traffic to node-local endpoints only, traffic is dropped if no node-local endpoints are ready. The default value is "Cluster".

---

##### `ipFamilies`<sup>Optional</sup> <a name="ipFamilies" id="cdk8s-metaflow.k8s.ServiceSpec.property.ipFamilies"></a>

```typescript
public readonly ipFamilies: string[];
```

- *Type:* string[]

IPFamilies is a list of IP families (e.g. IPv4, IPv6) assigned to this service, and is gated by the "IPv6DualStack" feature gate.  This field is usually assigned automatically based on cluster configuration and the ipFamilyPolicy field. If this field is specified manually, the requested family is available in the cluster, and ipFamilyPolicy allows it, it will be used; otherwise creation of the service will fail.  This field is conditionally mutable: it allows for adding or removing a secondary IP family, but it does not allow changing the primary IP family of the Service.  Valid values are "IPv4" and "IPv6".  This field only applies to Services of types ClusterIP, NodePort, and LoadBalancer, and does apply to "headless" services.  This field will be wiped when updating a Service to type ExternalName.

This field may hold a maximum of two entries (dual-stack families, in either order).  These families must correspond to the values of the clusterIPs field, if specified. Both clusterIPs and ipFamilies are governed by the ipFamilyPolicy field.

---

##### `ipFamilyPolicy`<sup>Optional</sup> <a name="ipFamilyPolicy" id="cdk8s-metaflow.k8s.ServiceSpec.property.ipFamilyPolicy"></a>

```typescript
public readonly ipFamilyPolicy: string;
```

- *Type:* string

IPFamilyPolicy represents the dual-stack-ness requested or required by this Service, and is gated by the "IPv6DualStack" feature gate.

If there is no value provided, then this field will be set to SingleStack. Services can be "SingleStack" (a single IP family), "PreferDualStack" (two IP families on dual-stack configured clusters or a single IP family on single-stack clusters), or "RequireDualStack" (two IP families on dual-stack configured clusters, otherwise fail). The ipFamilies and clusterIPs fields depend on the value of this field.  This field will be wiped when updating a service to type ExternalName.

---

##### `loadBalancerClass`<sup>Optional</sup> <a name="loadBalancerClass" id="cdk8s-metaflow.k8s.ServiceSpec.property.loadBalancerClass"></a>

```typescript
public readonly loadBalancerClass: string;
```

- *Type:* string

loadBalancerClass is the class of the load balancer implementation this Service belongs to.

If specified, the value of this field must be a label-style identifier, with an optional prefix, e.g. "internal-vip" or "example.com/internal-vip". Unprefixed names are reserved for end-users. This field can only be set when the Service type is 'LoadBalancer'. If not set, the default load balancer implementation is used, today this is typically done through the cloud provider integration, but should apply for any default implementation. If set, it is assumed that a load balancer implementation is watching for Services with a matching class. Any default load balancer implementation (e.g. cloud providers) should ignore Services that set this field. This field can only be set when creating or updating a Service to type 'LoadBalancer'. Once set, it can not be changed. This field will be wiped when a service is updated to a non 'LoadBalancer' type.

---

##### `loadBalancerIp`<sup>Optional</sup> <a name="loadBalancerIp" id="cdk8s-metaflow.k8s.ServiceSpec.property.loadBalancerIp"></a>

```typescript
public readonly loadBalancerIp: string;
```

- *Type:* string

Only applies to Service Type: LoadBalancer LoadBalancer will get created with the IP specified in this field.

This feature depends on whether the underlying cloud-provider supports specifying the loadBalancerIP when a load balancer is created. This field will be ignored if the cloud-provider does not support the feature.

---

##### `loadBalancerSourceRanges`<sup>Optional</sup> <a name="loadBalancerSourceRanges" id="cdk8s-metaflow.k8s.ServiceSpec.property.loadBalancerSourceRanges"></a>

```typescript
public readonly loadBalancerSourceRanges: string[];
```

- *Type:* string[]

If specified and supported by the platform, this will restrict traffic through the cloud-provider load-balancer will be restricted to the specified client IPs.

This field will be ignored if the cloud-provider does not support the feature." More info: https://kubernetes.io/docs/tasks/access-application-cluster/create-external-load-balancer/

---

##### `ports`<sup>Optional</sup> <a name="ports" id="cdk8s-metaflow.k8s.ServiceSpec.property.ports"></a>

```typescript
public readonly ports: ServicePort[];
```

- *Type:* cdk8s-metaflow.k8s.ServicePort[]

The list of ports that are exposed by this service.

More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies

---

##### `publishNotReadyAddresses`<sup>Optional</sup> <a name="publishNotReadyAddresses" id="cdk8s-metaflow.k8s.ServiceSpec.property.publishNotReadyAddresses"></a>

```typescript
public readonly publishNotReadyAddresses: boolean;
```

- *Type:* boolean

publishNotReadyAddresses indicates that any agent which deals with endpoints for this Service should disregard any indications of ready/not-ready.

The primary use case for setting this field is for a StatefulSet's Headless Service to propagate SRV DNS records for its Pods for the purpose of peer discovery. The Kubernetes controllers that generate Endpoints and EndpointSlice resources for Services interpret this to mean that all endpoints are considered "ready" even if the Pods themselves are not. Agents which consume only Kubernetes generated endpoints through the Endpoints or EndpointSlice resources can safely assume this behavior.

---

##### `selector`<sup>Optional</sup> <a name="selector" id="cdk8s-metaflow.k8s.ServiceSpec.property.selector"></a>

```typescript
public readonly selector: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

Route service traffic to pods with label keys and values matching this selector.

If empty or not present, the service is assumed to have an external process managing its endpoints, which Kubernetes will not modify. Only applies to types ClusterIP, NodePort, and LoadBalancer. Ignored if type is ExternalName. More info: https://kubernetes.io/docs/concepts/services-networking/service/

---

##### `sessionAffinity`<sup>Optional</sup> <a name="sessionAffinity" id="cdk8s-metaflow.k8s.ServiceSpec.property.sessionAffinity"></a>

```typescript
public readonly sessionAffinity: string;
```

- *Type:* string
- *Default:* None. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies

Supports "ClientIP" and "None".

Used to maintain session affinity. Enable client IP based session affinity. Must be ClientIP or None. Defaults to None. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies

---

##### `sessionAffinityConfig`<sup>Optional</sup> <a name="sessionAffinityConfig" id="cdk8s-metaflow.k8s.ServiceSpec.property.sessionAffinityConfig"></a>

```typescript
public readonly sessionAffinityConfig: SessionAffinityConfig;
```

- *Type:* cdk8s-metaflow.k8s.SessionAffinityConfig

sessionAffinityConfig contains the configurations of session affinity.

---

##### `type`<sup>Optional</sup> <a name="type" id="cdk8s-metaflow.k8s.ServiceSpec.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string
- *Default:* ClusterIP. Valid options are ExternalName, ClusterIP, NodePort, and LoadBalancer. "ClusterIP" allocates a cluster-internal IP address for load-balancing to endpoints. Endpoints are determined by the selector or if that is not specified, by manual construction of an Endpoints object or EndpointSlice objects. If clusterIP is "None", no virtual IP is allocated and the endpoints are published as a set of endpoints rather than a virtual IP. "NodePort" builds on ClusterIP and allocates a port on every node which routes to the same endpoints as the clusterIP. "LoadBalancer" builds on NodePort and creates an external load-balancer (if supported in the current cloud) which routes to the same endpoints as the clusterIP. "ExternalName" aliases this service to the specified externalName. Several other fields do not apply to ExternalName services. More info: https://kubernetes.io/docs/concepts/services-networking/service/#publishing-services-service-types

type determines how the Service is exposed.

Defaults to ClusterIP. Valid options are ExternalName, ClusterIP, NodePort, and LoadBalancer. "ClusterIP" allocates a cluster-internal IP address for load-balancing to endpoints. Endpoints are determined by the selector or if that is not specified, by manual construction of an Endpoints object or EndpointSlice objects. If clusterIP is "None", no virtual IP is allocated and the endpoints are published as a set of endpoints rather than a virtual IP. "NodePort" builds on ClusterIP and allocates a port on every node which routes to the same endpoints as the clusterIP. "LoadBalancer" builds on NodePort and creates an external load-balancer (if supported in the current cloud) which routes to the same endpoints as the clusterIP. "ExternalName" aliases this service to the specified externalName. Several other fields do not apply to ExternalName services. More info: https://kubernetes.io/docs/concepts/services-networking/service/#publishing-services-service-types

---

### SessionAffinityConfig <a name="SessionAffinityConfig" id="cdk8s-metaflow.k8s.SessionAffinityConfig"></a>

SessionAffinityConfig represents the configurations of session affinity.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SessionAffinityConfig.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const sessionAffinityConfig: k8s.SessionAffinityConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SessionAffinityConfig.property.clientIp">clientIp</a></code> | <code>cdk8s-metaflow.k8s.ClientIpConfig</code> | clientIP contains the configurations of Client IP based session affinity. |

---

##### `clientIp`<sup>Optional</sup> <a name="clientIp" id="cdk8s-metaflow.k8s.SessionAffinityConfig.property.clientIp"></a>

```typescript
public readonly clientIp: ClientIpConfig;
```

- *Type:* cdk8s-metaflow.k8s.ClientIpConfig

clientIP contains the configurations of Client IP based session affinity.

---

### StatefulSetListProps <a name="StatefulSetListProps" id="cdk8s-metaflow.k8s.StatefulSetListProps"></a>

StatefulSetList is a collection of StatefulSets.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.StatefulSetListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const statefulSetListProps: k8s.StatefulSetListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.StatefulSet[]</code> | Items is the list of stateful sets. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list's metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.StatefulSetListProps.property.items"></a>

```typescript
public readonly items: StatefulSet[];
```

- *Type:* cdk8s-metaflow.k8s.StatefulSet[]

Items is the list of stateful sets.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.StatefulSetListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### StatefulSetProps <a name="StatefulSetProps" id="cdk8s-metaflow.k8s.StatefulSetProps"></a>

StatefulSet represents a set of pods with consistent identities.

Identities are defined as:
- Network: A single stable DNS and hostname.
- Storage: As many VolumeClaims as requested.
The StatefulSet guarantees that a given network identity will always map to the same storage identity.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.StatefulSetProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const statefulSetProps: k8s.StatefulSetProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.StatefulSetSpec</code> | Spec defines the desired identities of pods in this set. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.StatefulSetProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `spec`<sup>Optional</sup> <a name="spec" id="cdk8s-metaflow.k8s.StatefulSetProps.property.spec"></a>

```typescript
public readonly spec: StatefulSetSpec;
```

- *Type:* cdk8s-metaflow.k8s.StatefulSetSpec

Spec defines the desired identities of pods in this set.

---

### StatefulSetSpec <a name="StatefulSetSpec" id="cdk8s-metaflow.k8s.StatefulSetSpec"></a>

A StatefulSetSpec is the specification of a StatefulSet.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.StatefulSetSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const statefulSetSpec: k8s.StatefulSetSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetSpec.property.selector">selector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | selector is a label query over pods that should match the replica count. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetSpec.property.serviceName">serviceName</a></code> | <code>string</code> | serviceName is the name of the service that governs this StatefulSet. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetSpec.property.template">template</a></code> | <code>cdk8s-metaflow.k8s.PodTemplateSpec</code> | template is the object that describes the pod that will be created if insufficient replicas are detected. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetSpec.property.minReadySeconds">minReadySeconds</a></code> | <code>number</code> | Minimum number of seconds for which a newly created pod should be ready without any of its container crashing for it to be considered available. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetSpec.property.podManagementPolicy">podManagementPolicy</a></code> | <code>string</code> | podManagementPolicy controls how pods are created during initial scale up, when replacing pods on nodes, or when scaling down. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetSpec.property.replicas">replicas</a></code> | <code>number</code> | replicas is the desired number of replicas of the given Template. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetSpec.property.revisionHistoryLimit">revisionHistoryLimit</a></code> | <code>number</code> | revisionHistoryLimit is the maximum number of revisions that will be maintained in the StatefulSet's revision history. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetSpec.property.updateStrategy">updateStrategy</a></code> | <code>cdk8s-metaflow.k8s.StatefulSetUpdateStrategy</code> | updateStrategy indicates the StatefulSetUpdateStrategy that will be employed to update Pods in the StatefulSet when a revision is made to Template. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetSpec.property.volumeClaimTemplates">volumeClaimTemplates</a></code> | <code>cdk8s-metaflow.k8s.PersistentVolumeClaim[]</code> | volumeClaimTemplates is a list of claims that pods are allowed to reference. |

---

##### `selector`<sup>Required</sup> <a name="selector" id="cdk8s-metaflow.k8s.StatefulSetSpec.property.selector"></a>

```typescript
public readonly selector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

selector is a label query over pods that should match the replica count.

It must match the pod template's labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors

---

##### `serviceName`<sup>Required</sup> <a name="serviceName" id="cdk8s-metaflow.k8s.StatefulSetSpec.property.serviceName"></a>

```typescript
public readonly serviceName: string;
```

- *Type:* string

serviceName is the name of the service that governs this StatefulSet.

This service must exist before the StatefulSet, and is responsible for the network identity of the set. Pods get DNS/hostnames that follow the pattern: pod-specific-string.serviceName.default.svc.cluster.local where "pod-specific-string" is managed by the StatefulSet controller.

---

##### `template`<sup>Required</sup> <a name="template" id="cdk8s-metaflow.k8s.StatefulSetSpec.property.template"></a>

```typescript
public readonly template: PodTemplateSpec;
```

- *Type:* cdk8s-metaflow.k8s.PodTemplateSpec

template is the object that describes the pod that will be created if insufficient replicas are detected.

Each pod stamped out by the StatefulSet will fulfill this Template, but have a unique identity from the rest of the StatefulSet.

---

##### `minReadySeconds`<sup>Optional</sup> <a name="minReadySeconds" id="cdk8s-metaflow.k8s.StatefulSetSpec.property.minReadySeconds"></a>

```typescript
public readonly minReadySeconds: number;
```

- *Type:* number
- *Default:* 0 (pod will be considered available as soon as it is ready) This is an alpha field and requires enabling StatefulSetMinReadySeconds feature gate.

Minimum number of seconds for which a newly created pod should be ready without any of its container crashing for it to be considered available.

Defaults to 0 (pod will be considered available as soon as it is ready) This is an alpha field and requires enabling StatefulSetMinReadySeconds feature gate.

---

##### `podManagementPolicy`<sup>Optional</sup> <a name="podManagementPolicy" id="cdk8s-metaflow.k8s.StatefulSetSpec.property.podManagementPolicy"></a>

```typescript
public readonly podManagementPolicy: string;
```

- *Type:* string

podManagementPolicy controls how pods are created during initial scale up, when replacing pods on nodes, or when scaling down.

The default policy is `OrderedReady`, where pods are created in increasing order (pod-0, then pod-1, etc) and the controller will wait until each pod is ready before continuing. When scaling down, the pods are removed in the opposite order. The alternative policy is `Parallel` which will create pods in parallel to match the desired scale without waiting, and on scale down will delete all pods at once.

---

##### `replicas`<sup>Optional</sup> <a name="replicas" id="cdk8s-metaflow.k8s.StatefulSetSpec.property.replicas"></a>

```typescript
public readonly replicas: number;
```

- *Type:* number

replicas is the desired number of replicas of the given Template.

These are replicas in the sense that they are instantiations of the same Template, but individual replicas also have a consistent identity. If unspecified, defaults to 1.

---

##### `revisionHistoryLimit`<sup>Optional</sup> <a name="revisionHistoryLimit" id="cdk8s-metaflow.k8s.StatefulSetSpec.property.revisionHistoryLimit"></a>

```typescript
public readonly revisionHistoryLimit: number;
```

- *Type:* number

revisionHistoryLimit is the maximum number of revisions that will be maintained in the StatefulSet's revision history.

The revision history consists of all revisions not represented by a currently applied StatefulSetSpec version. The default value is 10.

---

##### `updateStrategy`<sup>Optional</sup> <a name="updateStrategy" id="cdk8s-metaflow.k8s.StatefulSetSpec.property.updateStrategy"></a>

```typescript
public readonly updateStrategy: StatefulSetUpdateStrategy;
```

- *Type:* cdk8s-metaflow.k8s.StatefulSetUpdateStrategy

updateStrategy indicates the StatefulSetUpdateStrategy that will be employed to update Pods in the StatefulSet when a revision is made to Template.

---

##### `volumeClaimTemplates`<sup>Optional</sup> <a name="volumeClaimTemplates" id="cdk8s-metaflow.k8s.StatefulSetSpec.property.volumeClaimTemplates"></a>

```typescript
public readonly volumeClaimTemplates: PersistentVolumeClaim[];
```

- *Type:* cdk8s-metaflow.k8s.PersistentVolumeClaim[]

volumeClaimTemplates is a list of claims that pods are allowed to reference.

The StatefulSet controller is responsible for mapping network identities to claims in a way that maintains the identity of a pod. Every claim in this list must have at least one matching (by name) volumeMount in one container in the template. A claim in this list takes precedence over any volumes in the template, with the same name.

---

### StatefulSetUpdateStrategy <a name="StatefulSetUpdateStrategy" id="cdk8s-metaflow.k8s.StatefulSetUpdateStrategy"></a>

StatefulSetUpdateStrategy indicates the strategy that the StatefulSet controller will use to perform updates.

It includes any additional parameters necessary to perform the update for the indicated strategy.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.StatefulSetUpdateStrategy.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const statefulSetUpdateStrategy: k8s.StatefulSetUpdateStrategy = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetUpdateStrategy.property.rollingUpdate">rollingUpdate</a></code> | <code>cdk8s-metaflow.k8s.RollingUpdateStatefulSetStrategy</code> | RollingUpdate is used to communicate parameters when Type is RollingUpdateStatefulSetStrategyType. |
| <code><a href="#cdk8s-metaflow.k8s.StatefulSetUpdateStrategy.property.type">type</a></code> | <code>string</code> | Type indicates the type of the StatefulSetUpdateStrategy. |

---

##### `rollingUpdate`<sup>Optional</sup> <a name="rollingUpdate" id="cdk8s-metaflow.k8s.StatefulSetUpdateStrategy.property.rollingUpdate"></a>

```typescript
public readonly rollingUpdate: RollingUpdateStatefulSetStrategy;
```

- *Type:* cdk8s-metaflow.k8s.RollingUpdateStatefulSetStrategy

RollingUpdate is used to communicate parameters when Type is RollingUpdateStatefulSetStrategyType.

---

##### `type`<sup>Optional</sup> <a name="type" id="cdk8s-metaflow.k8s.StatefulSetUpdateStrategy.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string
- *Default:* RollingUpdate.

Type indicates the type of the StatefulSetUpdateStrategy.

Default is RollingUpdate.

---

### StatusCause <a name="StatusCause" id="cdk8s-metaflow.k8s.StatusCause"></a>

StatusCause provides more information about an api.Status failure, including cases when multiple errors are encountered.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.StatusCause.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const statusCause: k8s.StatusCause = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StatusCause.property.field">field</a></code> | <code>string</code> | The field of the resource that has caused this error, as named by its JSON serialization. |
| <code><a href="#cdk8s-metaflow.k8s.StatusCause.property.message">message</a></code> | <code>string</code> | A human-readable description of the cause of the error. |
| <code><a href="#cdk8s-metaflow.k8s.StatusCause.property.reason">reason</a></code> | <code>string</code> | A machine-readable description of the cause of the error. |

---

##### `field`<sup>Optional</sup> <a name="field" id="cdk8s-metaflow.k8s.StatusCause.property.field"></a>

```typescript
public readonly field: string;
```

- *Type:* string

The field of the resource that has caused this error, as named by its JSON serialization.

May include dot and postfix notation for nested attributes. Arrays are zero-indexed.  Fields may appear more than once in an array of causes due to fields having multiple errors. Optional.

Examples:
"name" - the field "name" on the current resource
"items[0].name" - the field "name" on the first array entry in "items"

---

##### `message`<sup>Optional</sup> <a name="message" id="cdk8s-metaflow.k8s.StatusCause.property.message"></a>

```typescript
public readonly message: string;
```

- *Type:* string

A human-readable description of the cause of the error.

This field may be presented as-is to a reader.

---

##### `reason`<sup>Optional</sup> <a name="reason" id="cdk8s-metaflow.k8s.StatusCause.property.reason"></a>

```typescript
public readonly reason: string;
```

- *Type:* string

A machine-readable description of the cause of the error.

If this value is empty there is no information available.

---

### StatusDetails <a name="StatusDetails" id="cdk8s-metaflow.k8s.StatusDetails"></a>

StatusDetails is a set of additional properties that MAY be set by the server to provide additional information about a response.

The Reason field of a Status object defines what attributes will be set. Clients must ignore fields that do not match the defined type of each attribute, and should assume that any attribute may be empty, invalid, or under defined.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.StatusDetails.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const statusDetails: k8s.StatusDetails = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StatusDetails.property.causes">causes</a></code> | <code>cdk8s-metaflow.k8s.StatusCause[]</code> | The Causes array includes more details associated with the StatusReason failure. |
| <code><a href="#cdk8s-metaflow.k8s.StatusDetails.property.group">group</a></code> | <code>string</code> | The group attribute of the resource associated with the status StatusReason. |
| <code><a href="#cdk8s-metaflow.k8s.StatusDetails.property.kind">kind</a></code> | <code>string</code> | The kind attribute of the resource associated with the status StatusReason. |
| <code><a href="#cdk8s-metaflow.k8s.StatusDetails.property.name">name</a></code> | <code>string</code> | The name attribute of the resource associated with the status StatusReason (when there is a single name which can be described). |
| <code><a href="#cdk8s-metaflow.k8s.StatusDetails.property.retryAfterSeconds">retryAfterSeconds</a></code> | <code>number</code> | If specified, the time in seconds before the operation should be retried. |
| <code><a href="#cdk8s-metaflow.k8s.StatusDetails.property.uid">uid</a></code> | <code>string</code> | UID of the resource. |

---

##### `causes`<sup>Optional</sup> <a name="causes" id="cdk8s-metaflow.k8s.StatusDetails.property.causes"></a>

```typescript
public readonly causes: StatusCause[];
```

- *Type:* cdk8s-metaflow.k8s.StatusCause[]

The Causes array includes more details associated with the StatusReason failure.

Not all StatusReasons may provide detailed causes.

---

##### `group`<sup>Optional</sup> <a name="group" id="cdk8s-metaflow.k8s.StatusDetails.property.group"></a>

```typescript
public readonly group: string;
```

- *Type:* string

The group attribute of the resource associated with the status StatusReason.

---

##### `kind`<sup>Optional</sup> <a name="kind" id="cdk8s-metaflow.k8s.StatusDetails.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

The kind attribute of the resource associated with the status StatusReason.

On some operations may differ from the requested resource Kind. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

##### `name`<sup>Optional</sup> <a name="name" id="cdk8s-metaflow.k8s.StatusDetails.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name attribute of the resource associated with the status StatusReason (when there is a single name which can be described).

---

##### `retryAfterSeconds`<sup>Optional</sup> <a name="retryAfterSeconds" id="cdk8s-metaflow.k8s.StatusDetails.property.retryAfterSeconds"></a>

```typescript
public readonly retryAfterSeconds: number;
```

- *Type:* number

If specified, the time in seconds before the operation should be retried.

Some errors may indicate the client must take an alternate action - for those errors this field may indicate how long to wait before taking the alternate action.

---

##### `uid`<sup>Optional</sup> <a name="uid" id="cdk8s-metaflow.k8s.StatusDetails.property.uid"></a>

```typescript
public readonly uid: string;
```

- *Type:* string

UID of the resource.

(when there is a single resource which can be described). More info: http://kubernetes.io/docs/user-guide/identifiers#uids

---

### StatusProps <a name="StatusProps" id="cdk8s-metaflow.k8s.StatusProps"></a>

Status is a return value for calls that don't return other objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.StatusProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const statusProps: k8s.StatusProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StatusProps.property.code">code</a></code> | <code>number</code> | Suggested HTTP return code for this status, 0 if not set. |
| <code><a href="#cdk8s-metaflow.k8s.StatusProps.property.details">details</a></code> | <code>cdk8s-metaflow.k8s.StatusDetails</code> | Extended data associated with the reason. |
| <code><a href="#cdk8s-metaflow.k8s.StatusProps.property.message">message</a></code> | <code>string</code> | A human-readable description of the status of this operation. |
| <code><a href="#cdk8s-metaflow.k8s.StatusProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |
| <code><a href="#cdk8s-metaflow.k8s.StatusProps.property.reason">reason</a></code> | <code>string</code> | A machine-readable description of why this operation is in the "Failure" status. |

---

##### `code`<sup>Optional</sup> <a name="code" id="cdk8s-metaflow.k8s.StatusProps.property.code"></a>

```typescript
public readonly code: number;
```

- *Type:* number

Suggested HTTP return code for this status, 0 if not set.

---

##### `details`<sup>Optional</sup> <a name="details" id="cdk8s-metaflow.k8s.StatusProps.property.details"></a>

```typescript
public readonly details: StatusDetails;
```

- *Type:* cdk8s-metaflow.k8s.StatusDetails

Extended data associated with the reason.

Each reason may define its own extended details. This field is optional and the data returned is not guaranteed to conform to any schema except that defined by the reason type.

---

##### `message`<sup>Optional</sup> <a name="message" id="cdk8s-metaflow.k8s.StatusProps.property.message"></a>

```typescript
public readonly message: string;
```

- *Type:* string

A human-readable description of the status of this operation.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.StatusProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

##### `reason`<sup>Optional</sup> <a name="reason" id="cdk8s-metaflow.k8s.StatusProps.property.reason"></a>

```typescript
public readonly reason: string;
```

- *Type:* string

A machine-readable description of why this operation is in the "Failure" status.

If this value is empty there is no information available. A Reason clarifies an HTTP status code but does not override it.

---

### StorageClassListProps <a name="StorageClassListProps" id="cdk8s-metaflow.k8s.StorageClassListProps"></a>

StorageClassList is a collection of storage classes.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.StorageClassListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const storageClassListProps: k8s.StorageClassListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.StorageClass[]</code> | Items is the list of StorageClasses. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.StorageClassListProps.property.items"></a>

```typescript
public readonly items: StorageClass[];
```

- *Type:* cdk8s-metaflow.k8s.StorageClass[]

Items is the list of StorageClasses.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.StorageClassListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

### StorageClassProps <a name="StorageClassProps" id="cdk8s-metaflow.k8s.StorageClassProps"></a>

StorageClass describes the parameters for a class of storage for which PersistentVolumes can be dynamically provisioned.

StorageClasses are non-namespaced; the name of the storage class according to etcd is in ObjectMeta.Name.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.StorageClassProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const storageClassProps: k8s.StorageClassProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassProps.property.provisioner">provisioner</a></code> | <code>string</code> | Provisioner indicates the type of the provisioner. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassProps.property.allowedTopologies">allowedTopologies</a></code> | <code>cdk8s-metaflow.k8s.TopologySelectorTerm[]</code> | Restrict the node topologies where volumes can be dynamically provisioned. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassProps.property.allowVolumeExpansion">allowVolumeExpansion</a></code> | <code>boolean</code> | AllowVolumeExpansion shows whether the storage class allow volume expand. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassProps.property.mountOptions">mountOptions</a></code> | <code>string[]</code> | Dynamically provisioned PersistentVolumes of this storage class are created with these mountOptions, e.g. ["ro", "soft"]. Not validated - mount of the PVs will simply fail if one is invalid. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassProps.property.parameters">parameters</a></code> | <code>{[ key: string ]: string}</code> | Parameters holds the parameters for the provisioner that should create volumes of this storage class. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassProps.property.reclaimPolicy">reclaimPolicy</a></code> | <code>string</code> | Dynamically provisioned PersistentVolumes of this storage class are created with this reclaimPolicy. |
| <code><a href="#cdk8s-metaflow.k8s.StorageClassProps.property.volumeBindingMode">volumeBindingMode</a></code> | <code>string</code> | VolumeBindingMode indicates how PersistentVolumeClaims should be provisioned and bound. |

---

##### `provisioner`<sup>Required</sup> <a name="provisioner" id="cdk8s-metaflow.k8s.StorageClassProps.property.provisioner"></a>

```typescript
public readonly provisioner: string;
```

- *Type:* string

Provisioner indicates the type of the provisioner.

---

##### `allowedTopologies`<sup>Optional</sup> <a name="allowedTopologies" id="cdk8s-metaflow.k8s.StorageClassProps.property.allowedTopologies"></a>

```typescript
public readonly allowedTopologies: TopologySelectorTerm[];
```

- *Type:* cdk8s-metaflow.k8s.TopologySelectorTerm[]

Restrict the node topologies where volumes can be dynamically provisioned.

Each volume plugin defines its own supported topology specifications. An empty TopologySelectorTerm list means there is no topology restriction. This field is only honored by servers that enable the VolumeScheduling feature.

---

##### `allowVolumeExpansion`<sup>Optional</sup> <a name="allowVolumeExpansion" id="cdk8s-metaflow.k8s.StorageClassProps.property.allowVolumeExpansion"></a>

```typescript
public readonly allowVolumeExpansion: boolean;
```

- *Type:* boolean

AllowVolumeExpansion shows whether the storage class allow volume expand.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.StorageClassProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

##### `mountOptions`<sup>Optional</sup> <a name="mountOptions" id="cdk8s-metaflow.k8s.StorageClassProps.property.mountOptions"></a>

```typescript
public readonly mountOptions: string[];
```

- *Type:* string[]

Dynamically provisioned PersistentVolumes of this storage class are created with these mountOptions, e.g. ["ro", "soft"]. Not validated - mount of the PVs will simply fail if one is invalid.

---

##### `parameters`<sup>Optional</sup> <a name="parameters" id="cdk8s-metaflow.k8s.StorageClassProps.property.parameters"></a>

```typescript
public readonly parameters: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

Parameters holds the parameters for the provisioner that should create volumes of this storage class.

---

##### `reclaimPolicy`<sup>Optional</sup> <a name="reclaimPolicy" id="cdk8s-metaflow.k8s.StorageClassProps.property.reclaimPolicy"></a>

```typescript
public readonly reclaimPolicy: string;
```

- *Type:* string
- *Default:* Delete.

Dynamically provisioned PersistentVolumes of this storage class are created with this reclaimPolicy.

Defaults to Delete.

---

##### `volumeBindingMode`<sup>Optional</sup> <a name="volumeBindingMode" id="cdk8s-metaflow.k8s.StorageClassProps.property.volumeBindingMode"></a>

```typescript
public readonly volumeBindingMode: string;
```

- *Type:* string

VolumeBindingMode indicates how PersistentVolumeClaims should be provisioned and bound.

When unset, VolumeBindingImmediate is used. This field is only honored by servers that enable the VolumeScheduling feature.

---

### StorageOsPersistentVolumeSource <a name="StorageOsPersistentVolumeSource" id="cdk8s-metaflow.k8s.StorageOsPersistentVolumeSource"></a>

Represents a StorageOS persistent volume resource.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.StorageOsPersistentVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const storageOsPersistentVolumeSource: k8s.StorageOsPersistentVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageOsPersistentVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type to mount. |
| <code><a href="#cdk8s-metaflow.k8s.StorageOsPersistentVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Defaults to false (read/write). |
| <code><a href="#cdk8s-metaflow.k8s.StorageOsPersistentVolumeSource.property.secretRef">secretRef</a></code> | <code>cdk8s-metaflow.k8s.ObjectReference</code> | SecretRef specifies the secret to use for obtaining the StorageOS API credentials. |
| <code><a href="#cdk8s-metaflow.k8s.StorageOsPersistentVolumeSource.property.volumeName">volumeName</a></code> | <code>string</code> | VolumeName is the human-readable name of the StorageOS volume. |
| <code><a href="#cdk8s-metaflow.k8s.StorageOsPersistentVolumeSource.property.volumeNamespace">volumeNamespace</a></code> | <code>string</code> | VolumeNamespace specifies the scope of the volume within StorageOS. |

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.StorageOsPersistentVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type to mount.

Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.StorageOsPersistentVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.

Defaults to false (read/write).

ReadOnly here will force the ReadOnly setting in VolumeMounts.

---

##### `secretRef`<sup>Optional</sup> <a name="secretRef" id="cdk8s-metaflow.k8s.StorageOsPersistentVolumeSource.property.secretRef"></a>

```typescript
public readonly secretRef: ObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.ObjectReference

SecretRef specifies the secret to use for obtaining the StorageOS API credentials.

If not specified, default values will be attempted.

---

##### `volumeName`<sup>Optional</sup> <a name="volumeName" id="cdk8s-metaflow.k8s.StorageOsPersistentVolumeSource.property.volumeName"></a>

```typescript
public readonly volumeName: string;
```

- *Type:* string

VolumeName is the human-readable name of the StorageOS volume.

Volume names are only unique within a namespace.

---

##### `volumeNamespace`<sup>Optional</sup> <a name="volumeNamespace" id="cdk8s-metaflow.k8s.StorageOsPersistentVolumeSource.property.volumeNamespace"></a>

```typescript
public readonly volumeNamespace: string;
```

- *Type:* string

VolumeNamespace specifies the scope of the volume within StorageOS.

If no namespace is specified then the Pod's namespace will be used.  This allows the Kubernetes name scoping to be mirrored within StorageOS for tighter integration. Set VolumeName to any name to override the default behaviour. Set to "default" if you are not using namespaces within StorageOS. Namespaces that do not pre-exist within StorageOS will be created.

---

### StorageOsVolumeSource <a name="StorageOsVolumeSource" id="cdk8s-metaflow.k8s.StorageOsVolumeSource"></a>

Represents a StorageOS persistent volume resource.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.StorageOsVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const storageOsVolumeSource: k8s.StorageOsVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageOsVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type to mount. |
| <code><a href="#cdk8s-metaflow.k8s.StorageOsVolumeSource.property.readOnly">readOnly</a></code> | <code>boolean</code> | Defaults to false (read/write). |
| <code><a href="#cdk8s-metaflow.k8s.StorageOsVolumeSource.property.secretRef">secretRef</a></code> | <code>cdk8s-metaflow.k8s.LocalObjectReference</code> | SecretRef specifies the secret to use for obtaining the StorageOS API credentials. |
| <code><a href="#cdk8s-metaflow.k8s.StorageOsVolumeSource.property.volumeName">volumeName</a></code> | <code>string</code> | VolumeName is the human-readable name of the StorageOS volume. |
| <code><a href="#cdk8s-metaflow.k8s.StorageOsVolumeSource.property.volumeNamespace">volumeNamespace</a></code> | <code>string</code> | VolumeNamespace specifies the scope of the volume within StorageOS. |

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.StorageOsVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type to mount.

Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.StorageOsVolumeSource.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts.

Defaults to false (read/write).

ReadOnly here will force the ReadOnly setting in VolumeMounts.

---

##### `secretRef`<sup>Optional</sup> <a name="secretRef" id="cdk8s-metaflow.k8s.StorageOsVolumeSource.property.secretRef"></a>

```typescript
public readonly secretRef: LocalObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.LocalObjectReference

SecretRef specifies the secret to use for obtaining the StorageOS API credentials.

If not specified, default values will be attempted.

---

##### `volumeName`<sup>Optional</sup> <a name="volumeName" id="cdk8s-metaflow.k8s.StorageOsVolumeSource.property.volumeName"></a>

```typescript
public readonly volumeName: string;
```

- *Type:* string

VolumeName is the human-readable name of the StorageOS volume.

Volume names are only unique within a namespace.

---

##### `volumeNamespace`<sup>Optional</sup> <a name="volumeNamespace" id="cdk8s-metaflow.k8s.StorageOsVolumeSource.property.volumeNamespace"></a>

```typescript
public readonly volumeNamespace: string;
```

- *Type:* string

VolumeNamespace specifies the scope of the volume within StorageOS.

If no namespace is specified then the Pod's namespace will be used.  This allows the Kubernetes name scoping to be mirrored within StorageOS for tighter integration. Set VolumeName to any name to override the default behaviour. Set to "default" if you are not using namespaces within StorageOS. Namespaces that do not pre-exist within StorageOS will be created.

---

### StorageVersionListV1Alpha1Props <a name="StorageVersionListV1Alpha1Props" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1Props"></a>

A list of StorageVersions.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const storageVersionListV1Alpha1Props: k8s.StorageVersionListV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.StorageVersionV1Alpha1[]</code> | Items holds a list of StorageVersion. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionListV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1Props.property.items"></a>

```typescript
public readonly items: StorageVersionV1Alpha1[];
```

- *Type:* cdk8s-metaflow.k8s.StorageVersionV1Alpha1[]

Items holds a list of StorageVersion.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.StorageVersionListV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### StorageVersionV1Alpha1Props <a name="StorageVersionV1Alpha1Props" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1Props"></a>

Storage version of a specific resource.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const storageVersionV1Alpha1Props: k8s.StorageVersionV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1Props.property.spec">spec</a></code> | <code>any</code> | Spec is an empty spec. |
| <code><a href="#cdk8s-metaflow.k8s.StorageVersionV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | The name is <group>.<resource>. |

---

##### `spec`<sup>Required</sup> <a name="spec" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1Props.property.spec"></a>

```typescript
public readonly spec: any;
```

- *Type:* any

Spec is an empty spec.

It is here to comply with Kubernetes API style.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.StorageVersionV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

The name is <group>.<resource>.

---

### Subject <a name="Subject" id="cdk8s-metaflow.k8s.Subject"></a>

Subject contains a reference to the object or user identities a role binding applies to.

This can either hold a direct API object reference, or a value for non-objects such as user and group names.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.Subject.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const subject: k8s.Subject = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Subject.property.kind">kind</a></code> | <code>string</code> | Kind of object being referenced. |
| <code><a href="#cdk8s-metaflow.k8s.Subject.property.name">name</a></code> | <code>string</code> | Name of the object being referenced. |
| <code><a href="#cdk8s-metaflow.k8s.Subject.property.apiGroup">apiGroup</a></code> | <code>string</code> | APIGroup holds the API group of the referenced subject. |
| <code><a href="#cdk8s-metaflow.k8s.Subject.property.namespace">namespace</a></code> | <code>string</code> | Namespace of the referenced object. |

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.Subject.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

Kind of object being referenced.

Values defined by this API group are "User", "Group", and "ServiceAccount". If the Authorizer does not recognized the kind value, the Authorizer should report an error.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Subject.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the object being referenced.

---

##### `apiGroup`<sup>Optional</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.Subject.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string
- *Default:* for ServiceAccount subjects. Defaults to "rbac.authorization.k8s.io" for User and Group subjects.

APIGroup holds the API group of the referenced subject.

Defaults to "" for ServiceAccount subjects. Defaults to "rbac.authorization.k8s.io" for User and Group subjects.

---

##### `namespace`<sup>Optional</sup> <a name="namespace" id="cdk8s-metaflow.k8s.Subject.property.namespace"></a>

```typescript
public readonly namespace: string;
```

- *Type:* string

Namespace of the referenced object.

If the object kind is non-namespace, such as "User" or "Group", and this value is not empty the Authorizer should report an error.

---

### SubjectAccessReviewProps <a name="SubjectAccessReviewProps" id="cdk8s-metaflow.k8s.SubjectAccessReviewProps"></a>

SubjectAccessReview checks whether or not a user or group can perform an action.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SubjectAccessReviewProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const subjectAccessReviewProps: k8s.SubjectAccessReviewProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReviewProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.SubjectAccessReviewSpec</code> | Spec holds information about the request being evaluated. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReviewProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard list metadata. |

---

##### `spec`<sup>Required</sup> <a name="spec" id="cdk8s-metaflow.k8s.SubjectAccessReviewProps.property.spec"></a>

```typescript
public readonly spec: SubjectAccessReviewSpec;
```

- *Type:* cdk8s-metaflow.k8s.SubjectAccessReviewSpec

Spec holds information about the request being evaluated.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.SubjectAccessReviewProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### SubjectAccessReviewSpec <a name="SubjectAccessReviewSpec" id="cdk8s-metaflow.k8s.SubjectAccessReviewSpec"></a>

SubjectAccessReviewSpec is a description of the access request.

Exactly one of ResourceAuthorizationAttributes and NonResourceAuthorizationAttributes must be set

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SubjectAccessReviewSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const subjectAccessReviewSpec: k8s.SubjectAccessReviewSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReviewSpec.property.extra">extra</a></code> | <code>{[ key: string ]: string[]}</code> | Extra corresponds to the user.Info.GetExtra() method from the authenticator.  Since that is input to the authorizer it needs a reflection here. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReviewSpec.property.groups">groups</a></code> | <code>string[]</code> | Groups is the groups you're testing for. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReviewSpec.property.nonResourceAttributes">nonResourceAttributes</a></code> | <code>cdk8s-metaflow.k8s.NonResourceAttributes</code> | NonResourceAttributes describes information for a non-resource access request. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReviewSpec.property.resourceAttributes">resourceAttributes</a></code> | <code>cdk8s-metaflow.k8s.ResourceAttributes</code> | ResourceAuthorizationAttributes describes information for a resource access request. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReviewSpec.property.uid">uid</a></code> | <code>string</code> | UID information about the requesting user. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectAccessReviewSpec.property.user">user</a></code> | <code>string</code> | User is the user you're testing for. |

---

##### `extra`<sup>Optional</sup> <a name="extra" id="cdk8s-metaflow.k8s.SubjectAccessReviewSpec.property.extra"></a>

```typescript
public readonly extra: {[ key: string ]: string[]};
```

- *Type:* {[ key: string ]: string[]}

Extra corresponds to the user.Info.GetExtra() method from the authenticator.  Since that is input to the authorizer it needs a reflection here.

---

##### `groups`<sup>Optional</sup> <a name="groups" id="cdk8s-metaflow.k8s.SubjectAccessReviewSpec.property.groups"></a>

```typescript
public readonly groups: string[];
```

- *Type:* string[]

Groups is the groups you're testing for.

---

##### `nonResourceAttributes`<sup>Optional</sup> <a name="nonResourceAttributes" id="cdk8s-metaflow.k8s.SubjectAccessReviewSpec.property.nonResourceAttributes"></a>

```typescript
public readonly nonResourceAttributes: NonResourceAttributes;
```

- *Type:* cdk8s-metaflow.k8s.NonResourceAttributes

NonResourceAttributes describes information for a non-resource access request.

---

##### `resourceAttributes`<sup>Optional</sup> <a name="resourceAttributes" id="cdk8s-metaflow.k8s.SubjectAccessReviewSpec.property.resourceAttributes"></a>

```typescript
public readonly resourceAttributes: ResourceAttributes;
```

- *Type:* cdk8s-metaflow.k8s.ResourceAttributes

ResourceAuthorizationAttributes describes information for a resource access request.

---

##### `uid`<sup>Optional</sup> <a name="uid" id="cdk8s-metaflow.k8s.SubjectAccessReviewSpec.property.uid"></a>

```typescript
public readonly uid: string;
```

- *Type:* string

UID information about the requesting user.

---

##### `user`<sup>Optional</sup> <a name="user" id="cdk8s-metaflow.k8s.SubjectAccessReviewSpec.property.user"></a>

```typescript
public readonly user: string;
```

- *Type:* string

User is the user you're testing for.

If you specify "User" but not "Groups", then is it interpreted as "What if User were not a member of any groups

---

### SubjectV1Alpha1 <a name="SubjectV1Alpha1" id="cdk8s-metaflow.k8s.SubjectV1Alpha1"></a>

Subject contains a reference to the object or user identities a role binding applies to.

This can either hold a direct API object reference, or a value for non-objects such as user and group names.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SubjectV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const subjectV1Alpha1: k8s.SubjectV1Alpha1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SubjectV1Alpha1.property.kind">kind</a></code> | <code>string</code> | Kind of object being referenced. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectV1Alpha1.property.name">name</a></code> | <code>string</code> | Name of the object being referenced. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectV1Alpha1.property.apiVersion">apiVersion</a></code> | <code>string</code> | APIVersion holds the API group and version of the referenced subject. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectV1Alpha1.property.namespace">namespace</a></code> | <code>string</code> | Namespace of the referenced object. |

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.SubjectV1Alpha1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

Kind of object being referenced.

Values defined by this API group are "User", "Group", and "ServiceAccount". If the Authorizer does not recognized the kind value, the Authorizer should report an error.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.SubjectV1Alpha1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the object being referenced.

---

##### `apiVersion`<sup>Optional</sup> <a name="apiVersion" id="cdk8s-metaflow.k8s.SubjectV1Alpha1.property.apiVersion"></a>

```typescript
public readonly apiVersion: string;
```

- *Type:* string
- *Default:* v1" for ServiceAccount subjects. Defaults to "rbac.authorization.k8s.io/v1alpha1" for User and Group subjects.

APIVersion holds the API group and version of the referenced subject.

Defaults to "v1" for ServiceAccount subjects. Defaults to "rbac.authorization.k8s.io/v1alpha1" for User and Group subjects.

---

##### `namespace`<sup>Optional</sup> <a name="namespace" id="cdk8s-metaflow.k8s.SubjectV1Alpha1.property.namespace"></a>

```typescript
public readonly namespace: string;
```

- *Type:* string

Namespace of the referenced object.

If the object kind is non-namespace, such as "User" or "Group", and this value is not empty the Authorizer should report an error.

---

### SubjectV1Beta1 <a name="SubjectV1Beta1" id="cdk8s-metaflow.k8s.SubjectV1Beta1"></a>

Subject matches the originator of a request, as identified by the request authentication system.

There are three ways of matching an originator; by user, group, or service account.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SubjectV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const subjectV1Beta1: k8s.SubjectV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SubjectV1Beta1.property.kind">kind</a></code> | <code>string</code> | `kind` indicates which one of the other fields is non-empty. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectV1Beta1.property.group">group</a></code> | <code>cdk8s-metaflow.k8s.GroupSubjectV1Beta1</code> | `group` matches based on user group name. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectV1Beta1.property.serviceAccount">serviceAccount</a></code> | <code>cdk8s-metaflow.k8s.ServiceAccountSubjectV1Beta1</code> | `serviceAccount` matches ServiceAccounts. |
| <code><a href="#cdk8s-metaflow.k8s.SubjectV1Beta1.property.user">user</a></code> | <code>cdk8s-metaflow.k8s.UserSubjectV1Beta1</code> | `user` matches based on username. |

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.SubjectV1Beta1.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

`kind` indicates which one of the other fields is non-empty.

Required

---

##### `group`<sup>Optional</sup> <a name="group" id="cdk8s-metaflow.k8s.SubjectV1Beta1.property.group"></a>

```typescript
public readonly group: GroupSubjectV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.GroupSubjectV1Beta1

`group` matches based on user group name.

---

##### `serviceAccount`<sup>Optional</sup> <a name="serviceAccount" id="cdk8s-metaflow.k8s.SubjectV1Beta1.property.serviceAccount"></a>

```typescript
public readonly serviceAccount: ServiceAccountSubjectV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.ServiceAccountSubjectV1Beta1

`serviceAccount` matches ServiceAccounts.

---

##### `user`<sup>Optional</sup> <a name="user" id="cdk8s-metaflow.k8s.SubjectV1Beta1.property.user"></a>

```typescript
public readonly user: UserSubjectV1Beta1;
```

- *Type:* cdk8s-metaflow.k8s.UserSubjectV1Beta1

`user` matches based on username.

---

### SupplementalGroupsStrategyOptionsV1Beta1 <a name="SupplementalGroupsStrategyOptionsV1Beta1" id="cdk8s-metaflow.k8s.SupplementalGroupsStrategyOptionsV1Beta1"></a>

SupplementalGroupsStrategyOptions defines the strategy type and options used to create the strategy.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.SupplementalGroupsStrategyOptionsV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const supplementalGroupsStrategyOptionsV1Beta1: k8s.SupplementalGroupsStrategyOptionsV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.SupplementalGroupsStrategyOptionsV1Beta1.property.ranges">ranges</a></code> | <code>cdk8s-metaflow.k8s.IdRangeV1Beta1[]</code> | ranges are the allowed ranges of supplemental groups. |
| <code><a href="#cdk8s-metaflow.k8s.SupplementalGroupsStrategyOptionsV1Beta1.property.rule">rule</a></code> | <code>string</code> | rule is the strategy that will dictate what supplemental groups is used in the SecurityContext. |

---

##### `ranges`<sup>Optional</sup> <a name="ranges" id="cdk8s-metaflow.k8s.SupplementalGroupsStrategyOptionsV1Beta1.property.ranges"></a>

```typescript
public readonly ranges: IdRangeV1Beta1[];
```

- *Type:* cdk8s-metaflow.k8s.IdRangeV1Beta1[]

ranges are the allowed ranges of supplemental groups.

If you would like to force a single supplemental group then supply a single range with the same start and end. Required for MustRunAs.

---

##### `rule`<sup>Optional</sup> <a name="rule" id="cdk8s-metaflow.k8s.SupplementalGroupsStrategyOptionsV1Beta1.property.rule"></a>

```typescript
public readonly rule: string;
```

- *Type:* string

rule is the strategy that will dictate what supplemental groups is used in the SecurityContext.

---

### Sysctl <a name="Sysctl" id="cdk8s-metaflow.k8s.Sysctl"></a>

Sysctl defines a kernel parameter to be set.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.Sysctl.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const sysctl: k8s.Sysctl = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Sysctl.property.name">name</a></code> | <code>string</code> | Name of a property to set. |
| <code><a href="#cdk8s-metaflow.k8s.Sysctl.property.value">value</a></code> | <code>string</code> | Value of a property to set. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Sysctl.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of a property to set.

---

##### `value`<sup>Required</sup> <a name="value" id="cdk8s-metaflow.k8s.Sysctl.property.value"></a>

```typescript
public readonly value: string;
```

- *Type:* string

Value of a property to set.

---

### Taint <a name="Taint" id="cdk8s-metaflow.k8s.Taint"></a>

The node this Taint is attached to has the "effect" on any pod that does not tolerate the Taint.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.Taint.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const taint: k8s.Taint = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Taint.property.effect">effect</a></code> | <code>string</code> | Required. |
| <code><a href="#cdk8s-metaflow.k8s.Taint.property.key">key</a></code> | <code>string</code> | Required. |
| <code><a href="#cdk8s-metaflow.k8s.Taint.property.timeAdded">timeAdded</a></code> | <code>Date</code> | TimeAdded represents the time at which the taint was added. |
| <code><a href="#cdk8s-metaflow.k8s.Taint.property.value">value</a></code> | <code>string</code> | The taint value corresponding to the taint key. |

---

##### `effect`<sup>Required</sup> <a name="effect" id="cdk8s-metaflow.k8s.Taint.property.effect"></a>

```typescript
public readonly effect: string;
```

- *Type:* string

Required.

The effect of the taint on pods that do not tolerate the taint. Valid effects are NoSchedule, PreferNoSchedule and NoExecute.

---

##### `key`<sup>Required</sup> <a name="key" id="cdk8s-metaflow.k8s.Taint.property.key"></a>

```typescript
public readonly key: string;
```

- *Type:* string

Required.

The taint key to be applied to a node.

---

##### `timeAdded`<sup>Optional</sup> <a name="timeAdded" id="cdk8s-metaflow.k8s.Taint.property.timeAdded"></a>

```typescript
public readonly timeAdded: Date;
```

- *Type:* Date

TimeAdded represents the time at which the taint was added.

It is only written for NoExecute taints.

---

##### `value`<sup>Optional</sup> <a name="value" id="cdk8s-metaflow.k8s.Taint.property.value"></a>

```typescript
public readonly value: string;
```

- *Type:* string

The taint value corresponding to the taint key.

---

### TcpSocketAction <a name="TcpSocketAction" id="cdk8s-metaflow.k8s.TcpSocketAction"></a>

TCPSocketAction describes an action based on opening a socket.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.TcpSocketAction.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const tcpSocketAction: k8s.TcpSocketAction = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TcpSocketAction.property.port">port</a></code> | <code>cdk8s-metaflow.k8s.IntOrString</code> | Number or name of the port to access on the container. |
| <code><a href="#cdk8s-metaflow.k8s.TcpSocketAction.property.host">host</a></code> | <code>string</code> | Optional: Host name to connect to, defaults to the pod IP. |

---

##### `port`<sup>Required</sup> <a name="port" id="cdk8s-metaflow.k8s.TcpSocketAction.property.port"></a>

```typescript
public readonly port: IntOrString;
```

- *Type:* cdk8s-metaflow.k8s.IntOrString

Number or name of the port to access on the container.

Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.

---

##### `host`<sup>Optional</sup> <a name="host" id="cdk8s-metaflow.k8s.TcpSocketAction.property.host"></a>

```typescript
public readonly host: string;
```

- *Type:* string

Optional: Host name to connect to, defaults to the pod IP.

---

### TokenRequestProps <a name="TokenRequestProps" id="cdk8s-metaflow.k8s.TokenRequestProps"></a>

TokenRequest requests a token for a given service account.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.TokenRequestProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const tokenRequestProps: k8s.TokenRequestProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequestProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.TokenRequestSpec</code> | Spec holds information about the request being evaluated. |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequestProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |

---

##### `spec`<sup>Required</sup> <a name="spec" id="cdk8s-metaflow.k8s.TokenRequestProps.property.spec"></a>

```typescript
public readonly spec: TokenRequestSpec;
```

- *Type:* cdk8s-metaflow.k8s.TokenRequestSpec

Spec holds information about the request being evaluated.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.TokenRequestProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### TokenRequestSpec <a name="TokenRequestSpec" id="cdk8s-metaflow.k8s.TokenRequestSpec"></a>

TokenRequestSpec contains client provided parameters of a token request.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.TokenRequestSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const tokenRequestSpec: k8s.TokenRequestSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequestSpec.property.audiences">audiences</a></code> | <code>string[]</code> | Audiences are the intendend audiences of the token. |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequestSpec.property.boundObjectRef">boundObjectRef</a></code> | <code>cdk8s-metaflow.k8s.BoundObjectReference</code> | BoundObjectRef is a reference to an object that the token will be bound to. |
| <code><a href="#cdk8s-metaflow.k8s.TokenRequestSpec.property.expirationSeconds">expirationSeconds</a></code> | <code>number</code> | ExpirationSeconds is the requested duration of validity of the request. |

---

##### `audiences`<sup>Required</sup> <a name="audiences" id="cdk8s-metaflow.k8s.TokenRequestSpec.property.audiences"></a>

```typescript
public readonly audiences: string[];
```

- *Type:* string[]

Audiences are the intendend audiences of the token.

A recipient of a token must identitfy themself with an identifier in the list of audiences of the token, and otherwise should reject the token. A token issued for multiple audiences may be used to authenticate against any of the audiences listed but implies a high degree of trust between the target audiences.

---

##### `boundObjectRef`<sup>Optional</sup> <a name="boundObjectRef" id="cdk8s-metaflow.k8s.TokenRequestSpec.property.boundObjectRef"></a>

```typescript
public readonly boundObjectRef: BoundObjectReference;
```

- *Type:* cdk8s-metaflow.k8s.BoundObjectReference

BoundObjectRef is a reference to an object that the token will be bound to.

The token will only be valid for as long as the bound object exists. NOTE: The API server's TokenReview endpoint will validate the BoundObjectRef, but other audiences may not. Keep ExpirationSeconds small if you want prompt revocation.

---

##### `expirationSeconds`<sup>Optional</sup> <a name="expirationSeconds" id="cdk8s-metaflow.k8s.TokenRequestSpec.property.expirationSeconds"></a>

```typescript
public readonly expirationSeconds: number;
```

- *Type:* number

ExpirationSeconds is the requested duration of validity of the request.

The token issuer may return a token with a different validity duration so a client needs to check the 'expiration' field in a response.

---

### TokenReviewProps <a name="TokenReviewProps" id="cdk8s-metaflow.k8s.TokenReviewProps"></a>

TokenReview attempts to authenticate a token to a known user.

Note: TokenReview requests may be cached by the webhook token authenticator plugin in the kube-apiserver.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.TokenReviewProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const tokenReviewProps: k8s.TokenReviewProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TokenReviewProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.TokenReviewSpec</code> | Spec holds information about the request being evaluated. |
| <code><a href="#cdk8s-metaflow.k8s.TokenReviewProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object's metadata. |

---

##### `spec`<sup>Required</sup> <a name="spec" id="cdk8s-metaflow.k8s.TokenReviewProps.property.spec"></a>

```typescript
public readonly spec: TokenReviewSpec;
```

- *Type:* cdk8s-metaflow.k8s.TokenReviewSpec

Spec holds information about the request being evaluated.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.TokenReviewProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object's metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### TokenReviewSpec <a name="TokenReviewSpec" id="cdk8s-metaflow.k8s.TokenReviewSpec"></a>

TokenReviewSpec is a description of the token authentication request.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.TokenReviewSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const tokenReviewSpec: k8s.TokenReviewSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TokenReviewSpec.property.audiences">audiences</a></code> | <code>string[]</code> | Audiences is a list of the identifiers that the resource server presented with the token identifies as. |
| <code><a href="#cdk8s-metaflow.k8s.TokenReviewSpec.property.token">token</a></code> | <code>string</code> | Token is the opaque bearer token. |

---

##### `audiences`<sup>Optional</sup> <a name="audiences" id="cdk8s-metaflow.k8s.TokenReviewSpec.property.audiences"></a>

```typescript
public readonly audiences: string[];
```

- *Type:* string[]

Audiences is a list of the identifiers that the resource server presented with the token identifies as.

Audience-aware token authenticators will verify that the token was intended for at least one of the audiences in this list. If no audiences are provided, the audience will default to the audience of the Kubernetes apiserver.

---

##### `token`<sup>Optional</sup> <a name="token" id="cdk8s-metaflow.k8s.TokenReviewSpec.property.token"></a>

```typescript
public readonly token: string;
```

- *Type:* string

Token is the opaque bearer token.

---

### Toleration <a name="Toleration" id="cdk8s-metaflow.k8s.Toleration"></a>

The pod this Toleration is attached to tolerates any taint that matches the triple <key,value,effect> using the matching operator <operator>.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.Toleration.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const toleration: k8s.Toleration = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Toleration.property.effect">effect</a></code> | <code>string</code> | Effect indicates the taint effect to match. |
| <code><a href="#cdk8s-metaflow.k8s.Toleration.property.key">key</a></code> | <code>string</code> | Key is the taint key that the toleration applies to. |
| <code><a href="#cdk8s-metaflow.k8s.Toleration.property.operator">operator</a></code> | <code>string</code> | Operator represents a key's relationship to the value. |
| <code><a href="#cdk8s-metaflow.k8s.Toleration.property.tolerationSeconds">tolerationSeconds</a></code> | <code>number</code> | TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. |
| <code><a href="#cdk8s-metaflow.k8s.Toleration.property.value">value</a></code> | <code>string</code> | Value is the taint value the toleration matches to. |

---

##### `effect`<sup>Optional</sup> <a name="effect" id="cdk8s-metaflow.k8s.Toleration.property.effect"></a>

```typescript
public readonly effect: string;
```

- *Type:* string

Effect indicates the taint effect to match.

Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.

---

##### `key`<sup>Optional</sup> <a name="key" id="cdk8s-metaflow.k8s.Toleration.property.key"></a>

```typescript
public readonly key: string;
```

- *Type:* string

Key is the taint key that the toleration applies to.

Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.

---

##### `operator`<sup>Optional</sup> <a name="operator" id="cdk8s-metaflow.k8s.Toleration.property.operator"></a>

```typescript
public readonly operator: string;
```

- *Type:* string
- *Default:* Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.

Operator represents a key's relationship to the value.

Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.

---

##### `tolerationSeconds`<sup>Optional</sup> <a name="tolerationSeconds" id="cdk8s-metaflow.k8s.Toleration.property.tolerationSeconds"></a>

```typescript
public readonly tolerationSeconds: number;
```

- *Type:* number

TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint.

By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.

---

##### `value`<sup>Optional</sup> <a name="value" id="cdk8s-metaflow.k8s.Toleration.property.value"></a>

```typescript
public readonly value: string;
```

- *Type:* string

Value is the taint value the toleration matches to.

If the operator is Exists, the value should be empty, otherwise just a regular string.

---

### TopologySelectorLabelRequirement <a name="TopologySelectorLabelRequirement" id="cdk8s-metaflow.k8s.TopologySelectorLabelRequirement"></a>

A topology selector requirement is a selector that matches given label.

This is an alpha feature and may change in the future.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.TopologySelectorLabelRequirement.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const topologySelectorLabelRequirement: k8s.TopologySelectorLabelRequirement = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TopologySelectorLabelRequirement.property.key">key</a></code> | <code>string</code> | The label key that the selector applies to. |
| <code><a href="#cdk8s-metaflow.k8s.TopologySelectorLabelRequirement.property.values">values</a></code> | <code>string[]</code> | An array of string values. |

---

##### `key`<sup>Required</sup> <a name="key" id="cdk8s-metaflow.k8s.TopologySelectorLabelRequirement.property.key"></a>

```typescript
public readonly key: string;
```

- *Type:* string

The label key that the selector applies to.

---

##### `values`<sup>Required</sup> <a name="values" id="cdk8s-metaflow.k8s.TopologySelectorLabelRequirement.property.values"></a>

```typescript
public readonly values: string[];
```

- *Type:* string[]

An array of string values.

One value must match the label to be selected. Each entry in Values is ORed.

---

### TopologySelectorTerm <a name="TopologySelectorTerm" id="cdk8s-metaflow.k8s.TopologySelectorTerm"></a>

A topology selector term represents the result of label queries.

A null or empty topology selector term matches no objects. The requirements of them are ANDed. It provides a subset of functionality as NodeSelectorTerm. This is an alpha feature and may change in the future.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.TopologySelectorTerm.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const topologySelectorTerm: k8s.TopologySelectorTerm = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TopologySelectorTerm.property.matchLabelExpressions">matchLabelExpressions</a></code> | <code>cdk8s-metaflow.k8s.TopologySelectorLabelRequirement[]</code> | A list of topology selector requirements by labels. |

---

##### `matchLabelExpressions`<sup>Optional</sup> <a name="matchLabelExpressions" id="cdk8s-metaflow.k8s.TopologySelectorTerm.property.matchLabelExpressions"></a>

```typescript
public readonly matchLabelExpressions: TopologySelectorLabelRequirement[];
```

- *Type:* cdk8s-metaflow.k8s.TopologySelectorLabelRequirement[]

A list of topology selector requirements by labels.

---

### TopologySpreadConstraint <a name="TopologySpreadConstraint" id="cdk8s-metaflow.k8s.TopologySpreadConstraint"></a>

TopologySpreadConstraint specifies how to spread matching pods among the given topology.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.TopologySpreadConstraint.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const topologySpreadConstraint: k8s.TopologySpreadConstraint = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TopologySpreadConstraint.property.maxSkew">maxSkew</a></code> | <code>number</code> | MaxSkew describes the degree to which pods may be unevenly distributed. |
| <code><a href="#cdk8s-metaflow.k8s.TopologySpreadConstraint.property.topologyKey">topologyKey</a></code> | <code>string</code> | TopologyKey is the key of node labels. |
| <code><a href="#cdk8s-metaflow.k8s.TopologySpreadConstraint.property.whenUnsatisfiable">whenUnsatisfiable</a></code> | <code>string</code> | WhenUnsatisfiable indicates how to deal with a pod if it doesn't satisfy the spread constraint. |
| <code><a href="#cdk8s-metaflow.k8s.TopologySpreadConstraint.property.labelSelector">labelSelector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | LabelSelector is used to find matching pods. |

---

##### `maxSkew`<sup>Required</sup> <a name="maxSkew" id="cdk8s-metaflow.k8s.TopologySpreadConstraint.property.maxSkew"></a>

```typescript
public readonly maxSkew: number;
```

- *Type:* number

MaxSkew describes the degree to which pods may be unevenly distributed.

When `whenUnsatisfiable=DoNotSchedule`, it is the maximum permitted difference between the number of matching pods in the target topology and the global minimum. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 1/1/0: | zone1 | zone2 | zone3 | |   P   |   P   |       | - if MaxSkew is 1, incoming pod can only be scheduled to zone3 to become 1/1/1; scheduling it onto zone1(zone2) would make the ActualSkew(2-0) on zone1(zone2) violate MaxSkew(1). - if MaxSkew is 2, incoming pod can be scheduled onto any zone. When `whenUnsatisfiable=ScheduleAnyway`, it is used to give higher precedence to topologies that satisfy it. It's a required field. Default value is 1 and 0 is not allowed.

---

##### `topologyKey`<sup>Required</sup> <a name="topologyKey" id="cdk8s-metaflow.k8s.TopologySpreadConstraint.property.topologyKey"></a>

```typescript
public readonly topologyKey: string;
```

- *Type:* string

TopologyKey is the key of node labels.

Nodes that have a label with this key and identical values are considered to be in the same topology. We consider each <key, value> as a "bucket", and try to put balanced number of pods into each bucket. It's a required field.

---

##### `whenUnsatisfiable`<sup>Required</sup> <a name="whenUnsatisfiable" id="cdk8s-metaflow.k8s.TopologySpreadConstraint.property.whenUnsatisfiable"></a>

```typescript
public readonly whenUnsatisfiable: string;
```

- *Type:* string

WhenUnsatisfiable indicates how to deal with a pod if it doesn't satisfy the spread constraint.

DoNotSchedule (default) tells the scheduler not to schedule it. - ScheduleAnyway tells the scheduler to schedule the pod in any location,
but giving higher precedence to topologies that would help reduce the
skew.
A constraint is considered "Unsatisfiable" for an incoming pod if and only if every possible node assigment for that pod would violate "MaxSkew" on some topology. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 3/1/1: | zone1 | zone2 | zone3 | | P P P |   P   |   P   | If WhenUnsatisfiable is set to DoNotSchedule, incoming pod can only be scheduled to zone2(zone3) to become 3/2/1(3/1/2) as ActualSkew(2-1) on zone2(zone3) satisfies MaxSkew(1). In other words, the cluster can still be imbalanced, but scheduler won't make it *more* imbalanced. It's a required field.

---

##### `labelSelector`<sup>Optional</sup> <a name="labelSelector" id="cdk8s-metaflow.k8s.TopologySpreadConstraint.property.labelSelector"></a>

```typescript
public readonly labelSelector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector

LabelSelector is used to find matching pods.

Pods that match this label selector are counted to determine the number of pods in their corresponding topology domain.

---

### TypedLocalObjectReference <a name="TypedLocalObjectReference" id="cdk8s-metaflow.k8s.TypedLocalObjectReference"></a>

TypedLocalObjectReference contains enough information to let you locate the typed referenced object inside the same namespace.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.TypedLocalObjectReference.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const typedLocalObjectReference: k8s.TypedLocalObjectReference = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.TypedLocalObjectReference.property.kind">kind</a></code> | <code>string</code> | Kind is the type of resource being referenced. |
| <code><a href="#cdk8s-metaflow.k8s.TypedLocalObjectReference.property.name">name</a></code> | <code>string</code> | Name is the name of resource being referenced. |
| <code><a href="#cdk8s-metaflow.k8s.TypedLocalObjectReference.property.apiGroup">apiGroup</a></code> | <code>string</code> | APIGroup is the group for the resource being referenced. |

---

##### `kind`<sup>Required</sup> <a name="kind" id="cdk8s-metaflow.k8s.TypedLocalObjectReference.property.kind"></a>

```typescript
public readonly kind: string;
```

- *Type:* string

Kind is the type of resource being referenced.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.TypedLocalObjectReference.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name is the name of resource being referenced.

---

##### `apiGroup`<sup>Optional</sup> <a name="apiGroup" id="cdk8s-metaflow.k8s.TypedLocalObjectReference.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

APIGroup is the group for the resource being referenced.

If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.

---

### UserSubjectV1Beta1 <a name="UserSubjectV1Beta1" id="cdk8s-metaflow.k8s.UserSubjectV1Beta1"></a>

UserSubject holds detailed information for user-kind subject.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.UserSubjectV1Beta1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const userSubjectV1Beta1: k8s.UserSubjectV1Beta1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.UserSubjectV1Beta1.property.name">name</a></code> | <code>string</code> | `name` is the username that matches, or "*" to match all usernames. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.UserSubjectV1Beta1.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

`name` is the username that matches, or "*" to match all usernames.

Required.

---

### ValidatingWebhook <a name="ValidatingWebhook" id="cdk8s-metaflow.k8s.ValidatingWebhook"></a>

ValidatingWebhook describes an admission webhook and the resources and operations it applies to.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ValidatingWebhook.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const validatingWebhook: k8s.ValidatingWebhook = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhook.property.admissionReviewVersions">admissionReviewVersions</a></code> | <code>string[]</code> | AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhook.property.clientConfig">clientConfig</a></code> | <code>cdk8s-metaflow.k8s.WebhookClientConfig</code> | ClientConfig defines how to communicate with the hook. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhook.property.name">name</a></code> | <code>string</code> | The name of the admission webhook. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhook.property.sideEffects">sideEffects</a></code> | <code>string</code> | SideEffects states whether this webhook has side effects. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhook.property.failurePolicy">failurePolicy</a></code> | <code>string</code> | FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhook.property.matchPolicy">matchPolicy</a></code> | <code>string</code> | matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent". |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhook.property.namespaceSelector">namespaceSelector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | NamespaceSelector decides whether to run the webhook on an object based on whether the namespace for that object matches the selector. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhook.property.objectSelector">objectSelector</a></code> | <code>cdk8s-metaflow.k8s.LabelSelector</code> | ObjectSelector decides whether to run the webhook based on if the object has matching labels. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhook.property.rules">rules</a></code> | <code>cdk8s-metaflow.k8s.RuleWithOperations[]</code> | Rules describes what operations on what resources/subresources the webhook cares about. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhook.property.timeoutSeconds">timeoutSeconds</a></code> | <code>number</code> | TimeoutSeconds specifies the timeout for this webhook. |

---

##### `admissionReviewVersions`<sup>Required</sup> <a name="admissionReviewVersions" id="cdk8s-metaflow.k8s.ValidatingWebhook.property.admissionReviewVersions"></a>

```typescript
public readonly admissionReviewVersions: string[];
```

- *Type:* string[]

AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects.

API server will try to use first version in the list which it supports. If none of the versions specified in this list supported by API server, validation will fail for this object. If a persisted webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail and be subject to the failure policy.

---

##### `clientConfig`<sup>Required</sup> <a name="clientConfig" id="cdk8s-metaflow.k8s.ValidatingWebhook.property.clientConfig"></a>

```typescript
public readonly clientConfig: WebhookClientConfig;
```

- *Type:* cdk8s-metaflow.k8s.WebhookClientConfig

ClientConfig defines how to communicate with the hook.

Required

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.ValidatingWebhook.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the admission webhook.

Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where "imagepolicy" is the name of the webhook, and kubernetes.io is the name of the organization. Required.

---

##### `sideEffects`<sup>Required</sup> <a name="sideEffects" id="cdk8s-metaflow.k8s.ValidatingWebhook.property.sideEffects"></a>

```typescript
public readonly sideEffects: string;
```

- *Type:* string

SideEffects states whether this webhook has side effects.

Acceptable values are: None, NoneOnDryRun (webhooks created via v1beta1 may also specify Some or Unknown). Webhooks with side effects MUST implement a reconciliation system, since a request may be rejected by a future step in the admission chain and the side effects therefore need to be undone. Requests with the dryRun attribute will be auto-rejected if they match a webhook with sideEffects == Unknown or Some.

---

##### `failurePolicy`<sup>Optional</sup> <a name="failurePolicy" id="cdk8s-metaflow.k8s.ValidatingWebhook.property.failurePolicy"></a>

```typescript
public readonly failurePolicy: string;
```

- *Type:* string
- *Default:* Fail.

FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail.

Defaults to Fail.

---

##### `matchPolicy`<sup>Optional</sup> <a name="matchPolicy" id="cdk8s-metaflow.k8s.ValidatingWebhook.property.matchPolicy"></a>

```typescript
public readonly matchPolicy: string;
```

- *Type:* string
- *Default:* Equivalent"

matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".

Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the webhook.

- Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the webhook.

Defaults to "Equivalent"

---

##### `namespaceSelector`<sup>Optional</sup> <a name="namespaceSelector" id="cdk8s-metaflow.k8s.ValidatingWebhook.property.namespaceSelector"></a>

```typescript
public readonly namespaceSelector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector
- *Default:* the empty LabelSelector, which matches everything.

NamespaceSelector decides whether to run the webhook on an object based on whether the namespace for that object matches the selector.

If the object itself is a namespace, the matching is performed on object.metadata.labels. If the object is another cluster scoped resource, it never skips the webhook.

For example, to run the webhook on any objects whose namespace is not associated with "runlevel" of "0" or "1";  you will set the selector as follows: "namespaceSelector": {
"matchExpressions": [
{
"key": "runlevel",
"operator": "NotIn",
"values": [
"0",
"1"
]
}
]
}

If instead you want to only run the webhook on any objects whose namespace is associated with the "environment" of "prod" or "staging"; you will set the selector as follows: "namespaceSelector": {
"matchExpressions": [
{
"key": "environment",
"operator": "In",
"values": [
"prod",
"staging"
]
}
]
}

See https://kubernetes.io/docs/concepts/overview/working-with-objects/labels for more examples of label selectors.

Default to the empty LabelSelector, which matches everything.

---

##### `objectSelector`<sup>Optional</sup> <a name="objectSelector" id="cdk8s-metaflow.k8s.ValidatingWebhook.property.objectSelector"></a>

```typescript
public readonly objectSelector: LabelSelector;
```

- *Type:* cdk8s-metaflow.k8s.LabelSelector
- *Default:* the empty LabelSelector, which matches everything.

ObjectSelector decides whether to run the webhook based on if the object has matching labels.

objectSelector is evaluated against both the oldObject and newObject that would be sent to the webhook, and is considered to match if either object matches the selector. A null object (oldObject in the case of create, or newObject in the case of delete) or an object that cannot have labels (like a DeploymentRollback or a PodProxyOptions object) is not considered to match. Use the object selector only if the webhook is opt-in, because end users may skip the admission webhook by setting the labels. Default to the empty LabelSelector, which matches everything.

---

##### `rules`<sup>Optional</sup> <a name="rules" id="cdk8s-metaflow.k8s.ValidatingWebhook.property.rules"></a>

```typescript
public readonly rules: RuleWithOperations[];
```

- *Type:* cdk8s-metaflow.k8s.RuleWithOperations[]

Rules describes what operations on what resources/subresources the webhook cares about.

The webhook cares about an operation if it matches _any_ Rule. However, in order to prevent ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks from putting the cluster in a state which cannot be recovered from without completely disabling the plugin, ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks are never called on admission requests for ValidatingWebhookConfiguration and MutatingWebhookConfiguration objects.

---

##### `timeoutSeconds`<sup>Optional</sup> <a name="timeoutSeconds" id="cdk8s-metaflow.k8s.ValidatingWebhook.property.timeoutSeconds"></a>

```typescript
public readonly timeoutSeconds: number;
```

- *Type:* number
- *Default:* 10 seconds.

TimeoutSeconds specifies the timeout for this webhook.

After the timeout passes, the webhook call will be ignored or the API call will fail based on the failure policy. The timeout value must be between 1 and 30 seconds. Default to 10 seconds.

---

### ValidatingWebhookConfigurationListProps <a name="ValidatingWebhookConfigurationListProps" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationListProps"></a>

ValidatingWebhookConfigurationList is a list of ValidatingWebhookConfiguration.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const validatingWebhookConfigurationListProps: k8s.ValidatingWebhookConfigurationListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.ValidatingWebhookConfiguration[]</code> | List of ValidatingWebhookConfiguration. |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationListProps.property.items"></a>

```typescript
public readonly items: ValidatingWebhookConfiguration[];
```

- *Type:* cdk8s-metaflow.k8s.ValidatingWebhookConfiguration[]

List of ValidatingWebhookConfiguration.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

---

### ValidatingWebhookConfigurationProps <a name="ValidatingWebhookConfigurationProps" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationProps"></a>

ValidatingWebhookConfiguration describes the configuration of and admission webhook that accept or reject and object without changing it.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const validatingWebhookConfigurationProps: k8s.ValidatingWebhookConfigurationProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object metadata; |
| <code><a href="#cdk8s-metaflow.k8s.ValidatingWebhookConfigurationProps.property.webhooks">webhooks</a></code> | <code>cdk8s-metaflow.k8s.ValidatingWebhook[]</code> | Webhooks is a list of webhooks and the affected resources and operations. |

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object metadata;

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

##### `webhooks`<sup>Optional</sup> <a name="webhooks" id="cdk8s-metaflow.k8s.ValidatingWebhookConfigurationProps.property.webhooks"></a>

```typescript
public readonly webhooks: ValidatingWebhook[];
```

- *Type:* cdk8s-metaflow.k8s.ValidatingWebhook[]

Webhooks is a list of webhooks and the affected resources and operations.

---

### Volume <a name="Volume" id="cdk8s-metaflow.k8s.Volume"></a>

Volume represents a named volume in a pod that may be accessed by any container in the pod.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.Volume.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const volume: k8s.Volume = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.name">name</a></code> | <code>string</code> | Volume's name. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.awsElasticBlockStore">awsElasticBlockStore</a></code> | <code>cdk8s-metaflow.k8s.AwsElasticBlockStoreVolumeSource</code> | AWSElasticBlockStore represents an AWS Disk resource that is attached to a kubelet's host machine and then exposed to the pod. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.azureDisk">azureDisk</a></code> | <code>cdk8s-metaflow.k8s.AzureDiskVolumeSource</code> | AzureDisk represents an Azure Data Disk mount on the host and bind mount to the pod. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.azureFile">azureFile</a></code> | <code>cdk8s-metaflow.k8s.AzureFileVolumeSource</code> | AzureFile represents an Azure File Service mount on the host and bind mount to the pod. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.cephfs">cephfs</a></code> | <code>cdk8s-metaflow.k8s.CephFsVolumeSource</code> | CephFS represents a Ceph FS mount on the host that shares a pod's lifetime. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.cinder">cinder</a></code> | <code>cdk8s-metaflow.k8s.CinderVolumeSource</code> | Cinder represents a cinder volume attached and mounted on kubelets host machine. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.configMap">configMap</a></code> | <code>cdk8s-metaflow.k8s.ConfigMapVolumeSource</code> | ConfigMap represents a configMap that should populate this volume. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.csi">csi</a></code> | <code>cdk8s-metaflow.k8s.CsiVolumeSource</code> | CSI (Container Storage Interface) represents ephemeral storage that is handled by certain external CSI drivers (Beta feature). |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.downwardApi">downwardApi</a></code> | <code>cdk8s-metaflow.k8s.DownwardApiVolumeSource</code> | DownwardAPI represents downward API about the pod that should populate this volume. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.emptyDir">emptyDir</a></code> | <code>cdk8s-metaflow.k8s.EmptyDirVolumeSource</code> | EmptyDir represents a temporary directory that shares a pod's lifetime. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.ephemeral">ephemeral</a></code> | <code>cdk8s-metaflow.k8s.EphemeralVolumeSource</code> | Ephemeral represents a volume that is handled by a cluster storage driver. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.fc">fc</a></code> | <code>cdk8s-metaflow.k8s.FcVolumeSource</code> | FC represents a Fibre Channel resource that is attached to a kubelet's host machine and then exposed to the pod. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.flexVolume">flexVolume</a></code> | <code>cdk8s-metaflow.k8s.FlexVolumeSource</code> | FlexVolume represents a generic volume resource that is provisioned/attached using an exec based plugin. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.flocker">flocker</a></code> | <code>cdk8s-metaflow.k8s.FlockerVolumeSource</code> | Flocker represents a Flocker volume attached to a kubelet's host machine. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.gcePersistentDisk">gcePersistentDisk</a></code> | <code>cdk8s-metaflow.k8s.GcePersistentDiskVolumeSource</code> | GCEPersistentDisk represents a GCE Disk resource that is attached to a kubelet's host machine and then exposed to the pod. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.gitRepo">gitRepo</a></code> | <code>cdk8s-metaflow.k8s.GitRepoVolumeSource</code> | GitRepo represents a git repository at a particular revision. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.glusterfs">glusterfs</a></code> | <code>cdk8s-metaflow.k8s.GlusterfsVolumeSource</code> | Glusterfs represents a Glusterfs mount on the host that shares a pod's lifetime. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.hostPath">hostPath</a></code> | <code>cdk8s-metaflow.k8s.HostPathVolumeSource</code> | HostPath represents a pre-existing file or directory on the host machine that is directly exposed to the container. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.iscsi">iscsi</a></code> | <code>cdk8s-metaflow.k8s.IscsiVolumeSource</code> | ISCSI represents an ISCSI Disk resource that is attached to a kubelet's host machine and then exposed to the pod. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.nfs">nfs</a></code> | <code>cdk8s-metaflow.k8s.NfsVolumeSource</code> | NFS represents an NFS mount on the host that shares a pod's lifetime More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.persistentVolumeClaim">persistentVolumeClaim</a></code> | <code>cdk8s-metaflow.k8s.PersistentVolumeClaimVolumeSource</code> | PersistentVolumeClaimVolumeSource represents a reference to a PersistentVolumeClaim in the same namespace. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.photonPersistentDisk">photonPersistentDisk</a></code> | <code>cdk8s-metaflow.k8s.PhotonPersistentDiskVolumeSource</code> | PhotonPersistentDisk represents a PhotonController persistent disk attached and mounted on kubelets host machine. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.portworxVolume">portworxVolume</a></code> | <code>cdk8s-metaflow.k8s.PortworxVolumeSource</code> | PortworxVolume represents a portworx volume attached and mounted on kubelets host machine. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.projected">projected</a></code> | <code>cdk8s-metaflow.k8s.ProjectedVolumeSource</code> | Items for all in one resources secrets, configmaps, and downward API. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.quobyte">quobyte</a></code> | <code>cdk8s-metaflow.k8s.QuobyteVolumeSource</code> | Quobyte represents a Quobyte mount on the host that shares a pod's lifetime. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.rbd">rbd</a></code> | <code>cdk8s-metaflow.k8s.RbdVolumeSource</code> | RBD represents a Rados Block Device mount on the host that shares a pod's lifetime. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.scaleIo">scaleIo</a></code> | <code>cdk8s-metaflow.k8s.ScaleIoVolumeSource</code> | ScaleIO represents a ScaleIO persistent volume attached and mounted on Kubernetes nodes. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.secret">secret</a></code> | <code>cdk8s-metaflow.k8s.SecretVolumeSource</code> | Secret represents a secret that should populate this volume. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.storageos">storageos</a></code> | <code>cdk8s-metaflow.k8s.StorageOsVolumeSource</code> | StorageOS represents a StorageOS volume attached and mounted on Kubernetes nodes. |
| <code><a href="#cdk8s-metaflow.k8s.Volume.property.vsphereVolume">vsphereVolume</a></code> | <code>cdk8s-metaflow.k8s.VsphereVirtualDiskVolumeSource</code> | VsphereVolume represents a vSphere volume attached and mounted on kubelets host machine. |

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.Volume.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Volume's name.

Must be a DNS_LABEL and unique within the pod. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names

---

##### `awsElasticBlockStore`<sup>Optional</sup> <a name="awsElasticBlockStore" id="cdk8s-metaflow.k8s.Volume.property.awsElasticBlockStore"></a>

```typescript
public readonly awsElasticBlockStore: AwsElasticBlockStoreVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.AwsElasticBlockStoreVolumeSource

AWSElasticBlockStore represents an AWS Disk resource that is attached to a kubelet's host machine and then exposed to the pod.

More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore

---

##### `azureDisk`<sup>Optional</sup> <a name="azureDisk" id="cdk8s-metaflow.k8s.Volume.property.azureDisk"></a>

```typescript
public readonly azureDisk: AzureDiskVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.AzureDiskVolumeSource

AzureDisk represents an Azure Data Disk mount on the host and bind mount to the pod.

---

##### `azureFile`<sup>Optional</sup> <a name="azureFile" id="cdk8s-metaflow.k8s.Volume.property.azureFile"></a>

```typescript
public readonly azureFile: AzureFileVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.AzureFileVolumeSource

AzureFile represents an Azure File Service mount on the host and bind mount to the pod.

---

##### `cephfs`<sup>Optional</sup> <a name="cephfs" id="cdk8s-metaflow.k8s.Volume.property.cephfs"></a>

```typescript
public readonly cephfs: CephFsVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.CephFsVolumeSource

CephFS represents a Ceph FS mount on the host that shares a pod's lifetime.

---

##### `cinder`<sup>Optional</sup> <a name="cinder" id="cdk8s-metaflow.k8s.Volume.property.cinder"></a>

```typescript
public readonly cinder: CinderVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.CinderVolumeSource

Cinder represents a cinder volume attached and mounted on kubelets host machine.

More info: https://examples.k8s.io/mysql-cinder-pd/README.md

---

##### `configMap`<sup>Optional</sup> <a name="configMap" id="cdk8s-metaflow.k8s.Volume.property.configMap"></a>

```typescript
public readonly configMap: ConfigMapVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.ConfigMapVolumeSource

ConfigMap represents a configMap that should populate this volume.

---

##### `csi`<sup>Optional</sup> <a name="csi" id="cdk8s-metaflow.k8s.Volume.property.csi"></a>

```typescript
public readonly csi: CsiVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.CsiVolumeSource

CSI (Container Storage Interface) represents ephemeral storage that is handled by certain external CSI drivers (Beta feature).

---

##### `downwardApi`<sup>Optional</sup> <a name="downwardApi" id="cdk8s-metaflow.k8s.Volume.property.downwardApi"></a>

```typescript
public readonly downwardApi: DownwardApiVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.DownwardApiVolumeSource

DownwardAPI represents downward API about the pod that should populate this volume.

---

##### `emptyDir`<sup>Optional</sup> <a name="emptyDir" id="cdk8s-metaflow.k8s.Volume.property.emptyDir"></a>

```typescript
public readonly emptyDir: EmptyDirVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.EmptyDirVolumeSource

EmptyDir represents a temporary directory that shares a pod's lifetime.

More info: https://kubernetes.io/docs/concepts/storage/volumes#emptydir

---

##### `ephemeral`<sup>Optional</sup> <a name="ephemeral" id="cdk8s-metaflow.k8s.Volume.property.ephemeral"></a>

```typescript
public readonly ephemeral: EphemeralVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.EphemeralVolumeSource

Ephemeral represents a volume that is handled by a cluster storage driver.

The volume's lifecycle is tied to the pod that defines it - it will be created before the pod starts, and deleted when the pod is removed.

Use this if: a) the volume is only needed while the pod runs, b) features of normal volumes like restoring from snapshot or capacity
tracking are needed,
c) the storage driver is specified through a storage class, and d) the storage driver supports dynamic volume provisioning through
a PersistentVolumeClaim (see EphemeralVolumeSource for more
information on the connection between this volume type
and PersistentVolumeClaim).

Use PersistentVolumeClaim or one of the vendor-specific APIs for volumes that persist for longer than the lifecycle of an individual pod.

Use CSI for light-weight local ephemeral volumes if the CSI driver is meant to be used that way - see the documentation of the driver for more information.

A pod can use both types of ephemeral volumes and persistent volumes at the same time.

This is a beta feature and only available when the GenericEphemeralVolume feature gate is enabled.

---

##### `fc`<sup>Optional</sup> <a name="fc" id="cdk8s-metaflow.k8s.Volume.property.fc"></a>

```typescript
public readonly fc: FcVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.FcVolumeSource

FC represents a Fibre Channel resource that is attached to a kubelet's host machine and then exposed to the pod.

---

##### `flexVolume`<sup>Optional</sup> <a name="flexVolume" id="cdk8s-metaflow.k8s.Volume.property.flexVolume"></a>

```typescript
public readonly flexVolume: FlexVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.FlexVolumeSource

FlexVolume represents a generic volume resource that is provisioned/attached using an exec based plugin.

---

##### `flocker`<sup>Optional</sup> <a name="flocker" id="cdk8s-metaflow.k8s.Volume.property.flocker"></a>

```typescript
public readonly flocker: FlockerVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.FlockerVolumeSource

Flocker represents a Flocker volume attached to a kubelet's host machine.

This depends on the Flocker control service being running

---

##### `gcePersistentDisk`<sup>Optional</sup> <a name="gcePersistentDisk" id="cdk8s-metaflow.k8s.Volume.property.gcePersistentDisk"></a>

```typescript
public readonly gcePersistentDisk: GcePersistentDiskVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.GcePersistentDiskVolumeSource

GCEPersistentDisk represents a GCE Disk resource that is attached to a kubelet's host machine and then exposed to the pod.

More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk

---

##### `gitRepo`<sup>Optional</sup> <a name="gitRepo" id="cdk8s-metaflow.k8s.Volume.property.gitRepo"></a>

```typescript
public readonly gitRepo: GitRepoVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.GitRepoVolumeSource

GitRepo represents a git repository at a particular revision.

DEPRECATED: GitRepo is deprecated. To provision a container with a git repo, mount an EmptyDir into an InitContainer that clones the repo using git, then mount the EmptyDir into the Pod's container.

---

##### `glusterfs`<sup>Optional</sup> <a name="glusterfs" id="cdk8s-metaflow.k8s.Volume.property.glusterfs"></a>

```typescript
public readonly glusterfs: GlusterfsVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.GlusterfsVolumeSource

Glusterfs represents a Glusterfs mount on the host that shares a pod's lifetime.

More info: https://examples.k8s.io/volumes/glusterfs/README.md

---

##### `hostPath`<sup>Optional</sup> <a name="hostPath" id="cdk8s-metaflow.k8s.Volume.property.hostPath"></a>

```typescript
public readonly hostPath: HostPathVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.HostPathVolumeSource

HostPath represents a pre-existing file or directory on the host machine that is directly exposed to the container.

This is generally used for system agents or other privileged things that are allowed to see the host machine. Most containers will NOT need this. More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath

---

##### `iscsi`<sup>Optional</sup> <a name="iscsi" id="cdk8s-metaflow.k8s.Volume.property.iscsi"></a>

```typescript
public readonly iscsi: IscsiVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.IscsiVolumeSource

ISCSI represents an ISCSI Disk resource that is attached to a kubelet's host machine and then exposed to the pod.

More info: https://examples.k8s.io/volumes/iscsi/README.md

---

##### `nfs`<sup>Optional</sup> <a name="nfs" id="cdk8s-metaflow.k8s.Volume.property.nfs"></a>

```typescript
public readonly nfs: NfsVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.NfsVolumeSource

NFS represents an NFS mount on the host that shares a pod's lifetime More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs.

---

##### `persistentVolumeClaim`<sup>Optional</sup> <a name="persistentVolumeClaim" id="cdk8s-metaflow.k8s.Volume.property.persistentVolumeClaim"></a>

```typescript
public readonly persistentVolumeClaim: PersistentVolumeClaimVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.PersistentVolumeClaimVolumeSource

PersistentVolumeClaimVolumeSource represents a reference to a PersistentVolumeClaim in the same namespace.

More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims

---

##### `photonPersistentDisk`<sup>Optional</sup> <a name="photonPersistentDisk" id="cdk8s-metaflow.k8s.Volume.property.photonPersistentDisk"></a>

```typescript
public readonly photonPersistentDisk: PhotonPersistentDiskVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.PhotonPersistentDiskVolumeSource

PhotonPersistentDisk represents a PhotonController persistent disk attached and mounted on kubelets host machine.

---

##### `portworxVolume`<sup>Optional</sup> <a name="portworxVolume" id="cdk8s-metaflow.k8s.Volume.property.portworxVolume"></a>

```typescript
public readonly portworxVolume: PortworxVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.PortworxVolumeSource

PortworxVolume represents a portworx volume attached and mounted on kubelets host machine.

---

##### `projected`<sup>Optional</sup> <a name="projected" id="cdk8s-metaflow.k8s.Volume.property.projected"></a>

```typescript
public readonly projected: ProjectedVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.ProjectedVolumeSource

Items for all in one resources secrets, configmaps, and downward API.

---

##### `quobyte`<sup>Optional</sup> <a name="quobyte" id="cdk8s-metaflow.k8s.Volume.property.quobyte"></a>

```typescript
public readonly quobyte: QuobyteVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.QuobyteVolumeSource

Quobyte represents a Quobyte mount on the host that shares a pod's lifetime.

---

##### `rbd`<sup>Optional</sup> <a name="rbd" id="cdk8s-metaflow.k8s.Volume.property.rbd"></a>

```typescript
public readonly rbd: RbdVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.RbdVolumeSource

RBD represents a Rados Block Device mount on the host that shares a pod's lifetime.

More info: https://examples.k8s.io/volumes/rbd/README.md

---

##### `scaleIo`<sup>Optional</sup> <a name="scaleIo" id="cdk8s-metaflow.k8s.Volume.property.scaleIo"></a>

```typescript
public readonly scaleIo: ScaleIoVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.ScaleIoVolumeSource

ScaleIO represents a ScaleIO persistent volume attached and mounted on Kubernetes nodes.

---

##### `secret`<sup>Optional</sup> <a name="secret" id="cdk8s-metaflow.k8s.Volume.property.secret"></a>

```typescript
public readonly secret: SecretVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.SecretVolumeSource

Secret represents a secret that should populate this volume.

More info: https://kubernetes.io/docs/concepts/storage/volumes#secret

---

##### `storageos`<sup>Optional</sup> <a name="storageos" id="cdk8s-metaflow.k8s.Volume.property.storageos"></a>

```typescript
public readonly storageos: StorageOsVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.StorageOsVolumeSource

StorageOS represents a StorageOS volume attached and mounted on Kubernetes nodes.

---

##### `vsphereVolume`<sup>Optional</sup> <a name="vsphereVolume" id="cdk8s-metaflow.k8s.Volume.property.vsphereVolume"></a>

```typescript
public readonly vsphereVolume: VsphereVirtualDiskVolumeSource;
```

- *Type:* cdk8s-metaflow.k8s.VsphereVirtualDiskVolumeSource

VsphereVolume represents a vSphere volume attached and mounted on kubelets host machine.

---

### VolumeAttachmentListProps <a name="VolumeAttachmentListProps" id="cdk8s-metaflow.k8s.VolumeAttachmentListProps"></a>

VolumeAttachmentList is a collection of VolumeAttachment objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.VolumeAttachmentListProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const volumeAttachmentListProps: k8s.VolumeAttachmentListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListProps.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.VolumeAttachment[]</code> | Items is the list of VolumeAttachments. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.VolumeAttachmentListProps.property.items"></a>

```typescript
public readonly items: VolumeAttachment[];
```

- *Type:* cdk8s-metaflow.k8s.VolumeAttachment[]

Items is the list of VolumeAttachments.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.VolumeAttachmentListProps.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

### VolumeAttachmentListV1Alpha1Props <a name="VolumeAttachmentListV1Alpha1Props" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1Props"></a>

VolumeAttachmentList is a collection of VolumeAttachment objects.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const volumeAttachmentListV1Alpha1Props: k8s.VolumeAttachmentListV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1Props.property.items">items</a></code> | <code>cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1[]</code> | Items is the list of VolumeAttachments. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ListMeta</code> | Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata. |

---

##### `items`<sup>Required</sup> <a name="items" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1Props.property.items"></a>

```typescript
public readonly items: VolumeAttachmentV1Alpha1[];
```

- *Type:* cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1[]

Items is the list of VolumeAttachments.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.VolumeAttachmentListV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ListMeta;
```

- *Type:* cdk8s-metaflow.k8s.ListMeta

Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.

---

### VolumeAttachmentProps <a name="VolumeAttachmentProps" id="cdk8s-metaflow.k8s.VolumeAttachmentProps"></a>

VolumeAttachment captures the intent to attach or detach the specified volume to/from the specified node.

VolumeAttachment objects are non-namespaced.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.VolumeAttachmentProps.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const volumeAttachmentProps: k8s.VolumeAttachmentProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentProps.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.VolumeAttachmentSpec</code> | Specification of the desired attach/detach volume behavior. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentProps.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object metadata. |

---

##### `spec`<sup>Required</sup> <a name="spec" id="cdk8s-metaflow.k8s.VolumeAttachmentProps.property.spec"></a>

```typescript
public readonly spec: VolumeAttachmentSpec;
```

- *Type:* cdk8s-metaflow.k8s.VolumeAttachmentSpec

Specification of the desired attach/detach volume behavior.

Populated by the Kubernetes system.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.VolumeAttachmentProps.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### VolumeAttachmentSource <a name="VolumeAttachmentSource" id="cdk8s-metaflow.k8s.VolumeAttachmentSource"></a>

VolumeAttachmentSource represents a volume that should be attached.

Right now only PersistenVolumes can be attached via external attacher, in future we may allow also inline volumes in pods. Exactly one member can be set.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.VolumeAttachmentSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const volumeAttachmentSource: k8s.VolumeAttachmentSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentSource.property.inlineVolumeSpec">inlineVolumeSpec</a></code> | <code>cdk8s-metaflow.k8s.PersistentVolumeSpec</code> | inlineVolumeSpec contains all the information necessary to attach a persistent volume defined by a pod's inline VolumeSource. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentSource.property.persistentVolumeName">persistentVolumeName</a></code> | <code>string</code> | Name of the persistent volume to attach. |

---

##### `inlineVolumeSpec`<sup>Optional</sup> <a name="inlineVolumeSpec" id="cdk8s-metaflow.k8s.VolumeAttachmentSource.property.inlineVolumeSpec"></a>

```typescript
public readonly inlineVolumeSpec: PersistentVolumeSpec;
```

- *Type:* cdk8s-metaflow.k8s.PersistentVolumeSpec

inlineVolumeSpec contains all the information necessary to attach a persistent volume defined by a pod's inline VolumeSource.

This field is populated only for the CSIMigration feature. It contains translated fields from a pod's inline VolumeSource to a PersistentVolumeSpec. This field is beta-level and is only honored by servers that enabled the CSIMigration feature.

---

##### `persistentVolumeName`<sup>Optional</sup> <a name="persistentVolumeName" id="cdk8s-metaflow.k8s.VolumeAttachmentSource.property.persistentVolumeName"></a>

```typescript
public readonly persistentVolumeName: string;
```

- *Type:* string

Name of the persistent volume to attach.

---

### VolumeAttachmentSourceV1Alpha1 <a name="VolumeAttachmentSourceV1Alpha1" id="cdk8s-metaflow.k8s.VolumeAttachmentSourceV1Alpha1"></a>

VolumeAttachmentSource represents a volume that should be attached.

Right now only PersistenVolumes can be attached via external attacher, in future we may allow also inline volumes in pods. Exactly one member can be set.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.VolumeAttachmentSourceV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const volumeAttachmentSourceV1Alpha1: k8s.VolumeAttachmentSourceV1Alpha1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentSourceV1Alpha1.property.inlineVolumeSpec">inlineVolumeSpec</a></code> | <code>cdk8s-metaflow.k8s.PersistentVolumeSpec</code> | inlineVolumeSpec contains all the information necessary to attach a persistent volume defined by a pod's inline VolumeSource. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentSourceV1Alpha1.property.persistentVolumeName">persistentVolumeName</a></code> | <code>string</code> | Name of the persistent volume to attach. |

---

##### `inlineVolumeSpec`<sup>Optional</sup> <a name="inlineVolumeSpec" id="cdk8s-metaflow.k8s.VolumeAttachmentSourceV1Alpha1.property.inlineVolumeSpec"></a>

```typescript
public readonly inlineVolumeSpec: PersistentVolumeSpec;
```

- *Type:* cdk8s-metaflow.k8s.PersistentVolumeSpec

inlineVolumeSpec contains all the information necessary to attach a persistent volume defined by a pod's inline VolumeSource.

This field is populated only for the CSIMigration feature. It contains translated fields from a pod's inline VolumeSource to a PersistentVolumeSpec. This field is alpha-level and is only honored by servers that enabled the CSIMigration feature.

---

##### `persistentVolumeName`<sup>Optional</sup> <a name="persistentVolumeName" id="cdk8s-metaflow.k8s.VolumeAttachmentSourceV1Alpha1.property.persistentVolumeName"></a>

```typescript
public readonly persistentVolumeName: string;
```

- *Type:* string

Name of the persistent volume to attach.

---

### VolumeAttachmentSpec <a name="VolumeAttachmentSpec" id="cdk8s-metaflow.k8s.VolumeAttachmentSpec"></a>

VolumeAttachmentSpec is the specification of a VolumeAttachment request.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.VolumeAttachmentSpec.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const volumeAttachmentSpec: k8s.VolumeAttachmentSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentSpec.property.attacher">attacher</a></code> | <code>string</code> | Attacher indicates the name of the volume driver that MUST handle this request. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentSpec.property.nodeName">nodeName</a></code> | <code>string</code> | The node that the volume should be attached to. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentSpec.property.source">source</a></code> | <code>cdk8s-metaflow.k8s.VolumeAttachmentSource</code> | Source represents the volume that should be attached. |

---

##### `attacher`<sup>Required</sup> <a name="attacher" id="cdk8s-metaflow.k8s.VolumeAttachmentSpec.property.attacher"></a>

```typescript
public readonly attacher: string;
```

- *Type:* string

Attacher indicates the name of the volume driver that MUST handle this request.

This is the name returned by GetPluginName().

---

##### `nodeName`<sup>Required</sup> <a name="nodeName" id="cdk8s-metaflow.k8s.VolumeAttachmentSpec.property.nodeName"></a>

```typescript
public readonly nodeName: string;
```

- *Type:* string

The node that the volume should be attached to.

---

##### `source`<sup>Required</sup> <a name="source" id="cdk8s-metaflow.k8s.VolumeAttachmentSpec.property.source"></a>

```typescript
public readonly source: VolumeAttachmentSource;
```

- *Type:* cdk8s-metaflow.k8s.VolumeAttachmentSource

Source represents the volume that should be attached.

---

### VolumeAttachmentSpecV1Alpha1 <a name="VolumeAttachmentSpecV1Alpha1" id="cdk8s-metaflow.k8s.VolumeAttachmentSpecV1Alpha1"></a>

VolumeAttachmentSpec is the specification of a VolumeAttachment request.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.VolumeAttachmentSpecV1Alpha1.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const volumeAttachmentSpecV1Alpha1: k8s.VolumeAttachmentSpecV1Alpha1 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentSpecV1Alpha1.property.attacher">attacher</a></code> | <code>string</code> | Attacher indicates the name of the volume driver that MUST handle this request. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentSpecV1Alpha1.property.nodeName">nodeName</a></code> | <code>string</code> | The node that the volume should be attached to. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentSpecV1Alpha1.property.source">source</a></code> | <code>cdk8s-metaflow.k8s.VolumeAttachmentSourceV1Alpha1</code> | Source represents the volume that should be attached. |

---

##### `attacher`<sup>Required</sup> <a name="attacher" id="cdk8s-metaflow.k8s.VolumeAttachmentSpecV1Alpha1.property.attacher"></a>

```typescript
public readonly attacher: string;
```

- *Type:* string

Attacher indicates the name of the volume driver that MUST handle this request.

This is the name returned by GetPluginName().

---

##### `nodeName`<sup>Required</sup> <a name="nodeName" id="cdk8s-metaflow.k8s.VolumeAttachmentSpecV1Alpha1.property.nodeName"></a>

```typescript
public readonly nodeName: string;
```

- *Type:* string

The node that the volume should be attached to.

---

##### `source`<sup>Required</sup> <a name="source" id="cdk8s-metaflow.k8s.VolumeAttachmentSpecV1Alpha1.property.source"></a>

```typescript
public readonly source: VolumeAttachmentSourceV1Alpha1;
```

- *Type:* cdk8s-metaflow.k8s.VolumeAttachmentSourceV1Alpha1

Source represents the volume that should be attached.

---

### VolumeAttachmentV1Alpha1Props <a name="VolumeAttachmentV1Alpha1Props" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1Props"></a>

VolumeAttachment captures the intent to attach or detach the specified volume to/from the specified node.

VolumeAttachment objects are non-namespaced.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1Props.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const volumeAttachmentV1Alpha1Props: k8s.VolumeAttachmentV1Alpha1Props = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1Props.property.spec">spec</a></code> | <code>cdk8s-metaflow.k8s.VolumeAttachmentSpecV1Alpha1</code> | Specification of the desired attach/detach volume behavior. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1Props.property.metadata">metadata</a></code> | <code>cdk8s-metaflow.k8s.ObjectMeta</code> | Standard object metadata. |

---

##### `spec`<sup>Required</sup> <a name="spec" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1Props.property.spec"></a>

```typescript
public readonly spec: VolumeAttachmentSpecV1Alpha1;
```

- *Type:* cdk8s-metaflow.k8s.VolumeAttachmentSpecV1Alpha1

Specification of the desired attach/detach volume behavior.

Populated by the Kubernetes system.

---

##### `metadata`<sup>Optional</sup> <a name="metadata" id="cdk8s-metaflow.k8s.VolumeAttachmentV1Alpha1Props.property.metadata"></a>

```typescript
public readonly metadata: ObjectMeta;
```

- *Type:* cdk8s-metaflow.k8s.ObjectMeta

Standard object metadata.

More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

---

### VolumeDevice <a name="VolumeDevice" id="cdk8s-metaflow.k8s.VolumeDevice"></a>

volumeDevice describes a mapping of a raw block device within a container.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.VolumeDevice.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const volumeDevice: k8s.VolumeDevice = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeDevice.property.devicePath">devicePath</a></code> | <code>string</code> | devicePath is the path inside of the container that the device will be mapped to. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeDevice.property.name">name</a></code> | <code>string</code> | name must match the name of a persistentVolumeClaim in the pod. |

---

##### `devicePath`<sup>Required</sup> <a name="devicePath" id="cdk8s-metaflow.k8s.VolumeDevice.property.devicePath"></a>

```typescript
public readonly devicePath: string;
```

- *Type:* string

devicePath is the path inside of the container that the device will be mapped to.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.VolumeDevice.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

name must match the name of a persistentVolumeClaim in the pod.

---

### VolumeMount <a name="VolumeMount" id="cdk8s-metaflow.k8s.VolumeMount"></a>

VolumeMount describes a mounting of a Volume within a container.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.VolumeMount.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const volumeMount: k8s.VolumeMount = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeMount.property.mountPath">mountPath</a></code> | <code>string</code> | Path within the container at which the volume should be mounted. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeMount.property.name">name</a></code> | <code>string</code> | This must match the Name of a Volume. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeMount.property.mountPropagation">mountPropagation</a></code> | <code>string</code> | mountPropagation determines how mounts are propagated from the host to container and the other way around. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeMount.property.readOnly">readOnly</a></code> | <code>boolean</code> | Mounted read-only if true, read-write otherwise (false or unspecified). |
| <code><a href="#cdk8s-metaflow.k8s.VolumeMount.property.subPath">subPath</a></code> | <code>string</code> | Path within the volume from which the container's volume should be mounted. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeMount.property.subPathExpr">subPathExpr</a></code> | <code>string</code> | Expanded path within the volume from which the container's volume should be mounted. |

---

##### `mountPath`<sup>Required</sup> <a name="mountPath" id="cdk8s-metaflow.k8s.VolumeMount.property.mountPath"></a>

```typescript
public readonly mountPath: string;
```

- *Type:* string

Path within the container at which the volume should be mounted.

Must not contain ':'.

---

##### `name`<sup>Required</sup> <a name="name" id="cdk8s-metaflow.k8s.VolumeMount.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

This must match the Name of a Volume.

---

##### `mountPropagation`<sup>Optional</sup> <a name="mountPropagation" id="cdk8s-metaflow.k8s.VolumeMount.property.mountPropagation"></a>

```typescript
public readonly mountPropagation: string;
```

- *Type:* string

mountPropagation determines how mounts are propagated from the host to container and the other way around.

When not set, MountPropagationNone is used. This field is beta in 1.10.

---

##### `readOnly`<sup>Optional</sup> <a name="readOnly" id="cdk8s-metaflow.k8s.VolumeMount.property.readOnly"></a>

```typescript
public readonly readOnly: boolean;
```

- *Type:* boolean
- *Default:* false.

Mounted read-only if true, read-write otherwise (false or unspecified).

Defaults to false.

---

##### `subPath`<sup>Optional</sup> <a name="subPath" id="cdk8s-metaflow.k8s.VolumeMount.property.subPath"></a>

```typescript
public readonly subPath: string;
```

- *Type:* string
- *Default:* volume's root).

Path within the volume from which the container's volume should be mounted.

Defaults to "" (volume's root).

---

##### `subPathExpr`<sup>Optional</sup> <a name="subPathExpr" id="cdk8s-metaflow.k8s.VolumeMount.property.subPathExpr"></a>

```typescript
public readonly subPathExpr: string;
```

- *Type:* string
- *Default:* volume's root). SubPathExpr and SubPath are mutually exclusive.

Expanded path within the volume from which the container's volume should be mounted.

Behaves similarly to SubPath but environment variable references $(VAR_NAME) are expanded using the container's environment. Defaults to "" (volume's root). SubPathExpr and SubPath are mutually exclusive.

---

### VolumeNodeAffinity <a name="VolumeNodeAffinity" id="cdk8s-metaflow.k8s.VolumeNodeAffinity"></a>

VolumeNodeAffinity defines constraints that limit what nodes this volume can be accessed from.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.VolumeNodeAffinity.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const volumeNodeAffinity: k8s.VolumeNodeAffinity = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeNodeAffinity.property.required">required</a></code> | <code>cdk8s-metaflow.k8s.NodeSelector</code> | Required specifies hard node constraints that must be met. |

---

##### `required`<sup>Optional</sup> <a name="required" id="cdk8s-metaflow.k8s.VolumeNodeAffinity.property.required"></a>

```typescript
public readonly required: NodeSelector;
```

- *Type:* cdk8s-metaflow.k8s.NodeSelector

Required specifies hard node constraints that must be met.

---

### VolumeNodeResources <a name="VolumeNodeResources" id="cdk8s-metaflow.k8s.VolumeNodeResources"></a>

VolumeNodeResources is a set of resource limits for scheduling of volumes.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.VolumeNodeResources.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const volumeNodeResources: k8s.VolumeNodeResources = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeNodeResources.property.count">count</a></code> | <code>number</code> | Maximum number of unique volumes managed by the CSI driver that can be used on a node. |

---

##### `count`<sup>Optional</sup> <a name="count" id="cdk8s-metaflow.k8s.VolumeNodeResources.property.count"></a>

```typescript
public readonly count: number;
```

- *Type:* number

Maximum number of unique volumes managed by the CSI driver that can be used on a node.

A volume that is both attached and mounted on a node is considered to be used once, not twice. The same rule applies for a unique volume that is shared among multiple pods on the same node. If this field is not specified, then the supported number of volumes on this node is unbounded.

---

### VolumeProjection <a name="VolumeProjection" id="cdk8s-metaflow.k8s.VolumeProjection"></a>

Projection that may be projected along with other supported volume types.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.VolumeProjection.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const volumeProjection: k8s.VolumeProjection = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VolumeProjection.property.configMap">configMap</a></code> | <code>cdk8s-metaflow.k8s.ConfigMapProjection</code> | information about the configMap data to project. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeProjection.property.downwardApi">downwardApi</a></code> | <code>cdk8s-metaflow.k8s.DownwardApiProjection</code> | information about the downwardAPI data to project. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeProjection.property.secret">secret</a></code> | <code>cdk8s-metaflow.k8s.SecretProjection</code> | information about the secret data to project. |
| <code><a href="#cdk8s-metaflow.k8s.VolumeProjection.property.serviceAccountToken">serviceAccountToken</a></code> | <code>cdk8s-metaflow.k8s.ServiceAccountTokenProjection</code> | information about the serviceAccountToken data to project. |

---

##### `configMap`<sup>Optional</sup> <a name="configMap" id="cdk8s-metaflow.k8s.VolumeProjection.property.configMap"></a>

```typescript
public readonly configMap: ConfigMapProjection;
```

- *Type:* cdk8s-metaflow.k8s.ConfigMapProjection

information about the configMap data to project.

---

##### `downwardApi`<sup>Optional</sup> <a name="downwardApi" id="cdk8s-metaflow.k8s.VolumeProjection.property.downwardApi"></a>

```typescript
public readonly downwardApi: DownwardApiProjection;
```

- *Type:* cdk8s-metaflow.k8s.DownwardApiProjection

information about the downwardAPI data to project.

---

##### `secret`<sup>Optional</sup> <a name="secret" id="cdk8s-metaflow.k8s.VolumeProjection.property.secret"></a>

```typescript
public readonly secret: SecretProjection;
```

- *Type:* cdk8s-metaflow.k8s.SecretProjection

information about the secret data to project.

---

##### `serviceAccountToken`<sup>Optional</sup> <a name="serviceAccountToken" id="cdk8s-metaflow.k8s.VolumeProjection.property.serviceAccountToken"></a>

```typescript
public readonly serviceAccountToken: ServiceAccountTokenProjection;
```

- *Type:* cdk8s-metaflow.k8s.ServiceAccountTokenProjection

information about the serviceAccountToken data to project.

---

### VsphereVirtualDiskVolumeSource <a name="VsphereVirtualDiskVolumeSource" id="cdk8s-metaflow.k8s.VsphereVirtualDiskVolumeSource"></a>

Represents a vSphere volume resource.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.VsphereVirtualDiskVolumeSource.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const vsphereVirtualDiskVolumeSource: k8s.VsphereVirtualDiskVolumeSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.VsphereVirtualDiskVolumeSource.property.volumePath">volumePath</a></code> | <code>string</code> | Path that identifies vSphere volume vmdk. |
| <code><a href="#cdk8s-metaflow.k8s.VsphereVirtualDiskVolumeSource.property.fsType">fsType</a></code> | <code>string</code> | Filesystem type to mount. |
| <code><a href="#cdk8s-metaflow.k8s.VsphereVirtualDiskVolumeSource.property.storagePolicyId">storagePolicyId</a></code> | <code>string</code> | Storage Policy Based Management (SPBM) profile ID associated with the StoragePolicyName. |
| <code><a href="#cdk8s-metaflow.k8s.VsphereVirtualDiskVolumeSource.property.storagePolicyName">storagePolicyName</a></code> | <code>string</code> | Storage Policy Based Management (SPBM) profile name. |

---

##### `volumePath`<sup>Required</sup> <a name="volumePath" id="cdk8s-metaflow.k8s.VsphereVirtualDiskVolumeSource.property.volumePath"></a>

```typescript
public readonly volumePath: string;
```

- *Type:* string

Path that identifies vSphere volume vmdk.

---

##### `fsType`<sup>Optional</sup> <a name="fsType" id="cdk8s-metaflow.k8s.VsphereVirtualDiskVolumeSource.property.fsType"></a>

```typescript
public readonly fsType: string;
```

- *Type:* string

Filesystem type to mount.

Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified.

---

##### `storagePolicyId`<sup>Optional</sup> <a name="storagePolicyId" id="cdk8s-metaflow.k8s.VsphereVirtualDiskVolumeSource.property.storagePolicyId"></a>

```typescript
public readonly storagePolicyId: string;
```

- *Type:* string

Storage Policy Based Management (SPBM) profile ID associated with the StoragePolicyName.

---

##### `storagePolicyName`<sup>Optional</sup> <a name="storagePolicyName" id="cdk8s-metaflow.k8s.VsphereVirtualDiskVolumeSource.property.storagePolicyName"></a>

```typescript
public readonly storagePolicyName: string;
```

- *Type:* string

Storage Policy Based Management (SPBM) profile name.

---

### WebhookClientConfig <a name="WebhookClientConfig" id="cdk8s-metaflow.k8s.WebhookClientConfig"></a>

WebhookClientConfig contains the information to make a TLS connection with the webhook.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.WebhookClientConfig.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const webhookClientConfig: k8s.WebhookClientConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.WebhookClientConfig.property.caBundle">caBundle</a></code> | <code>string</code> | `caBundle` is a PEM encoded CA bundle which will be used to validate the webhook's server certificate. |
| <code><a href="#cdk8s-metaflow.k8s.WebhookClientConfig.property.service">service</a></code> | <code>cdk8s-metaflow.k8s.ServiceReference</code> | `service` is a reference to the service for this webhook. Either `service` or `url` must be specified. |
| <code><a href="#cdk8s-metaflow.k8s.WebhookClientConfig.property.url">url</a></code> | <code>string</code> | `url` gives the location of the webhook, in standard URL form (`scheme://host:port/path`). |

---

##### `caBundle`<sup>Optional</sup> <a name="caBundle" id="cdk8s-metaflow.k8s.WebhookClientConfig.property.caBundle"></a>

```typescript
public readonly caBundle: string;
```

- *Type:* string

`caBundle` is a PEM encoded CA bundle which will be used to validate the webhook's server certificate.

If unspecified, system trust roots on the apiserver are used.

---

##### `service`<sup>Optional</sup> <a name="service" id="cdk8s-metaflow.k8s.WebhookClientConfig.property.service"></a>

```typescript
public readonly service: ServiceReference;
```

- *Type:* cdk8s-metaflow.k8s.ServiceReference

`service` is a reference to the service for this webhook. Either `service` or `url` must be specified.

If the webhook is running within the cluster, then you should use `service`.

---

##### `url`<sup>Optional</sup> <a name="url" id="cdk8s-metaflow.k8s.WebhookClientConfig.property.url"></a>

```typescript
public readonly url: string;
```

- *Type:* string

`url` gives the location of the webhook, in standard URL form (`scheme://host:port/path`).

Exactly one of `url` or `service` must be specified.

The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.

Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.

The scheme must be "https"; the URL must begin with "https://".

A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.

Attempting to use a user or basic auth e.g. "user:password@" is not allowed. Fragments ("#...") and query parameters ("?...") are not allowed, either.

---

### WebhookConversion <a name="WebhookConversion" id="cdk8s-metaflow.k8s.WebhookConversion"></a>

WebhookConversion describes how to call a conversion webhook.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.WebhookConversion.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const webhookConversion: k8s.WebhookConversion = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.WebhookConversion.property.conversionReviewVersions">conversionReviewVersions</a></code> | <code>string[]</code> | conversionReviewVersions is an ordered list of preferred `ConversionReview` versions the Webhook expects. |
| <code><a href="#cdk8s-metaflow.k8s.WebhookConversion.property.clientConfig">clientConfig</a></code> | <code>cdk8s-metaflow.k8s.WebhookClientConfig</code> | clientConfig is the instructions for how to call the webhook if strategy is `Webhook`. |

---

##### `conversionReviewVersions`<sup>Required</sup> <a name="conversionReviewVersions" id="cdk8s-metaflow.k8s.WebhookConversion.property.conversionReviewVersions"></a>

```typescript
public readonly conversionReviewVersions: string[];
```

- *Type:* string[]

conversionReviewVersions is an ordered list of preferred `ConversionReview` versions the Webhook expects.

The API server will use the first version in the list which it supports. If none of the versions specified in this list are supported by API server, conversion will fail for the custom resource. If a persisted Webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail.

---

##### `clientConfig`<sup>Optional</sup> <a name="clientConfig" id="cdk8s-metaflow.k8s.WebhookConversion.property.clientConfig"></a>

```typescript
public readonly clientConfig: WebhookClientConfig;
```

- *Type:* cdk8s-metaflow.k8s.WebhookClientConfig

clientConfig is the instructions for how to call the webhook if strategy is `Webhook`.

---

### WeightedPodAffinityTerm <a name="WeightedPodAffinityTerm" id="cdk8s-metaflow.k8s.WeightedPodAffinityTerm"></a>

The weights of all of the matched WeightedPodAffinityTerm fields are added per-node to find the most preferred node(s).

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.WeightedPodAffinityTerm.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const weightedPodAffinityTerm: k8s.WeightedPodAffinityTerm = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.WeightedPodAffinityTerm.property.podAffinityTerm">podAffinityTerm</a></code> | <code>cdk8s-metaflow.k8s.PodAffinityTerm</code> | Required. |
| <code><a href="#cdk8s-metaflow.k8s.WeightedPodAffinityTerm.property.weight">weight</a></code> | <code>number</code> | weight associated with matching the corresponding podAffinityTerm, in the range 1-100. |

---

##### `podAffinityTerm`<sup>Required</sup> <a name="podAffinityTerm" id="cdk8s-metaflow.k8s.WeightedPodAffinityTerm.property.podAffinityTerm"></a>

```typescript
public readonly podAffinityTerm: PodAffinityTerm;
```

- *Type:* cdk8s-metaflow.k8s.PodAffinityTerm

Required.

A pod affinity term, associated with the corresponding weight.

---

##### `weight`<sup>Required</sup> <a name="weight" id="cdk8s-metaflow.k8s.WeightedPodAffinityTerm.property.weight"></a>

```typescript
public readonly weight: number;
```

- *Type:* number

weight associated with matching the corresponding podAffinityTerm, in the range 1-100.

---

### WindowsSecurityContextOptions <a name="WindowsSecurityContextOptions" id="cdk8s-metaflow.k8s.WindowsSecurityContextOptions"></a>

WindowsSecurityContextOptions contain Windows-specific options and credentials.

#### Initializer <a name="Initializer" id="cdk8s-metaflow.k8s.WindowsSecurityContextOptions.Initializer"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

const windowsSecurityContextOptions: k8s.WindowsSecurityContextOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.WindowsSecurityContextOptions.property.gmsaCredentialSpec">gmsaCredentialSpec</a></code> | <code>string</code> | GMSACredentialSpec is where the GMSA admission webhook (https://github.com/kubernetes-sigs/windows-gmsa) inlines the contents of the GMSA credential spec named by the GMSACredentialSpecName field. |
| <code><a href="#cdk8s-metaflow.k8s.WindowsSecurityContextOptions.property.gmsaCredentialSpecName">gmsaCredentialSpecName</a></code> | <code>string</code> | GMSACredentialSpecName is the name of the GMSA credential spec to use. |
| <code><a href="#cdk8s-metaflow.k8s.WindowsSecurityContextOptions.property.hostProcess">hostProcess</a></code> | <code>boolean</code> | HostProcess determines if a container should be run as a 'Host Process' container. |
| <code><a href="#cdk8s-metaflow.k8s.WindowsSecurityContextOptions.property.runAsUserName">runAsUserName</a></code> | <code>string</code> | The UserName in Windows to run the entrypoint of the container process. |

---

##### `gmsaCredentialSpec`<sup>Optional</sup> <a name="gmsaCredentialSpec" id="cdk8s-metaflow.k8s.WindowsSecurityContextOptions.property.gmsaCredentialSpec"></a>

```typescript
public readonly gmsaCredentialSpec: string;
```

- *Type:* string

GMSACredentialSpec is where the GMSA admission webhook (https://github.com/kubernetes-sigs/windows-gmsa) inlines the contents of the GMSA credential spec named by the GMSACredentialSpecName field.

---

##### `gmsaCredentialSpecName`<sup>Optional</sup> <a name="gmsaCredentialSpecName" id="cdk8s-metaflow.k8s.WindowsSecurityContextOptions.property.gmsaCredentialSpecName"></a>

```typescript
public readonly gmsaCredentialSpecName: string;
```

- *Type:* string

GMSACredentialSpecName is the name of the GMSA credential spec to use.

---

##### `hostProcess`<sup>Optional</sup> <a name="hostProcess" id="cdk8s-metaflow.k8s.WindowsSecurityContextOptions.property.hostProcess"></a>

```typescript
public readonly hostProcess: boolean;
```

- *Type:* boolean

HostProcess determines if a container should be run as a 'Host Process' container.

This field is alpha-level and will only be honored by components that enable the WindowsHostProcessContainers feature flag. Setting this field without the feature flag will result in errors when validating the Pod. All of a Pod's containers must have the same effective HostProcess value (it is not allowed to have a mix of HostProcess containers and non-HostProcess containers).  In addition, if HostProcess is true then HostNetwork must also be set to true.

---

##### `runAsUserName`<sup>Optional</sup> <a name="runAsUserName" id="cdk8s-metaflow.k8s.WindowsSecurityContextOptions.property.runAsUserName"></a>

```typescript
public readonly runAsUserName: string;
```

- *Type:* string
- *Default:* the user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.

The UserName in Windows to run the entrypoint of the container process.

Defaults to the user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.

---

## Classes <a name="Classes" id="Classes"></a>

### IntOrString <a name="IntOrString" id="cdk8s-metaflow.k8s.IntOrString"></a>


#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IntOrString.fromNumber">fromNumber</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.IntOrString.fromString">fromString</a></code> | *No description.* |

---

##### `fromNumber` <a name="fromNumber" id="cdk8s-metaflow.k8s.IntOrString.fromNumber"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.IntOrString.fromNumber(value: number)
```

###### `value`<sup>Required</sup> <a name="value" id="cdk8s-metaflow.k8s.IntOrString.fromNumber.parameter.value"></a>

- *Type:* number

---

##### `fromString` <a name="fromString" id="cdk8s-metaflow.k8s.IntOrString.fromString"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.IntOrString.fromString(value: string)
```

###### `value`<sup>Required</sup> <a name="value" id="cdk8s-metaflow.k8s.IntOrString.fromString.parameter.value"></a>

- *Type:* string

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IntOrString.property.value">value</a></code> | <code>any</code> | *No description.* |

---

##### `value`<sup>Required</sup> <a name="value" id="cdk8s-metaflow.k8s.IntOrString.property.value"></a>

```typescript
public readonly value: any;
```

- *Type:* any

---


### Quantity <a name="Quantity" id="cdk8s-metaflow.k8s.Quantity"></a>


#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Quantity.fromNumber">fromNumber</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.k8s.Quantity.fromString">fromString</a></code> | *No description.* |

---

##### `fromNumber` <a name="fromNumber" id="cdk8s-metaflow.k8s.Quantity.fromNumber"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Quantity.fromNumber(value: number)
```

###### `value`<sup>Required</sup> <a name="value" id="cdk8s-metaflow.k8s.Quantity.fromNumber.parameter.value"></a>

- *Type:* number

---

##### `fromString` <a name="fromString" id="cdk8s-metaflow.k8s.Quantity.fromString"></a>

```typescript
import { k8s } from 'cdk8s-metaflow'

k8s.Quantity.fromString(value: string)
```

###### `value`<sup>Required</sup> <a name="value" id="cdk8s-metaflow.k8s.Quantity.fromString.parameter.value"></a>

- *Type:* string

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.Quantity.property.value">value</a></code> | <code>any</code> | *No description.* |

---

##### `value`<sup>Required</sup> <a name="value" id="cdk8s-metaflow.k8s.Quantity.property.value"></a>

```typescript
public readonly value: any;
```

- *Type:* any

---


## Protocols <a name="Protocols" id="Protocols"></a>

### IApiResource <a name="IApiResource" id="cdk8s-metaflow.IApiResource"></a>

- *Implemented By:* <a href="#cdk8s-metaflow.IApiResource">IApiResource</a>


#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk8s-metaflow.IApiResource.property.apiGroup">apiGroup</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.IApiResource.property.resourceName">resourceName</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk8s-metaflow.IApiResource.property.resourceType">resourceType</a></code> | <code>string</code> | *No description.* |

---

##### `apiGroup`<sup>Optional</sup> <a name="apiGroup" id="cdk8s-metaflow.IApiResource.property.apiGroup"></a>

```typescript
public readonly apiGroup: string;
```

- *Type:* string

---

##### `resourceName`<sup>Optional</sup> <a name="resourceName" id="cdk8s-metaflow.IApiResource.property.resourceName"></a>

```typescript
public readonly resourceName: string;
```

- *Type:* string

---

##### `resourceType`<sup>Optional</sup> <a name="resourceType" id="cdk8s-metaflow.IApiResource.property.resourceType"></a>

```typescript
public readonly resourceType: string;
```

- *Type:* string

---

## Enums <a name="Enums" id="Enums"></a>

### HttpIngressPathType <a name="HttpIngressPathType" id="cdk8s-metaflow.HttpIngressPathType"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.HttpIngressPathType.PREFIX">PREFIX</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.HttpIngressPathType.EXACT">EXACT</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.HttpIngressPathType.IMPLEMENTATION_SPECIFIC">IMPLEMENTATION_SPECIFIC</a></code> | *No description.* |

---

##### `PREFIX` <a name="PREFIX" id="cdk8s-metaflow.HttpIngressPathType.PREFIX"></a>

---


##### `EXACT` <a name="EXACT" id="cdk8s-metaflow.HttpIngressPathType.EXACT"></a>

---


##### `IMPLEMENTATION_SPECIFIC` <a name="IMPLEMENTATION_SPECIFIC" id="cdk8s-metaflow.HttpIngressPathType.IMPLEMENTATION_SPECIFIC"></a>

---


### ImagePullPolicy <a name="ImagePullPolicy" id="cdk8s-metaflow.ImagePullPolicy"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.ImagePullPolicy.ALWAYS">ALWAYS</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.ImagePullPolicy.IF_NOT_PRESENT">IF_NOT_PRESENT</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.ImagePullPolicy.NEVER">NEVER</a></code> | *No description.* |

---

##### `ALWAYS` <a name="ALWAYS" id="cdk8s-metaflow.ImagePullPolicy.ALWAYS"></a>

---


##### `IF_NOT_PRESENT` <a name="IF_NOT_PRESENT" id="cdk8s-metaflow.ImagePullPolicy.IF_NOT_PRESENT"></a>

---


##### `NEVER` <a name="NEVER" id="cdk8s-metaflow.ImagePullPolicy.NEVER"></a>

---


### IoK8SApimachineryPkgApisMetaV1DeleteOptionsKind <a name="IoK8SApimachineryPkgApisMetaV1DeleteOptionsKind" id="cdk8s-metaflow.k8s.IoK8SApimachineryPkgApisMetaV1DeleteOptionsKind"></a>

Kind is a string value representing the REST resource this object represents.

Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.k8s.IoK8SApimachineryPkgApisMetaV1DeleteOptionsKind.DELETE_OPTIONS">DELETE_OPTIONS</a></code> | DeleteOptions. |

---

##### `DELETE_OPTIONS` <a name="DELETE_OPTIONS" id="cdk8s-metaflow.k8s.IoK8SApimachineryPkgApisMetaV1DeleteOptionsKind.DELETE_OPTIONS"></a>

DeleteOptions.

---


### ServiceType <a name="ServiceType" id="cdk8s-metaflow.ServiceType"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk8s-metaflow.ServiceType.CLUSTER_IP">CLUSTER_IP</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.ServiceType.NODE_PORT">NODE_PORT</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.ServiceType.LOAD_BALANCER">LOAD_BALANCER</a></code> | *No description.* |
| <code><a href="#cdk8s-metaflow.ServiceType.EXTERNAL_NAME">EXTERNAL_NAME</a></code> | *No description.* |

---

##### `CLUSTER_IP` <a name="CLUSTER_IP" id="cdk8s-metaflow.ServiceType.CLUSTER_IP"></a>

---


##### `NODE_PORT` <a name="NODE_PORT" id="cdk8s-metaflow.ServiceType.NODE_PORT"></a>

---


##### `LOAD_BALANCER` <a name="LOAD_BALANCER" id="cdk8s-metaflow.ServiceType.LOAD_BALANCER"></a>

---


##### `EXTERNAL_NAME` <a name="EXTERNAL_NAME" id="cdk8s-metaflow.ServiceType.EXTERNAL_NAME"></a>

---

